""" Cisco_IOS_XR_ip_static_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-static package configuration.

This module contains definitions
for the following management objects\:
  router\-static\: This class represents router static
    configuration

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class RouterStatic(Entity):
    """
    This class represents router static configuration
    
    .. attribute:: default_vrf
    
    	Default VRF configuration
    	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf>`
    
    .. attribute:: maximum_routes
    
    	The maximum number of static routes that can be configured
    	**type**\:   :py:class:`MaximumRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.MaximumRoutes>`
    
    .. attribute:: vrfs
    
    	VRF static configuration container
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs>`
    
    

    """

    _prefix = 'ip-static-cfg'
    _revision = '2017-05-01'

    def __init__(self):
        super(RouterStatic, self).__init__()
        self._top_entity = None

        self.yang_name = "router-static"
        self.yang_parent_name = "Cisco-IOS-XR-ip-static-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"default-vrf" : ("default_vrf", RouterStatic.DefaultVrf), "maximum-routes" : ("maximum_routes", RouterStatic.MaximumRoutes), "vrfs" : ("vrfs", RouterStatic.Vrfs)}
        self._child_list_classes = {}

        self.default_vrf = RouterStatic.DefaultVrf()
        self.default_vrf.parent = self
        self._children_name_map["default_vrf"] = "default-vrf"
        self._children_yang_names.add("default-vrf")

        self.maximum_routes = RouterStatic.MaximumRoutes()
        self.maximum_routes.parent = self
        self._children_name_map["maximum_routes"] = "maximum-routes"
        self._children_yang_names.add("maximum-routes")

        self.vrfs = RouterStatic.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._children_yang_names.add("vrfs")
        self._segment_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static"


    class DefaultVrf(Entity):
        """
        Default VRF configuration
        
        .. attribute:: address_family
        
        	Address family configuration
        	**type**\:   :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily>`
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2017-05-01'

        def __init__(self):
            super(RouterStatic.DefaultVrf, self).__init__()

            self.yang_name = "default-vrf"
            self.yang_parent_name = "router-static"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"address-family" : ("address_family", RouterStatic.DefaultVrf.AddressFamily)}
            self._child_list_classes = {}

            self.address_family = RouterStatic.DefaultVrf.AddressFamily()
            self.address_family.parent = self
            self._children_name_map["address_family"] = "address-family"
            self._children_yang_names.add("address-family")
            self._segment_path = lambda: "default-vrf"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self._segment_path()


        class AddressFamily(Entity):
            """
            Address family configuration
            
            .. attribute:: vrfipv4
            
            	IPv4 static configuration
            	**type**\:   :py:class:`Vrfipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4>`
            
            .. attribute:: vrfipv6
            
            	IPv6 static configuration
            	**type**\:   :py:class:`Vrfipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6>`
            
            

            """

            _prefix = 'ip-static-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(RouterStatic.DefaultVrf.AddressFamily, self).__init__()

                self.yang_name = "address-family"
                self.yang_parent_name = "default-vrf"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"vrfipv4" : ("vrfipv4", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4), "vrfipv6" : ("vrfipv6", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6)}
                self._child_list_classes = {}

                self.vrfipv4 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4()
                self.vrfipv4.parent = self
                self._children_name_map["vrfipv4"] = "vrfipv4"
                self._children_yang_names.add("vrfipv4")

                self.vrfipv6 = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6()
                self.vrfipv6.parent = self
                self._children_name_map["vrfipv6"] = "vrfipv6"
                self._children_yang_names.add("vrfipv6")
                self._segment_path = lambda: "address-family"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/%s" % self._segment_path()


            class Vrfipv4(Entity):
                """
                IPv4 static configuration
                
                .. attribute:: vrf_multicast
                
                	Multicast static configuration
                	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast>`
                
                .. attribute:: vrf_unicast
                
                	Unicast static configuration
                	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4, self).__init__()

                    self.yang_name = "vrfipv4"
                    self.yang_parent_name = "address-family"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"vrf-multicast" : ("vrf_multicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast), "vrf-unicast" : ("vrf_unicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast)}
                    self._child_list_classes = {}

                    self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast()
                    self.vrf_multicast.parent = self
                    self._children_name_map["vrf_multicast"] = "vrf-multicast"
                    self._children_yang_names.add("vrf-multicast")

                    self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast()
                    self.vrf_unicast.parent = self
                    self._children_name_map["vrf_unicast"] = "vrf-unicast"
                    self._children_yang_names.add("vrf-unicast")
                    self._segment_path = lambda: "vrfipv4"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/%s" % self._segment_path()


                class VrfMulticast(Entity):
                    """
                    Multicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast, self).__init__()

                        self.yang_name = "vrf-multicast"
                        self.yang_parent_name = "vrfipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology), "topologies" : ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes)}
                        self._child_list_classes = {}

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")
                        self._segment_path = lambda: "vrf-multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/%s" % self._segment_path()


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies)}
                            self._child_list_classes = {}

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self._segment_path()


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/default-topology/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"topology" : ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology)}

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/topologies/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix)}

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-multicast/vrf-prefixes/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                    self._child_list_classes = {}

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")
                                    self._segment_path = lambda: "vrf-route"


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                    self._child_list_classes = {}

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")
                                    self._segment_path = lambda: "vrf-seg-route"


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                class VrfUnicast(Entity):
                    """
                    Unicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast, self).__init__()

                        self.yang_name = "vrf-unicast"
                        self.yang_parent_name = "vrfipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology), "topologies" : ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes)}
                        self._child_list_classes = {}

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")
                        self._segment_path = lambda: "vrf-unicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/%s" % self._segment_path()


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies)}
                            self._child_list_classes = {}

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self._segment_path()


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/default-topology/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"topology" : ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology)}

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/topologies/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix)}

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv4/vrf-unicast/vrf-prefixes/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                    self._child_list_classes = {}

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")
                                    self._segment_path = lambda: "vrf-route"


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                    self._child_list_classes = {}

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")
                                    self._segment_path = lambda: "vrf-seg-route"


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


            class Vrfipv6(Entity):
                """
                IPv6 static configuration
                
                .. attribute:: vrf_multicast
                
                	Multicast static configuration
                	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast>`
                
                .. attribute:: vrf_unicast
                
                	Unicast static configuration
                	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6, self).__init__()

                    self.yang_name = "vrfipv6"
                    self.yang_parent_name = "address-family"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"vrf-multicast" : ("vrf_multicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast), "vrf-unicast" : ("vrf_unicast", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast)}
                    self._child_list_classes = {}

                    self.vrf_multicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast()
                    self.vrf_multicast.parent = self
                    self._children_name_map["vrf_multicast"] = "vrf-multicast"
                    self._children_yang_names.add("vrf-multicast")

                    self.vrf_unicast = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast()
                    self.vrf_unicast.parent = self
                    self._children_name_map["vrf_unicast"] = "vrf-unicast"
                    self._children_yang_names.add("vrf-unicast")
                    self._segment_path = lambda: "vrfipv6"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/%s" % self._segment_path()


                class VrfMulticast(Entity):
                    """
                    Multicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast, self).__init__()

                        self.yang_name = "vrf-multicast"
                        self.yang_parent_name = "vrfipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology), "topologies" : ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes)}
                        self._child_list_classes = {}

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")
                        self._segment_path = lambda: "vrf-multicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/%s" % self._segment_path()


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies)}
                            self._child_list_classes = {}

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self._segment_path()


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/default-topology/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"topology" : ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology)}

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/topologies/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-multicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix)}

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-multicast/vrf-prefixes/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                    self._child_list_classes = {}

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")
                                    self._segment_path = lambda: "vrf-route"


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                    self._child_list_classes = {}

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")
                                    self._segment_path = lambda: "vrf-seg-route"


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                class VrfUnicast(Entity):
                    """
                    Unicast static configuration
                    
                    .. attribute:: default_topology
                    
                    	Default topology configuration
                    	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology>`
                    
                    .. attribute:: topologies
                    
                    	Topology static configuration container
                    	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies>`
                    
                    .. attribute:: vrf_prefixes
                    
                    	The set of all Static Topologies for this AFI
                    	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast, self).__init__()

                        self.yang_name = "vrf-unicast"
                        self.yang_parent_name = "vrfipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology), "topologies" : ("topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes)}
                        self._child_list_classes = {}

                        self.default_topology = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                        self.default_topology.parent = self
                        self._children_name_map["default_topology"] = "default-topology"
                        self._children_yang_names.add("default-topology")

                        self.topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                        self.topologies.parent = self
                        self._children_name_map["topologies"] = "topologies"
                        self._children_yang_names.add("topologies")

                        self.vrf_prefixes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                        self.vrf_prefixes.parent = self
                        self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                        self._children_yang_names.add("vrf-prefixes")
                        self._segment_path = lambda: "vrf-unicast"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/%s" % self._segment_path()


                    class DefaultTopology(Entity):
                        """
                        Default topology configuration
                        
                        .. attribute:: vrf_prefix_topologies
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, self).__init__()

                            self.yang_name = "default-topology"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies)}
                            self._child_list_classes = {}

                            self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                            self.vrf_prefix_topologies.parent = self
                            self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                            self._children_yang_names.add("vrf-prefix-topologies")
                            self._segment_path = lambda: "default-topology"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self._segment_path()


                        class VrfPrefixTopologies(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix_topology
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                self.yang_name = "vrf-prefix-topologies"
                                self.yang_parent_name = "default-topology"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                self.vrf_prefix_topology = YList(self)
                                self._segment_path = lambda: "vrf-prefix-topologies"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/default-topology/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                            class VrfPrefixTopology(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                    self.yang_name = "vrf-prefix-topology"
                                    self.yang_parent_name = "vrf-prefix-topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/default-topology/vrf-prefix-topologies/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix-topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class Topologies(Entity):
                        """
                        Topology static configuration container
                        
                        .. attribute:: topology
                        
                        	Topology static configuration
                        	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__init__()

                            self.yang_name = "topologies"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"topology" : ("topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology)}

                            self.topology = YList(self)
                            self._segment_path = lambda: "topologies"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, [], name, value)


                        class Topology(Entity):
                            """
                            Topology static configuration
                            
                            .. attribute:: topology_name  <key>
                            
                            	Topology name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__init__()

                                self.yang_name = "topology"
                                self.yang_parent_name = "topologies"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.topology_name = YLeaf(YType.str, "topology-name")

                                self.vrf_prefix_topologies = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/topologies/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class VrfPrefixes(Entity):
                        """
                        The set of all Static Topologies for this AFI.
                        
                        .. attribute:: vrf_prefix
                        
                        	A static route
                        	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__init__()

                            self.yang_name = "vrf-prefixes"
                            self.yang_parent_name = "vrf-unicast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix)}

                            self.vrf_prefix = YList(self)
                            self._segment_path = lambda: "vrf-prefixes"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, [], name, value)


                        class VrfPrefix(Entity):
                            """
                            A static route
                            
                            .. attribute:: prefix  <key>
                            
                            	Destination prefix
                            	**type**\: one of the below types:
                            
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            
                            ----
                            .. attribute:: prefix_length  <key>
                            
                            	Destination prefix length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            .. attribute:: vrf_recurse_routes
                            
                            	A recursive next VRF static route
                            	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                            
                            .. attribute:: vrf_route
                            
                            	A connected or recursive  static route
                            	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                            
                            .. attribute:: vrf_seg_route
                            
                            	A static segment route
                            	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                self.yang_name = "vrf-prefix"
                                self.yang_parent_name = "vrf-prefixes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                self._child_list_classes = {}

                                self.prefix = YLeaf(YType.str, "prefix")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.vrf_recurse_routes = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                self.vrf_recurse_routes.parent = self
                                self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                self._children_yang_names.add("vrf-recurse-routes")

                                self.vrf_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                self.vrf_route.parent = self
                                self._children_name_map["vrf_route"] = "vrf-route"
                                self._children_yang_names.add("vrf-route")

                                self.vrf_seg_route = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                self.vrf_seg_route.parent = self
                                self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                self._children_yang_names.add("vrf-seg-route")
                                self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/default-vrf/address-family/vrfipv6/vrf-unicast/vrf-prefixes/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                            class VrfRecurseRoutes(Entity):
                                """
                                A recursive next VRF static route
                                
                                .. attribute:: vrf_recurse_route
                                
                                	A recursive next vrf static route
                                	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                    self.yang_name = "vrf-recurse-routes"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                    self.vrf_recurse_route = YList(self)
                                    self._segment_path = lambda: "vrf-recurse-routes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                class VrfRecurseRoute(Entity):
                                    """
                                    A recursive next vrf static route
                                    
                                    .. attribute:: vrf_name  <key>
                                    
                                    	Fallback or recusive VRF name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: vrf_recursive_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                        self.yang_name = "vrf-recurse-route"
                                        self.yang_parent_name = "vrf-recurse-routes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_name = YLeaf(YType.str, "vrf-name")

                                        self.vrf_recursive_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                        self.vrf_recursive_next_hop_table.parent = self
                                        self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                        self._children_yang_names.add("vrf-recursive-next-hop-table")
                                        self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                    class VrfRecursiveNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                            self.yang_name = "vrf-recursive-next-hop-table"
                                            self.yang_parent_name = "vrf-recurse-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfRoute(Entity):
                                """
                                A connected or recursive  static route
                                
                                .. attribute:: vrf_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                    self.yang_name = "vrf-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                    self._child_list_classes = {}

                                    self.vrf_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                    self.vrf_next_hop_table.parent = self
                                    self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                    self._children_yang_names.add("vrf-next-hop-table")
                                    self._segment_path = lambda: "vrf-route"


                                class VrfNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                        self.yang_name = "vrf-next-hop-table"
                                        self.yang_parent_name = "vrf-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "vrf-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "vrf-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                            class VrfSegRoute(Entity):
                                """
                                A static segment route
                                
                                .. attribute:: segment_route_next_hop_table
                                
                                	The set of nexthop information configured for this route
                                	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                    self.yang_name = "vrf-seg-route"
                                    self.yang_parent_name = "vrf-prefix"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                    self._child_list_classes = {}

                                    self.segment_route_next_hop_table = RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                    self.segment_route_next_hop_table.parent = self
                                    self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                    self._children_yang_names.add("segment-route-next-hop-table")
                                    self._segment_path = lambda: "vrf-seg-route"


                                class SegmentRouteNextHopTable(Entity):
                                    """
                                    The set of nexthop information configured for
                                    this route
                                    
                                    .. attribute:: vrf_next_hop_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                    
                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                    
                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                    
                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                        self.yang_name = "segment-route-next-hop-table"
                                        self.yang_parent_name = "vrf-seg-route"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                        self.vrf_next_hop_interface_name = YList(self)
                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address = YList(self)
                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                        self._segment_path = lambda: "segment-route-next-hop-table"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                    class VrfNextHopExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: interface_name  <key>
                                        
                                        	Forwarding interface
                                        	**type**\:  str
                                        
                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddress(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                        """
                                        A forwarding interface or Segement Routing mpls
                                        path name and/or the address of a nexthop router
                                        for this route (one of these must be specified)
                                        
                                        .. attribute:: next_hop_address  <key>
                                        
                                        	Next hop address
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: explicit_path_name  <key>
                                        
                                        	Segment Routing mpls path name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: bfd_fast_detect
                                        
                                        	If set, bfd is enabled
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: description
                                        
                                        	Short Description of Static Route
                                        	**type**\:  str
                                        
                                        .. attribute:: detect_multiplier
                                        
                                        	BFD Detect Multiplier
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: index
                                        
                                        	Nexthop Identifier for OC Yang model
                                        	**type**\:  str
                                        
                                        .. attribute:: load_metric
                                        
                                        	UCMP load metric
                                        	**type**\:  int
                                        
                                        	**range:** 1..16777214
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: metric
                                        
                                        	Distance metric for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..254
                                        
                                        	**default value**\: 1
                                        
                                        .. attribute:: minimum_interval
                                        
                                        	BFD Hello interval in milliseconds
                                        	**type**\:  int
                                        
                                        	**range:** 3..30000
                                        
                                        	**units**\: millisecond
                                        
                                        	**default value**\: 100
                                        
                                        .. attribute:: object_name
                                        
                                        	Name of the object to track
                                        	**type**\:  str
                                        
                                        	**length:** 1..32
                                        
                                        .. attribute:: permanent
                                        
                                        	If set, path is permanent
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: tag
                                        
                                        	Tag for this path
                                        	**type**\:  int
                                        
                                        	**range:** 1..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	Tunnel ID for this path
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        	**default value**\: 0
                                        
                                        .. attribute:: vrf_lable
                                        
                                        	VRF LABEL
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**default value**\: 0
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                            self.yang_parent_name = "segment-route-next-hop-table"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                            self.description = YLeaf(YType.str, "description")

                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                            self.index = YLeaf(YType.str, "index")

                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                            self.metric = YLeaf(YType.uint32, "metric")

                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                            self.object_name = YLeaf(YType.str, "object-name")

                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                            self.tag = YLeaf(YType.uint32, "tag")

                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.DefaultVrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


    class MaximumRoutes(Entity):
        """
        The maximum number of static routes that can be
        configured.
        
        .. attribute:: ipv4_routes
        
        	The maximum number of static routes that can be configured for IPv4 AFI
        	**type**\:  int
        
        	**range:** 1..140000
        
        	**default value**\: 4000
        
        .. attribute:: ipv6_routes
        
        	The maximum number of static routes that can be configured for IPv6 AFI
        	**type**\:  int
        
        	**range:** 1..140000
        
        	**default value**\: 4000
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2017-05-01'

        def __init__(self):
            super(RouterStatic.MaximumRoutes, self).__init__()

            self.yang_name = "maximum-routes"
            self.yang_parent_name = "router-static"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.ipv4_routes = YLeaf(YType.uint32, "ipv4-routes")

            self.ipv6_routes = YLeaf(YType.uint32, "ipv6-routes")
            self._segment_path = lambda: "maximum-routes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(RouterStatic.MaximumRoutes, ['ipv4_routes', 'ipv6_routes'], name, value)


    class Vrfs(Entity):
        """
        VRF static configuration container
        
        .. attribute:: vrf
        
        	VRF static configuration
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-static-cfg'
        _revision = '2017-05-01'

        def __init__(self):
            super(RouterStatic.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "router-static"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"vrf" : ("vrf", RouterStatic.Vrfs.Vrf)}

            self.vrf = YList(self)
            self._segment_path = lambda: "vrfs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(RouterStatic.Vrfs, [], name, value)


        class Vrf(Entity):
            """
            VRF static configuration
            
            .. attribute:: vrf_name  <key>
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: address_family
            
            	Address family configuration
            	**type**\:   :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily>`
            
            

            """

            _prefix = 'ip-static-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(RouterStatic.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"address-family" : ("address_family", RouterStatic.Vrfs.Vrf.AddressFamily)}
                self._child_list_classes = {}

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.address_family = RouterStatic.Vrfs.Vrf.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"
                self._children_yang_names.add("address-family")
                self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-static-cfg:router-static/vrfs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(RouterStatic.Vrfs.Vrf, ['vrf_name'], name, value)


            class AddressFamily(Entity):
                """
                Address family configuration
                
                .. attribute:: vrfipv4
                
                	IPv4 static configuration
                	**type**\:   :py:class:`Vrfipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4>`
                
                .. attribute:: vrfipv6
                
                	IPv6 static configuration
                	**type**\:   :py:class:`Vrfipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6>`
                
                

                """

                _prefix = 'ip-static-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(RouterStatic.Vrfs.Vrf.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"vrfipv4" : ("vrfipv4", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4), "vrfipv6" : ("vrfipv6", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6)}
                    self._child_list_classes = {}

                    self.vrfipv4 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4()
                    self.vrfipv4.parent = self
                    self._children_name_map["vrfipv4"] = "vrfipv4"
                    self._children_yang_names.add("vrfipv4")

                    self.vrfipv6 = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6()
                    self.vrfipv6.parent = self
                    self._children_name_map["vrfipv6"] = "vrfipv6"
                    self._children_yang_names.add("vrfipv6")
                    self._segment_path = lambda: "address-family"


                class Vrfipv4(Entity):
                    """
                    IPv4 static configuration
                    
                    .. attribute:: vrf_multicast
                    
                    	Multicast static configuration
                    	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast>`
                    
                    .. attribute:: vrf_unicast
                    
                    	Unicast static configuration
                    	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4, self).__init__()

                        self.yang_name = "vrfipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"vrf-multicast" : ("vrf_multicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast), "vrf-unicast" : ("vrf_unicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast)}
                        self._child_list_classes = {}

                        self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast()
                        self.vrf_multicast.parent = self
                        self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        self._children_yang_names.add("vrf-multicast")

                        self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast()
                        self.vrf_unicast.parent = self
                        self._children_name_map["vrf_unicast"] = "vrf-unicast"
                        self._children_yang_names.add("vrf-unicast")
                        self._segment_path = lambda: "vrfipv4"


                    class VrfMulticast(Entity):
                        """
                        Multicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast, self).__init__()

                            self.yang_name = "vrf-multicast"
                            self.yang_parent_name = "vrfipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology), "topologies" : ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes)}
                            self._child_list_classes = {}

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")
                            self._segment_path = lambda: "vrf-multicast"


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "default-topology"


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"topology" : ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology)}

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies)}
                                    self._child_list_classes = {}

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")
                                    self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                            self._child_list_classes = {}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                    self._child_list_classes = {}

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")
                                                self._segment_path = lambda: "vrf-route"


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                                self._child_list_classes = {}

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")
                                                self._segment_path = lambda: "vrf-seg-route"


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix)}

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class VrfUnicast(Entity):
                        """
                        Unicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast, self).__init__()

                            self.yang_name = "vrf-unicast"
                            self.yang_parent_name = "vrfipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology), "topologies" : ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes)}
                            self._child_list_classes = {}

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")
                            self._segment_path = lambda: "vrf-unicast"


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "default-topology"


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"topology" : ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology)}

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies)}
                                    self._child_list_classes = {}

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")
                                    self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                            self._child_list_classes = {}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                    self._child_list_classes = {}

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")
                                                self._segment_path = lambda: "vrf-route"


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                                self._child_list_classes = {}

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")
                                                self._segment_path = lambda: "vrf-seg-route"


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix)}

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv4.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                class Vrfipv6(Entity):
                    """
                    IPv6 static configuration
                    
                    .. attribute:: vrf_multicast
                    
                    	Multicast static configuration
                    	**type**\:   :py:class:`VrfMulticast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast>`
                    
                    .. attribute:: vrf_unicast
                    
                    	Unicast static configuration
                    	**type**\:   :py:class:`VrfUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast>`
                    
                    

                    """

                    _prefix = 'ip-static-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6, self).__init__()

                        self.yang_name = "vrfipv6"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"vrf-multicast" : ("vrf_multicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast), "vrf-unicast" : ("vrf_unicast", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast)}
                        self._child_list_classes = {}

                        self.vrf_multicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast()
                        self.vrf_multicast.parent = self
                        self._children_name_map["vrf_multicast"] = "vrf-multicast"
                        self._children_yang_names.add("vrf-multicast")

                        self.vrf_unicast = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast()
                        self.vrf_unicast.parent = self
                        self._children_name_map["vrf_unicast"] = "vrf-unicast"
                        self._children_yang_names.add("vrf-unicast")
                        self._segment_path = lambda: "vrfipv6"


                    class VrfMulticast(Entity):
                        """
                        Multicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast, self).__init__()

                            self.yang_name = "vrf-multicast"
                            self.yang_parent_name = "vrfipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology), "topologies" : ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes)}
                            self._child_list_classes = {}

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")
                            self._segment_path = lambda: "vrf-multicast"


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "default-topology"


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"topology" : ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology)}

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies)}
                                    self._child_list_classes = {}

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")
                                    self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                            self._child_list_classes = {}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                    self._child_list_classes = {}

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")
                                                self._segment_path = lambda: "vrf-route"


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                                self._child_list_classes = {}

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")
                                                self._segment_path = lambda: "vrf-seg-route"


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-multicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix)}

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfMulticast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                    class VrfUnicast(Entity):
                        """
                        Unicast static configuration
                        
                        .. attribute:: default_topology
                        
                        	Default topology configuration
                        	**type**\:   :py:class:`DefaultTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology>`
                        
                        .. attribute:: topologies
                        
                        	Topology static configuration container
                        	**type**\:   :py:class:`Topologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies>`
                        
                        .. attribute:: vrf_prefixes
                        
                        	The set of all Static Topologies for this AFI
                        	**type**\:   :py:class:`VrfPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes>`
                        
                        

                        """

                        _prefix = 'ip-static-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast, self).__init__()

                            self.yang_name = "vrf-unicast"
                            self.yang_parent_name = "vrfipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"default-topology" : ("default_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology), "topologies" : ("topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies), "vrf-prefixes" : ("vrf_prefixes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes)}
                            self._child_list_classes = {}

                            self.default_topology = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology()
                            self.default_topology.parent = self
                            self._children_name_map["default_topology"] = "default-topology"
                            self._children_yang_names.add("default-topology")

                            self.topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies()
                            self.topologies.parent = self
                            self._children_name_map["topologies"] = "topologies"
                            self._children_yang_names.add("topologies")

                            self.vrf_prefixes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes()
                            self.vrf_prefixes.parent = self
                            self._children_name_map["vrf_prefixes"] = "vrf-prefixes"
                            self._children_yang_names.add("vrf-prefixes")
                            self._segment_path = lambda: "vrf-unicast"


                        class DefaultTopology(Entity):
                            """
                            Default topology configuration
                            
                            .. attribute:: vrf_prefix_topologies
                            
                            	The set of all Static Topologies for this AFI
                            	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology, self).__init__()

                                self.yang_name = "default-topology"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies)}
                                self._child_list_classes = {}

                                self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies()
                                self.vrf_prefix_topologies.parent = self
                                self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                self._children_yang_names.add("vrf-prefix-topologies")
                                self._segment_path = lambda: "default-topology"


                            class VrfPrefixTopologies(Entity):
                                """
                                The set of all Static Topologies for this AFI.
                                
                                .. attribute:: vrf_prefix_topology
                                
                                	A static route
                                	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, self).__init__()

                                    self.yang_name = "vrf-prefix-topologies"
                                    self.yang_parent_name = "default-topology"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology)}

                                    self.vrf_prefix_topology = YList(self)
                                    self._segment_path = lambda: "vrf-prefix-topologies"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies, [], name, value)


                                class VrfPrefixTopology(Entity):
                                    """
                                    A static route
                                    
                                    .. attribute:: prefix  <key>
                                    
                                    	Destination prefix
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    .. attribute:: prefix_length  <key>
                                    
                                    	Destination prefix length
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    .. attribute:: vrf_recurse_routes
                                    
                                    	A recursive next VRF static route
                                    	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                    
                                    .. attribute:: vrf_route
                                    
                                    	A connected or recursive  static route
                                    	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                    
                                    .. attribute:: vrf_seg_route
                                    
                                    	A static segment route
                                    	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                        self.yang_name = "vrf-prefix-topology"
                                        self.yang_parent_name = "vrf-prefix-topologies"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                        self._child_list_classes = {}

                                        self.prefix = YLeaf(YType.str, "prefix")

                                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                        self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                        self.vrf_recurse_routes.parent = self
                                        self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                        self._children_yang_names.add("vrf-recurse-routes")

                                        self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                        self.vrf_route.parent = self
                                        self._children_name_map["vrf_route"] = "vrf-route"
                                        self._children_yang_names.add("vrf-route")

                                        self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                        self.vrf_seg_route.parent = self
                                        self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                        self._children_yang_names.add("vrf-seg-route")
                                        self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                    class VrfRecurseRoutes(Entity):
                                        """
                                        A recursive next VRF static route
                                        
                                        .. attribute:: vrf_recurse_route
                                        
                                        	A recursive next vrf static route
                                        	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                            self.yang_name = "vrf-recurse-routes"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                            self.vrf_recurse_route = YList(self)
                                            self._segment_path = lambda: "vrf-recurse-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                        class VrfRecurseRoute(Entity):
                                            """
                                            A recursive next vrf static route
                                            
                                            .. attribute:: vrf_name  <key>
                                            
                                            	Fallback or recusive VRF name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: vrf_recursive_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                self.yang_name = "vrf-recurse-route"
                                                self.yang_parent_name = "vrf-recurse-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                self.vrf_recursive_next_hop_table.parent = self
                                                self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                            class VrfRecursiveNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-recursive-next-hop-table"
                                                    self.yang_parent_name = "vrf-recurse-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfRoute(Entity):
                                        """
                                        A connected or recursive  static route
                                        
                                        .. attribute:: vrf_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                            self.yang_name = "vrf-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                            self.vrf_next_hop_table.parent = self
                                            self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                            self._children_yang_names.add("vrf-next-hop-table")
                                            self._segment_path = lambda: "vrf-route"


                                        class VrfNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                self.yang_name = "vrf-next-hop-table"
                                                self.yang_parent_name = "vrf-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                    class VrfSegRoute(Entity):
                                        """
                                        A static segment route
                                        
                                        .. attribute:: segment_route_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                            self.yang_name = "vrf-seg-route"
                                            self.yang_parent_name = "vrf-prefix-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                            self._child_list_classes = {}

                                            self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                            self.segment_route_next_hop_table.parent = self
                                            self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                            self._children_yang_names.add("segment-route-next-hop-table")
                                            self._segment_path = lambda: "vrf-seg-route"


                                        class SegmentRouteNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                self.yang_name = "segment-route-next-hop-table"
                                                self.yang_parent_name = "vrf-seg-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "segment-route-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "segment-route-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.DefaultTopology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class Topologies(Entity):
                            """
                            Topology static configuration container
                            
                            .. attribute:: topology
                            
                            	Topology static configuration
                            	**type**\: list of    :py:class:`Topology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, self).__init__()

                                self.yang_name = "topologies"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"topology" : ("topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology)}

                                self.topology = YList(self)
                                self._segment_path = lambda: "topologies"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies, [], name, value)


                            class Topology(Entity):
                                """
                                Topology static configuration
                                
                                .. attribute:: topology_name  <key>
                                
                                	Topology name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: vrf_prefix_topologies
                                
                                	The set of all Static Topologies for this AFI
                                	**type**\:   :py:class:`VrfPrefixTopologies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, self).__init__()

                                    self.yang_name = "topology"
                                    self.yang_parent_name = "topologies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-prefix-topologies" : ("vrf_prefix_topologies", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies)}
                                    self._child_list_classes = {}

                                    self.topology_name = YLeaf(YType.str, "topology-name")

                                    self.vrf_prefix_topologies = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies()
                                    self.vrf_prefix_topologies.parent = self
                                    self._children_name_map["vrf_prefix_topologies"] = "vrf-prefix-topologies"
                                    self._children_yang_names.add("vrf-prefix-topologies")
                                    self._segment_path = lambda: "topology" + "[topology-name='" + self.topology_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology, ['topology_name'], name, value)


                                class VrfPrefixTopologies(Entity):
                                    """
                                    The set of all Static Topologies for this AFI.
                                    
                                    .. attribute:: vrf_prefix_topology
                                    
                                    	A static route
                                    	**type**\: list of    :py:class:`VrfPrefixTopology <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, self).__init__()

                                        self.yang_name = "vrf-prefix-topologies"
                                        self.yang_parent_name = "topology"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-prefix-topology" : ("vrf_prefix_topology", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology)}

                                        self.vrf_prefix_topology = YList(self)
                                        self._segment_path = lambda: "vrf-prefix-topologies"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies, [], name, value)


                                    class VrfPrefixTopology(Entity):
                                        """
                                        A static route
                                        
                                        .. attribute:: prefix  <key>
                                        
                                        	Destination prefix
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: prefix_length  <key>
                                        
                                        	Destination prefix length
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: vrf_recurse_routes
                                        
                                        	A recursive next VRF static route
                                        	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes>`
                                        
                                        .. attribute:: vrf_route
                                        
                                        	A connected or recursive  static route
                                        	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute>`
                                        
                                        .. attribute:: vrf_seg_route
                                        
                                        	A static segment route
                                        	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, self).__init__()

                                            self.yang_name = "vrf-prefix-topology"
                                            self.yang_parent_name = "vrf-prefix-topologies"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute)}
                                            self._child_list_classes = {}

                                            self.prefix = YLeaf(YType.str, "prefix")

                                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                            self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes()
                                            self.vrf_recurse_routes.parent = self
                                            self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                            self._children_yang_names.add("vrf-recurse-routes")

                                            self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute()
                                            self.vrf_route.parent = self
                                            self._children_name_map["vrf_route"] = "vrf-route"
                                            self._children_yang_names.add("vrf-route")

                                            self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute()
                                            self.vrf_seg_route.parent = self
                                            self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                            self._children_yang_names.add("vrf-seg-route")
                                            self._segment_path = lambda: "vrf-prefix-topology" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology, ['prefix', 'prefix_length'], name, value)


                                        class VrfRecurseRoutes(Entity):
                                            """
                                            A recursive next VRF static route
                                            
                                            .. attribute:: vrf_recurse_route
                                            
                                            	A recursive next vrf static route
                                            	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, self).__init__()

                                                self.yang_name = "vrf-recurse-routes"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute)}

                                                self.vrf_recurse_route = YList(self)
                                                self._segment_path = lambda: "vrf-recurse-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes, [], name, value)


                                            class VrfRecurseRoute(Entity):
                                                """
                                                A recursive next vrf static route
                                                
                                                .. attribute:: vrf_name  <key>
                                                
                                                	Fallback or recusive VRF name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: vrf_recursive_next_hop_table
                                                
                                                	The set of nexthop information configured for this route
                                                	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                                    self.yang_name = "vrf-recurse-route"
                                                    self.yang_parent_name = "vrf-recurse-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                                    self._child_list_classes = {}

                                                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                                                    self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                                    self.vrf_recursive_next_hop_table.parent = self
                                                    self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                                    self._children_yang_names.add("vrf-recursive-next-hop-table")
                                                    self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                                class VrfRecursiveNextHopTable(Entity):
                                                    """
                                                    The set of nexthop information configured for
                                                    this route
                                                    
                                                    .. attribute:: vrf_next_hop_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                                    
                                                    .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                                    
                                                    .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                    
                                                    	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                    	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                        self.yang_name = "vrf-recursive-next-hop-table"
                                                        self.yang_parent_name = "vrf-recurse-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                        self.vrf_next_hop_explicit_path_name = YList(self)
                                                        self.vrf_next_hop_interface_name = YList(self)
                                                        self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address = YList(self)
                                                        self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                        self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                                    class VrfNextHopExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: interface_name  <key>
                                                        
                                                        	Forwarding interface
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddress(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                    class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                        """
                                                        A forwarding interface or Segement Routing mpls
                                                        path name and/or the address of a nexthop router
                                                        for this route (one of these must be specified)
                                                        
                                                        .. attribute:: next_hop_address  <key>
                                                        
                                                        	Next hop address
                                                        	**type**\: one of the below types:
                                                        
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        
                                                        ----
                                                        .. attribute:: explicit_path_name  <key>
                                                        
                                                        	Segment Routing mpls path name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                        
                                                        .. attribute:: bfd_fast_detect
                                                        
                                                        	If set, bfd is enabled
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: description
                                                        
                                                        	Short Description of Static Route
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: detect_multiplier
                                                        
                                                        	BFD Detect Multiplier
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..10
                                                        
                                                        	**default value**\: 3
                                                        
                                                        .. attribute:: index
                                                        
                                                        	Nexthop Identifier for OC Yang model
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	UCMP load metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..16777214
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Distance metric for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..254
                                                        
                                                        	**default value**\: 1
                                                        
                                                        .. attribute:: minimum_interval
                                                        
                                                        	BFD Hello interval in milliseconds
                                                        	**type**\:  int
                                                        
                                                        	**range:** 3..30000
                                                        
                                                        	**units**\: millisecond
                                                        
                                                        	**default value**\: 100
                                                        
                                                        .. attribute:: object_name
                                                        
                                                        	Name of the object to track
                                                        	**type**\:  str
                                                        
                                                        	**length:** 1..32
                                                        
                                                        .. attribute:: permanent
                                                        
                                                        	If set, path is permanent
                                                        	**type**\:  bool
                                                        
                                                        	**default value**\: false
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Tag for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 1..4294967295
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        	**default value**\: 0
                                                        
                                                        .. attribute:: vrf_lable
                                                        
                                                        	VRF LABEL
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**default value**\: 0
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-static-cfg'
                                                        _revision = '2017-05-01'

                                                        def __init__(self):
                                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                            self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                            self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                            self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                            self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                            self.description = YLeaf(YType.str, "description")

                                                            self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                            self.index = YLeaf(YType.str, "index")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                            self.object_name = YLeaf(YType.str, "object-name")

                                                            self.permanent = YLeaf(YType.boolean, "permanent")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                            self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfRoute(Entity):
                                            """
                                            A connected or recursive  static route
                                            
                                            .. attribute:: vrf_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute, self).__init__()

                                                self.yang_name = "vrf-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable)}
                                                self._child_list_classes = {}

                                                self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable()
                                                self.vrf_next_hop_table.parent = self
                                                self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                                self._children_yang_names.add("vrf-next-hop-table")
                                                self._segment_path = lambda: "vrf-route"


                                            class VrfNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, self).__init__()

                                                    self.yang_name = "vrf-next-hop-table"
                                                    self.yang_parent_name = "vrf-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "vrf-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "vrf-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfSegRoute(Entity):
                                            """
                                            A static segment route
                                            
                                            .. attribute:: segment_route_next_hop_table
                                            
                                            	The set of nexthop information configured for this route
                                            	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute, self).__init__()

                                                self.yang_name = "vrf-seg-route"
                                                self.yang_parent_name = "vrf-prefix-topology"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable)}
                                                self._child_list_classes = {}

                                                self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable()
                                                self.segment_route_next_hop_table.parent = self
                                                self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                                self._children_yang_names.add("segment-route-next-hop-table")
                                                self._segment_path = lambda: "vrf-seg-route"


                                            class SegmentRouteNextHopTable(Entity):
                                                """
                                                The set of nexthop information configured for
                                                this route
                                                
                                                .. attribute:: vrf_next_hop_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                                
                                                .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                                
                                                .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                                
                                                	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                                	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                                    self.yang_name = "segment-route-next-hop-table"
                                                    self.yang_parent_name = "vrf-seg-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                    self.vrf_next_hop_explicit_path_name = YList(self)
                                                    self.vrf_next_hop_interface_name = YList(self)
                                                    self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address = YList(self)
                                                    self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                    self._segment_path = lambda: "segment-route-next-hop-table"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                                class VrfNextHopExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: interface_name  <key>
                                                    
                                                    	Forwarding interface
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddress(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                                class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                    """
                                                    A forwarding interface or Segement Routing mpls
                                                    path name and/or the address of a nexthop router
                                                    for this route (one of these must be specified)
                                                    
                                                    .. attribute:: next_hop_address  <key>
                                                    
                                                    	Next hop address
                                                    	**type**\: one of the below types:
                                                    
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    
                                                    ----
                                                    .. attribute:: explicit_path_name  <key>
                                                    
                                                    	Segment Routing mpls path name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                    
                                                    .. attribute:: bfd_fast_detect
                                                    
                                                    	If set, bfd is enabled
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: description
                                                    
                                                    	Short Description of Static Route
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: detect_multiplier
                                                    
                                                    	BFD Detect Multiplier
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..10
                                                    
                                                    	**default value**\: 3
                                                    
                                                    .. attribute:: index
                                                    
                                                    	Nexthop Identifier for OC Yang model
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	UCMP load metric
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..16777214
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Distance metric for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..254
                                                    
                                                    	**default value**\: 1
                                                    
                                                    .. attribute:: minimum_interval
                                                    
                                                    	BFD Hello interval in milliseconds
                                                    	**type**\:  int
                                                    
                                                    	**range:** 3..30000
                                                    
                                                    	**units**\: millisecond
                                                    
                                                    	**default value**\: 100
                                                    
                                                    .. attribute:: object_name
                                                    
                                                    	Name of the object to track
                                                    	**type**\:  str
                                                    
                                                    	**length:** 1..32
                                                    
                                                    .. attribute:: permanent
                                                    
                                                    	If set, path is permanent
                                                    	**type**\:  bool
                                                    
                                                    	**default value**\: false
                                                    
                                                    .. attribute:: tag
                                                    
                                                    	Tag for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 1..4294967295
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**default value**\: 0
                                                    
                                                    .. attribute:: vrf_lable
                                                    
                                                    	VRF LABEL
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**default value**\: 0
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-static-cfg'
                                                    _revision = '2017-05-01'

                                                    def __init__(self):
                                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                        self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                        self.yang_parent_name = "segment-route-next-hop-table"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                        self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                        self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                        self.description = YLeaf(YType.str, "description")

                                                        self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                        self.index = YLeaf(YType.str, "index")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                        self.object_name = YLeaf(YType.str, "object-name")

                                                        self.permanent = YLeaf(YType.boolean, "permanent")

                                                        self.tag = YLeaf(YType.uint32, "tag")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                        self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.Topologies.Topology.VrfPrefixTopologies.VrfPrefixTopology.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                        class VrfPrefixes(Entity):
                            """
                            The set of all Static Topologies for this AFI.
                            
                            .. attribute:: vrf_prefix
                            
                            	A static route
                            	**type**\: list of    :py:class:`VrfPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix>`
                            
                            

                            """

                            _prefix = 'ip-static-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, self).__init__()

                                self.yang_name = "vrf-prefixes"
                                self.yang_parent_name = "vrf-unicast"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-prefix" : ("vrf_prefix", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix)}

                                self.vrf_prefix = YList(self)
                                self._segment_path = lambda: "vrf-prefixes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes, [], name, value)


                            class VrfPrefix(Entity):
                                """
                                A static route
                                
                                .. attribute:: prefix  <key>
                                
                                	Destination prefix
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: prefix_length  <key>
                                
                                	Destination prefix length
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                .. attribute:: vrf_recurse_routes
                                
                                	A recursive next VRF static route
                                	**type**\:   :py:class:`VrfRecurseRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes>`
                                
                                .. attribute:: vrf_route
                                
                                	A connected or recursive  static route
                                	**type**\:   :py:class:`VrfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute>`
                                
                                .. attribute:: vrf_seg_route
                                
                                	A static segment route
                                	**type**\:   :py:class:`VrfSegRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute>`
                                
                                

                                """

                                _prefix = 'ip-static-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, self).__init__()

                                    self.yang_name = "vrf-prefix"
                                    self.yang_parent_name = "vrf-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"vrf-recurse-routes" : ("vrf_recurse_routes", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes), "vrf-route" : ("vrf_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute), "vrf-seg-route" : ("vrf_seg_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute)}
                                    self._child_list_classes = {}

                                    self.prefix = YLeaf(YType.str, "prefix")

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.vrf_recurse_routes = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes()
                                    self.vrf_recurse_routes.parent = self
                                    self._children_name_map["vrf_recurse_routes"] = "vrf-recurse-routes"
                                    self._children_yang_names.add("vrf-recurse-routes")

                                    self.vrf_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute()
                                    self.vrf_route.parent = self
                                    self._children_name_map["vrf_route"] = "vrf-route"
                                    self._children_yang_names.add("vrf-route")

                                    self.vrf_seg_route = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute()
                                    self.vrf_seg_route.parent = self
                                    self._children_name_map["vrf_seg_route"] = "vrf-seg-route"
                                    self._children_yang_names.add("vrf-seg-route")
                                    self._segment_path = lambda: "vrf-prefix" + "[prefix='" + self.prefix.get() + "']" + "[prefix-length='" + self.prefix_length.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix, ['prefix', 'prefix_length'], name, value)


                                class VrfRecurseRoutes(Entity):
                                    """
                                    A recursive next VRF static route
                                    
                                    .. attribute:: vrf_recurse_route
                                    
                                    	A recursive next vrf static route
                                    	**type**\: list of    :py:class:`VrfRecurseRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, self).__init__()

                                        self.yang_name = "vrf-recurse-routes"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-recurse-route" : ("vrf_recurse_route", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute)}

                                        self.vrf_recurse_route = YList(self)
                                        self._segment_path = lambda: "vrf-recurse-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes, [], name, value)


                                    class VrfRecurseRoute(Entity):
                                        """
                                        A recursive next vrf static route
                                        
                                        .. attribute:: vrf_name  <key>
                                        
                                        	Fallback or recusive VRF name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: vrf_recursive_next_hop_table
                                        
                                        	The set of nexthop information configured for this route
                                        	**type**\:   :py:class:`VrfRecursiveNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, self).__init__()

                                            self.yang_name = "vrf-recurse-route"
                                            self.yang_parent_name = "vrf-recurse-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"vrf-recursive-next-hop-table" : ("vrf_recursive_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable)}
                                            self._child_list_classes = {}

                                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                                            self.vrf_recursive_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable()
                                            self.vrf_recursive_next_hop_table.parent = self
                                            self._children_name_map["vrf_recursive_next_hop_table"] = "vrf-recursive-next-hop-table"
                                            self._children_yang_names.add("vrf-recursive-next-hop-table")
                                            self._segment_path = lambda: "vrf-recurse-route" + "[vrf-name='" + self.vrf_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute, ['vrf_name'], name, value)


                                        class VrfRecursiveNextHopTable(Entity):
                                            """
                                            The set of nexthop information configured for
                                            this route
                                            
                                            .. attribute:: vrf_next_hop_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName>`
                                            
                                            .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress>`
                                            
                                            .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                            
                                            	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                            	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, self).__init__()

                                                self.yang_name = "vrf-recursive-next-hop-table"
                                                self.yang_parent_name = "vrf-recurse-route"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                                self.vrf_next_hop_explicit_path_name = YList(self)
                                                self.vrf_next_hop_interface_name = YList(self)
                                                self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address = YList(self)
                                                self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                                self._segment_path = lambda: "vrf-recursive-next-hop-table"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable, [], name, value)


                                            class VrfNextHopExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: interface_name  <key>
                                                
                                                	Forwarding interface
                                                	**type**\:  str
                                                
                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddress(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                            class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                                """
                                                A forwarding interface or Segement Routing mpls
                                                path name and/or the address of a nexthop router
                                                for this route (one of these must be specified)
                                                
                                                .. attribute:: next_hop_address  <key>
                                                
                                                	Next hop address
                                                	**type**\: one of the below types:
                                                
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                	**type**\:  str
                                                
                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                
                                                ----
                                                .. attribute:: explicit_path_name  <key>
                                                
                                                	Segment Routing mpls path name
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: bfd_fast_detect
                                                
                                                	If set, bfd is enabled
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: description
                                                
                                                	Short Description of Static Route
                                                	**type**\:  str
                                                
                                                .. attribute:: detect_multiplier
                                                
                                                	BFD Detect Multiplier
                                                	**type**\:  int
                                                
                                                	**range:** 1..10
                                                
                                                	**default value**\: 3
                                                
                                                .. attribute:: index
                                                
                                                	Nexthop Identifier for OC Yang model
                                                	**type**\:  str
                                                
                                                .. attribute:: load_metric
                                                
                                                	UCMP load metric
                                                	**type**\:  int
                                                
                                                	**range:** 1..16777214
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: metric
                                                
                                                	Distance metric for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..254
                                                
                                                	**default value**\: 1
                                                
                                                .. attribute:: minimum_interval
                                                
                                                	BFD Hello interval in milliseconds
                                                	**type**\:  int
                                                
                                                	**range:** 3..30000
                                                
                                                	**units**\: millisecond
                                                
                                                	**default value**\: 100
                                                
                                                .. attribute:: object_name
                                                
                                                	Name of the object to track
                                                	**type**\:  str
                                                
                                                	**length:** 1..32
                                                
                                                .. attribute:: permanent
                                                
                                                	If set, path is permanent
                                                	**type**\:  bool
                                                
                                                	**default value**\: false
                                                
                                                .. attribute:: tag
                                                
                                                	Tag for this path
                                                	**type**\:  int
                                                
                                                	**range:** 1..4294967295
                                                
                                                .. attribute:: tunnel_id
                                                
                                                	Tunnel ID for this path
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                	**default value**\: 0
                                                
                                                .. attribute:: vrf_lable
                                                
                                                	VRF LABEL
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**default value**\: 0
                                                
                                                

                                                """

                                                _prefix = 'ip-static-cfg'
                                                _revision = '2017-05-01'

                                                def __init__(self):
                                                    super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                    self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                    self.yang_parent_name = "vrf-recursive-next-hop-table"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                    self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                    self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                    self.description = YLeaf(YType.str, "description")

                                                    self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                    self.index = YLeaf(YType.str, "index")

                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                    self.object_name = YLeaf(YType.str, "object-name")

                                                    self.permanent = YLeaf(YType.boolean, "permanent")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                    self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                    self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRecurseRoutes.VrfRecurseRoute.VrfRecursiveNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfRoute(Entity):
                                    """
                                    A connected or recursive  static route
                                    
                                    .. attribute:: vrf_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`VrfNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute, self).__init__()

                                        self.yang_name = "vrf-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"vrf-next-hop-table" : ("vrf_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable)}
                                        self._child_list_classes = {}

                                        self.vrf_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable()
                                        self.vrf_next_hop_table.parent = self
                                        self._children_name_map["vrf_next_hop_table"] = "vrf-next-hop-table"
                                        self._children_yang_names.add("vrf-next-hop-table")
                                        self._segment_path = lambda: "vrf-route"


                                    class VrfNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, self).__init__()

                                            self.yang_name = "vrf-next-hop-table"
                                            self.yang_parent_name = "vrf-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "vrf-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "vrf-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfRoute.VrfNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                class VrfSegRoute(Entity):
                                    """
                                    A static segment route
                                    
                                    .. attribute:: segment_route_next_hop_table
                                    
                                    	The set of nexthop information configured for this route
                                    	**type**\:   :py:class:`SegmentRouteNextHopTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable>`
                                    
                                    

                                    """

                                    _prefix = 'ip-static-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute, self).__init__()

                                        self.yang_name = "vrf-seg-route"
                                        self.yang_parent_name = "vrf-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"segment-route-next-hop-table" : ("segment_route_next_hop_table", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable)}
                                        self._child_list_classes = {}

                                        self.segment_route_next_hop_table = RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable()
                                        self.segment_route_next_hop_table.parent = self
                                        self._children_name_map["segment_route_next_hop_table"] = "segment-route-next-hop-table"
                                        self._children_yang_names.add("segment-route-next-hop-table")
                                        self._segment_path = lambda: "vrf-seg-route"


                                    class SegmentRouteNextHopTable(Entity):
                                        """
                                        The set of nexthop information configured for
                                        this route
                                        
                                        .. attribute:: vrf_next_hop_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName>`
                                        
                                        .. attribute:: vrf_next_hop_interface_name_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopInterfaceNameNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress>`
                                        
                                        .. attribute:: vrf_next_hop_next_hop_address_explicit_path_name
                                        
                                        	A forwarding interface or Segement Routing mpls path name and/or the address of a nexthop router for this route (one of these must be specified)
                                        	**type**\: list of    :py:class:`VrfNextHopNextHopAddressExplicitPathName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_static_cfg.RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName>`
                                        
                                        

                                        """

                                        _prefix = 'ip-static-cfg'
                                        _revision = '2017-05-01'

                                        def __init__(self):
                                            super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, self).__init__()

                                            self.yang_name = "segment-route-next-hop-table"
                                            self.yang_parent_name = "vrf-seg-route"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"vrf-next-hop-explicit-path-name" : ("vrf_next_hop_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName), "vrf-next-hop-interface-name" : ("vrf_next_hop_interface_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName), "vrf-next-hop-interface-name-next-hop-address" : ("vrf_next_hop_interface_name_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress), "vrf-next-hop-next-hop-address" : ("vrf_next_hop_next_hop_address", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress), "vrf-next-hop-next-hop-address-explicit-path-name" : ("vrf_next_hop_next_hop_address_explicit_path_name", RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName)}

                                            self.vrf_next_hop_explicit_path_name = YList(self)
                                            self.vrf_next_hop_interface_name = YList(self)
                                            self.vrf_next_hop_interface_name_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address = YList(self)
                                            self.vrf_next_hop_next_hop_address_explicit_path_name = YList(self)
                                            self._segment_path = lambda: "segment-route-next-hop-table"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable, [], name, value)


                                        class VrfNextHopExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-explicit-path-name" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopExplicitPathName, ['explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name" + "[interface-name='" + self.interface_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceName, ['interface_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopInterfaceNameNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: interface_name  <key>
                                            
                                            	Forwarding interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-interface-name-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-interface-name-next-hop-address" + "[interface-name='" + self.interface_name.get() + "']" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopInterfaceNameNextHopAddress, ['interface_name', 'next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddress(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address" + "[next-hop-address='" + self.next_hop_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddress, ['next_hop_address', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)


                                        class VrfNextHopNextHopAddressExplicitPathName(Entity):
                                            """
                                            A forwarding interface or Segement Routing mpls
                                            path name and/or the address of a nexthop router
                                            for this route (one of these must be specified)
                                            
                                            .. attribute:: next_hop_address  <key>
                                            
                                            	Next hop address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: explicit_path_name  <key>
                                            
                                            	Segment Routing mpls path name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: bfd_fast_detect
                                            
                                            	If set, bfd is enabled
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: description
                                            
                                            	Short Description of Static Route
                                            	**type**\:  str
                                            
                                            .. attribute:: detect_multiplier
                                            
                                            	BFD Detect Multiplier
                                            	**type**\:  int
                                            
                                            	**range:** 1..10
                                            
                                            	**default value**\: 3
                                            
                                            .. attribute:: index
                                            
                                            	Nexthop Identifier for OC Yang model
                                            	**type**\:  str
                                            
                                            .. attribute:: load_metric
                                            
                                            	UCMP load metric
                                            	**type**\:  int
                                            
                                            	**range:** 1..16777214
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: metric
                                            
                                            	Distance metric for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..254
                                            
                                            	**default value**\: 1
                                            
                                            .. attribute:: minimum_interval
                                            
                                            	BFD Hello interval in milliseconds
                                            	**type**\:  int
                                            
                                            	**range:** 3..30000
                                            
                                            	**units**\: millisecond
                                            
                                            	**default value**\: 100
                                            
                                            .. attribute:: object_name
                                            
                                            	Name of the object to track
                                            	**type**\:  str
                                            
                                            	**length:** 1..32
                                            
                                            .. attribute:: permanent
                                            
                                            	If set, path is permanent
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: tag
                                            
                                            	Tag for this path
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            .. attribute:: tunnel_id
                                            
                                            	Tunnel ID for this path
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: vrf_lable
                                            
                                            	VRF LABEL
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ip-static-cfg'
                                            _revision = '2017-05-01'

                                            def __init__(self):
                                                super(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, self).__init__()

                                                self.yang_name = "vrf-next-hop-next-hop-address-explicit-path-name"
                                                self.yang_parent_name = "segment-route-next-hop-table"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.explicit_path_name = YLeaf(YType.str, "explicit-path-name")

                                                self.bfd_fast_detect = YLeaf(YType.boolean, "bfd-fast-detect")

                                                self.description = YLeaf(YType.str, "description")

                                                self.detect_multiplier = YLeaf(YType.uint32, "detect-multiplier")

                                                self.index = YLeaf(YType.str, "index")

                                                self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                                self.object_name = YLeaf(YType.str, "object-name")

                                                self.permanent = YLeaf(YType.boolean, "permanent")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                self.vrf_lable = YLeaf(YType.uint32, "vrf-lable")
                                                self._segment_path = lambda: "vrf-next-hop-next-hop-address-explicit-path-name" + "[next-hop-address='" + self.next_hop_address.get() + "']" + "[explicit-path-name='" + self.explicit_path_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RouterStatic.Vrfs.Vrf.AddressFamily.Vrfipv6.VrfUnicast.VrfPrefixes.VrfPrefix.VrfSegRoute.SegmentRouteNextHopTable.VrfNextHopNextHopAddressExplicitPathName, ['next_hop_address', 'explicit_path_name', 'bfd_fast_detect', 'description', 'detect_multiplier', 'index', 'load_metric', 'metric', 'minimum_interval', 'object_name', 'permanent', 'tag', 'tunnel_id', 'vrf_lable'], name, value)

    def clone_ptr(self):
        self._top_entity = RouterStatic()
        return self._top_entity

