""" Cisco_IOS_XR_ipv4_bgp_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-bgp package configuration.

This module contains definitions
for the following management objects\:
  bgp\: BGP configuration commands
  bmp\-server\-all\: bmp server all
  bmp\-servers\: bmp servers

This YANG module augments the
  Cisco\-IOS\-XR\-infra\-rsi\-cfg,
  Cisco\-IOS\-XR\-snmp\-agent\-cfg
modules with configuration data.

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class BgpAdvRt(Enum):
    """
    BgpAdvRt

    Bgp adv rt

    .. data:: bgp_regular_rt = 0

    	Regular RT type

    .. data:: bgp_stitching_rt = 1

    	Stitching RT type

    """

    bgp_regular_rt = Enum.YLeaf(0, "bgp-regular-rt")

    bgp_stitching_rt = Enum.YLeaf(1, "bgp-stitching-rt")


class BgpAfEncapsulation(Enum):
    """
    BgpAfEncapsulation

    Bgp af encapsulation

    .. data:: vx_lan = 1

    	VxLAN encapsulation type

    """

    vx_lan = Enum.YLeaf(1, "vx-lan")


class BgpAigpCfg(Enum):
    """
    BgpAigpCfg

    Bgp aigp cfg

    .. data:: enable = 1

    	Enable AIGP

    .. data:: disable = 2

    	Disable AIGP

    """

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")


class BgpAigpCfgPoi(Enum):
    """
    BgpAigpCfgPoi

    Bgp aigp cfg poi

    .. data:: pre_best_path = 1

    	AIGP Pre-bestpath POI

    .. data:: igp_cost = 2

    	AIGP igp-cost POI

    """

    pre_best_path = Enum.YLeaf(1, "pre-best-path")

    igp_cost = Enum.YLeaf(2, "igp-cost")


class BgpBfdEnableMode(Enum):
    """
    BgpBfdEnableMode

    Bgp bfd enable mode

    .. data:: disable = 0

    	Disable Mode - Prevent inheritance

    .. data:: default = 1

    	Default Mode - Default BFD behavior

    .. data:: strict = 2

    	Strict Mode - Hold down adj until BFD session

    	up

    """

    disable = Enum.YLeaf(0, "disable")

    default = Enum.YLeaf(1, "default")

    strict = Enum.YLeaf(2, "strict")


class BgpClusterId(Enum):
    """
    BgpClusterId

    Bgp cluster id

    .. data:: number = 1

    	Number

    .. data:: ipv4_address = 2

    	IPv4 Address

    """

    number = Enum.YLeaf(1, "number")

    ipv4_address = Enum.YLeaf(2, "ipv4-address")


class BgpEbgpSendDmzEnableMode(Enum):
    """
    BgpEbgpSendDmzEnableMode

    Bgp ebgp send dmz enable mode

    .. data:: disable = 0

    	Disable Mode - Prevent inheritance

    .. data:: default = 1

    	Default Mode - Send dmz link bandwidth value to

    	ebgp neighbor

    .. data:: cumulative = 2

    	Strict Mode - Send cumulative dmz link

    	bandwidth value to ebgp neighbor

    """

    disable = Enum.YLeaf(0, "disable")

    default = Enum.YLeaf(1, "default")

    cumulative = Enum.YLeaf(2, "cumulative")


class BgpFlowspecValidationCfg(Enum):
    """
    BgpFlowspecValidationCfg

    Bgp flowspec validation cfg

    .. data:: enable = 1

    	Enable Flowspec validation

    .. data:: disable = 2

    	Disable Flowspec validation

    .. data:: redirect_nexhop_disable = 3

    	Disable Flowspec redirect nexthop validation

    """

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")

    redirect_nexhop_disable = Enum.YLeaf(3, "redirect-nexhop-disable")


class BgpMvpnSfsSelect(Enum):
    """
    BgpMvpnSfsSelect

    Bgp mvpn sfs select

    .. data:: all_paths = 1

    	Select all paths as single forwarder PE

    .. data:: highest_ip_address = 2

    	Select PE with highest address as single

    	forwarder PE

    """

    all_paths = Enum.YLeaf(1, "all-paths")

    highest_ip_address = Enum.YLeaf(2, "highest-ip-address")


class BgpOrf(Enum):
    """
    BgpOrf

    Bgp orf

    .. data:: none = 0

    	No capability to send or receive

    .. data:: receive = 1

    	Receive ORF capability

    .. data:: send = 2

    	Send ORF capability

    .. data:: both = 3

    	Send and receive ORF capability

    """

    none = Enum.YLeaf(0, "none")

    receive = Enum.YLeaf(1, "receive")

    send = Enum.YLeaf(2, "send")

    both = Enum.YLeaf(3, "both")


class BgpReorgOpt(Enum):
    """
    BgpReorgOpt

    Bgp reorg opt

    .. data:: bgp_cfg_adv = 1

    	Advertise translated routes

    .. data:: bgp_cfg_adv_reorg = 2

    	Advertise Reorig routes

    .. data:: bgp_cfg_adv_disable = 3

    	Disable adv of routes

    .. data:: bgp_cfg_adv_local = 4

    	Advertise local routes

    .. data:: bgp_cfg_adv_def_vrf_imp_disable = 5

    	Disable adv of Def VRF Imported routes

    .. data:: bgp_cfg_adv_vrf_re_imp_disable = 6

    	Disable adv of VRF ReImported routes

    """

    bgp_cfg_adv = Enum.YLeaf(1, "bgp-cfg-adv")

    bgp_cfg_adv_reorg = Enum.YLeaf(2, "bgp-cfg-adv-reorg")

    bgp_cfg_adv_disable = Enum.YLeaf(3, "bgp-cfg-adv-disable")

    bgp_cfg_adv_local = Enum.YLeaf(4, "bgp-cfg-adv-local")

    bgp_cfg_adv_def_vrf_imp_disable = Enum.YLeaf(5, "bgp-cfg-adv-def-vrf-imp-disable")

    bgp_cfg_adv_vrf_re_imp_disable = Enum.YLeaf(6, "bgp-cfg-adv-vrf-re-imp-disable")


class BgpRnhInstallFormat(Enum):
    """
    BgpRnhInstallFormat

    Bgp rnh install format

    .. data:: ext_comm = 0

    	Install RNH as opaque and extcomm

    .. data:: ext_comm_only = 1

    	Install RNH as extcomm only

    """

    ext_comm = Enum.YLeaf(0, "ext-comm")

    ext_comm_only = Enum.YLeaf(1, "ext-comm-only")


class BgpRouteDistinguisher(Enum):
    """
    BgpRouteDistinguisher

    Bgp route distinguisher

    .. data:: auto = 1

    	Automatically assigned

    .. data:: as_ = 2

    	AS format RD

    .. data:: four_byte_as = 3

    	4-byte AS format RD

    .. data:: ipv4_address = 4

    	IPv4 address format RD

    """

    auto = Enum.YLeaf(1, "auto")

    as_ = Enum.YLeaf(2, "as")

    four_byte_as = Enum.YLeaf(3, "four-byte-as")

    ipv4_address = Enum.YLeaf(4, "ipv4-address")


class BgpRpkiTransport(Enum):
    """
    BgpRpkiTransport

    Bgp rpki transport

    .. data:: tcp = 0

    	TCP Transport

    .. data:: ssh = 1

    	SSH Transport

    """

    tcp = Enum.YLeaf(0, "tcp")

    ssh = Enum.YLeaf(1, "ssh")


class BgpSendMcastAttrCfg(Enum):
    """
    BgpSendMcastAttrCfg

    Bgp send mcast attr cfg

    .. data:: enable = 1

    	Enable SendMcastAttr

    .. data:: disable = 2

    	Disable SendMcastAttr

    """

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")


class BgpSignal(Enum):
    """
    BgpSignal

    Bgp signal

    .. data:: bgp_disable = 1

    	Signalling BGP disable

    .. data:: ldp_disable = 2

    	Signalling LDP disable

    """

    bgp_disable = Enum.YLeaf(1, "bgp-disable")

    ldp_disable = Enum.YLeaf(2, "ldp-disable")


class BgpSiteOfOrigin(Enum):
    """
    BgpSiteOfOrigin

    Bgp site of origin

    .. data:: as_ = 0

    	AS format SoO

    .. data:: ipv4_address = 1

    	IPv4 address format SoO

    .. data:: four_byte_as = 2

    	4-byte AS format SoO

    """

    as_ = Enum.YLeaf(0, "as")

    ipv4_address = Enum.YLeaf(1, "ipv4-address")

    four_byte_as = Enum.YLeaf(2, "four-byte-as")


class BgpTcpMode(Enum):
    """
    BgpTcpMode

    Bgp tcp mode

    .. data:: either = 0

    	Either active or passive mode

    .. data:: active_only = 1

    	Active mode only

    .. data:: passive_only = 2

    	Passive mode only

    """

    either = Enum.YLeaf(0, "either")

    active_only = Enum.YLeaf(1, "active-only")

    passive_only = Enum.YLeaf(2, "passive-only")


class BgpVrfRouteTarget(Enum):
    """
    BgpVrfRouteTarget

    Bgp vrf route target

    .. data:: as_ = 0

    	AS format RT

    .. data:: ipv4_address = 1

    	IPv4 address format RT

    .. data:: four_byte_as = 2

    	4-byte AS format RT

    """

    as_ = Enum.YLeaf(0, "as")

    ipv4_address = Enum.YLeaf(1, "ipv4-address")

    four_byte_as = Enum.YLeaf(2, "four-byte-as")


class BmpPolicySelect(Enum):
    """
    BmpPolicySelect

    Bmp policy select

    .. data:: post_policy = 2

    	Pickup routes after policy application

    """

    post_policy = Enum.YLeaf(2, "post-policy")


class BmpRouteDirection(Enum):
    """
    BmpRouteDirection

    Bmp route direction

    .. data:: inbound = 1

    	Pickup routes at inbound direction from peer

    """

    inbound = Enum.YLeaf(1, "inbound")



class Bgp(Entity):
    """
    BGP configuration commands
    
    .. attribute:: instance
    
    	BGP instance configuration commands
    	**type**\: list of    :py:class:`Instance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance>`
    
    

    """

    _prefix = 'ipv4-bgp-cfg'
    _revision = '2017-06-26'

    def __init__(self):
        super(Bgp, self).__init__()
        self._top_entity = None

        self.yang_name = "bgp"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {}
        self._child_list_classes = {"instance" : ("instance", Bgp.Instance)}

        self.instance = YList(self)
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-bgp-cfg:bgp"

    def __setattr__(self, name, value):
        self._perform_setattr(Bgp, [], name, value)


    class Instance(Entity):
        """
        BGP instance configuration commands
        
        .. attribute:: instance_name  <key>
        
        	Instance Name. For Default instance use \- default
        	**type**\:  str
        
        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
        
        .. attribute:: instance_as
        
        	Autonomous system
        	**type**\: list of    :py:class:`InstanceAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs>`
        
        

        """

        _prefix = 'ipv4-bgp-cfg'
        _revision = '2017-06-26'

        def __init__(self):
            super(Bgp.Instance, self).__init__()

            self.yang_name = "instance"
            self.yang_parent_name = "bgp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"instance-as" : ("instance_as", Bgp.Instance.InstanceAs)}

            self.instance_name = YLeaf(YType.str, "instance-name")

            self.instance_as = YList(self)
            self._segment_path = lambda: "instance" + "[instance-name='" + self.instance_name.get() + "']"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-cfg:bgp/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bgp.Instance, ['instance_name'], name, value)


        class InstanceAs(Entity):
            """
            Autonomous system
            
            .. attribute:: as_  <key>
            
            	Higher 16 bits of 4\-byte Autonomous system number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: four_byte_as
            
            	4\-byte Autonomous system
            	**type**\: list of    :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs>`
            
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(Bgp.Instance.InstanceAs, self).__init__()

                self.yang_name = "instance-as"
                self.yang_parent_name = "instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"four-byte-as" : ("four_byte_as", Bgp.Instance.InstanceAs.FourByteAs)}

                self.as_ = YLeaf(YType.uint32, "as")

                self.four_byte_as = YList(self)
                self._segment_path = lambda: "instance-as" + "[as='" + self.as_.get() + "']"

            def __setattr__(self, name, value):
                self._perform_setattr(Bgp.Instance.InstanceAs, ['as_'], name, value)


            class FourByteAs(Entity):
                """
                4\-byte Autonomous system
                
                .. attribute:: as_  <key>
                
                	2\-byte or 4\-byte Autonomous system number
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_running
                
                	Enable BGP. Deletion of this object causes deletion of all the objects under FourByteAS associated with this object
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: default_vrf
                
                	Global default config
                	**type**\:   :py:class:`DefaultVrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf>`
                
                .. attribute:: vrfs
                
                	VRF config
                	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs>`
                
                

                """

                _prefix = 'ipv4-bgp-cfg'
                _revision = '2017-06-26'

                def __init__(self):
                    super(Bgp.Instance.InstanceAs.FourByteAs, self).__init__()

                    self.yang_name = "four-byte-as"
                    self.yang_parent_name = "instance-as"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"default-vrf" : ("default_vrf", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf), "vrfs" : ("vrfs", Bgp.Instance.InstanceAs.FourByteAs.Vrfs)}
                    self._child_list_classes = {}

                    self.as_ = YLeaf(YType.uint32, "as")

                    self.bgp_running = YLeaf(YType.empty, "bgp-running")

                    self.default_vrf = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf()
                    self.default_vrf.parent = self
                    self._children_name_map["default_vrf"] = "default-vrf"
                    self._children_yang_names.add("default-vrf")

                    self.vrfs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs()
                    self.vrfs.parent = self
                    self._children_name_map["vrfs"] = "vrfs"
                    self._children_yang_names.add("vrfs")
                    self._segment_path = lambda: "four-byte-as" + "[as='" + self.as_.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs, ['as_', 'bgp_running'], name, value)


                class DefaultVrf(Entity):
                    """
                    Global default config
                    
                    .. attribute:: bgp_entity
                    
                    	Neighbor, neighbor\-group, af\-group and session\-group configuration
                    	**type**\:   :py:class:`BgpEntity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity>`
                    
                    .. attribute:: global_
                    
                    	Global default config
                    	**type**\:   :py:class:`Global_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-cfg'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf, self).__init__()

                        self.yang_name = "default-vrf"
                        self.yang_parent_name = "four-byte-as"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"bgp-entity" : ("bgp_entity", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity), "global" : ("global_", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_)}
                        self._child_list_classes = {}

                        self.bgp_entity = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity()
                        self.bgp_entity.parent = self
                        self._children_name_map["bgp_entity"] = "bgp-entity"
                        self._children_yang_names.add("bgp-entity")

                        self.global_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"
                        self._children_yang_names.add("global")
                        self._segment_path = lambda: "default-vrf"


                    class BgpEntity(Entity):
                        """
                        Neighbor, neighbor\-group, af\-group and
                        session\-group configuration
                        
                        .. attribute:: af_groups
                        
                        	AF\-group configuration
                        	**type**\:   :py:class:`AfGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups>`
                        
                        .. attribute:: neighbor_groups
                        
                        	Neighbor\-group configuration
                        	**type**\:   :py:class:`NeighborGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups>`
                        
                        .. attribute:: neighbors
                        
                        	Neighbor configuration
                        	**type**\:   :py:class:`Neighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors>`
                        
                        .. attribute:: session_groups
                        
                        	Session group configuration
                        	**type**\:   :py:class:`SessionGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-cfg'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity, self).__init__()

                            self.yang_name = "bgp-entity"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"af-groups" : ("af_groups", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups), "neighbor-groups" : ("neighbor_groups", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups), "neighbors" : ("neighbors", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors), "session-groups" : ("session_groups", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups)}
                            self._child_list_classes = {}

                            self.af_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups()
                            self.af_groups.parent = self
                            self._children_name_map["af_groups"] = "af-groups"
                            self._children_yang_names.add("af-groups")

                            self.neighbor_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups()
                            self.neighbor_groups.parent = self
                            self._children_name_map["neighbor_groups"] = "neighbor-groups"
                            self._children_yang_names.add("neighbor-groups")

                            self.neighbors = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors()
                            self.neighbors.parent = self
                            self._children_name_map["neighbors"] = "neighbors"
                            self._children_yang_names.add("neighbors")

                            self.session_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups()
                            self.session_groups.parent = self
                            self._children_name_map["session_groups"] = "session-groups"
                            self._children_yang_names.add("session-groups")
                            self._segment_path = lambda: "bgp-entity"


                        class AfGroups(Entity):
                            """
                            AF\-group configuration
                            
                            .. attribute:: af_group
                            
                            	A particular BGP AF group
                            	**type**\: list of    :py:class:`AfGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups, self).__init__()

                                self.yang_name = "af-groups"
                                self.yang_parent_name = "bgp-entity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"af-group" : ("af_group", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup)}

                                self.af_group = YList(self)
                                self._segment_path = lambda: "af-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups, [], name, value)


                            class AfGroup(Entity):
                                """
                                A particular BGP AF group
                                
                                .. attribute:: af_group_name  <key>
                                
                                	BGP AF group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: af_group_afs
                                
                                	AF group configuration table
                                	**type**\:   :py:class:`AfGroupAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup, self).__init__()

                                    self.yang_name = "af-group"
                                    self.yang_parent_name = "af-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"af-group-afs" : ("af_group_afs", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs)}
                                    self._child_list_classes = {}

                                    self.af_group_name = YLeaf(YType.str, "af-group-name")

                                    self.af_group_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs()
                                    self.af_group_afs.parent = self
                                    self._children_name_map["af_group_afs"] = "af-group-afs"
                                    self._children_yang_names.add("af-group-afs")
                                    self._segment_path = lambda: "af-group" + "[af-group-name='" + self.af_group_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup, ['af_group_name'], name, value)


                                class AfGroupAfs(Entity):
                                    """
                                    AF group configuration table
                                    
                                    .. attribute:: af_group_af
                                    
                                    	Address family type of an AF group
                                    	**type**\: list of    :py:class:`AfGroupAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs, self).__init__()

                                        self.yang_name = "af-group-afs"
                                        self.yang_parent_name = "af-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"af-group-af" : ("af_group_af", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf)}

                                        self.af_group_af = YList(self)
                                        self._segment_path = lambda: "af-group-afs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs, [], name, value)


                                    class AfGroupAf(Entity):
                                        """
                                        Address family type of an AF group
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP AF group address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpn_evpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_l2vpn_evpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: create
                                        
                                        	Create this address family group. Deletion of this object causes deletion of all the objects under AFGroup associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: enforce_multiple_labels
                                        
                                        	TRUE to enforce multiple labels support
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf, self).__init__()

                                            self.yang_name = "af-group-af"
                                            self.yang_parent_name = "af-group-afs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"advertise-def-imp-disable-v4" : ("advertise_def_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4), "advertise-def-imp-disable-v6" : ("advertise_def_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6), "advertise-disable" : ("advertise_disable", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable), "advertise-l2vpn-evpn" : ("advertise_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2VpnEvpn), "advertise-local-l2vpn-evpn" : ("advertise_local_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2VpnEvpn), "advertise-local-v4" : ("advertise_local_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4), "advertise-local-v6" : ("advertise_local_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6), "advertise-v4" : ("advertise_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4), "advertise-v6" : ("advertise_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6), "advertise-vrf-imp-disable-v4" : ("advertise_vrf_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4), "advertise-vrf-imp-disable-v6" : ("advertise_vrf_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6), "aigp-cost-community" : ("aigp_cost_community", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity), "default-originate" : ("default_originate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate), "import" : ("import_", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_), "maximum-prefixes" : ("maximum_prefixes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes), "neighbor-af-long-lived-graceful-restart-stale-time" : ("neighbor_af_long_lived_graceful_restart_stale_time", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime), "remove-private-as-entire-as-path" : ("remove_private_as_entire_as_path", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath), "remove-private-as-entire-as-path-inbound" : ("remove_private_as_entire_as_path_inbound", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound), "site-of-origin" : ("site_of_origin", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin), "soft-reconfiguration" : ("soft_reconfiguration", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.create = YLeaf(YType.empty, "create")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.enforce_multiple_labels = YLeaf(YType.boolean, "enforce-multiple-labels")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2VpnEvpn()
                                            self.advertise_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_l2vpn_evpn"] = "advertise-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-l2vpn-evpn")

                                            self.advertise_local_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2VpnEvpn()
                                            self.advertise_local_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_local_l2vpn_evpn"] = "advertise-local-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-local-l2vpn-evpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")
                                            self._segment_path = lambda: "af-group-af" + "[af-name='" + self.af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf, ['af_name', 'accept_own', 'accept_route_legacy_rt', 'advertise_local_labeled_route', 'advertise_orf', 'advertise_permanent_network', 'af_group', 'aigp', 'aigp_send_med', 'allow_as_in', 'as_override', 'create', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'flowspec_validation', 'l2vpn_signalling', 'multipath', 'neighbor_af_long_lived_graceful_restart_capable', 'next_hop_self', 'next_hop_unchanged', 'next_hop_unchanged_multipath', 'prefix_orf_policy', 'route_policy_in', 'route_policy_out', 'route_reflector_client', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'send_community_ebgp', 'send_community_ebgp_graceful_shutdown', 'send_ext_community_ebgp', 'send_multicast_attr'], name, value)


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDefImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-disable"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseDisable, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseL2VpnEvpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-l2vpn-evpn"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalL2VpnEvpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpn-evpn"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseLocalV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AdvertiseVrfImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")
                                                self._segment_path = lambda: "aigp-cost-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.AigpCostCommunity, ['cost_community_id', 'cost_community_poi_type', 'enable', 'transitive'], name, value)


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "default-originate"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.DefaultOriginate, ['enable', 'route_policy_name'], name, value)


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")
                                                self._segment_path = lambda: "import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.Import_, ['import_reoriginate', 'import_reoriginate_stitching', 'import_stitching'], name, value)


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")
                                                self._segment_path = lambda: "maximum-prefixes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.MaximumPrefixes, ['discard_extra_paths', 'prefix_limit', 'restart_time', 'warning_only', 'warning_percentage'], name, value)


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")
                                                self._segment_path = lambda: "neighbor-af-long-lived-graceful-restart-stale-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, ['stale_time_accept', 'stale_time_send'], name, value)


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPath, ['enable', 'entire'], name, value)


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path-inbound"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.RemovePrivateAsEntireAsPathInbound, ['enable', 'entire'], name, value)


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "site-of-origin"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SiteOfOrigin, ['address', 'address_index', 'as_', 'as_index', 'as_xx', 'type'], name, value)


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "af-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")
                                                self._segment_path = lambda: "soft-reconfiguration"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.AfGroups.AfGroup.AfGroupAfs.AfGroupAf.SoftReconfiguration, ['inbound_soft', 'soft_always'], name, value)


                        class NeighborGroups(Entity):
                            """
                            Neighbor\-group configuration
                            
                            .. attribute:: neighbor_group
                            
                            	A particular BGP neighbor group
                            	**type**\: list of    :py:class:`NeighborGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups, self).__init__()

                                self.yang_name = "neighbor-groups"
                                self.yang_parent_name = "bgp-entity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor-group" : ("neighbor_group", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup)}

                                self.neighbor_group = YList(self)
                                self._segment_path = lambda: "neighbor-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups, [], name, value)


                            class NeighborGroup(Entity):
                                """
                                A particular BGP neighbor group
                                
                                .. attribute:: neighbor_group_name  <key>
                                
                                	BGP neighbor group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates>`
                                
                                .. attribute:: create
                                
                                	Create this group. Deletion of this object causes deletion of all the objects under NeighborGroup/SessionGroup associated with this object
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgp_ce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: neighbor_group_afs
                                
                                	BGP neighbor\-group AF configuration table
                                	**type**\:   :py:class:`NeighborGroupAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs>`
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup, self).__init__()

                                    self.yang_name = "neighbor-group"
                                    self.yang_parent_name = "neighbor-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertisement-interval" : ("advertisement_interval", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval), "bmp-activates" : ("bmp_activates", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates), "ebgp-multihop" : ("ebgp_multihop", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance), "keychain" : ("keychain", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain), "local-address" : ("local_address", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress), "local-as" : ("local_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs), "msg-log-in" : ("msg_log_in", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn), "msg-log-out" : ("msg_log_out", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut), "neighbor-cluster-id" : ("neighbor_cluster_id", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId), "neighbor-group-afs" : ("neighbor_group_afs", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs), "password" : ("password", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password), "receive-buffer-size" : ("receive_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize), "remote-as" : ("remote_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs), "send-buffer-size" : ("send_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize), "tcpmss" : ("tcpmss", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss), "timers" : ("timers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers), "tos" : ("tos", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos), "update-in-filtering" : ("update_in_filtering", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering)}
                                    self._child_list_classes = {}

                                    self.neighbor_group_name = YLeaf(YType.str, "neighbor-group-name")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.create = YLeaf(YType.empty, "create")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgp_ce = YLeaf(YType.boolean, "internal-vpn-client-ibgp-ce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.neighbor_group_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs()
                                    self.neighbor_group_afs.parent = self
                                    self._children_name_map["neighbor_group_afs"] = "neighbor-group-afs"
                                    self._children_yang_names.add("neighbor-group-afs")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")
                                    self._segment_path = lambda: "neighbor-group" + "[neighbor-group-name='" + self.neighbor_group_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup, ['neighbor_group_name', 'additional_paths_receive_capability', 'additional_paths_send_capability', 'bfd_enable_modes', 'bfd_minimum_interval', 'bfd_multiplier', 'create', 'description', 'ebgp_recv_dmz', 'ebgp_send_dmz_enable_modes', 'egress_peer_engineering', 'enforce_first_as', 'idle_watch_time', 'ignore_connected_check_ebgp', 'internal_vpn_client_ibgp_ce', 'max_peers', 'neighbor_graceful_restart', 'neighbor_graceful_restart_stalepath_time', 'neighbor_graceful_restart_time', 'neighbor_group_add_member', 'propagate_dmz_link_bandwidth', 'remote_as_list', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'session_group_add_member', 'session_open_mode', 'shutdown', 'suppress_all_capabilities', 'suppress_four_byte_as_capability', 'ttl_security', 'update_source_interface'], name, value)


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")
                                        self._segment_path = lambda: "advertisement-interval"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.AdvertisementInterval, ['minimum_interval', 'minimum_interval_msecs'], name, value)


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-activate" : ("bmp_activate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate)}

                                        self.bmp_activate = YList(self)
                                        self._segment_path = lambda: "bmp-activates"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates, [], name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.server_id = YLeaf(YType.uint32, "server-id")
                                            self._segment_path = lambda: "bmp-activate" + "[server-id='" + self.server_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.BmpActivates.BmpActivate, ['server_id'], name, value)


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")
                                        self._segment_path = lambda: "ebgp-multihop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.EbgpMultihop, ['max_hop_count', 'mpls_deactivation'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"graceful-maintenance-as-prepends" : ("graceful_maintenance_as_prepends", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends), "graceful-maintenance-local-preference" : ("graceful_maintenance_local_preference", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance, ['enable', 'graceful_maintenance_activate'], name, value)


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")
                                            self._segment_path = lambda: "graceful-maintenance-as-prepends"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, ['as_prepends', 'gshut_prepends_disable'], name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")
                                            self._segment_path = lambda: "graceful-maintenance-local-preference"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, ['gshut_loc_pref_disable', 'local_preference'], name, value)


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "keychain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Keychain, ['keychain_disable', 'keychain_name'], name, value)


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")
                                        self._segment_path = lambda: "local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAddress, ['local_address_disable', 'local_ip_address'], name, value)


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")
                                        self._segment_path = lambda: "local-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.LocalAs, ['as_xx', 'as_yy', 'disable', 'dual_as', 'no_prepend', 'replace_as'], name, value)


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-in"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogIn, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-out"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.MsgLogOut, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                        self._segment_path = lambda: "neighbor-cluster-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborClusterId, ['cluster_id_address', 'cluster_id_number'], name, value)


                                class NeighborGroupAfs(Entity):
                                    """
                                    BGP neighbor\-group AF configuration table
                                    
                                    .. attribute:: neighbor_group_af
                                    
                                    	Address family type of neighbor group
                                    	**type**\: list of    :py:class:`NeighborGroupAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs, self).__init__()

                                        self.yang_name = "neighbor-group-afs"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor-group-af" : ("neighbor_group_af", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf)}

                                        self.neighbor_group_af = YList(self)
                                        self._segment_path = lambda: "neighbor-group-afs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs, [], name, value)


                                    class NeighborGroupAf(Entity):
                                        """
                                        Address family type of neighbor group
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor group address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpn_evpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_l2vpn_evpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: enforce_multiple_labels
                                        
                                        	TRUE to enforce multiple labels support
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf, self).__init__()

                                            self.yang_name = "neighbor-group-af"
                                            self.yang_parent_name = "neighbor-group-afs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"advertise-def-imp-disable-v4" : ("advertise_def_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4), "advertise-def-imp-disable-v6" : ("advertise_def_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6), "advertise-disable" : ("advertise_disable", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable), "advertise-l2vpn-evpn" : ("advertise_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2VpnEvpn), "advertise-local-l2vpn-evpn" : ("advertise_local_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2VpnEvpn), "advertise-local-v4" : ("advertise_local_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4), "advertise-local-v6" : ("advertise_local_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6), "advertise-v4" : ("advertise_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4), "advertise-v6" : ("advertise_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6), "advertise-vrf-imp-disable-v4" : ("advertise_vrf_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4), "advertise-vrf-imp-disable-v6" : ("advertise_vrf_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6), "aigp-cost-community" : ("aigp_cost_community", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity), "default-originate" : ("default_originate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate), "import" : ("import_", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_), "maximum-prefixes" : ("maximum_prefixes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes), "neighbor-af-long-lived-graceful-restart-stale-time" : ("neighbor_af_long_lived_graceful_restart_stale_time", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime), "remove-private-as-entire-as-path" : ("remove_private_as_entire_as_path", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath), "remove-private-as-entire-as-path-inbound" : ("remove_private_as_entire_as_path_inbound", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound), "site-of-origin" : ("site_of_origin", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin), "soft-reconfiguration" : ("soft_reconfiguration", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.enforce_multiple_labels = YLeaf(YType.boolean, "enforce-multiple-labels")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2VpnEvpn()
                                            self.advertise_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_l2vpn_evpn"] = "advertise-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-l2vpn-evpn")

                                            self.advertise_local_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2VpnEvpn()
                                            self.advertise_local_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_local_l2vpn_evpn"] = "advertise-local-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-local-l2vpn-evpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")
                                            self._segment_path = lambda: "neighbor-group-af" + "[af-name='" + self.af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf, ['af_name', 'accept_own', 'accept_route_legacy_rt', 'activate', 'advertise_local_labeled_route', 'advertise_orf', 'advertise_permanent_network', 'af_group', 'aigp', 'aigp_send_med', 'allow_as_in', 'as_override', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'flowspec_validation', 'l2vpn_signalling', 'multipath', 'neighbor_af_long_lived_graceful_restart_capable', 'next_hop_self', 'next_hop_unchanged', 'next_hop_unchanged_multipath', 'prefix_orf_policy', 'route_policy_in', 'route_policy_out', 'route_reflector_client', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'send_community_ebgp', 'send_community_ebgp_graceful_shutdown', 'send_ext_community_ebgp', 'send_multicast_attr'], name, value)


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDefImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-disable"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseDisable, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseL2VpnEvpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-l2vpn-evpn"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalL2VpnEvpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpn-evpn"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseLocalV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AdvertiseVrfImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")
                                                self._segment_path = lambda: "aigp-cost-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.AigpCostCommunity, ['cost_community_id', 'cost_community_poi_type', 'enable', 'transitive'], name, value)


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "default-originate"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.DefaultOriginate, ['enable', 'route_policy_name'], name, value)


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")
                                                self._segment_path = lambda: "import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.Import_, ['import_reoriginate', 'import_reoriginate_stitching', 'import_stitching'], name, value)


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")
                                                self._segment_path = lambda: "maximum-prefixes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.MaximumPrefixes, ['discard_extra_paths', 'prefix_limit', 'restart_time', 'warning_only', 'warning_percentage'], name, value)


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")
                                                self._segment_path = lambda: "neighbor-af-long-lived-graceful-restart-stale-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.NeighborAfLongLivedGracefulRestartStaleTime, ['stale_time_accept', 'stale_time_send'], name, value)


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPath, ['enable', 'entire'], name, value)


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path-inbound"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.RemovePrivateAsEntireAsPathInbound, ['enable', 'entire'], name, value)


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "site-of-origin"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SiteOfOrigin, ['address', 'address_index', 'as_', 'as_index', 'as_xx', 'type'], name, value)


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "neighbor-group-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")
                                                self._segment_path = lambda: "soft-reconfiguration"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.NeighborGroupAfs.NeighborGroupAf.SoftReconfiguration, ['inbound_soft', 'soft_always'], name, value)


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")
                                        self._segment_path = lambda: "password"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Password, ['password', 'password_disable'], name, value)


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                        self._segment_path = lambda: "receive-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.ReceiveBufferSize, ['bgp_receive_size', 'socket_receive_size'], name, value)


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")
                                        self._segment_path = lambda: "remote-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.RemoteAs, ['as_xx', 'as_yy'], name, value)


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                        self._segment_path = lambda: "send-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.SendBufferSize, ['bgp_send_size', 'socket_send_size'], name, value)


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")
                                        self._segment_path = lambda: "tcpmss"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tcpmss, ['mss', 'tcpmss_disable'], name, value)


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                        self._segment_path = lambda: "timers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Timers, ['hold_time', 'keepalive_interval', 'min_accept_hold_time'], name, value)


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")
                                        self._segment_path = lambda: "tos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.Tos, ['type', 'value'], name, value)


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "neighbor-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-in-filtering-message-buffers" : ("update_in_filtering_message_buffers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")
                                        self._segment_path = lambda: "update-in-filtering"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering, ['enable', 'update_in_filtering_attribute_filter_group', 'update_in_filtering_syslog_disable'], name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")
                                            self._segment_path = lambda: "update-in-filtering-message-buffers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.NeighborGroups.NeighborGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, ['non_circular_buffer', 'number_of_buffers'], name, value)


                        class Neighbors(Entity):
                            """
                            Neighbor configuration
                            
                            .. attribute:: neighbor
                            
                            	A particular BGP peer
                            	**type**\: list of    :py:class:`Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor>`
                            
                            .. attribute:: neighbor_prefix_length
                            
                            	A particular BGP peer
                            	**type**\: list of    :py:class:`NeighborPrefixLength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors, self).__init__()

                                self.yang_name = "neighbors"
                                self.yang_parent_name = "bgp-entity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"neighbor" : ("neighbor", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor), "neighbor-prefix-length" : ("neighbor_prefix_length", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength)}

                                self.neighbor = YList(self)
                                self.neighbor_prefix_length = YList(self)
                                self._segment_path = lambda: "neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors, [], name, value)


                            class Neighbor(Entity):
                                """
                                A particular BGP peer
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgp_ce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut>`
                                
                                .. attribute:: neighbor_afs
                                
                                	BGP neighbor AF configuration table
                                	**type**\:   :py:class:`NeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor, self).__init__()

                                    self.yang_name = "neighbor"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertisement-interval" : ("advertisement_interval", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval), "bmp-activates" : ("bmp_activates", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates), "ebgp-multihop" : ("ebgp_multihop", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance), "keychain" : ("keychain", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain), "local-address" : ("local_address", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress), "local-as" : ("local_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs), "msg-log-in" : ("msg_log_in", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn), "msg-log-out" : ("msg_log_out", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut), "neighbor-afs" : ("neighbor_afs", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs), "neighbor-cluster-id" : ("neighbor_cluster_id", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId), "password" : ("password", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password), "receive-buffer-size" : ("receive_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize), "remote-as" : ("remote_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs), "send-buffer-size" : ("send_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize), "tcpmss" : ("tcpmss", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss), "timers" : ("timers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers), "tos" : ("tos", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos), "update-in-filtering" : ("update_in_filtering", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering)}
                                    self._child_list_classes = {}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgp_ce = YLeaf(YType.boolean, "internal-vpn-client-ibgp-ce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs()
                                    self.neighbor_afs.parent = self
                                    self._children_name_map["neighbor_afs"] = "neighbor-afs"
                                    self._children_yang_names.add("neighbor-afs")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")
                                    self._segment_path = lambda: "neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor, ['neighbor_address', 'additional_paths_receive_capability', 'additional_paths_send_capability', 'bfd_enable_modes', 'bfd_minimum_interval', 'bfd_multiplier', 'description', 'ebgp_recv_dmz', 'ebgp_send_dmz_enable_modes', 'egress_peer_engineering', 'enforce_first_as', 'idle_watch_time', 'ignore_connected_check_ebgp', 'internal_vpn_client_ibgp_ce', 'max_peers', 'neighbor_graceful_restart', 'neighbor_graceful_restart_stalepath_time', 'neighbor_graceful_restart_time', 'neighbor_group_add_member', 'propagate_dmz_link_bandwidth', 'remote_as_list', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'session_group_add_member', 'session_open_mode', 'shutdown', 'suppress_all_capabilities', 'suppress_four_byte_as_capability', 'ttl_security', 'update_source_interface'], name, value)


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")
                                        self._segment_path = lambda: "advertisement-interval"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.AdvertisementInterval, ['minimum_interval', 'minimum_interval_msecs'], name, value)


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-activate" : ("bmp_activate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate)}

                                        self.bmp_activate = YList(self)
                                        self._segment_path = lambda: "bmp-activates"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates, [], name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.server_id = YLeaf(YType.uint32, "server-id")
                                            self._segment_path = lambda: "bmp-activate" + "[server-id='" + self.server_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.BmpActivates.BmpActivate, ['server_id'], name, value)


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")
                                        self._segment_path = lambda: "ebgp-multihop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.EbgpMultihop, ['max_hop_count', 'mpls_deactivation'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"graceful-maintenance-as-prepends" : ("graceful_maintenance_as_prepends", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends), "graceful-maintenance-local-preference" : ("graceful_maintenance_local_preference", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance, ['enable', 'graceful_maintenance_activate'], name, value)


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")
                                            self._segment_path = lambda: "graceful-maintenance-as-prepends"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, ['as_prepends', 'gshut_prepends_disable'], name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")
                                            self._segment_path = lambda: "graceful-maintenance-local-preference"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, ['gshut_loc_pref_disable', 'local_preference'], name, value)


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "keychain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Keychain, ['keychain_disable', 'keychain_name'], name, value)


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")
                                        self._segment_path = lambda: "local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAddress, ['local_address_disable', 'local_ip_address'], name, value)


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")
                                        self._segment_path = lambda: "local-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.LocalAs, ['as_xx', 'as_yy', 'disable', 'dual_as', 'no_prepend', 'replace_as'], name, value)


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-in"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogIn, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-out"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.MsgLogOut, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class NeighborAfs(Entity):
                                    """
                                    BGP neighbor AF configuration table
                                    
                                    .. attribute:: neighbor_af
                                    
                                    	Address family type of neighbor
                                    	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs, self).__init__()

                                        self.yang_name = "neighbor-afs"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor-af" : ("neighbor_af", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf)}

                                        self.neighbor_af = YList(self)
                                        self._segment_path = lambda: "neighbor-afs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs, [], name, value)


                                    class NeighborAf(Entity):
                                        """
                                        Address family type of neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpn_evpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_l2vpn_evpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: enforce_multiple_labels
                                        
                                        	TRUE to enforce multiple labels support
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf, self).__init__()

                                            self.yang_name = "neighbor-af"
                                            self.yang_parent_name = "neighbor-afs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"advertise-def-imp-disable-v4" : ("advertise_def_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4), "advertise-def-imp-disable-v6" : ("advertise_def_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6), "advertise-disable" : ("advertise_disable", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable), "advertise-l2vpn-evpn" : ("advertise_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn), "advertise-local-l2vpn-evpn" : ("advertise_local_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn), "advertise-local-v4" : ("advertise_local_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4), "advertise-local-v6" : ("advertise_local_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6), "advertise-v4" : ("advertise_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4), "advertise-v6" : ("advertise_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6), "advertise-vrf-imp-disable-v4" : ("advertise_vrf_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4), "advertise-vrf-imp-disable-v6" : ("advertise_vrf_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6), "aigp-cost-community" : ("aigp_cost_community", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity), "default-originate" : ("default_originate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate), "import" : ("import_", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_), "maximum-prefixes" : ("maximum_prefixes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes), "neighbor-af-long-lived-graceful-restart-stale-time" : ("neighbor_af_long_lived_graceful_restart_stale_time", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime), "remove-private-as-entire-as-path" : ("remove_private_as_entire_as_path", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath), "remove-private-as-entire-as-path-inbound" : ("remove_private_as_entire_as_path_inbound", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound), "soft-reconfiguration" : ("soft_reconfiguration", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.enforce_multiple_labels = YLeaf(YType.boolean, "enforce-multiple-labels")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn()
                                            self.advertise_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_l2vpn_evpn"] = "advertise-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-l2vpn-evpn")

                                            self.advertise_local_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn()
                                            self.advertise_local_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_local_l2vpn_evpn"] = "advertise-local-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-local-l2vpn-evpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")
                                            self._segment_path = lambda: "neighbor-af" + "[af-name='" + self.af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf, ['af_name', 'accept_own', 'accept_route_legacy_rt', 'activate', 'advertise_local_labeled_route', 'advertise_orf', 'advertise_permanent_network', 'af_group', 'aigp', 'aigp_send_med', 'allow_as_in', 'as_override', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'flowspec_validation', 'l2vpn_signalling', 'multipath', 'neighbor_af_long_lived_graceful_restart_capable', 'next_hop_self', 'next_hop_unchanged', 'next_hop_unchanged_multipath', 'prefix_orf_policy', 'route_policy_in', 'route_policy_out', 'route_reflector_client', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'send_community_ebgp', 'send_community_ebgp_graceful_shutdown', 'send_ext_community_ebgp', 'send_multicast_attr'], name, value)


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-disable"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseDisable, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseL2VpnEvpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-l2vpn-evpn"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalL2VpnEvpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpn-evpn"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseLocalV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")
                                                self._segment_path = lambda: "aigp-cost-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.AigpCostCommunity, ['cost_community_id', 'cost_community_poi_type', 'enable', 'transitive'], name, value)


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "default-originate"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.DefaultOriginate, ['enable', 'route_policy_name'], name, value)


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")
                                                self._segment_path = lambda: "import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.Import_, ['import_reoriginate', 'import_reoriginate_stitching', 'import_stitching'], name, value)


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")
                                                self._segment_path = lambda: "maximum-prefixes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.MaximumPrefixes, ['discard_extra_paths', 'prefix_limit', 'restart_time', 'warning_only', 'warning_percentage'], name, value)


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")
                                                self._segment_path = lambda: "neighbor-af-long-lived-graceful-restart-stale-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, ['stale_time_accept', 'stale_time_send'], name, value)


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, ['enable', 'entire'], name, value)


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path-inbound"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, ['enable', 'entire'], name, value)


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")
                                                self._segment_path = lambda: "soft-reconfiguration"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborAfs.NeighborAf.SoftReconfiguration, ['inbound_soft', 'soft_always'], name, value)


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                        self._segment_path = lambda: "neighbor-cluster-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.NeighborClusterId, ['cluster_id_address', 'cluster_id_number'], name, value)


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")
                                        self._segment_path = lambda: "password"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Password, ['password', 'password_disable'], name, value)


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                        self._segment_path = lambda: "receive-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.ReceiveBufferSize, ['bgp_receive_size', 'socket_receive_size'], name, value)


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")
                                        self._segment_path = lambda: "remote-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.RemoteAs, ['as_xx', 'as_yy'], name, value)


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                        self._segment_path = lambda: "send-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.SendBufferSize, ['bgp_send_size', 'socket_send_size'], name, value)


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")
                                        self._segment_path = lambda: "tcpmss"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tcpmss, ['mss', 'tcpmss_disable'], name, value)


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                        self._segment_path = lambda: "timers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Timers, ['hold_time', 'keepalive_interval', 'min_accept_hold_time'], name, value)


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")
                                        self._segment_path = lambda: "tos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.Tos, ['type', 'value'], name, value)


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-in-filtering-message-buffers" : ("update_in_filtering_message_buffers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")
                                        self._segment_path = lambda: "update-in-filtering"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering, ['enable', 'update_in_filtering_attribute_filter_group', 'update_in_filtering_syslog_disable'], name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")
                                            self._segment_path = lambda: "update-in-filtering-message-buffers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.Neighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, ['non_circular_buffer', 'number_of_buffers'], name, value)


                            class NeighborPrefixLength(Entity):
                                """
                                A particular BGP peer
                                
                                .. attribute:: prefix_length  <key>
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..127
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgp_ce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut>`
                                
                                .. attribute:: neighbor_afs
                                
                                	BGP neighbor AF configuration table
                                	**type**\:   :py:class:`NeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength, self).__init__()

                                    self.yang_name = "neighbor-prefix-length"
                                    self.yang_parent_name = "neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertisement-interval" : ("advertisement_interval", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval), "bmp-activates" : ("bmp_activates", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates), "ebgp-multihop" : ("ebgp_multihop", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance), "keychain" : ("keychain", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain), "local-address" : ("local_address", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress), "local-as" : ("local_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs), "msg-log-in" : ("msg_log_in", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn), "msg-log-out" : ("msg_log_out", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut), "neighbor-afs" : ("neighbor_afs", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs), "neighbor-cluster-id" : ("neighbor_cluster_id", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId), "password" : ("password", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password), "receive-buffer-size" : ("receive_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize), "remote-as" : ("remote_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs), "send-buffer-size" : ("send_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize), "tcpmss" : ("tcpmss", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss), "timers" : ("timers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers), "tos" : ("tos", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos), "update-in-filtering" : ("update_in_filtering", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering)}
                                    self._child_list_classes = {}

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgp_ce = YLeaf(YType.boolean, "internal-vpn-client-ibgp-ce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs()
                                    self.neighbor_afs.parent = self
                                    self._children_name_map["neighbor_afs"] = "neighbor-afs"
                                    self._children_yang_names.add("neighbor-afs")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")
                                    self._segment_path = lambda: "neighbor-prefix-length" + "[prefix-length='" + self.prefix_length.get() + "']" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength, ['prefix_length', 'neighbor_address', 'additional_paths_receive_capability', 'additional_paths_send_capability', 'bfd_enable_modes', 'bfd_minimum_interval', 'bfd_multiplier', 'description', 'ebgp_recv_dmz', 'ebgp_send_dmz_enable_modes', 'egress_peer_engineering', 'enforce_first_as', 'idle_watch_time', 'ignore_connected_check_ebgp', 'internal_vpn_client_ibgp_ce', 'max_peers', 'neighbor_graceful_restart', 'neighbor_graceful_restart_stalepath_time', 'neighbor_graceful_restart_time', 'neighbor_group_add_member', 'propagate_dmz_link_bandwidth', 'remote_as_list', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'session_group_add_member', 'session_open_mode', 'shutdown', 'suppress_all_capabilities', 'suppress_four_byte_as_capability', 'ttl_security', 'update_source_interface'], name, value)


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")
                                        self._segment_path = lambda: "advertisement-interval"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.AdvertisementInterval, ['minimum_interval', 'minimum_interval_msecs'], name, value)


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-activate" : ("bmp_activate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate)}

                                        self.bmp_activate = YList(self)
                                        self._segment_path = lambda: "bmp-activates"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates, [], name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.server_id = YLeaf(YType.uint32, "server-id")
                                            self._segment_path = lambda: "bmp-activate" + "[server-id='" + self.server_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.BmpActivates.BmpActivate, ['server_id'], name, value)


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")
                                        self._segment_path = lambda: "ebgp-multihop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.EbgpMultihop, ['max_hop_count', 'mpls_deactivation'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"graceful-maintenance-as-prepends" : ("graceful_maintenance_as_prepends", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends), "graceful-maintenance-local-preference" : ("graceful_maintenance_local_preference", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance, ['enable', 'graceful_maintenance_activate'], name, value)


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")
                                            self._segment_path = lambda: "graceful-maintenance-as-prepends"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, ['as_prepends', 'gshut_prepends_disable'], name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")
                                            self._segment_path = lambda: "graceful-maintenance-local-preference"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, ['gshut_loc_pref_disable', 'local_preference'], name, value)


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "keychain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Keychain, ['keychain_disable', 'keychain_name'], name, value)


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")
                                        self._segment_path = lambda: "local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAddress, ['local_address_disable', 'local_ip_address'], name, value)


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")
                                        self._segment_path = lambda: "local-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.LocalAs, ['as_xx', 'as_yy', 'disable', 'dual_as', 'no_prepend', 'replace_as'], name, value)


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-in"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogIn, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-out"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.MsgLogOut, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class NeighborAfs(Entity):
                                    """
                                    BGP neighbor AF configuration table
                                    
                                    .. attribute:: neighbor_af
                                    
                                    	Address family type of neighbor
                                    	**type**\: list of    :py:class:`NeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs, self).__init__()

                                        self.yang_name = "neighbor-afs"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"neighbor-af" : ("neighbor_af", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf)}

                                        self.neighbor_af = YList(self)
                                        self._segment_path = lambda: "neighbor-afs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs, [], name, value)


                                    class NeighborAf(Entity):
                                        """
                                        Address family type of neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpn_evpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_l2vpn_evpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: enforce_multiple_labels
                                        
                                        	TRUE to enforce multiple labels support
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_>`
                                        
                                        .. attribute:: l2vpn_signalling
                                        
                                        	Disable signalling type on the peer
                                        	**type**\:   :py:class:`BgpSignal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSignal>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                        
                                        	RPKI bestpath origin\-AS allow invalid
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: rpki_origin_as_validation_disable
                                        
                                        	RPKI origin\-AS validation disable
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_multicast_attr
                                        
                                        	Config send multicast attribute for this neighbor
                                        	**type**\:   :py:class:`BgpSendMcastAttrCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSendMcastAttrCfg>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf, self).__init__()

                                            self.yang_name = "neighbor-af"
                                            self.yang_parent_name = "neighbor-afs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"advertise-def-imp-disable-v4" : ("advertise_def_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4), "advertise-def-imp-disable-v6" : ("advertise_def_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6), "advertise-disable" : ("advertise_disable", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable), "advertise-l2vpn-evpn" : ("advertise_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn), "advertise-local-l2vpn-evpn" : ("advertise_local_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn), "advertise-local-v4" : ("advertise_local_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4), "advertise-local-v6" : ("advertise_local_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6), "advertise-v4" : ("advertise_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4), "advertise-v6" : ("advertise_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6), "advertise-vrf-imp-disable-v4" : ("advertise_vrf_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4), "advertise-vrf-imp-disable-v6" : ("advertise_vrf_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6), "aigp-cost-community" : ("aigp_cost_community", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity), "default-originate" : ("default_originate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate), "import" : ("import_", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_), "maximum-prefixes" : ("maximum_prefixes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes), "neighbor-af-long-lived-graceful-restart-stale-time" : ("neighbor_af_long_lived_graceful_restart_stale_time", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime), "remove-private-as-entire-as-path" : ("remove_private_as_entire_as_path", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath), "remove-private-as-entire-as-path-inbound" : ("remove_private_as_entire_as_path_inbound", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound), "soft-reconfiguration" : ("soft_reconfiguration", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.enforce_multiple_labels = YLeaf(YType.boolean, "enforce-multiple-labels")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.l2vpn_signalling = YLeaf(YType.enumeration, "l2vpn-signalling")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.send_multicast_attr = YLeaf(YType.enumeration, "send-multicast-attr")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn()
                                            self.advertise_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_l2vpn_evpn"] = "advertise-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-l2vpn-evpn")

                                            self.advertise_local_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn()
                                            self.advertise_local_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_local_l2vpn_evpn"] = "advertise-local-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-local-l2vpn-evpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")
                                            self._segment_path = lambda: "neighbor-af" + "[af-name='" + self.af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf, ['af_name', 'accept_own', 'accept_route_legacy_rt', 'activate', 'advertise_local_labeled_route', 'advertise_orf', 'advertise_permanent_network', 'af_group', 'aigp', 'aigp_send_med', 'allow_as_in', 'as_override', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'flowspec_validation', 'l2vpn_signalling', 'multipath', 'neighbor_af_long_lived_graceful_restart_capable', 'next_hop_self', 'next_hop_unchanged', 'next_hop_unchanged_multipath', 'prefix_orf_policy', 'route_policy_in', 'route_policy_out', 'route_reflector_client', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'send_community_ebgp', 'send_community_ebgp_graceful_shutdown', 'send_ext_community_ebgp', 'send_multicast_attr'], name, value)


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDefImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-disable"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseDisable, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseL2VpnEvpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-l2vpn-evpn"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalL2VpnEvpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpn-evpn"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseLocalV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AdvertiseVrfImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")
                                                self._segment_path = lambda: "aigp-cost-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.AigpCostCommunity, ['cost_community_id', 'cost_community_poi_type', 'enable', 'transitive'], name, value)


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "default-originate"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.DefaultOriginate, ['enable', 'route_policy_name'], name, value)


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")
                                                self._segment_path = lambda: "import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.Import_, ['import_reoriginate', 'import_reoriginate_stitching', 'import_stitching'], name, value)


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")
                                                self._segment_path = lambda: "maximum-prefixes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.MaximumPrefixes, ['discard_extra_paths', 'prefix_limit', 'restart_time', 'warning_only', 'warning_percentage'], name, value)


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")
                                                self._segment_path = lambda: "neighbor-af-long-lived-graceful-restart-stale-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, ['stale_time_accept', 'stale_time_send'], name, value)


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPath, ['enable', 'entire'], name, value)


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path-inbound"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.RemovePrivateAsEntireAsPathInbound, ['enable', 'entire'], name, value)


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")
                                                self._segment_path = lambda: "soft-reconfiguration"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborAfs.NeighborAf.SoftReconfiguration, ['inbound_soft', 'soft_always'], name, value)


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                        self._segment_path = lambda: "neighbor-cluster-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.NeighborClusterId, ['cluster_id_address', 'cluster_id_number'], name, value)


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")
                                        self._segment_path = lambda: "password"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Password, ['password', 'password_disable'], name, value)


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                        self._segment_path = lambda: "receive-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.ReceiveBufferSize, ['bgp_receive_size', 'socket_receive_size'], name, value)


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")
                                        self._segment_path = lambda: "remote-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.RemoteAs, ['as_xx', 'as_yy'], name, value)


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                        self._segment_path = lambda: "send-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.SendBufferSize, ['bgp_send_size', 'socket_send_size'], name, value)


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")
                                        self._segment_path = lambda: "tcpmss"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tcpmss, ['mss', 'tcpmss_disable'], name, value)


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                        self._segment_path = lambda: "timers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Timers, ['hold_time', 'keepalive_interval', 'min_accept_hold_time'], name, value)


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")
                                        self._segment_path = lambda: "tos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.Tos, ['type', 'value'], name, value)


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-in-filtering-message-buffers" : ("update_in_filtering_message_buffers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")
                                        self._segment_path = lambda: "update-in-filtering"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering, ['enable', 'update_in_filtering_attribute_filter_group', 'update_in_filtering_syslog_disable'], name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")
                                            self._segment_path = lambda: "update-in-filtering-message-buffers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.Neighbors.NeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, ['non_circular_buffer', 'number_of_buffers'], name, value)


                        class SessionGroups(Entity):
                            """
                            Session group configuration
                            
                            .. attribute:: session_group
                            
                            	A particular BGP session group
                            	**type**\: list of    :py:class:`SessionGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups, self).__init__()

                                self.yang_name = "session-groups"
                                self.yang_parent_name = "bgp-entity"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"session-group" : ("session_group", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup)}

                                self.session_group = YList(self)
                                self._segment_path = lambda: "session-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups, [], name, value)


                            class SessionGroup(Entity):
                                """
                                A particular BGP session group
                                
                                .. attribute:: session_group_name  <key>
                                
                                	BGP session group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates>`
                                
                                .. attribute:: create
                                
                                	Create this group. Deletion of this object causes deletion of all the objects under NeighborGroup/SessionGroup associated with this object
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgp_ce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup, self).__init__()

                                    self.yang_name = "session-group"
                                    self.yang_parent_name = "session-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertisement-interval" : ("advertisement_interval", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval), "bmp-activates" : ("bmp_activates", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates), "ebgp-multihop" : ("ebgp_multihop", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance), "keychain" : ("keychain", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain), "local-address" : ("local_address", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress), "local-as" : ("local_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs), "msg-log-in" : ("msg_log_in", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn), "msg-log-out" : ("msg_log_out", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut), "neighbor-cluster-id" : ("neighbor_cluster_id", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId), "password" : ("password", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password), "receive-buffer-size" : ("receive_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize), "remote-as" : ("remote_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs), "send-buffer-size" : ("send_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize), "tcpmss" : ("tcpmss", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss), "timers" : ("timers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers), "tos" : ("tos", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos), "update-in-filtering" : ("update_in_filtering", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering)}
                                    self._child_list_classes = {}

                                    self.session_group_name = YLeaf(YType.str, "session-group-name")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.create = YLeaf(YType.empty, "create")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgp_ce = YLeaf(YType.boolean, "internal-vpn-client-ibgp-ce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")
                                    self._segment_path = lambda: "session-group" + "[session-group-name='" + self.session_group_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup, ['session_group_name', 'additional_paths_receive_capability', 'additional_paths_send_capability', 'bfd_enable_modes', 'bfd_minimum_interval', 'bfd_multiplier', 'create', 'description', 'ebgp_recv_dmz', 'ebgp_send_dmz_enable_modes', 'egress_peer_engineering', 'enforce_first_as', 'idle_watch_time', 'ignore_connected_check_ebgp', 'internal_vpn_client_ibgp_ce', 'max_peers', 'neighbor_graceful_restart', 'neighbor_graceful_restart_stalepath_time', 'neighbor_graceful_restart_time', 'propagate_dmz_link_bandwidth', 'remote_as_list', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_origin_as_validation_disable', 'session_group_add_member', 'session_open_mode', 'shutdown', 'suppress_all_capabilities', 'suppress_four_byte_as_capability', 'ttl_security', 'update_source_interface'], name, value)


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")
                                        self._segment_path = lambda: "advertisement-interval"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.AdvertisementInterval, ['minimum_interval', 'minimum_interval_msecs'], name, value)


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-activate" : ("bmp_activate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate)}

                                        self.bmp_activate = YList(self)
                                        self._segment_path = lambda: "bmp-activates"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates, [], name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.server_id = YLeaf(YType.uint32, "server-id")
                                            self._segment_path = lambda: "bmp-activate" + "[server-id='" + self.server_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.BmpActivates.BmpActivate, ['server_id'], name, value)


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")
                                        self._segment_path = lambda: "ebgp-multihop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.EbgpMultihop, ['max_hop_count', 'mpls_deactivation'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"graceful-maintenance-as-prepends" : ("graceful_maintenance_as_prepends", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends), "graceful-maintenance-local-preference" : ("graceful_maintenance_local_preference", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance, ['enable', 'graceful_maintenance_activate'], name, value)


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")
                                            self._segment_path = lambda: "graceful-maintenance-as-prepends"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceAsPrepends, ['as_prepends', 'gshut_prepends_disable'], name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")
                                            self._segment_path = lambda: "graceful-maintenance-local-preference"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.GracefulMaintenance.GracefulMaintenanceLocalPreference, ['gshut_loc_pref_disable', 'local_preference'], name, value)


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "keychain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Keychain, ['keychain_disable', 'keychain_name'], name, value)


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")
                                        self._segment_path = lambda: "local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAddress, ['local_address_disable', 'local_ip_address'], name, value)


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")
                                        self._segment_path = lambda: "local-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.LocalAs, ['as_xx', 'as_yy', 'disable', 'dual_as', 'no_prepend', 'replace_as'], name, value)


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-in"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogIn, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-out"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.MsgLogOut, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                        self._segment_path = lambda: "neighbor-cluster-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.NeighborClusterId, ['cluster_id_address', 'cluster_id_number'], name, value)


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")
                                        self._segment_path = lambda: "password"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Password, ['password', 'password_disable'], name, value)


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                        self._segment_path = lambda: "receive-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.ReceiveBufferSize, ['bgp_receive_size', 'socket_receive_size'], name, value)


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")
                                        self._segment_path = lambda: "remote-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.RemoteAs, ['as_xx', 'as_yy'], name, value)


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                        self._segment_path = lambda: "send-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.SendBufferSize, ['bgp_send_size', 'socket_send_size'], name, value)


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")
                                        self._segment_path = lambda: "tcpmss"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tcpmss, ['mss', 'tcpmss_disable'], name, value)


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                        self._segment_path = lambda: "timers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Timers, ['hold_time', 'keepalive_interval', 'min_accept_hold_time'], name, value)


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")
                                        self._segment_path = lambda: "tos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.Tos, ['type', 'value'], name, value)


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "session-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-in-filtering-message-buffers" : ("update_in_filtering_message_buffers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")
                                        self._segment_path = lambda: "update-in-filtering"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering, ['enable', 'update_in_filtering_attribute_filter_group', 'update_in_filtering_syslog_disable'], name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")
                                            self._segment_path = lambda: "update-in-filtering-message-buffers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.BgpEntity.SessionGroups.SessionGroup.UpdateInFiltering.UpdateInFilteringMessageBuffers, ['non_circular_buffer', 'number_of_buffers'], name, value)


                    class Global_(Entity):
                        """
                        Global default config
                        
                        .. attribute:: as_league
                        
                        	AS League
                        	**type**\:   :py:class:`AsLeague <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague>`
                        
                        .. attribute:: as_list_groups
                        
                        	AS\-list group lists
                        	**type**\:   :py:class:`AsListGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups>`
                        
                        .. attribute:: attribute_filter_groups
                        
                        	Attribute\-filter groups list
                        	**type**\:   :py:class:`AttributeFilterGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups>`
                        
                        .. attribute:: best_path_aigp_ignore
                        
                        	Change default route selection criteria to ignore AIGP unless both paths whichare compared have AIGP attribute
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_as_multipath_relax
                        
                        	Change default multi\-route selection criteria to relax as\-path checking \- only require same aspath length
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_as_path_length
                        
                        	Change default route selection criteria to ignore AS path length
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_confederation_paths
                        
                        	Change default route selection criteria and allow the comparing of MED among confederation paths
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_cost_community
                        
                        	Change default route selection criteria to ignore cost community comparison
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_med_always
                        
                        	Change default route selection criteria and allow comparing of MED from different neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_med_missing
                        
                        	Treat missing MED as the least preferred one
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: best_path_router_id
                        
                        	Change default route selection criteria and compare router\-id for identical EBGP paths
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: bfd
                        
                        	BFD configuration
                        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd>`
                        
                        .. attribute:: cluster_id
                        
                        	Configure Route\-Reflector Cluster\-id
                        	**type**\:   :py:class:`ClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId>`
                        
                        .. attribute:: confederation_domain
                        
                        	Set routing domain confederation AS
                        	**type**\:   :py:class:`ConfederationDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain>`
                        
                        .. attribute:: confederation_peer_ases
                        
                        	Define peer ASes in BGP confederation
                        	**type**\:   :py:class:`ConfederationPeerAses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses>`
                        
                        .. attribute:: default_info_originate
                        
                        	Control distribution of default information
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: default_metric
                        
                        	Default redistributed metric
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: disable_auto_soft_reset
                        
                        	Disable automatic soft peer reset on policy reconfiguration
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_enforce_first_as
                        
                        	Disable enforce the first AS for EBGP routes
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_fast_external_fallover
                        
                        	Disable immediate reset session if a link to a directly connected external peer goes down
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_msg_log
                        
                        	Disable inbound and outbound messagelogging for all neighbors under the vrf
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: disable_neighbor_logging
                        
                        	Disable neighbor change logging
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: enforce_ibgp_out_policy
                        
                        	Allow all attributes to be modified by outbound policy for iBGP peers
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: global_afs
                        
                        	Global AF\-specific configuration
                        	**type**\:   :py:class:`GlobalAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs>`
                        
                        .. attribute:: global_graceful_maintenance_activate
                        
                        	Activate Graceful Maintenance Mode for all neighbors with graceful maintenance config
                        	**type**\:   :py:class:`GlobalGracefulMaintenanceActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate>`
                        
                        .. attribute:: global_scan_time
                        
                        	Configure background scanner interval for generic scanner
                        	**type**\:  int
                        
                        	**range:** 5..3600
                        
                        	**units**\: second
                        
                        	**default value**\: 60
                        
                        .. attribute:: global_timers
                        
                        	Adjust routing timers
                        	**type**\:   :py:class:`GlobalTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers>`
                        
                        .. attribute:: graceful_reset
                        
                        	Reset gracefully if configuration change forces a peer reset
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: graceful_restart
                        
                        	Enable graceful restart support
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: graceful_restart_purge_time
                        
                        	Time before stale routes are purged
                        	**type**\:  int
                        
                        	**range:** 1..6000
                        
                        	**units**\: second
                        
                        	**default value**\: 600
                        
                        .. attribute:: graceful_restart_stalepath_time
                        
                        	Maximum time to wait for restart of GR capable peers
                        	**type**\:  int
                        
                        	**range:** 1..4095
                        
                        	**units**\: second
                        
                        	**default value**\: 360
                        
                        .. attribute:: graceful_restart_time
                        
                        	Restart time advertised to neighbors
                        	**type**\:  int
                        
                        	**range:** 1..4095
                        
                        	**units**\: second
                        
                        	**default value**\: 120
                        
                        .. attribute:: igp_loop_check
                        
                        	Enable AS\-path loop checking for iBGP peers
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: igp_redist_internal
                        
                        	Allow redistribution of iBGP into IGPs (dangerous)
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: install_diversion
                        
                        	Install diversion path to RIB/CEF
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: limits
                        
                        	Maximum number that can be configured
                        	**type**\:   :py:class:`Limits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits>`
                        
                        .. attribute:: local_preference
                        
                        	Configure default local preference
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**default value**\: 100
                        
                        .. attribute:: mpls_activated_interfaces
                        
                        	Configure list of MPLS activated interfaces
                        	**type**\:   :py:class:`MplsActivatedInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces>`
                        
                        .. attribute:: multi_path_as_path_ignore_onwards
                        
                        	Change default multi\-route selection criteria to ignore everything onwards as\-path check
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: mvpn
                        
                        	Connect to PIM/PIM6
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: neighbor_logging_detail
                        
                        	Include extra detail in neighbor change messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: next_hop_trigger_delay
                        
                        	Set the delay for triggering nexthop recalculations
                        	**type**\:  int
                        
                        	**range:** 0..300
                        
                        	**units**\: second
                        
                        	**default value**\: 5
                        
                        .. attribute:: nsr
                        
                        	TRUE to Enable non\-stop routing supportFALSE to Disable non\-stop routing support
                        	**type**\:  bool
                        
                        .. attribute:: read_only
                        
                        	Allow duplicate table config and disable update generation
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: receive_socket_buffer_sizes
                        
                        	Set socket and BGP receive buffer sizes
                        	**type**\:   :py:class:`ReceiveSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes>`
                        
                        .. attribute:: router_id
                        
                        	Configure Router\-id
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**default value**\: 0.0.0.0
                        
                        .. attribute:: rpki_bestpath_origin_as_allow_invalid
                        
                        	RPKI bestpath origin\-AS allow invalid
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_bestpath_use_origin_as_validity
                        
                        	RPKI bestpath use origin\-AS validity
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_origin_as_validation_disable
                        
                        	RPKI origin\-AS validation disable
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_origin_as_validation_time
                        
                        	Prefix validation time (in seconds). Range  \: 5 \- 60. Specify 0 to disable the timer
                        	**type**\:  int
                        
                        	**range:** 0..60
                        
                        	**units**\: second
                        
                        .. attribute:: rpki_origin_as_validity_signal_ibgp
                        
                        	RPKI origin\-AS validity signal ibgp
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: rpki_servers
                        
                        	RPKI server configuration
                        	**type**\:   :py:class:`RpkiServers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers>`
                        
                        .. attribute:: rpki_static_routes
                        
                        	RPKI static route configuration
                        	**type**\:   :py:class:`RpkiStaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes>`
                        
                        .. attribute:: send_socket_buffer_sizes
                        
                        	set socket parameters
                        	**type**\:   :py:class:`SendSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes>`
                        
                        .. attribute:: update_delay
                        
                        	Set the max initial delay for sending updates
                        	**type**\:   :py:class:`UpdateDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay>`
                        
                        .. attribute:: update_error_handling_basic_ebgp_disable
                        
                        	Inbound update basic error\-handling for EBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_error_handling_basic_ibgp_disable
                        
                        	Inbound update basic error\-handling for IBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_error_handling_extended_ebgp
                        
                        	Inbound update extended error\-handling for EBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_error_handling_extended_ibgp
                        
                        	Inbound update extended error\-handling for IBGP neighbors
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: update_limit_process
                        
                        	Upper bound on update generation transient memory usage for the process
                        	**type**\:  int
                        
                        	**range:** 16..2048
                        
                        	**units**\: megabyte
                        
                        	**default value**\: 512
                        
                        .. attribute:: update_out_logging
                        
                        	Enables logging of update generation events
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: write_limit
                        
                        	Set write\-queue limit for each update group
                        	**type**\:   :py:class:`WriteLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-cfg'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_, self).__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "default-vrf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"as-league" : ("as_league", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague), "as-list-groups" : ("as_list_groups", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups), "attribute-filter-groups" : ("attribute_filter_groups", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups), "bfd" : ("bfd", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd), "cluster-id" : ("cluster_id", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId), "confederation-domain" : ("confederation_domain", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain), "confederation-peer-ases" : ("confederation_peer_ases", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses), "global-afs" : ("global_afs", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs), "global-graceful-maintenance-activate" : ("global_graceful_maintenance_activate", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate), "global-timers" : ("global_timers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers), "limits" : ("limits", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits), "mpls-activated-interfaces" : ("mpls_activated_interfaces", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces), "receive-socket-buffer-sizes" : ("receive_socket_buffer_sizes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes), "rpki-servers" : ("rpki_servers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers), "rpki-static-routes" : ("rpki_static_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes), "send-socket-buffer-sizes" : ("send_socket_buffer_sizes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes), "update-delay" : ("update_delay", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay), "write-limit" : ("write_limit", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit)}
                            self._child_list_classes = {}

                            self.best_path_aigp_ignore = YLeaf(YType.empty, "best-path-aigp-ignore")

                            self.best_path_as_multipath_relax = YLeaf(YType.empty, "best-path-as-multipath-relax")

                            self.best_path_as_path_length = YLeaf(YType.empty, "best-path-as-path-length")

                            self.best_path_confederation_paths = YLeaf(YType.empty, "best-path-confederation-paths")

                            self.best_path_cost_community = YLeaf(YType.empty, "best-path-cost-community")

                            self.best_path_med_always = YLeaf(YType.empty, "best-path-med-always")

                            self.best_path_med_missing = YLeaf(YType.empty, "best-path-med-missing")

                            self.best_path_router_id = YLeaf(YType.empty, "best-path-router-id")

                            self.default_info_originate = YLeaf(YType.empty, "default-info-originate")

                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                            self.disable_auto_soft_reset = YLeaf(YType.empty, "disable-auto-soft-reset")

                            self.disable_enforce_first_as = YLeaf(YType.empty, "disable-enforce-first-as")

                            self.disable_fast_external_fallover = YLeaf(YType.empty, "disable-fast-external-fallover")

                            self.disable_msg_log = YLeaf(YType.empty, "disable-msg-log")

                            self.disable_neighbor_logging = YLeaf(YType.empty, "disable-neighbor-logging")

                            self.enforce_ibgp_out_policy = YLeaf(YType.empty, "enforce-ibgp-out-policy")

                            self.global_scan_time = YLeaf(YType.uint32, "global-scan-time")

                            self.graceful_reset = YLeaf(YType.empty, "graceful-reset")

                            self.graceful_restart = YLeaf(YType.empty, "graceful-restart")

                            self.graceful_restart_purge_time = YLeaf(YType.uint32, "graceful-restart-purge-time")

                            self.graceful_restart_stalepath_time = YLeaf(YType.uint32, "graceful-restart-stalepath-time")

                            self.graceful_restart_time = YLeaf(YType.uint32, "graceful-restart-time")

                            self.igp_loop_check = YLeaf(YType.empty, "igp-loop-check")

                            self.igp_redist_internal = YLeaf(YType.empty, "igp-redist-internal")

                            self.install_diversion = YLeaf(YType.empty, "install-diversion")

                            self.local_preference = YLeaf(YType.uint32, "local-preference")

                            self.multi_path_as_path_ignore_onwards = YLeaf(YType.empty, "multi-path-as-path-ignore-onwards")

                            self.mvpn = YLeaf(YType.empty, "mvpn")

                            self.neighbor_logging_detail = YLeaf(YType.empty, "neighbor-logging-detail")

                            self.next_hop_trigger_delay = YLeaf(YType.uint32, "next-hop-trigger-delay")

                            self.nsr = YLeaf(YType.boolean, "nsr")

                            self.read_only = YLeaf(YType.empty, "read-only")

                            self.router_id = YLeaf(YType.str, "router-id")

                            self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                            self.rpki_bestpath_use_origin_as_validity = YLeaf(YType.empty, "rpki-bestpath-use-origin-as-validity")

                            self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                            self.rpki_origin_as_validation_time = YLeaf(YType.uint32, "rpki-origin-as-validation-time")

                            self.rpki_origin_as_validity_signal_ibgp = YLeaf(YType.empty, "rpki-origin-as-validity-signal-ibgp")

                            self.update_error_handling_basic_ebgp_disable = YLeaf(YType.empty, "update-error-handling-basic-ebgp-disable")

                            self.update_error_handling_basic_ibgp_disable = YLeaf(YType.empty, "update-error-handling-basic-ibgp-disable")

                            self.update_error_handling_extended_ebgp = YLeaf(YType.empty, "update-error-handling-extended-ebgp")

                            self.update_error_handling_extended_ibgp = YLeaf(YType.empty, "update-error-handling-extended-ibgp")

                            self.update_limit_process = YLeaf(YType.uint32, "update-limit-process")

                            self.update_out_logging = YLeaf(YType.empty, "update-out-logging")

                            self.as_league = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague()
                            self.as_league.parent = self
                            self._children_name_map["as_league"] = "as-league"
                            self._children_yang_names.add("as-league")

                            self.as_list_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups()
                            self.as_list_groups.parent = self
                            self._children_name_map["as_list_groups"] = "as-list-groups"
                            self._children_yang_names.add("as-list-groups")

                            self.attribute_filter_groups = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups()
                            self.attribute_filter_groups.parent = self
                            self._children_name_map["attribute_filter_groups"] = "attribute-filter-groups"
                            self._children_yang_names.add("attribute-filter-groups")

                            self.bfd = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd()
                            self.bfd.parent = self
                            self._children_name_map["bfd"] = "bfd"
                            self._children_yang_names.add("bfd")

                            self.cluster_id = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId()
                            self.cluster_id.parent = self
                            self._children_name_map["cluster_id"] = "cluster-id"
                            self._children_yang_names.add("cluster-id")

                            self.confederation_domain = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain()
                            self.confederation_domain.parent = self
                            self._children_name_map["confederation_domain"] = "confederation-domain"
                            self._children_yang_names.add("confederation-domain")

                            self.confederation_peer_ases = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses()
                            self.confederation_peer_ases.parent = self
                            self._children_name_map["confederation_peer_ases"] = "confederation-peer-ases"
                            self._children_yang_names.add("confederation-peer-ases")

                            self.global_afs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs()
                            self.global_afs.parent = self
                            self._children_name_map["global_afs"] = "global-afs"
                            self._children_yang_names.add("global-afs")

                            self.global_graceful_maintenance_activate = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate()
                            self.global_graceful_maintenance_activate.parent = self
                            self._children_name_map["global_graceful_maintenance_activate"] = "global-graceful-maintenance-activate"
                            self._children_yang_names.add("global-graceful-maintenance-activate")

                            self.global_timers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers()
                            self.global_timers.parent = self
                            self._children_name_map["global_timers"] = "global-timers"
                            self._children_yang_names.add("global-timers")

                            self.limits = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits()
                            self.limits.parent = self
                            self._children_name_map["limits"] = "limits"
                            self._children_yang_names.add("limits")

                            self.mpls_activated_interfaces = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces()
                            self.mpls_activated_interfaces.parent = self
                            self._children_name_map["mpls_activated_interfaces"] = "mpls-activated-interfaces"
                            self._children_yang_names.add("mpls-activated-interfaces")

                            self.receive_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes()
                            self.receive_socket_buffer_sizes.parent = self
                            self._children_name_map["receive_socket_buffer_sizes"] = "receive-socket-buffer-sizes"
                            self._children_yang_names.add("receive-socket-buffer-sizes")

                            self.rpki_servers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers()
                            self.rpki_servers.parent = self
                            self._children_name_map["rpki_servers"] = "rpki-servers"
                            self._children_yang_names.add("rpki-servers")

                            self.rpki_static_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes()
                            self.rpki_static_routes.parent = self
                            self._children_name_map["rpki_static_routes"] = "rpki-static-routes"
                            self._children_yang_names.add("rpki-static-routes")

                            self.send_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes()
                            self.send_socket_buffer_sizes.parent = self
                            self._children_name_map["send_socket_buffer_sizes"] = "send-socket-buffer-sizes"
                            self._children_yang_names.add("send-socket-buffer-sizes")

                            self.update_delay = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay()
                            self.update_delay.parent = self
                            self._children_name_map["update_delay"] = "update-delay"
                            self._children_yang_names.add("update-delay")

                            self.write_limit = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit()
                            self.write_limit.parent = self
                            self._children_name_map["write_limit"] = "write-limit"
                            self._children_yang_names.add("write-limit")
                            self._segment_path = lambda: "global"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_, ['best_path_aigp_ignore', 'best_path_as_multipath_relax', 'best_path_as_path_length', 'best_path_confederation_paths', 'best_path_cost_community', 'best_path_med_always', 'best_path_med_missing', 'best_path_router_id', 'default_info_originate', 'default_metric', 'disable_auto_soft_reset', 'disable_enforce_first_as', 'disable_fast_external_fallover', 'disable_msg_log', 'disable_neighbor_logging', 'enforce_ibgp_out_policy', 'global_scan_time', 'graceful_reset', 'graceful_restart', 'graceful_restart_purge_time', 'graceful_restart_stalepath_time', 'graceful_restart_time', 'igp_loop_check', 'igp_redist_internal', 'install_diversion', 'local_preference', 'multi_path_as_path_ignore_onwards', 'mvpn', 'neighbor_logging_detail', 'next_hop_trigger_delay', 'nsr', 'read_only', 'router_id', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_bestpath_use_origin_as_validity', 'rpki_origin_as_validation_disable', 'rpki_origin_as_validation_time', 'rpki_origin_as_validity_signal_ibgp', 'update_error_handling_basic_ebgp_disable', 'update_error_handling_basic_ibgp_disable', 'update_error_handling_extended_ebgp', 'update_error_handling_extended_ibgp', 'update_limit_process', 'update_out_logging'], name, value)


                        class AsLeague(Entity):
                            """
                            AS League
                            
                            .. attribute:: enable
                            
                            	AS League creation
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: peers
                            
                            	AS League Peers
                            	**type**\:   :py:class:`Peers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague, self).__init__()

                                self.yang_name = "as-league"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"peers" : ("peers", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers)}
                                self._child_list_classes = {}

                                self.enable = YLeaf(YType.empty, "enable")

                                self.peers = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers()
                                self.peers.parent = self
                                self._children_name_map["peers"] = "peers"
                                self._children_yang_names.add("peers")
                                self._segment_path = lambda: "as-league"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague, ['enable'], name, value)


                            class Peers(Entity):
                                """
                                AS League Peers
                                
                                .. attribute:: peer
                                
                                	AS League Peer AS
                                	**type**\: list of    :py:class:`Peer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers, self).__init__()

                                    self.yang_name = "peers"
                                    self.yang_parent_name = "as-league"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"peer" : ("peer", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer)}

                                    self.peer = YList(self)
                                    self._segment_path = lambda: "peers"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers, [], name, value)


                                class Peer(Entity):
                                    """
                                    AS League Peer AS
                                    
                                    .. attribute:: as_xx  <key>
                                    
                                    	xx of peer AS xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy  <key>
                                    
                                    	yy of peer AS xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer, self).__init__()

                                        self.yang_name = "peer"
                                        self.yang_parent_name = "peers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")
                                        self._segment_path = lambda: "peer" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsLeague.Peers.Peer, ['as_xx', 'as_yy'], name, value)


                        class AsListGroups(Entity):
                            """
                            AS\-list group lists
                            
                            .. attribute:: as_list_group
                            
                            	AS\-List group
                            	**type**\: list of    :py:class:`AsListGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups, self).__init__()

                                self.yang_name = "as-list-groups"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"as-list-group" : ("as_list_group", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup)}

                                self.as_list_group = YList(self)
                                self._segment_path = lambda: "as-list-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups, [], name, value)


                            class AsListGroup(Entity):
                                """
                                AS\-List group
                                
                                .. attribute:: as_list_group_name  <key>
                                
                                	Group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: ases
                                
                                	AS list
                                	**type**\:   :py:class:`Ases <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases>`
                                
                                .. attribute:: enable
                                
                                	AS\-List group creation
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup, self).__init__()

                                    self.yang_name = "as-list-group"
                                    self.yang_parent_name = "as-list-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"ases" : ("ases", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases)}
                                    self._child_list_classes = {}

                                    self.as_list_group_name = YLeaf(YType.str, "as-list-group-name")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.ases = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases()
                                    self.ases.parent = self
                                    self._children_name_map["ases"] = "ases"
                                    self._children_yang_names.add("ases")
                                    self._segment_path = lambda: "as-list-group" + "[as-list-group-name='" + self.as_list_group_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup, ['as_list_group_name', 'enable'], name, value)


                                class Ases(Entity):
                                    """
                                    AS list
                                    
                                    .. attribute:: as_
                                    
                                    	AS\-List group
                                    	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases, self).__init__()

                                        self.yang_name = "ases"
                                        self.yang_parent_name = "as-list-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"as" : ("as_", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_)}

                                        self.as_ = YList(self)
                                        self._segment_path = lambda: "ases"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases, [], name, value)


                                    class As_(Entity):
                                        """
                                        AS\-List group
                                        
                                        .. attribute:: as_xx  <key>
                                        
                                        	xx of AS number/confed peer xx.yy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: as_yy  <key>
                                        
                                        	yy of AS number/confed peer xx.yy
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_, self).__init__()

                                            self.yang_name = "as"
                                            self.yang_parent_name = "ases"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.as_xx = YLeaf(YType.uint32, "as-xx")

                                            self.as_yy = YLeaf(YType.uint32, "as-yy")
                                            self._segment_path = lambda: "as" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AsListGroups.AsListGroup.Ases.As_, ['as_xx', 'as_yy'], name, value)


                        class AttributeFilterGroups(Entity):
                            """
                            Attribute\-filter groups list
                            
                            .. attribute:: attribute_filter_group
                            
                            	Attribute\-filter group
                            	**type**\: list of    :py:class:`AttributeFilterGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups, self).__init__()

                                self.yang_name = "attribute-filter-groups"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"attribute-filter-group" : ("attribute_filter_group", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup)}

                                self.attribute_filter_group = YList(self)
                                self._segment_path = lambda: "attribute-filter-groups"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups, [], name, value)


                            class AttributeFilterGroup(Entity):
                                """
                                Attribute\-filter group
                                
                                .. attribute:: attribute_filter_group_name  <key>
                                
                                	Group name
                                	**type**\:  str
                                
                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                
                                .. attribute:: attribute_filters
                                
                                	Attribute\-filter group attributes list
                                	**type**\:   :py:class:`AttributeFilters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters>`
                                
                                .. attribute:: enable
                                
                                	Attribute\-filter group creation
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup, self).__init__()

                                    self.yang_name = "attribute-filter-group"
                                    self.yang_parent_name = "attribute-filter-groups"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"attribute-filters" : ("attribute_filters", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters)}
                                    self._child_list_classes = {}

                                    self.attribute_filter_group_name = YLeaf(YType.str, "attribute-filter-group-name")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.attribute_filters = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters()
                                    self.attribute_filters.parent = self
                                    self._children_name_map["attribute_filters"] = "attribute-filters"
                                    self._children_yang_names.add("attribute-filters")
                                    self._segment_path = lambda: "attribute-filter-group" + "[attribute-filter-group-name='" + self.attribute_filter_group_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup, ['attribute_filter_group_name', 'enable'], name, value)


                                class AttributeFilters(Entity):
                                    """
                                    Attribute\-filter group attributes list
                                    
                                    .. attribute:: attribute_filter
                                    
                                    	Attribute\-filter group attribute
                                    	**type**\: list of    :py:class:`AttributeFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters, self).__init__()

                                        self.yang_name = "attribute-filters"
                                        self.yang_parent_name = "attribute-filter-group"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"attribute-filter" : ("attribute_filter", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter)}

                                        self.attribute_filter = YList(self)
                                        self._segment_path = lambda: "attribute-filters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters, [], name, value)


                                    class AttributeFilter(Entity):
                                        """
                                        Attribute\-filter group attribute
                                        
                                        .. attribute:: attribute_start  <key>
                                        
                                        	Start of attribute range
                                        	**type**\:  int
                                        
                                        	**range:** 0..256
                                        
                                        .. attribute:: attribute_end  <key>
                                        
                                        	End of attribute range
                                        	**type**\:  int
                                        
                                        	**range:** 0..256
                                        
                                        .. attribute:: filter_action
                                        
                                        	Filtering action
                                        	**type**\:   :py:class:`BgpUpdateFilterAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpUpdateFilterAction>`
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter, self).__init__()

                                            self.yang_name = "attribute-filter"
                                            self.yang_parent_name = "attribute-filters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.attribute_start = YLeaf(YType.uint32, "attribute-start")

                                            self.attribute_end = YLeaf(YType.uint32, "attribute-end")

                                            self.filter_action = YLeaf(YType.enumeration, "filter-action")
                                            self._segment_path = lambda: "attribute-filter" + "[attribute-start='" + self.attribute_start.get() + "']" + "[attribute-end='" + self.attribute_end.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.AttributeFilterGroups.AttributeFilterGroup.AttributeFilters.AttributeFilter, ['attribute_start', 'attribute_end', 'filter_action'], name, value)


                        class Bfd(Entity):
                            """
                            BFD configuration
                            
                            .. attribute:: detection_multiplier
                            
                            	Detection multiplier for BFD sessions created by BGP
                            	**type**\:  int
                            
                            	**range:** 2..16
                            
                            .. attribute:: interval
                            
                            	Hello interval for BFD sessions created by BGP
                            	**type**\:  int
                            
                            	**range:** 3..30000
                            
                            	**units**\: millisecond
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd, self).__init__()

                                self.yang_name = "bfd"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                self.interval = YLeaf(YType.uint32, "interval")
                                self._segment_path = lambda: "bfd"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Bfd, ['detection_multiplier', 'interval'], name, value)


                        class ClusterId(Entity):
                            """
                            Configure Route\-Reflector Cluster\-id
                            
                            .. attribute:: cluster_id_address
                            
                            	Route\-Reflector Cluster ID in IPV4 address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: cluster_id_number
                            
                            	Route\-Reflector Cluster ID as 32 bit quantity
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId, self).__init__()

                                self.yang_name = "cluster-id"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                self._segment_path = lambda: "cluster-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ClusterId, ['cluster_id_address', 'cluster_id_number'], name, value)


                        class ConfederationDomain(Entity):
                            """
                            Set routing domain confederation AS
                            
                            .. attribute:: as_xx
                            
                            	xx of AS number xx.yy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: as_yy
                            
                            	yy of AS number xx.yy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain, self).__init__()

                                self.yang_name = "confederation-domain"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                self.as_yy = YLeaf(YType.uint32, "as-yy")
                                self._segment_path = lambda: "confederation-domain"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationDomain, ['as_xx', 'as_yy'], name, value)


                        class ConfederationPeerAses(Entity):
                            """
                            Define peer ASes in BGP confederation
                            
                            .. attribute:: confederation_peer_as
                            
                            	Confederation peer AS
                            	**type**\: list of    :py:class:`ConfederationPeerAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses, self).__init__()

                                self.yang_name = "confederation-peer-ases"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"confederation-peer-as" : ("confederation_peer_as", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs)}

                                self.confederation_peer_as = YList(self)
                                self._segment_path = lambda: "confederation-peer-ases"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses, [], name, value)


                            class ConfederationPeerAs(Entity):
                                """
                                Confederation peer AS
                                
                                .. attribute:: as_xx  <key>
                                
                                	xx of AS number/confed peer xx.yy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_yy  <key>
                                
                                	yy of AS number/confed peer xx.yy
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs, self).__init__()

                                    self.yang_name = "confederation-peer-as"
                                    self.yang_parent_name = "confederation-peer-ases"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.as_yy = YLeaf(YType.uint32, "as-yy")
                                    self._segment_path = lambda: "confederation-peer-as" + "[as-xx='" + self.as_xx.get() + "']" + "[as-yy='" + self.as_yy.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ConfederationPeerAses.ConfederationPeerAs, ['as_xx', 'as_yy'], name, value)


                        class GlobalAfs(Entity):
                            """
                            Global AF\-specific configuration
                            
                            .. attribute:: global_af
                            
                            	Global AF\-specific configuration
                            	**type**\: list of    :py:class:`GlobalAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs, self).__init__()

                                self.yang_name = "global-afs"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"global-af" : ("global_af", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf)}

                                self.global_af = YList(self)
                                self._segment_path = lambda: "global-afs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs, [], name, value)


                            class GlobalAf(Entity):
                                """
                                Global AF\-specific configuration
                                
                                .. attribute:: af_name  <key>
                                
                                	Address family
                                	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                
                                .. attribute:: additional_paths_receive
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpAfAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAfAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_selection
                                
                                	Configure additional paths selection
                                	**type**\:   :py:class:`AdditionalPathsSelection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection>`
                                
                                .. attribute:: additional_paths_send
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpAfAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAfAdditionalPathsCfg>`
                                
                                .. attribute:: advertise_local_labeled_route_safi_unicast
                                
                                	Enable/disable advertisement of routes with local\-label via Unicast SAFI
                                	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                
                                .. attribute:: aggregate_addresses
                                
                                	Configure BGP aggregate entries
                                	**type**\:   :py:class:`AggregateAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses>`
                                
                                .. attribute:: allocate_label
                                
                                	Label allocation policy
                                	**type**\:   :py:class:`AllocateLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel>`
                                
                                .. attribute:: application_routes
                                
                                	Redistribute information for Application routes
                                	**type**\:   :py:class:`ApplicationRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes>`
                                
                                .. attribute:: attribute_download
                                
                                	Attribute download configuration
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: best_external
                                
                                	TRUE to enable BE FALSE to disable BE inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: connected_routes
                                
                                	Redistribute connected routes
                                	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dampening
                                
                                	Enable route\-flap dampening
                                	**type**\:   :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: disable_as_path_loop_check
                                
                                	Disable outbound AS Path loop check
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: disable_client_to_client_rr
                                
                                	Disable client\-to\-client reflection
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: disable_cluster_client_to_client_rrs
                                
                                	Disable client\-to\-client reflection for a cluster
                                	**type**\:   :py:class:`DisableClusterClientToClientRrs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs>`
                                
                                .. attribute:: disable_default_martian_check
                                
                                	Disable default Martian Check
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: distance
                                
                                	Define an administrative distance
                                	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance>`
                                
                                .. attribute:: domain_distinguisher
                                
                                	<ASN, router\-id> tuple to use to identify the link\-state domain
                                	**type**\:   :py:class:`DomainDistinguisher <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: dynamic_med_interval
                                
                                	Update generation delay (in minutes) after a MED change
                                	**type**\:  int
                                
                                	**range:** 0..10
                                
                                	**units**\: minute
                                
                                	**default value**\: 10
                                
                                .. attribute:: ebgp
                                
                                	Use eBGP multipaths
                                	**type**\:   :py:class:`Ebgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eibgp
                                
                                	Use eiBGP multipaths
                                	**type**\:   :py:class:`Eibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: eigrp_routes
                                
                                	Redistribute information for EIGRP routes
                                	**type**\:   :py:class:`EigrpRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes>`
                                
                                .. attribute:: enable
                                
                                	Enable the address family. Deletion of this object causes deletion of all the objects under GlobalAF/VRFGlobalAF associated with this object 
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: global_table_mcast
                                
                                	Enable global table multicast
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: ibgp
                                
                                	Use iBGP multipaths
                                	**type**\:   :py:class:`Ibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: import_delay
                                
                                	Delay timer to batch import processing
                                	**type**\:   :py:class:`ImportDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: inter_as_install
                                
                                	Enable install remote MVPN routes to PIM in default VRF
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: isis_routes
                                
                                	Redistribute information for IS\-IS routes 
                                	**type**\:   :py:class:`IsisRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes>`
                                
                                .. attribute:: label_delay
                                
                                	Delay timer to batch label processing
                                	**type**\:   :py:class:`LabelDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: label_mode
                                
                                	BGP 6PE/MPLS\-VPN label allocation mode
                                	**type**\:   :py:class:`LabelMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode>`
                                
                                .. attribute:: label_retain
                                
                                	Label retention time in minutes
                                	**type**\:  int
                                
                                	**range:** 3..60
                                
                                	**units**\: minute
                                
                                .. attribute:: label_security_rpf
                                
                                	Calculate label\-security RPF lists and install to RIB/LSD
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: lisp_routes
                                
                                	Redistribute lisp routes
                                	**type**\:   :py:class:`LispRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: mobile_routes
                                
                                	Redistribute mobile routes
                                	**type**\:   :py:class:`MobileRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: next_hop_critical_trigger_delay
                                
                                	Next hop Critical Trigger Delay
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                	**default value**\: 3000
                                
                                .. attribute:: next_hop_non_critical_trigger_delay
                                
                                	Next hop Non\-critical Trigger Delay
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: millisecond
                                
                                	**default value**\: 10000
                                
                                .. attribute:: next_hop_resolution_prefix_length_minimum
                                
                                	Minimum prefix\-length for nexthop resolution
                                	**type**\:  int
                                
                                	**range:** 0..128
                                
                                	**default value**\: 0
                                
                                .. attribute:: next_hop_route_policy
                                
                                	Next hop policy to filter out nexthop notification
                                	**type**\:  str
                                
                                .. attribute:: ospf_routes
                                
                                	Redistribute information for OSPF routes
                                	**type**\:   :py:class:`OspfRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes>`
                                
                                .. attribute:: permanent_network
                                
                                	Route policy for permanent networks
                                	**type**\:  str
                                
                                .. attribute:: reset_weight_on_import
                                
                                	TRUE to reset weight on import. FALSE to not reset and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: retain_rt
                                
                                	Accept received updates with the specified attributes
                                	**type**\:   :py:class:`RetainRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt>`
                                
                                .. attribute:: rip_routes
                                
                                	Redistribute RIP routes
                                	**type**\:   :py:class:`RipRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: rnh_install_format
                                
                                	RNH install format type\: extcomm \- install rnh as opaque and extcomms, extcomm\-only \- install rnh as extcomms only
                                	**type**\:   :py:class:`BgpRnhInstallFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRnhInstallFormat>`
                                
                                .. attribute:: rpki_bestpath_origin_as_allow_invalid
                                
                                	RPKI bestpath origin\-AS allow invalid
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_bestpath_use_origin_as_validity
                                
                                	RPKI bestpath use origin\-AS validity
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validation_disable
                                
                                	RPKI origin\-AS validation disable
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: rpki_origin_as_validity_signal_ibgp
                                
                                	RPKI origin\-AS validity signal ibgp
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: scan_time
                                
                                	Configure background scanner interval for this address family
                                	**type**\:  int
                                
                                	**range:** 5..3600
                                
                                	**units**\: second
                                
                                	**default value**\: 60
                                
                                .. attribute:: segmented_mcast
                                
                                	Enable segmented multicast
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: sourced_networks
                                
                                	Specify a network to announce via BGP
                                	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks>`
                                
                                .. attribute:: static_routes
                                
                                	Redistribute static routes
                                	**type**\:   :py:class:`StaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: subscriber_routes
                                
                                	Redistribute subscriber routes
                                	**type**\:   :py:class:`SubscriberRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: table_policy
                                
                                	Configure policy for installation of routes to RIB
                                	**type**\:  str
                                
                                .. attribute:: update_limit_address_family
                                
                                	Upper bound on update generation transient memory usage for the address\-family
                                	**type**\:  int
                                
                                	**range:** 4..2048
                                
                                	**units**\: megabyte
                                
                                	**default value**\: 256
                                
                                .. attribute:: update_limit_sub_group_ebgp
                                
                                	Upper bound on update generation transient memory usage for every EBGP Sub\-group
                                	**type**\:  int
                                
                                	**range:** 1..512
                                
                                	**units**\: megabyte
                                
                                	**default value**\: 32
                                
                                .. attribute:: update_limit_sub_group_ibgp
                                
                                	Upper bound on update generation transient memory usage for every IBGP Sub\-group
                                	**type**\:  int
                                
                                	**range:** 1..512
                                
                                	**units**\: megabyte
                                
                                	**default value**\: 32
                                
                                .. attribute:: use_igpsr_label
                                
                                	Use IGP SR label for resolution configuration
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: vrf_all
                                
                                	Configurations to be inherited to all vrfs
                                	**type**\:   :py:class:`VrfAll <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll>`
                                
                                .. attribute:: wait_rib_install
                                
                                	Wait for route install before sending updates to neighbors
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf, self).__init__()

                                    self.yang_name = "global-af"
                                    self.yang_parent_name = "global-afs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"additional-paths-selection" : ("additional_paths_selection", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection), "aggregate-addresses" : ("aggregate_addresses", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses), "allocate-label" : ("allocate_label", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel), "application-routes" : ("application_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes), "connected-routes" : ("connected_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes), "dampening" : ("dampening", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening), "disable-cluster-client-to-client-rrs" : ("disable_cluster_client_to_client_rrs", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs), "distance" : ("distance", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance), "domain-distinguisher" : ("domain_distinguisher", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher), "ebgp" : ("ebgp", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp), "eibgp" : ("eibgp", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp), "eigrp-routes" : ("eigrp_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes), "ibgp" : ("ibgp", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp), "import-delay" : ("import_delay", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay), "isis-routes" : ("isis_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes), "label-delay" : ("label_delay", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay), "label-mode" : ("label_mode", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode), "lisp-routes" : ("lisp_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes), "mobile-routes" : ("mobile_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes), "ospf-routes" : ("ospf_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes), "retain-rt" : ("retain_rt", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt), "rip-routes" : ("rip_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes), "sourced-networks" : ("sourced_networks", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks), "static-routes" : ("static_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes), "subscriber-routes" : ("subscriber_routes", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes), "vrf-all" : ("vrf_all", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll)}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.additional_paths_receive = YLeaf(YType.enumeration, "additional-paths-receive")

                                    self.additional_paths_send = YLeaf(YType.enumeration, "additional-paths-send")

                                    self.advertise_local_labeled_route_safi_unicast = YLeaf(YType.enumeration, "advertise-local-labeled-route-safi-unicast")

                                    self.attribute_download = YLeaf(YType.empty, "attribute-download")

                                    self.best_external = YLeaf(YType.boolean, "best-external")

                                    self.disable_as_path_loop_check = YLeaf(YType.empty, "disable-as-path-loop-check")

                                    self.disable_client_to_client_rr = YLeaf(YType.empty, "disable-client-to-client-rr")

                                    self.disable_default_martian_check = YLeaf(YType.empty, "disable-default-martian-check")

                                    self.dynamic_med_interval = YLeaf(YType.uint32, "dynamic-med-interval")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.global_table_mcast = YLeaf(YType.empty, "global-table-mcast")

                                    self.inter_as_install = YLeaf(YType.empty, "inter-as-install")

                                    self.label_retain = YLeaf(YType.uint32, "label-retain")

                                    self.label_security_rpf = YLeaf(YType.empty, "label-security-rpf")

                                    self.next_hop_critical_trigger_delay = YLeaf(YType.uint32, "next-hop-critical-trigger-delay")

                                    self.next_hop_non_critical_trigger_delay = YLeaf(YType.uint32, "next-hop-non-critical-trigger-delay")

                                    self.next_hop_resolution_prefix_length_minimum = YLeaf(YType.uint32, "next-hop-resolution-prefix-length-minimum")

                                    self.next_hop_route_policy = YLeaf(YType.str, "next-hop-route-policy")

                                    self.permanent_network = YLeaf(YType.str, "permanent-network")

                                    self.reset_weight_on_import = YLeaf(YType.boolean, "reset-weight-on-import")

                                    self.rnh_install_format = YLeaf(YType.enumeration, "rnh-install-format")

                                    self.rpki_bestpath_origin_as_allow_invalid = YLeaf(YType.empty, "rpki-bestpath-origin-as-allow-invalid")

                                    self.rpki_bestpath_use_origin_as_validity = YLeaf(YType.empty, "rpki-bestpath-use-origin-as-validity")

                                    self.rpki_origin_as_validation_disable = YLeaf(YType.empty, "rpki-origin-as-validation-disable")

                                    self.rpki_origin_as_validity_signal_ibgp = YLeaf(YType.empty, "rpki-origin-as-validity-signal-ibgp")

                                    self.scan_time = YLeaf(YType.uint32, "scan-time")

                                    self.segmented_mcast = YLeaf(YType.empty, "segmented-mcast")

                                    self.table_policy = YLeaf(YType.str, "table-policy")

                                    self.update_limit_address_family = YLeaf(YType.uint32, "update-limit-address-family")

                                    self.update_limit_sub_group_ebgp = YLeaf(YType.uint32, "update-limit-sub-group-ebgp")

                                    self.update_limit_sub_group_ibgp = YLeaf(YType.uint32, "update-limit-sub-group-ibgp")

                                    self.use_igpsr_label = YLeaf(YType.empty, "use-igpsr-label")

                                    self.wait_rib_install = YLeaf(YType.empty, "wait-rib-install")

                                    self.additional_paths_selection = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection()
                                    self.additional_paths_selection.parent = self
                                    self._children_name_map["additional_paths_selection"] = "additional-paths-selection"
                                    self._children_yang_names.add("additional-paths-selection")

                                    self.aggregate_addresses = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses()
                                    self.aggregate_addresses.parent = self
                                    self._children_name_map["aggregate_addresses"] = "aggregate-addresses"
                                    self._children_yang_names.add("aggregate-addresses")

                                    self.allocate_label = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel()
                                    self.allocate_label.parent = self
                                    self._children_name_map["allocate_label"] = "allocate-label"
                                    self._children_yang_names.add("allocate-label")

                                    self.application_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes()
                                    self.application_routes.parent = self
                                    self._children_name_map["application_routes"] = "application-routes"
                                    self._children_yang_names.add("application-routes")

                                    self.connected_routes = None
                                    self._children_name_map["connected_routes"] = "connected-routes"
                                    self._children_yang_names.add("connected-routes")

                                    self.dampening = None
                                    self._children_name_map["dampening"] = "dampening"
                                    self._children_yang_names.add("dampening")

                                    self.disable_cluster_client_to_client_rrs = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs()
                                    self.disable_cluster_client_to_client_rrs.parent = self
                                    self._children_name_map["disable_cluster_client_to_client_rrs"] = "disable-cluster-client-to-client-rrs"
                                    self._children_yang_names.add("disable-cluster-client-to-client-rrs")

                                    self.distance = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance()
                                    self.distance.parent = self
                                    self._children_name_map["distance"] = "distance"
                                    self._children_yang_names.add("distance")

                                    self.domain_distinguisher = None
                                    self._children_name_map["domain_distinguisher"] = "domain-distinguisher"
                                    self._children_yang_names.add("domain-distinguisher")

                                    self.ebgp = None
                                    self._children_name_map["ebgp"] = "ebgp"
                                    self._children_yang_names.add("ebgp")

                                    self.eibgp = None
                                    self._children_name_map["eibgp"] = "eibgp"
                                    self._children_yang_names.add("eibgp")

                                    self.eigrp_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes()
                                    self.eigrp_routes.parent = self
                                    self._children_name_map["eigrp_routes"] = "eigrp-routes"
                                    self._children_yang_names.add("eigrp-routes")

                                    self.ibgp = None
                                    self._children_name_map["ibgp"] = "ibgp"
                                    self._children_yang_names.add("ibgp")

                                    self.import_delay = None
                                    self._children_name_map["import_delay"] = "import-delay"
                                    self._children_yang_names.add("import-delay")

                                    self.isis_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes()
                                    self.isis_routes.parent = self
                                    self._children_name_map["isis_routes"] = "isis-routes"
                                    self._children_yang_names.add("isis-routes")

                                    self.label_delay = None
                                    self._children_name_map["label_delay"] = "label-delay"
                                    self._children_yang_names.add("label-delay")

                                    self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode()
                                    self.label_mode.parent = self
                                    self._children_name_map["label_mode"] = "label-mode"
                                    self._children_yang_names.add("label-mode")

                                    self.lisp_routes = None
                                    self._children_name_map["lisp_routes"] = "lisp-routes"
                                    self._children_yang_names.add("lisp-routes")

                                    self.mobile_routes = None
                                    self._children_name_map["mobile_routes"] = "mobile-routes"
                                    self._children_yang_names.add("mobile-routes")

                                    self.ospf_routes = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes()
                                    self.ospf_routes.parent = self
                                    self._children_name_map["ospf_routes"] = "ospf-routes"
                                    self._children_yang_names.add("ospf-routes")

                                    self.retain_rt = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt()
                                    self.retain_rt.parent = self
                                    self._children_name_map["retain_rt"] = "retain-rt"
                                    self._children_yang_names.add("retain-rt")

                                    self.rip_routes = None
                                    self._children_name_map["rip_routes"] = "rip-routes"
                                    self._children_yang_names.add("rip-routes")

                                    self.sourced_networks = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks()
                                    self.sourced_networks.parent = self
                                    self._children_name_map["sourced_networks"] = "sourced-networks"
                                    self._children_yang_names.add("sourced-networks")

                                    self.static_routes = None
                                    self._children_name_map["static_routes"] = "static-routes"
                                    self._children_yang_names.add("static-routes")

                                    self.subscriber_routes = None
                                    self._children_name_map["subscriber_routes"] = "subscriber-routes"
                                    self._children_yang_names.add("subscriber-routes")

                                    self.vrf_all = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll()
                                    self.vrf_all.parent = self
                                    self._children_name_map["vrf_all"] = "vrf-all"
                                    self._children_yang_names.add("vrf-all")
                                    self._segment_path = lambda: "global-af" + "[af-name='" + self.af_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf, ['af_name', 'additional_paths_receive', 'additional_paths_send', 'advertise_local_labeled_route_safi_unicast', 'attribute_download', 'best_external', 'disable_as_path_loop_check', 'disable_client_to_client_rr', 'disable_default_martian_check', 'dynamic_med_interval', 'enable', 'global_table_mcast', 'inter_as_install', 'label_retain', 'label_security_rpf', 'next_hop_critical_trigger_delay', 'next_hop_non_critical_trigger_delay', 'next_hop_resolution_prefix_length_minimum', 'next_hop_route_policy', 'permanent_network', 'reset_weight_on_import', 'rnh_install_format', 'rpki_bestpath_origin_as_allow_invalid', 'rpki_bestpath_use_origin_as_validity', 'rpki_origin_as_validation_disable', 'rpki_origin_as_validity_signal_ibgp', 'scan_time', 'segmented_mcast', 'table_policy', 'update_limit_address_family', 'update_limit_sub_group_ebgp', 'update_limit_sub_group_ibgp', 'use_igpsr_label', 'wait_rib_install'], name, value)


                                class AdditionalPathsSelection(Entity):
                                    """
                                    Configure additional paths selection
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy for selection
                                    	**type**\:  str
                                    
                                    .. attribute:: selection
                                    
                                    	Enable/disable selection 
                                    	**type**\:   :py:class:`BgpAfAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAfAdditionalPathsCfg>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection, self).__init__()

                                        self.yang_name = "additional-paths-selection"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.selection = YLeaf(YType.enumeration, "selection")
                                        self._segment_path = lambda: "additional-paths-selection"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AdditionalPathsSelection, ['route_policy_name', 'selection'], name, value)


                                class AggregateAddresses(Entity):
                                    """
                                    Configure BGP aggregate entries
                                    
                                    .. attribute:: aggregate_address
                                    
                                    	Aggregate address configuration
                                    	**type**\: list of    :py:class:`AggregateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses, self).__init__()

                                        self.yang_name = "aggregate-addresses"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"aggregate-address" : ("aggregate_address", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress)}

                                        self.aggregate_address = YList(self)
                                        self._segment_path = lambda: "aggregate-addresses"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses, [], name, value)


                                    class AggregateAddress(Entity):
                                        """
                                        Aggregate address configuration
                                        
                                        .. attribute:: aggregate_addr  <key>
                                        
                                        	Aggregate in prefix/length format (address part)
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: aggregate_prefix  <key>
                                        
                                        	Aggregate in prefix/length format (prefix part)
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: generate_confederation_set_info
                                        
                                        	TRUE to generate AS confederation set path information, FALSE otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: generate_set_info
                                        
                                        	TRUE to generate AS set path information, FALSE otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy on which to condition advertisement, suppression, and attributes
                                        	**type**\:  str
                                        
                                        .. attribute:: summary_only
                                        
                                        	TRUE to filter more specific routes from updates, FALSEotherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress, self).__init__()

                                            self.yang_name = "aggregate-address"
                                            self.yang_parent_name = "aggregate-addresses"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.aggregate_addr = YLeaf(YType.str, "aggregate-addr")

                                            self.aggregate_prefix = YLeaf(YType.uint16, "aggregate-prefix")

                                            self.generate_confederation_set_info = YLeaf(YType.boolean, "generate-confederation-set-info")

                                            self.generate_set_info = YLeaf(YType.boolean, "generate-set-info")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            self.summary_only = YLeaf(YType.boolean, "summary-only")
                                            self._segment_path = lambda: "aggregate-address" + "[aggregate-addr='" + self.aggregate_addr.get() + "']" + "[aggregate-prefix='" + self.aggregate_prefix.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AggregateAddresses.AggregateAddress, ['aggregate_addr', 'aggregate_prefix', 'generate_confederation_set_info', 'generate_set_info', 'route_policy_name', 'summary_only'], name, value)


                                class AllocateLabel(Entity):
                                    """
                                    Label allocation policy
                                    
                                    .. attribute:: all
                                    
                                    	Whether all nets should be labeled, default is FALSE
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel, self).__init__()

                                        self.yang_name = "allocate-label"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.all = YLeaf(YType.boolean, "all")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "allocate-label"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.AllocateLabel, ['all', 'route_policy_name'], name, value)


                                class ApplicationRoutes(Entity):
                                    """
                                    Redistribute information for Application routes.
                                    
                                    .. attribute:: application_route
                                    
                                    	Redistribute application routes
                                    	**type**\: list of    :py:class:`ApplicationRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes, self).__init__()

                                        self.yang_name = "application-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"application-route" : ("application_route", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute)}

                                        self.application_route = YList(self)
                                        self._segment_path = lambda: "application-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes, [], name, value)


                                    class ApplicationRoute(Entity):
                                        """
                                        Redistribute application routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	OnePK application name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute, self).__init__()

                                            self.yang_name = "application-route"
                                            self.yang_parent_name = "application-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "application-route" + "[instance-name='" + self.instance_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ApplicationRoutes.ApplicationRoute, ['instance_name', 'default_metric', 'not_used', 'route_policy_name'], name, value)


                                class ConnectedRoutes(Entity):
                                    """
                                    Redistribute connected routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes, self).__init__()

                                        self.yang_name = "connected-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "connected-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ConnectedRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                class Dampening(Entity):
                                    """
                                    Enable route\-flap dampening
                                    
                                    .. attribute:: half_life
                                    
                                    	Half\-life time for the penalty (minutes)
                                    	**type**\:  int
                                    
                                    	**range:** 1..45
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: reuse_threshold
                                    
                                    	Value to start reusing a route
                                    	**type**\:  int
                                    
                                    	**range:** 1..20000
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy to specify criteria for dampening. This cannot be specified if any other parameters are specified
                                    	**type**\:  str
                                    
                                    .. attribute:: suppress_threshold
                                    
                                    	Value to start suppressing a route
                                    	**type**\:  int
                                    
                                    	**range:** 1..20000
                                    
                                    .. attribute:: suppress_time
                                    
                                    	Maximum duration to suppress a stable route (seconds)
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**units**\: second
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening, self).__init__()

                                        self.yang_name = "dampening"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.half_life = YLeaf(YType.uint32, "half-life")

                                        self.reuse_threshold = YLeaf(YType.uint32, "reuse-threshold")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                        self.suppress_threshold = YLeaf(YType.uint32, "suppress-threshold")

                                        self.suppress_time = YLeaf(YType.uint32, "suppress-time")
                                        self._segment_path = lambda: "dampening"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Dampening, ['half_life', 'reuse_threshold', 'route_policy_name', 'suppress_threshold', 'suppress_time'], name, value)


                                class DisableClusterClientToClientRrs(Entity):
                                    """
                                    Disable client\-to\-client reflection for a
                                    cluster
                                    
                                    .. attribute:: disable_cluster_client_to_client_rr
                                    
                                    	Cluster ID for which reflection is to be disbled
                                    	**type**\: list of    :py:class:`DisableClusterClientToClientRr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs, self).__init__()

                                        self.yang_name = "disable-cluster-client-to-client-rrs"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"disable-cluster-client-to-client-rr" : ("disable_cluster_client_to_client_rr", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr)}

                                        self.disable_cluster_client_to_client_rr = YList(self)
                                        self._segment_path = lambda: "disable-cluster-client-to-client-rrs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs, [], name, value)


                                    class DisableClusterClientToClientRr(Entity):
                                        """
                                        Cluster ID for which reflection is to be
                                        disbled
                                        
                                        .. attribute:: cluster_type  <key>
                                        
                                        	Type of cluster\-id
                                        	**type**\:   :py:class:`BgpClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpClusterId>`
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	ipv4 address
                                        	**type**\: list of    :py:class:`Ipv4Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address>`
                                        
                                        .. attribute:: number
                                        
                                        	number
                                        	**type**\: list of    :py:class:`Number <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr, self).__init__()

                                            self.yang_name = "disable-cluster-client-to-client-rr"
                                            self.yang_parent_name = "disable-cluster-client-to-client-rrs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"ipv4-address" : ("ipv4_address", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address), "number" : ("number", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number)}

                                            self.cluster_type = YLeaf(YType.enumeration, "cluster-type")

                                            self.ipv4_address = YList(self)
                                            self.number = YList(self)
                                            self._segment_path = lambda: "disable-cluster-client-to-client-rr" + "[cluster-type='" + self.cluster_type.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr, ['cluster_type'], name, value)


                                        class Ipv4Address(Entity):
                                            """
                                            ipv4 address
                                            
                                            .. attribute:: cluster_id_address  <key>
                                            
                                            	Cluster ID\: if configured as an IP Address
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address, self).__init__()

                                                self.yang_name = "ipv4-address"
                                                self.yang_parent_name = "disable-cluster-client-to-client-rr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")
                                                self._segment_path = lambda: "ipv4-address" + "[cluster-id-address='" + self.cluster_id_address.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Ipv4Address, ['cluster_id_address'], name, value)


                                        class Number(Entity):
                                            """
                                            number
                                            
                                            .. attribute:: cluster_id_number  <key>
                                            
                                            	Cluster ID\: if configured as a number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number, self).__init__()

                                                self.yang_name = "number"
                                                self.yang_parent_name = "disable-cluster-client-to-client-rr"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                                self._segment_path = lambda: "number" + "[cluster-id-number='" + self.cluster_id_number.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DisableClusterClientToClientRrs.DisableClusterClientToClientRr.Number, ['cluster_id_number'], name, value)


                                class Distance(Entity):
                                    """
                                    Define an administrative distance
                                    
                                    .. attribute:: external_routes
                                    
                                    	Distance for routes external to the AS
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 20
                                    
                                    .. attribute:: internal_routes
                                    
                                    	Distance for routes internal to the AS
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 200
                                    
                                    .. attribute:: local_routes
                                    
                                    	Distance for local routes
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 200
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance, self).__init__()

                                        self.yang_name = "distance"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.external_routes = YLeaf(YType.uint32, "external-routes")

                                        self.internal_routes = YLeaf(YType.uint32, "internal-routes")

                                        self.local_routes = YLeaf(YType.uint32, "local-routes")
                                        self._segment_path = lambda: "distance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Distance, ['external_routes', 'internal_routes', 'local_routes'], name, value)


                                class DomainDistinguisher(Entity):
                                    """
                                    <ASN, router\-id> tuple to use to identify
                                    the link\-state domain
                                    
                                    .. attribute:: as_
                                    
                                    	AS Number
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: router_id
                                    
                                    	Router ID
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    	**mandatory**\: True
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher, self).__init__()

                                        self.yang_name = "domain-distinguisher"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.as_ = YLeaf(YType.uint32, "as")

                                        self.router_id = YLeaf(YType.str, "router-id")
                                        self._segment_path = lambda: "domain-distinguisher"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.DomainDistinguisher, ['as_', 'router_id'], name, value)


                                class Ebgp(Entity):
                                    """
                                    Use eBGP multipaths
                                    
                                    .. attribute:: order_by_igp_metric
                                    
                                    	Order candidate multipaths by IGP metric
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: paths_value
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 2..64
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: selective
                                    
                                    	Allow multipaths only from marked neighbors
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	UNUSED
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp, self).__init__()

                                        self.yang_name = "ebgp"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                        self.paths_value = YLeaf(YType.uint32, "paths-value")

                                        self.selective = YLeaf(YType.boolean, "selective")

                                        self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")
                                        self._segment_path = lambda: "ebgp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ebgp, ['order_by_igp_metric', 'paths_value', 'selective', 'unequal_cost'], name, value)


                                class Eibgp(Entity):
                                    """
                                    Use eiBGP multipaths
                                    
                                    .. attribute:: order_by_igp_metric
                                    
                                    	Order candidate multipaths by IGP metric
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: paths_value
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 2..64
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: selective
                                    
                                    	Allow multipaths only from marked neighbors
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	UNUSED
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp, self).__init__()

                                        self.yang_name = "eibgp"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                        self.paths_value = YLeaf(YType.uint32, "paths-value")

                                        self.selective = YLeaf(YType.boolean, "selective")

                                        self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")
                                        self._segment_path = lambda: "eibgp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Eibgp, ['order_by_igp_metric', 'paths_value', 'selective', 'unequal_cost'], name, value)


                                class EigrpRoutes(Entity):
                                    """
                                    Redistribute information for EIGRP routes.
                                    
                                    .. attribute:: eigrp_route
                                    
                                    	Redistribute EIGRP routes
                                    	**type**\: list of    :py:class:`EigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes, self).__init__()

                                        self.yang_name = "eigrp-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"eigrp-route" : ("eigrp_route", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute)}

                                        self.eigrp_route = YList(self)
                                        self._segment_path = lambda: "eigrp-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes, [], name, value)


                                    class EigrpRoute(Entity):
                                        """
                                        Redistribute EIGRP routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	EIGRP router tag
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: redist_type
                                        
                                        	Redistribution type\: 01 for internal routes, 02 for external routes, Logical combinations permitted
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute, self).__init__()

                                            self.yang_name = "eigrp-route"
                                            self.yang_parent_name = "eigrp-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.redist_type = YLeaf(YType.str, "redist-type")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "eigrp-route" + "[instance-name='" + self.instance_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.EigrpRoutes.EigrpRoute, ['instance_name', 'default_metric', 'redist_type', 'route_policy_name'], name, value)


                                class Ibgp(Entity):
                                    """
                                    Use iBGP multipaths
                                    
                                    .. attribute:: order_by_igp_metric
                                    
                                    	Order candidate multipaths by IGP metric
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: paths_value
                                    
                                    	Number of paths
                                    	**type**\:  int
                                    
                                    	**range:** 2..64
                                    
                                    	**mandatory**\: True
                                    
                                    .. attribute:: selective
                                    
                                    	Allow multipaths only from marked neighbors
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    .. attribute:: unequal_cost
                                    
                                    	Allow multipaths to have different IGP metrics
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp, self).__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                        self.paths_value = YLeaf(YType.uint32, "paths-value")

                                        self.selective = YLeaf(YType.boolean, "selective")

                                        self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")
                                        self._segment_path = lambda: "ibgp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.Ibgp, ['order_by_igp_metric', 'paths_value', 'selective', 'unequal_cost'], name, value)


                                class ImportDelay(Entity):
                                    """
                                    Delay timer to batch import processing.
                                    
                                    .. attribute:: milliseconds
                                    
                                    	Delay, milliseconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Delay, seconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..10
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay, self).__init__()

                                        self.yang_name = "import-delay"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.milliseconds = YLeaf(YType.uint32, "milliseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "import-delay"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.ImportDelay, ['milliseconds', 'seconds'], name, value)


                                class IsisRoutes(Entity):
                                    """
                                    Redistribute information for IS\-IS routes
                                    .
                                    
                                    .. attribute:: isis_route
                                    
                                    	Redistribute IS\-IS routes
                                    	**type**\: list of    :py:class:`IsisRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes, self).__init__()

                                        self.yang_name = "isis-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"isis-route" : ("isis_route", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute)}

                                        self.isis_route = YList(self)
                                        self._segment_path = lambda: "isis-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes, [], name, value)


                                    class IsisRoute(Entity):
                                        """
                                        Redistribute IS\-IS routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	IS\-IS instance name
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: redist_type
                                        
                                        	Redistribution type\: 01 for level 1 routes, 02 for level 2 routes, 04 for level 1 inter\-area routes. Logical combinations permitted
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute, self).__init__()

                                            self.yang_name = "isis-route"
                                            self.yang_parent_name = "isis-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.redist_type = YLeaf(YType.str, "redist-type")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "isis-route" + "[instance-name='" + self.instance_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.IsisRoutes.IsisRoute, ['instance_name', 'default_metric', 'redist_type', 'route_policy_name'], name, value)


                                class LabelDelay(Entity):
                                    """
                                    Delay timer to batch label processing.
                                    
                                    .. attribute:: milliseconds
                                    
                                    	Delay, milliseconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: millisecond
                                    
                                    .. attribute:: seconds
                                    
                                    	Delay, seconds part
                                    	**type**\:  int
                                    
                                    	**range:** 0..10
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay, self).__init__()

                                        self.yang_name = "label-delay"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.milliseconds = YLeaf(YType.uint32, "milliseconds")

                                        self.seconds = YLeaf(YType.uint32, "seconds")
                                        self._segment_path = lambda: "label-delay"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelDelay, ['milliseconds', 'seconds'], name, value)


                                class LabelMode(Entity):
                                    """
                                    BGP 6PE/MPLS\-VPN label allocation mode
                                    
                                    .. attribute:: label_allocation_mode
                                    
                                    	Label allocation mode\: per\-ce  Set per CE label mode, per\-vrf Set per VRF label mode, per\-prefix Set per Prefix label mode (for MPLS\-VPN only)
                                    	**type**\:  str
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Label mode route policy name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode, self).__init__()

                                        self.yang_name = "label-mode"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.label_allocation_mode = YLeaf(YType.str, "label-allocation-mode")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "label-mode"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LabelMode, ['label_allocation_mode', 'route_policy_name'], name, value)


                                class LispRoutes(Entity):
                                    """
                                    Redistribute lisp routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes, self).__init__()

                                        self.yang_name = "lisp-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "lisp-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.LispRoutes, ['default_metric', 'route_policy_name'], name, value)


                                class MobileRoutes(Entity):
                                    """
                                    Redistribute mobile routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes, self).__init__()

                                        self.yang_name = "mobile-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "mobile-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.MobileRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                class OspfRoutes(Entity):
                                    """
                                    Redistribute information for OSPF routes.
                                    
                                    .. attribute:: ospf_route
                                    
                                    	Redistribute OSPF routes
                                    	**type**\: list of    :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes, self).__init__()

                                        self.yang_name = "ospf-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"ospf-route" : ("ospf_route", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute)}

                                        self.ospf_route = YList(self)
                                        self._segment_path = lambda: "ospf-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes, [], name, value)


                                    class OspfRoute(Entity):
                                        """
                                        Redistribute OSPF routes
                                        
                                        .. attribute:: instance_name  <key>
                                        
                                        	OSPF router tag
                                        	**type**\:  str
                                        
                                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: redist_type
                                        
                                        	Redistribution type\: 01 for internal routes, 02 for external routes of type 1, 04 for external routes of type 2, 08 for NSSA external routes of type 1, 10 for NSSA external routes of type 2, 20 for external routes, 40 for NSSA external routes.  Logical combinations permitted
                                        	**type**\:  str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{1,8}
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute, self).__init__()

                                            self.yang_name = "ospf-route"
                                            self.yang_parent_name = "ospf-routes"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.instance_name = YLeaf(YType.str, "instance-name")

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.redist_type = YLeaf(YType.str, "redist-type")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "ospf-route" + "[instance-name='" + self.instance_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.OspfRoutes.OspfRoute, ['instance_name', 'default_metric', 'redist_type', 'route_policy_name'], name, value)


                                class RetainRt(Entity):
                                    """
                                    Accept received updates with the
                                    specified attributes
                                    
                                    .. attribute:: all
                                    
                                    	Whether all RTs are to be retained, default is FALSE
                                    	**type**\:  bool
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt, self).__init__()

                                        self.yang_name = "retain-rt"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.all = YLeaf(YType.boolean, "all")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "retain-rt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RetainRt, ['all', 'route_policy_name'], name, value)


                                class RipRoutes(Entity):
                                    """
                                    Redistribute RIP routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes, self).__init__()

                                        self.yang_name = "rip-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "rip-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.RipRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                class SourcedNetworks(Entity):
                                    """
                                    Specify a network to announce via BGP
                                    
                                    .. attribute:: sourced_network
                                    
                                    	Sourced network configuration
                                    	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks, self).__init__()

                                        self.yang_name = "sourced-networks"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"sourced-network" : ("sourced_network", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork)}

                                        self.sourced_network = YList(self)
                                        self._segment_path = lambda: "sourced-networks"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks, [], name, value)


                                    class SourcedNetwork(Entity):
                                        """
                                        Sourced network configuration
                                        
                                        .. attribute:: network_addr  <key>
                                        
                                        	Network in prefix/length format (address part)
                                        	**type**\: one of the below types:
                                        
                                        	**type**\:  str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        	**type**\:  str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        
                                        ----
                                        .. attribute:: network_prefix  <key>
                                        
                                        	Network in prefix/length format (prefix part)
                                        	**type**\:  int
                                        
                                        	**range:** 0..128
                                        
                                        .. attribute:: backdoor
                                        
                                        	Specify a BGP backdoor route, default is FALSE
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork, self).__init__()

                                            self.yang_name = "sourced-network"
                                            self.yang_parent_name = "sourced-networks"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.network_addr = YLeaf(YType.str, "network-addr")

                                            self.network_prefix = YLeaf(YType.uint16, "network-prefix")

                                            self.backdoor = YLeaf(YType.boolean, "backdoor")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "sourced-network" + "[network-addr='" + self.network_addr.get() + "']" + "[network-prefix='" + self.network_prefix.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SourcedNetworks.SourcedNetwork, ['network_addr', 'network_prefix', 'backdoor', 'route_policy_name'], name, value)


                                class StaticRoutes(Entity):
                                    """
                                    Redistribute static routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes, self).__init__()

                                        self.yang_name = "static-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "static-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.StaticRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                class SubscriberRoutes(Entity):
                                    """
                                    Redistribute subscriber routes
                                    
                                    .. attribute:: default_metric
                                    
                                    	Default metric
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: not_used
                                    
                                    	Not used
                                    	**type**\:  int
                                    
                                    	**range:** 0..127
                                    
                                    .. attribute:: route_policy_name
                                    
                                    	Route policy name
                                    	**type**\:  str
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes, self).__init__()

                                        self.yang_name = "subscriber-routes"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.default_metric = YLeaf(YType.uint32, "default-metric")

                                        self.not_used = YLeaf(YType.uint32, "not-used")

                                        self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                        self._segment_path = lambda: "subscriber-routes"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.SubscriberRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                class VrfAll(Entity):
                                    """
                                    Configurations to be inherited to all
                                    vrfs
                                    
                                    .. attribute:: enable
                                    
                                    	Enable vrf all configuration submode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: label_mode
                                    
                                    	MPLS\-VPN label allocation mode
                                    	**type**\:   :py:class:`LabelMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode>`
                                    
                                    .. attribute:: rnh_install_format
                                    
                                    	RNH install format type\: extcomm \- install rnh as opaque and extcomms, extcomm\-only \- install rnh as extcomms only
                                    	**type**\:   :py:class:`BgpRnhInstallFormat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRnhInstallFormat>`
                                    
                                    .. attribute:: source_rt_import_policy
                                    
                                    	Enable sourcing of import route\-targets  from import\-policy
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: table_policy
                                    
                                    	Configure policy for installation of routes to RIB
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll, self).__init__()

                                        self.yang_name = "vrf-all"
                                        self.yang_parent_name = "global-af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"label-mode" : ("label_mode", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.rnh_install_format = YLeaf(YType.enumeration, "rnh-install-format")

                                        self.source_rt_import_policy = YLeaf(YType.empty, "source-rt-import-policy")

                                        self.table_policy = YLeaf(YType.str, "table-policy")

                                        self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode()
                                        self.label_mode.parent = self
                                        self._children_name_map["label_mode"] = "label-mode"
                                        self._children_yang_names.add("label-mode")
                                        self._segment_path = lambda: "vrf-all"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll, ['enable', 'rnh_install_format', 'source_rt_import_policy', 'table_policy'], name, value)


                                    class LabelMode(Entity):
                                        """
                                        MPLS\-VPN label allocation mode
                                        
                                        .. attribute:: label_allocation_mode
                                        
                                        	Label allocation mode\: per\-ce  Set per CE label mode, per\-vrf Set per VRF label mode
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Label mode route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode, self).__init__()

                                            self.yang_name = "label-mode"
                                            self.yang_parent_name = "vrf-all"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_allocation_mode = YLeaf(YType.str, "label-allocation-mode")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "label-mode"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalAfs.GlobalAf.VrfAll.LabelMode, ['label_allocation_mode', 'route_policy_name'], name, value)


                        class GlobalGracefulMaintenanceActivate(Entity):
                            """
                            Activate Graceful Maintenance Mode for all
                            neighbors with graceful maintenance config
                            
                            .. attribute:: all_neighbors
                            
                            	Also for neighbors without graceful maintenance config
                            	**type**\:  bool
                            
                            .. attribute:: retain_routes
                            
                            	Keep routes in RIB once BGP stops
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate, self).__init__()

                                self.yang_name = "global-graceful-maintenance-activate"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.all_neighbors = YLeaf(YType.boolean, "all-neighbors")

                                self.retain_routes = YLeaf(YType.boolean, "retain-routes")
                                self._segment_path = lambda: "global-graceful-maintenance-activate"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalGracefulMaintenanceActivate, ['all_neighbors', 'retain_routes'], name, value)


                        class GlobalTimers(Entity):
                            """
                            Adjust routing timers.
                            
                            .. attribute:: hold_time
                            
                            	Hold time (seconds).  Specify 0 to disable keepalives/hold time
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 180
                            
                            .. attribute:: keepalive
                            
                            	Keepalive interval (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 60
                            
                            .. attribute:: min_accept_hold_time
                            
                            	Minimum acceptable hold time (seconds). Specify 0 to disable keepalives/hold time
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            	**default value**\: 3
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers, self).__init__()

                                self.yang_name = "global-timers"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.hold_time = YLeaf(YType.uint32, "hold-time")

                                self.keepalive = YLeaf(YType.uint32, "keepalive")

                                self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                self._segment_path = lambda: "global-timers"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.GlobalTimers, ['hold_time', 'keepalive', 'min_accept_hold_time'], name, value)


                        class Limits(Entity):
                            """
                            Maximum number that can be configured
                            
                            .. attribute:: maximum_neighbors
                            
                            	Maximum number of neighbors that can be configured
                            	**type**\:  int
                            
                            	**range:** 1..15000
                            
                            	**default value**\: 10000
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits, self).__init__()

                                self.yang_name = "limits"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.maximum_neighbors = YLeaf(YType.uint32, "maximum-neighbors")
                                self._segment_path = lambda: "limits"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.Limits, ['maximum_neighbors'], name, value)


                        class MplsActivatedInterfaces(Entity):
                            """
                            Configure list of MPLS activated interfaces
                            
                            .. attribute:: mpls_activated_interface
                            
                            	Configure a MPLS activated interface
                            	**type**\: list of    :py:class:`MplsActivatedInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces, self).__init__()

                                self.yang_name = "mpls-activated-interfaces"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"mpls-activated-interface" : ("mpls_activated_interface", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface)}

                                self.mpls_activated_interface = YList(self)
                                self._segment_path = lambda: "mpls-activated-interfaces"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces, [], name, value)


                            class MplsActivatedInterface(Entity):
                                """
                                Configure a MPLS activated interface
                                
                                .. attribute:: interface_name  <key>
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface, self).__init__()

                                    self.yang_name = "mpls-activated-interface"
                                    self.yang_parent_name = "mpls-activated-interfaces"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.interface_name = YLeaf(YType.str, "interface-name")
                                    self._segment_path = lambda: "mpls-activated-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.MplsActivatedInterfaces.MplsActivatedInterface, ['interface_name'], name, value)


                        class ReceiveSocketBufferSizes(Entity):
                            """
                            Set socket and BGP receive buffer sizes
                            
                            .. attribute:: bgp_receive_size
                            
                            	BGP Read buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 512..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 4096
                            
                            .. attribute:: socket_receive_size
                            
                            	Receive socket buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 512..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 32768
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes, self).__init__()

                                self.yang_name = "receive-socket-buffer-sizes"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                self._segment_path = lambda: "receive-socket-buffer-sizes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.ReceiveSocketBufferSizes, ['bgp_receive_size', 'socket_receive_size'], name, value)


                        class RpkiServers(Entity):
                            """
                            RPKI server configuration
                            
                            .. attribute:: rpki_server
                            
                            	RPKI server configuration
                            	**type**\: list of    :py:class:`RpkiServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers, self).__init__()

                                self.yang_name = "rpki-servers"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpki-server" : ("rpki_server", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer)}

                                self.rpki_server = YList(self)
                                self._segment_path = lambda: "rpki-servers"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers, [], name, value)


                            class RpkiServer(Entity):
                                """
                                RPKI server configuration
                                
                                .. attribute:: server  <key>
                                
                                	Server address (opaque string)
                                	**type**\:  str
                                
                                .. attribute:: enable
                                
                                	RPKI server configuration
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: password
                                
                                	RPKI server password
                                	**type**\:  str
                                
                                .. attribute:: purge_time
                                
                                	RPKI server purge\-time (seconds)
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                .. attribute:: refresh_time
                                
                                	RPKI server refresh\-time (seconds)
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                .. attribute:: response_time
                                
                                	RPKI server response\-time (seconds)
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                	**units**\: second
                                
                                .. attribute:: shutdown
                                
                                	RPKI server shutdown
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                .. attribute:: transport
                                
                                	RPKI server transport
                                	**type**\:   :py:class:`Transport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport>`
                                
                                .. attribute:: username
                                
                                	RPKI server username
                                	**type**\:  str
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer, self).__init__()

                                    self.yang_name = "rpki-server"
                                    self.yang_parent_name = "rpki-servers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"transport" : ("transport", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport)}
                                    self._child_list_classes = {}

                                    self.server = YLeaf(YType.str, "server")

                                    self.enable = YLeaf(YType.empty, "enable")

                                    self.password = YLeaf(YType.str, "password")

                                    self.purge_time = YLeaf(YType.int32, "purge-time")

                                    self.refresh_time = YLeaf(YType.int32, "refresh-time")

                                    self.response_time = YLeaf(YType.int32, "response-time")

                                    self.shutdown = YLeaf(YType.empty, "shutdown")

                                    self.username = YLeaf(YType.str, "username")

                                    self.transport = Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport()
                                    self.transport.parent = self
                                    self._children_name_map["transport"] = "transport"
                                    self._children_yang_names.add("transport")
                                    self._segment_path = lambda: "rpki-server" + "[server='" + self.server.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer, ['server', 'enable', 'password', 'purge_time', 'refresh_time', 'response_time', 'shutdown', 'username'], name, value)


                                class Transport(Entity):
                                    """
                                    RPKI server transport
                                    
                                    .. attribute:: port
                                    
                                    	port
                                    	**type**\:  int
                                    
                                    	**range:** 1..65535
                                    
                                    	**default value**\: 22
                                    
                                    .. attribute:: transport
                                    
                                    	RPKI server transport
                                    	**type**\:   :py:class:`BgpRpkiTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRpkiTransport>`
                                    
                                    	**default value**\: ssh
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport, self).__init__()

                                        self.yang_name = "transport"
                                        self.yang_parent_name = "rpki-server"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.port = YLeaf(YType.uint16, "port")

                                        self.transport = YLeaf(YType.enumeration, "transport")
                                        self._segment_path = lambda: "transport"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiServers.RpkiServer.Transport, ['port', 'transport'], name, value)


                        class RpkiStaticRoutes(Entity):
                            """
                            RPKI static route configuration
                            
                            .. attribute:: rpki_static_route
                            
                            	RPKI static route
                            	**type**\: list of    :py:class:`RpkiStaticRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes, self).__init__()

                                self.yang_name = "rpki-static-routes"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"rpki-static-route" : ("rpki_static_route", Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute)}

                                self.rpki_static_route = YList(self)
                                self._segment_path = lambda: "rpki-static-routes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes, [], name, value)


                            class RpkiStaticRoute(Entity):
                                """
                                RPKI static route
                                
                                .. attribute:: addrress  <key>
                                
                                	Address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: minimum  <key>
                                
                                	Minimum Prefix Length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: maximum  <key>
                                
                                	Maximum Prefix Length
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                .. attribute:: as_  <key>
                                
                                	AS Number
                                	**type**\:  int
                                
                                	**range:** \-2147483648..2147483647
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute, self).__init__()

                                    self.yang_name = "rpki-static-route"
                                    self.yang_parent_name = "rpki-static-routes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.addrress = YLeaf(YType.str, "addrress")

                                    self.minimum = YLeaf(YType.int32, "minimum")

                                    self.maximum = YLeaf(YType.int32, "maximum")

                                    self.as_ = YLeaf(YType.int32, "as")
                                    self._segment_path = lambda: "rpki-static-route" + "[addrress='" + self.addrress.get() + "']" + "[minimum='" + self.minimum.get() + "']" + "[maximum='" + self.maximum.get() + "']" + "[as='" + self.as_.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.RpkiStaticRoutes.RpkiStaticRoute, ['addrress', 'minimum', 'maximum', 'as_'], name, value)


                        class SendSocketBufferSizes(Entity):
                            """
                            set socket parameters
                            
                            .. attribute:: bgp_send_size
                            
                            	BGP Write buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 4096..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 4096
                            
                            .. attribute:: socket_send_size
                            
                            	Send socket buffer size in bytes
                            	**type**\:  int
                            
                            	**range:** 4096..131072
                            
                            	**units**\: byte
                            
                            	**default value**\: 24576
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes, self).__init__()

                                self.yang_name = "send-socket-buffer-sizes"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                self._segment_path = lambda: "send-socket-buffer-sizes"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.SendSocketBufferSizes, ['bgp_send_size', 'socket_send_size'], name, value)


                        class UpdateDelay(Entity):
                            """
                            Set the max initial delay for sending
                            updates
                            
                            .. attribute:: always
                            
                            	Set to TRUE to disable keepalive trigger bestpath and delay is enforced
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: delay
                            
                            	Delay value (seconds)
                            	**type**\:  int
                            
                            	**range:** 0..3600
                            
                            	**units**\: second
                            
                            	**default value**\: 120
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay, self).__init__()

                                self.yang_name = "update-delay"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.always = YLeaf(YType.boolean, "always")

                                self.delay = YLeaf(YType.uint32, "delay")
                                self._segment_path = lambda: "update-delay"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.UpdateDelay, ['always', 'delay'], name, value)


                        class WriteLimit(Entity):
                            """
                            Set write\-queue limit for each update group
                            
                            .. attribute:: desynchronize
                            
                            	TRUE to enable desynchronization, FALSE otherwise
                            	**type**\:  bool
                            
                            	**default value**\: false
                            
                            .. attribute:: enqueued_messages
                            
                            	Number of messages that can be enqueued in total
                            	**type**\:  int
                            
                            	**range:** 500..100000000
                            
                            	**default value**\: 250000
                            
                            .. attribute:: formatted_messages
                            
                            	Number of messages to be formatted per update group
                            	**type**\:  int
                            
                            	**range:** 500..100000000
                            
                            	**default value**\: 50000
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit, self).__init__()

                                self.yang_name = "write-limit"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.desynchronize = YLeaf(YType.boolean, "desynchronize")

                                self.enqueued_messages = YLeaf(YType.uint32, "enqueued-messages")

                                self.formatted_messages = YLeaf(YType.uint32, "formatted-messages")
                                self._segment_path = lambda: "write-limit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.DefaultVrf.Global_.WriteLimit, ['desynchronize', 'enqueued_messages', 'formatted_messages'], name, value)


                class Vrfs(Entity):
                    """
                    VRF config
                    
                    .. attribute:: vrf
                    
                    	VRF config
                    	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf>`
                    
                    

                    """

                    _prefix = 'ipv4-bgp-cfg'
                    _revision = '2017-06-26'

                    def __init__(self):
                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs, self).__init__()

                        self.yang_name = "vrfs"
                        self.yang_parent_name = "four-byte-as"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"vrf" : ("vrf", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf)}

                        self.vrf = YList(self)
                        self._segment_path = lambda: "vrfs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs, [], name, value)


                    class Vrf(Entity):
                        """
                        VRF config
                        
                        .. attribute:: vrf_name  <key>
                        
                        	VRF name
                        	**type**\:  str
                        
                        	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                        
                        .. attribute:: vrf_global
                        
                        	VRF attribute config
                        	**type**\:   :py:class:`VrfGlobal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal>`
                        
                        .. attribute:: vrf_neighbors
                        
                        	BGP VRF peer
                        	**type**\:   :py:class:`VrfNeighbors <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors>`
                        
                        

                        """

                        _prefix = 'ipv4-bgp-cfg'
                        _revision = '2017-06-26'

                        def __init__(self):
                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf, self).__init__()

                            self.yang_name = "vrf"
                            self.yang_parent_name = "vrfs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"vrf-global" : ("vrf_global", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal), "vrf-neighbors" : ("vrf_neighbors", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors)}
                            self._child_list_classes = {}

                            self.vrf_name = YLeaf(YType.str, "vrf-name")

                            self.vrf_global = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal()
                            self.vrf_global.parent = self
                            self._children_name_map["vrf_global"] = "vrf-global"
                            self._children_yang_names.add("vrf-global")

                            self.vrf_neighbors = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors()
                            self.vrf_neighbors.parent = self
                            self._children_name_map["vrf_neighbors"] = "vrf-neighbors"
                            self._children_yang_names.add("vrf-neighbors")
                            self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf, ['vrf_name'], name, value)


                        class VrfGlobal(Entity):
                            """
                            VRF attribute config
                            
                            .. attribute:: best_path_aigp_ignore
                            
                            	Change default route selection criteria to ignore AIGP unless both paths whichare compared have AIGP attribute
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_as_multipath_relax
                            
                            	Change default multi\-route selection criteria to relax as\-path checking \- only require same aspath length
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_as_path_length
                            
                            	Change default route selection criteria to ignore AS path length
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_confederation_paths
                            
                            	Change default route selection criteria and allow the comparing of MED among confederation paths
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_cost_community
                            
                            	Change default route selection criteria to ignore cost community comparison
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_med_always
                            
                            	Change default route selection criteria and allow comparing of MED from different neighbors
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_med_missing
                            
                            	Treat missing MED as the least preferred one
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: best_path_router_id
                            
                            	Change default route selection criteria and compare router\-id for identical EBGP paths
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: bfd
                            
                            	BFD configuration
                            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd>`
                            
                            .. attribute:: default_info_originate
                            
                            	Control distribution of default information
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: default_metric
                            
                            	Default redistributed metric
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: disable_auto_soft_reset
                            
                            	Disable automatic soft peer reset on policy reconfiguration
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_enforce_first_as
                            
                            	Disable enforce the first AS for EBGP routes
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_fast_external_fallover
                            
                            	Disable immediate reset session if a link to a directly connected external peer goes down
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_msg_log
                            
                            	Disable inbound and outbound messagelogging for all neighbors under the vrf
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: disable_neighbor_logging
                            
                            	Disable neighbor change logging
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: exists
                            
                            	Create this VRF. Deletion of this object causes deletion of all the objects under VRF associated with this object
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: global_timers
                            
                            	Adjust routing timers
                            	**type**\:   :py:class:`GlobalTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers>`
                            
                            .. attribute:: igp_redist_internal
                            
                            	Allow redistribution of iBGP into IGPs (dangerous)
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: local_preference
                            
                            	Configure default local preference
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**default value**\: 100
                            
                            .. attribute:: mpls_activated_interfaces
                            
                            	Configure list of MPLS activated interfaces
                            	**type**\:   :py:class:`MplsActivatedInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces>`
                            
                            .. attribute:: multi_path_as_path_ignore_onwards
                            
                            	Change default multi\-route selection criteria to ignore everything onwards as\-path check
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: receive_socket_buffer_sizes
                            
                            	Set socket and BGP receive buffer sizes
                            	**type**\:   :py:class:`ReceiveSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes>`
                            
                            .. attribute:: route_distinguisher
                            
                            	Route distinguisher
                            	**type**\:   :py:class:`RouteDistinguisher <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher>`
                            
                            .. attribute:: router_id
                            
                            	Configure Router\-id
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: send_socket_buffer_sizes
                            
                            	set socket parameters
                            	**type**\:   :py:class:`SendSocketBufferSizes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes>`
                            
                            .. attribute:: vrf_global_afs
                            
                            	Global VRF\-specific configuration
                            	**type**\:   :py:class:`VrfGlobalAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal, self).__init__()

                                self.yang_name = "vrf-global"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"bfd" : ("bfd", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd), "global-timers" : ("global_timers", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers), "mpls-activated-interfaces" : ("mpls_activated_interfaces", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces), "receive-socket-buffer-sizes" : ("receive_socket_buffer_sizes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes), "route-distinguisher" : ("route_distinguisher", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher), "send-socket-buffer-sizes" : ("send_socket_buffer_sizes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes), "vrf-global-afs" : ("vrf_global_afs", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs)}
                                self._child_list_classes = {}

                                self.best_path_aigp_ignore = YLeaf(YType.empty, "best-path-aigp-ignore")

                                self.best_path_as_multipath_relax = YLeaf(YType.empty, "best-path-as-multipath-relax")

                                self.best_path_as_path_length = YLeaf(YType.empty, "best-path-as-path-length")

                                self.best_path_confederation_paths = YLeaf(YType.empty, "best-path-confederation-paths")

                                self.best_path_cost_community = YLeaf(YType.empty, "best-path-cost-community")

                                self.best_path_med_always = YLeaf(YType.empty, "best-path-med-always")

                                self.best_path_med_missing = YLeaf(YType.empty, "best-path-med-missing")

                                self.best_path_router_id = YLeaf(YType.empty, "best-path-router-id")

                                self.default_info_originate = YLeaf(YType.empty, "default-info-originate")

                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                self.disable_auto_soft_reset = YLeaf(YType.empty, "disable-auto-soft-reset")

                                self.disable_enforce_first_as = YLeaf(YType.empty, "disable-enforce-first-as")

                                self.disable_fast_external_fallover = YLeaf(YType.empty, "disable-fast-external-fallover")

                                self.disable_msg_log = YLeaf(YType.empty, "disable-msg-log")

                                self.disable_neighbor_logging = YLeaf(YType.empty, "disable-neighbor-logging")

                                self.exists = YLeaf(YType.empty, "exists")

                                self.igp_redist_internal = YLeaf(YType.empty, "igp-redist-internal")

                                self.local_preference = YLeaf(YType.uint32, "local-preference")

                                self.multi_path_as_path_ignore_onwards = YLeaf(YType.empty, "multi-path-as-path-ignore-onwards")

                                self.router_id = YLeaf(YType.str, "router-id")

                                self.bfd = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"
                                self._children_yang_names.add("bfd")

                                self.global_timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers()
                                self.global_timers.parent = self
                                self._children_name_map["global_timers"] = "global-timers"
                                self._children_yang_names.add("global-timers")

                                self.mpls_activated_interfaces = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces()
                                self.mpls_activated_interfaces.parent = self
                                self._children_name_map["mpls_activated_interfaces"] = "mpls-activated-interfaces"
                                self._children_yang_names.add("mpls-activated-interfaces")

                                self.receive_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes()
                                self.receive_socket_buffer_sizes.parent = self
                                self._children_name_map["receive_socket_buffer_sizes"] = "receive-socket-buffer-sizes"
                                self._children_yang_names.add("receive-socket-buffer-sizes")

                                self.route_distinguisher = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher()
                                self.route_distinguisher.parent = self
                                self._children_name_map["route_distinguisher"] = "route-distinguisher"
                                self._children_yang_names.add("route-distinguisher")

                                self.send_socket_buffer_sizes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes()
                                self.send_socket_buffer_sizes.parent = self
                                self._children_name_map["send_socket_buffer_sizes"] = "send-socket-buffer-sizes"
                                self._children_yang_names.add("send-socket-buffer-sizes")

                                self.vrf_global_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs()
                                self.vrf_global_afs.parent = self
                                self._children_name_map["vrf_global_afs"] = "vrf-global-afs"
                                self._children_yang_names.add("vrf-global-afs")
                                self._segment_path = lambda: "vrf-global"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal, ['best_path_aigp_ignore', 'best_path_as_multipath_relax', 'best_path_as_path_length', 'best_path_confederation_paths', 'best_path_cost_community', 'best_path_med_always', 'best_path_med_missing', 'best_path_router_id', 'default_info_originate', 'default_metric', 'disable_auto_soft_reset', 'disable_enforce_first_as', 'disable_fast_external_fallover', 'disable_msg_log', 'disable_neighbor_logging', 'exists', 'igp_redist_internal', 'local_preference', 'multi_path_as_path_ignore_onwards', 'router_id'], name, value)


                            class Bfd(Entity):
                                """
                                BFD configuration
                                
                                .. attribute:: detection_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd, self).__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "vrf-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                                    self.interval = YLeaf(YType.uint32, "interval")
                                    self._segment_path = lambda: "bfd"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.Bfd, ['detection_multiplier', 'interval'], name, value)


                            class GlobalTimers(Entity):
                                """
                                Adjust routing timers.
                                
                                .. attribute:: hold_time
                                
                                	Hold time (seconds).  Specify 0 to disable keepalives/hold time
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 180
                                
                                .. attribute:: keepalive
                                
                                	Keepalive interval (seconds)
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 60
                                
                                .. attribute:: min_accept_hold_time
                                
                                	Minimum acceptable hold time (seconds). Specify 0 to disable keepalives/hold time
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                	**units**\: second
                                
                                	**default value**\: 3
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers, self).__init__()

                                    self.yang_name = "global-timers"
                                    self.yang_parent_name = "vrf-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                                    self.keepalive = YLeaf(YType.uint32, "keepalive")

                                    self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                    self._segment_path = lambda: "global-timers"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.GlobalTimers, ['hold_time', 'keepalive', 'min_accept_hold_time'], name, value)


                            class MplsActivatedInterfaces(Entity):
                                """
                                Configure list of MPLS activated interfaces
                                
                                .. attribute:: mpls_activated_interface
                                
                                	Configure a MPLS activated interface
                                	**type**\: list of    :py:class:`MplsActivatedInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces, self).__init__()

                                    self.yang_name = "mpls-activated-interfaces"
                                    self.yang_parent_name = "vrf-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"mpls-activated-interface" : ("mpls_activated_interface", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface)}

                                    self.mpls_activated_interface = YList(self)
                                    self._segment_path = lambda: "mpls-activated-interfaces"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces, [], name, value)


                                class MplsActivatedInterface(Entity):
                                    """
                                    Configure a MPLS activated interface
                                    
                                    .. attribute:: interface_name  <key>
                                    
                                    	Interface Name
                                    	**type**\:  str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface, self).__init__()

                                        self.yang_name = "mpls-activated-interface"
                                        self.yang_parent_name = "mpls-activated-interfaces"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.interface_name = YLeaf(YType.str, "interface-name")
                                        self._segment_path = lambda: "mpls-activated-interface" + "[interface-name='" + self.interface_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.MplsActivatedInterfaces.MplsActivatedInterface, ['interface_name'], name, value)


                            class ReceiveSocketBufferSizes(Entity):
                                """
                                Set socket and BGP receive buffer sizes
                                
                                .. attribute:: bgp_receive_size
                                
                                	BGP Read buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 512..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 4096
                                
                                .. attribute:: socket_receive_size
                                
                                	Receive socket buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 512..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 32768
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes, self).__init__()

                                    self.yang_name = "receive-socket-buffer-sizes"
                                    self.yang_parent_name = "vrf-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                    self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                    self._segment_path = lambda: "receive-socket-buffer-sizes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.ReceiveSocketBufferSizes, ['bgp_receive_size', 'socket_receive_size'], name, value)


                            class RouteDistinguisher(Entity):
                                """
                                Route distinguisher
                                
                                .. attribute:: address
                                
                                	IP address
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: address_index
                                
                                	IP address index
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_
                                
                                	AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_index
                                
                                	ASN Index
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: as_xx
                                
                                	AS number
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: type
                                
                                	Type of RD
                                	**type**\:   :py:class:`BgpRouteDistinguisher <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpRouteDistinguisher>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher, self).__init__()

                                    self.yang_name = "route-distinguisher"
                                    self.yang_parent_name = "vrf-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.address = YLeaf(YType.str, "address")

                                    self.address_index = YLeaf(YType.uint32, "address-index")

                                    self.as_ = YLeaf(YType.uint32, "as")

                                    self.as_index = YLeaf(YType.uint32, "as-index")

                                    self.as_xx = YLeaf(YType.uint32, "as-xx")

                                    self.type = YLeaf(YType.enumeration, "type")
                                    self._segment_path = lambda: "route-distinguisher"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.RouteDistinguisher, ['address', 'address_index', 'as_', 'as_index', 'as_xx', 'type'], name, value)


                            class SendSocketBufferSizes(Entity):
                                """
                                set socket parameters
                                
                                .. attribute:: bgp_send_size
                                
                                	BGP Write buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 4096..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 4096
                                
                                .. attribute:: socket_send_size
                                
                                	Send socket buffer size in bytes
                                	**type**\:  int
                                
                                	**range:** 4096..131072
                                
                                	**units**\: byte
                                
                                	**default value**\: 24576
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes, self).__init__()

                                    self.yang_name = "send-socket-buffer-sizes"
                                    self.yang_parent_name = "vrf-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                    self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                    self._segment_path = lambda: "send-socket-buffer-sizes"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.SendSocketBufferSizes, ['bgp_send_size', 'socket_send_size'], name, value)


                            class VrfGlobalAfs(Entity):
                                """
                                Global VRF\-specific configuration
                                
                                .. attribute:: vrf_global_af
                                
                                	Global VRF AF\-specific configuration
                                	**type**\: list of    :py:class:`VrfGlobalAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs, self).__init__()

                                    self.yang_name = "vrf-global-afs"
                                    self.yang_parent_name = "vrf-global"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"vrf-global-af" : ("vrf_global_af", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf)}

                                    self.vrf_global_af = YList(self)
                                    self._segment_path = lambda: "vrf-global-afs"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs, [], name, value)


                                class VrfGlobalAf(Entity):
                                    """
                                    Global VRF AF\-specific configuration
                                    
                                    .. attribute:: af_name  <key>
                                    
                                    	Address family
                                    	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                    
                                    .. attribute:: additional_paths_receive
                                    
                                    	Advertise additional paths Receive capability
                                    	**type**\:   :py:class:`BgpAfAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAfAdditionalPathsCfg>`
                                    
                                    .. attribute:: additional_paths_selection
                                    
                                    	Configure additional paths selection
                                    	**type**\:   :py:class:`AdditionalPathsSelection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection>`
                                    
                                    .. attribute:: additional_paths_send
                                    
                                    	Advertise additional paths Send capability
                                    	**type**\:   :py:class:`BgpAfAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAfAdditionalPathsCfg>`
                                    
                                    .. attribute:: advertise_local_labeled_route_safi_unicast
                                    
                                    	Enable/disable advertisement of routes with local\-label via Unicast SAFI
                                    	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                    
                                    .. attribute:: aggregate_addresses
                                    
                                    	Configure BGP aggregate entries
                                    	**type**\:   :py:class:`AggregateAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses>`
                                    
                                    .. attribute:: allocate_label
                                    
                                    	Label allocation policy
                                    	**type**\:   :py:class:`AllocateLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel>`
                                    
                                    .. attribute:: allow_vpn_default_originate
                                    
                                    	TRUE to send default orig route to VPN neighborFALSE to not send default originate route 
                                    	**type**\:  bool
                                    
                                    .. attribute:: application_routes
                                    
                                    	Redistribute information for Application routes
                                    	**type**\:   :py:class:`ApplicationRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes>`
                                    
                                    .. attribute:: attribute_download
                                    
                                    	Attribute download configuration
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: best_external
                                    
                                    	TRUE to enable BE FALSE to disable BE inheritance from a parent
                                    	**type**\:  bool
                                    
                                    .. attribute:: connected_routes
                                    
                                    	Redistribute connected routes
                                    	**type**\:   :py:class:`ConnectedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: dampening
                                    
                                    	Enable route\-flap dampening
                                    	**type**\:   :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: disable_as_path_loop_check
                                    
                                    	Disable outbound AS Path loop check
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: distance
                                    
                                    	Define an administrative distance
                                    	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance>`
                                    
                                    .. attribute:: dynamic_med_interval
                                    
                                    	Update generation delay (in minutes) after a MED change
                                    	**type**\:  int
                                    
                                    	**range:** 0..10
                                    
                                    	**units**\: minute
                                    
                                    	**default value**\: 10
                                    
                                    .. attribute:: ebgp
                                    
                                    	Use eBGP multipaths
                                    	**type**\:   :py:class:`Ebgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eibgp
                                    
                                    	Use eiBGP multipaths
                                    	**type**\:   :py:class:`Eibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: eigrp_routes
                                    
                                    	Redistribute information for EIGRP routes
                                    	**type**\:   :py:class:`EigrpRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes>`
                                    
                                    .. attribute:: enable
                                    
                                    	Enable the address family. Deletion of this object causes deletion of all the objects under GlobalAF/VRFGlobalAF associated with this object 
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: ibgp
                                    
                                    	Use iBGP multipaths
                                    	**type**\:   :py:class:`Ibgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: label_mode
                                    
                                    	BGP 6PE/MPLS\-VPN label allocation mode
                                    	**type**\:   :py:class:`LabelMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode>`
                                    
                                    .. attribute:: lisp_routes
                                    
                                    	Redistribute lisp routes
                                    	**type**\:   :py:class:`LispRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: mobile_routes
                                    
                                    	Redistribute mobile routes
                                    	**type**\:   :py:class:`MobileRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: mvpn
                                    
                                    	MVPN configurations
                                    	**type**\:   :py:class:`Mvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn>`
                                    
                                    .. attribute:: next_hop_resolution_prefix_length_minimum
                                    
                                    	Minimum prefix\-length for nexthop resolution
                                    	**type**\:  int
                                    
                                    	**range:** 0..128
                                    
                                    	**default value**\: 0
                                    
                                    .. attribute:: ospf_routes
                                    
                                    	Redistribute information for OSPF routes
                                    	**type**\:   :py:class:`OspfRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes>`
                                    
                                    .. attribute:: permanent_network
                                    
                                    	Route policy for permanent networks
                                    	**type**\:  str
                                    
                                    .. attribute:: reset_weight_on_import
                                    
                                    	TRUE to reset weight on import. FALSE to not reset and to prevent inheritance from a parent
                                    	**type**\:  bool
                                    
                                    .. attribute:: rip_routes
                                    
                                    	Redistribute RIP routes
                                    	**type**\:   :py:class:`RipRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: rt_download
                                    
                                    	Route\-Target download configuration
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: sourced_networks
                                    
                                    	Specify a network to announce via BGP
                                    	**type**\:   :py:class:`SourcedNetworks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks>`
                                    
                                    .. attribute:: static_routes
                                    
                                    	Redistribute static routes
                                    	**type**\:   :py:class:`StaticRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: subscriber_routes
                                    
                                    	Redistribute subscriber routes
                                    	**type**\:   :py:class:`SubscriberRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: table_policy
                                    
                                    	Configure policy for installation of routes to RIB
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf, self).__init__()

                                        self.yang_name = "vrf-global-af"
                                        self.yang_parent_name = "vrf-global-afs"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"additional-paths-selection" : ("additional_paths_selection", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection), "aggregate-addresses" : ("aggregate_addresses", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses), "allocate-label" : ("allocate_label", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel), "application-routes" : ("application_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes), "connected-routes" : ("connected_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes), "dampening" : ("dampening", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening), "distance" : ("distance", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance), "ebgp" : ("ebgp", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp), "eibgp" : ("eibgp", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp), "eigrp-routes" : ("eigrp_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes), "ibgp" : ("ibgp", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp), "label-mode" : ("label_mode", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode), "lisp-routes" : ("lisp_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes), "mobile-routes" : ("mobile_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes), "mvpn" : ("mvpn", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn), "ospf-routes" : ("ospf_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes), "rip-routes" : ("rip_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes), "sourced-networks" : ("sourced_networks", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks), "static-routes" : ("static_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes), "subscriber-routes" : ("subscriber_routes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes)}
                                        self._child_list_classes = {}

                                        self.af_name = YLeaf(YType.enumeration, "af-name")

                                        self.additional_paths_receive = YLeaf(YType.enumeration, "additional-paths-receive")

                                        self.additional_paths_send = YLeaf(YType.enumeration, "additional-paths-send")

                                        self.advertise_local_labeled_route_safi_unicast = YLeaf(YType.enumeration, "advertise-local-labeled-route-safi-unicast")

                                        self.allow_vpn_default_originate = YLeaf(YType.boolean, "allow-vpn-default-originate")

                                        self.attribute_download = YLeaf(YType.empty, "attribute-download")

                                        self.best_external = YLeaf(YType.boolean, "best-external")

                                        self.disable_as_path_loop_check = YLeaf(YType.empty, "disable-as-path-loop-check")

                                        self.dynamic_med_interval = YLeaf(YType.uint32, "dynamic-med-interval")

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.next_hop_resolution_prefix_length_minimum = YLeaf(YType.uint32, "next-hop-resolution-prefix-length-minimum")

                                        self.permanent_network = YLeaf(YType.str, "permanent-network")

                                        self.reset_weight_on_import = YLeaf(YType.boolean, "reset-weight-on-import")

                                        self.rt_download = YLeaf(YType.empty, "rt-download")

                                        self.table_policy = YLeaf(YType.str, "table-policy")

                                        self.additional_paths_selection = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection()
                                        self.additional_paths_selection.parent = self
                                        self._children_name_map["additional_paths_selection"] = "additional-paths-selection"
                                        self._children_yang_names.add("additional-paths-selection")

                                        self.aggregate_addresses = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses()
                                        self.aggregate_addresses.parent = self
                                        self._children_name_map["aggregate_addresses"] = "aggregate-addresses"
                                        self._children_yang_names.add("aggregate-addresses")

                                        self.allocate_label = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel()
                                        self.allocate_label.parent = self
                                        self._children_name_map["allocate_label"] = "allocate-label"
                                        self._children_yang_names.add("allocate-label")

                                        self.application_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes()
                                        self.application_routes.parent = self
                                        self._children_name_map["application_routes"] = "application-routes"
                                        self._children_yang_names.add("application-routes")

                                        self.connected_routes = None
                                        self._children_name_map["connected_routes"] = "connected-routes"
                                        self._children_yang_names.add("connected-routes")

                                        self.dampening = None
                                        self._children_name_map["dampening"] = "dampening"
                                        self._children_yang_names.add("dampening")

                                        self.distance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance()
                                        self.distance.parent = self
                                        self._children_name_map["distance"] = "distance"
                                        self._children_yang_names.add("distance")

                                        self.ebgp = None
                                        self._children_name_map["ebgp"] = "ebgp"
                                        self._children_yang_names.add("ebgp")

                                        self.eibgp = None
                                        self._children_name_map["eibgp"] = "eibgp"
                                        self._children_yang_names.add("eibgp")

                                        self.eigrp_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes()
                                        self.eigrp_routes.parent = self
                                        self._children_name_map["eigrp_routes"] = "eigrp-routes"
                                        self._children_yang_names.add("eigrp-routes")

                                        self.ibgp = None
                                        self._children_name_map["ibgp"] = "ibgp"
                                        self._children_yang_names.add("ibgp")

                                        self.label_mode = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode()
                                        self.label_mode.parent = self
                                        self._children_name_map["label_mode"] = "label-mode"
                                        self._children_yang_names.add("label-mode")

                                        self.lisp_routes = None
                                        self._children_name_map["lisp_routes"] = "lisp-routes"
                                        self._children_yang_names.add("lisp-routes")

                                        self.mobile_routes = None
                                        self._children_name_map["mobile_routes"] = "mobile-routes"
                                        self._children_yang_names.add("mobile-routes")

                                        self.mvpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn()
                                        self.mvpn.parent = self
                                        self._children_name_map["mvpn"] = "mvpn"
                                        self._children_yang_names.add("mvpn")

                                        self.ospf_routes = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes()
                                        self.ospf_routes.parent = self
                                        self._children_name_map["ospf_routes"] = "ospf-routes"
                                        self._children_yang_names.add("ospf-routes")

                                        self.rip_routes = None
                                        self._children_name_map["rip_routes"] = "rip-routes"
                                        self._children_yang_names.add("rip-routes")

                                        self.sourced_networks = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks()
                                        self.sourced_networks.parent = self
                                        self._children_name_map["sourced_networks"] = "sourced-networks"
                                        self._children_yang_names.add("sourced-networks")

                                        self.static_routes = None
                                        self._children_name_map["static_routes"] = "static-routes"
                                        self._children_yang_names.add("static-routes")

                                        self.subscriber_routes = None
                                        self._children_name_map["subscriber_routes"] = "subscriber-routes"
                                        self._children_yang_names.add("subscriber-routes")
                                        self._segment_path = lambda: "vrf-global-af" + "[af-name='" + self.af_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf, ['af_name', 'additional_paths_receive', 'additional_paths_send', 'advertise_local_labeled_route_safi_unicast', 'allow_vpn_default_originate', 'attribute_download', 'best_external', 'disable_as_path_loop_check', 'dynamic_med_interval', 'enable', 'next_hop_resolution_prefix_length_minimum', 'permanent_network', 'reset_weight_on_import', 'rt_download', 'table_policy'], name, value)


                                    class AdditionalPathsSelection(Entity):
                                        """
                                        Configure additional paths selection
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy for selection
                                        	**type**\:  str
                                        
                                        .. attribute:: selection
                                        
                                        	Enable/disable selection 
                                        	**type**\:   :py:class:`BgpAfAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAfAdditionalPathsCfg>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection, self).__init__()

                                            self.yang_name = "additional-paths-selection"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            self.selection = YLeaf(YType.enumeration, "selection")
                                            self._segment_path = lambda: "additional-paths-selection"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AdditionalPathsSelection, ['route_policy_name', 'selection'], name, value)


                                    class AggregateAddresses(Entity):
                                        """
                                        Configure BGP aggregate entries
                                        
                                        .. attribute:: aggregate_address
                                        
                                        	Aggregate address configuration
                                        	**type**\: list of    :py:class:`AggregateAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses, self).__init__()

                                            self.yang_name = "aggregate-addresses"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"aggregate-address" : ("aggregate_address", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress)}

                                            self.aggregate_address = YList(self)
                                            self._segment_path = lambda: "aggregate-addresses"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses, [], name, value)


                                        class AggregateAddress(Entity):
                                            """
                                            Aggregate address configuration
                                            
                                            .. attribute:: aggregate_addr  <key>
                                            
                                            	Aggregate in prefix/length format (address part)
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: aggregate_prefix  <key>
                                            
                                            	Aggregate in prefix/length format (prefix part)
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: generate_confederation_set_info
                                            
                                            	TRUE to generate AS confederation set path information, FALSE otherwise
                                            	**type**\:  bool
                                            
                                            .. attribute:: generate_set_info
                                            
                                            	TRUE to generate AS set path information, FALSE otherwise
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy on which to condition advertisement, suppression, and attributes
                                            	**type**\:  str
                                            
                                            .. attribute:: summary_only
                                            
                                            	TRUE to filter more specific routes from updates, FALSEotherwise
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress, self).__init__()

                                                self.yang_name = "aggregate-address"
                                                self.yang_parent_name = "aggregate-addresses"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.aggregate_addr = YLeaf(YType.str, "aggregate-addr")

                                                self.aggregate_prefix = YLeaf(YType.uint16, "aggregate-prefix")

                                                self.generate_confederation_set_info = YLeaf(YType.boolean, "generate-confederation-set-info")

                                                self.generate_set_info = YLeaf(YType.boolean, "generate-set-info")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                                self.summary_only = YLeaf(YType.boolean, "summary-only")
                                                self._segment_path = lambda: "aggregate-address" + "[aggregate-addr='" + self.aggregate_addr.get() + "']" + "[aggregate-prefix='" + self.aggregate_prefix.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AggregateAddresses.AggregateAddress, ['aggregate_addr', 'aggregate_prefix', 'generate_confederation_set_info', 'generate_set_info', 'route_policy_name', 'summary_only'], name, value)


                                    class AllocateLabel(Entity):
                                        """
                                        Label allocation policy
                                        
                                        .. attribute:: all
                                        
                                        	Whether all nets should be labeled, default is FALSE
                                        	**type**\:  bool
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel, self).__init__()

                                            self.yang_name = "allocate-label"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.all = YLeaf(YType.boolean, "all")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "allocate-label"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.AllocateLabel, ['all', 'route_policy_name'], name, value)


                                    class ApplicationRoutes(Entity):
                                        """
                                        Redistribute information for Application routes.
                                        
                                        .. attribute:: application_route
                                        
                                        	Redistribute application routes
                                        	**type**\: list of    :py:class:`ApplicationRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes, self).__init__()

                                            self.yang_name = "application-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"application-route" : ("application_route", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute)}

                                            self.application_route = YList(self)
                                            self._segment_path = lambda: "application-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes, [], name, value)


                                        class ApplicationRoute(Entity):
                                            """
                                            Redistribute application routes
                                            
                                            .. attribute:: instance_name  <key>
                                            
                                            	OnePK application name
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: default_metric
                                            
                                            	Default metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: not_used
                                            
                                            	Not used
                                            	**type**\:  int
                                            
                                            	**range:** 0..127
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute, self).__init__()

                                                self.yang_name = "application-route"
                                                self.yang_parent_name = "application-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.instance_name = YLeaf(YType.str, "instance-name")

                                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                                self.not_used = YLeaf(YType.uint32, "not-used")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "application-route" + "[instance-name='" + self.instance_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ApplicationRoutes.ApplicationRoute, ['instance_name', 'default_metric', 'not_used', 'route_policy_name'], name, value)


                                    class ConnectedRoutes(Entity):
                                        """
                                        Redistribute connected routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes, self).__init__()

                                            self.yang_name = "connected-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "connected-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.ConnectedRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                    class Dampening(Entity):
                                        """
                                        Enable route\-flap dampening
                                        
                                        .. attribute:: half_life
                                        
                                        	Half\-life time for the penalty (minutes)
                                        	**type**\:  int
                                        
                                        	**range:** 1..45
                                        
                                        	**units**\: minute
                                        
                                        .. attribute:: reuse_threshold
                                        
                                        	Value to start reusing a route
                                        	**type**\:  int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy to specify criteria for dampening. This cannot be specified if any other parameters are specified
                                        	**type**\:  str
                                        
                                        .. attribute:: suppress_threshold
                                        
                                        	Value to start suppressing a route
                                        	**type**\:  int
                                        
                                        	**range:** 1..20000
                                        
                                        .. attribute:: suppress_time
                                        
                                        	Maximum duration to suppress a stable route (seconds)
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**units**\: second
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening, self).__init__()

                                            self.yang_name = "dampening"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.half_life = YLeaf(YType.uint32, "half-life")

                                            self.reuse_threshold = YLeaf(YType.uint32, "reuse-threshold")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")

                                            self.suppress_threshold = YLeaf(YType.uint32, "suppress-threshold")

                                            self.suppress_time = YLeaf(YType.uint32, "suppress-time")
                                            self._segment_path = lambda: "dampening"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Dampening, ['half_life', 'reuse_threshold', 'route_policy_name', 'suppress_threshold', 'suppress_time'], name, value)


                                    class Distance(Entity):
                                        """
                                        Define an administrative distance
                                        
                                        .. attribute:: external_routes
                                        
                                        	Distance for routes external to the AS
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**default value**\: 20
                                        
                                        .. attribute:: internal_routes
                                        
                                        	Distance for routes internal to the AS
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**default value**\: 200
                                        
                                        .. attribute:: local_routes
                                        
                                        	Distance for local routes
                                        	**type**\:  int
                                        
                                        	**range:** 1..255
                                        
                                        	**default value**\: 200
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance, self).__init__()

                                            self.yang_name = "distance"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.external_routes = YLeaf(YType.uint32, "external-routes")

                                            self.internal_routes = YLeaf(YType.uint32, "internal-routes")

                                            self.local_routes = YLeaf(YType.uint32, "local-routes")
                                            self._segment_path = lambda: "distance"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Distance, ['external_routes', 'internal_routes', 'local_routes'], name, value)


                                    class Ebgp(Entity):
                                        """
                                        Use eBGP multipaths
                                        
                                        .. attribute:: order_by_igp_metric
                                        
                                        	Order candidate multipaths by IGP metric
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: paths_value
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 2..32
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: selective
                                        
                                        	Allow multipaths only from marked neighbors
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	UNUSED
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp, self).__init__()

                                            self.yang_name = "ebgp"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                            self.paths_value = YLeaf(YType.uint32, "paths-value")

                                            self.selective = YLeaf(YType.boolean, "selective")

                                            self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")
                                            self._segment_path = lambda: "ebgp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ebgp, ['order_by_igp_metric', 'paths_value', 'selective', 'unequal_cost'], name, value)


                                    class Eibgp(Entity):
                                        """
                                        Use eiBGP multipaths
                                        
                                        .. attribute:: order_by_igp_metric
                                        
                                        	Order candidate multipaths by IGP metric
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: paths_value
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 2..32
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: selective
                                        
                                        	Allow multipaths only from marked neighbors
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	UNUSED
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp, self).__init__()

                                            self.yang_name = "eibgp"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                            self.paths_value = YLeaf(YType.uint32, "paths-value")

                                            self.selective = YLeaf(YType.boolean, "selective")

                                            self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")
                                            self._segment_path = lambda: "eibgp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Eibgp, ['order_by_igp_metric', 'paths_value', 'selective', 'unequal_cost'], name, value)


                                    class EigrpRoutes(Entity):
                                        """
                                        Redistribute information for EIGRP routes.
                                        
                                        .. attribute:: eigrp_route
                                        
                                        	Redistribute EIGRP routes
                                        	**type**\: list of    :py:class:`EigrpRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes, self).__init__()

                                            self.yang_name = "eigrp-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"eigrp-route" : ("eigrp_route", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute)}

                                            self.eigrp_route = YList(self)
                                            self._segment_path = lambda: "eigrp-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes, [], name, value)


                                        class EigrpRoute(Entity):
                                            """
                                            Redistribute EIGRP routes
                                            
                                            .. attribute:: instance_name  <key>
                                            
                                            	EIGRP router tag
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: default_metric
                                            
                                            	Default metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: redist_type
                                            
                                            	Redistribution type\: 01 for internal routes, 02 for external routes, Logical combinations permitted
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute, self).__init__()

                                                self.yang_name = "eigrp-route"
                                                self.yang_parent_name = "eigrp-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.instance_name = YLeaf(YType.str, "instance-name")

                                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                                self.redist_type = YLeaf(YType.str, "redist-type")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "eigrp-route" + "[instance-name='" + self.instance_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.EigrpRoutes.EigrpRoute, ['instance_name', 'default_metric', 'redist_type', 'route_policy_name'], name, value)


                                    class Ibgp(Entity):
                                        """
                                        Use iBGP multipaths
                                        
                                        .. attribute:: order_by_igp_metric
                                        
                                        	Order candidate multipaths by IGP metric
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: paths_value
                                        
                                        	Number of paths
                                        	**type**\:  int
                                        
                                        	**range:** 2..32
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: selective
                                        
                                        	Allow multipaths only from marked neighbors
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: unequal_cost
                                        
                                        	Allow multipaths to have different IGP metrics
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp, self).__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.order_by_igp_metric = YLeaf(YType.boolean, "order-by-igp-metric")

                                            self.paths_value = YLeaf(YType.uint32, "paths-value")

                                            self.selective = YLeaf(YType.boolean, "selective")

                                            self.unequal_cost = YLeaf(YType.boolean, "unequal-cost")
                                            self._segment_path = lambda: "ibgp"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Ibgp, ['order_by_igp_metric', 'paths_value', 'selective', 'unequal_cost'], name, value)


                                    class LabelMode(Entity):
                                        """
                                        BGP 6PE/MPLS\-VPN label allocation mode
                                        
                                        .. attribute:: label_allocation_mode
                                        
                                        	Label allocation mode\: per\-ce  Set per CE label mode, per\-vrf Set per VRF label mode, per\-prefix Set per Prefix label mode (for MPLS\-VPN only)
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Label mode route policy name
                                        	**type**\:  str
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode, self).__init__()

                                            self.yang_name = "label-mode"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.label_allocation_mode = YLeaf(YType.str, "label-allocation-mode")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "label-mode"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LabelMode, ['label_allocation_mode', 'route_policy_name'], name, value)


                                    class LispRoutes(Entity):
                                        """
                                        Redistribute lisp routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes, self).__init__()

                                            self.yang_name = "lisp-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "lisp-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.LispRoutes, ['default_metric', 'route_policy_name'], name, value)


                                    class MobileRoutes(Entity):
                                        """
                                        Redistribute mobile routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes, self).__init__()

                                            self.yang_name = "mobile-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "mobile-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.MobileRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                    class Mvpn(Entity):
                                        """
                                        MVPN configurations
                                        
                                        .. attribute:: single_forwarder_selection
                                        
                                        	Select MVPN single forwarder selection
                                        	**type**\:   :py:class:`BgpMvpnSfsSelect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpMvpnSfsSelect>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn, self).__init__()

                                            self.yang_name = "mvpn"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.single_forwarder_selection = YLeaf(YType.enumeration, "single-forwarder-selection")
                                            self._segment_path = lambda: "mvpn"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.Mvpn, ['single_forwarder_selection'], name, value)


                                    class OspfRoutes(Entity):
                                        """
                                        Redistribute information for OSPF routes.
                                        
                                        .. attribute:: ospf_route
                                        
                                        	Redistribute OSPF routes
                                        	**type**\: list of    :py:class:`OspfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes, self).__init__()

                                            self.yang_name = "ospf-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"ospf-route" : ("ospf_route", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute)}

                                            self.ospf_route = YList(self)
                                            self._segment_path = lambda: "ospf-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes, [], name, value)


                                        class OspfRoute(Entity):
                                            """
                                            Redistribute OSPF routes
                                            
                                            .. attribute:: instance_name  <key>
                                            
                                            	OSPF router tag
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            .. attribute:: default_metric
                                            
                                            	Default metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: redist_type
                                            
                                            	Redistribution type\: 01 for internal routes, 02 for external routes of type 1, 04 for external routes of type 2, 08 for NSSA external routes of type 1, 10 for NSSA external routes of type 2, 20 for external routes, 40 for NSSA external routes.  Logical combinations permitted
                                            	**type**\:  str
                                            
                                            	**pattern:** [0\-9a\-fA\-F]{1,8}
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute, self).__init__()

                                                self.yang_name = "ospf-route"
                                                self.yang_parent_name = "ospf-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.instance_name = YLeaf(YType.str, "instance-name")

                                                self.default_metric = YLeaf(YType.uint32, "default-metric")

                                                self.redist_type = YLeaf(YType.str, "redist-type")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "ospf-route" + "[instance-name='" + self.instance_name.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.OspfRoutes.OspfRoute, ['instance_name', 'default_metric', 'redist_type', 'route_policy_name'], name, value)


                                    class RipRoutes(Entity):
                                        """
                                        Redistribute RIP routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes, self).__init__()

                                            self.yang_name = "rip-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "rip-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.RipRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                    class SourcedNetworks(Entity):
                                        """
                                        Specify a network to announce via BGP
                                        
                                        .. attribute:: sourced_network
                                        
                                        	Sourced network configuration
                                        	**type**\: list of    :py:class:`SourcedNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks, self).__init__()

                                            self.yang_name = "sourced-networks"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"sourced-network" : ("sourced_network", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork)}

                                            self.sourced_network = YList(self)
                                            self._segment_path = lambda: "sourced-networks"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks, [], name, value)


                                        class SourcedNetwork(Entity):
                                            """
                                            Sourced network configuration
                                            
                                            .. attribute:: network_addr  <key>
                                            
                                            	Network in prefix/length format (address part)
                                            	**type**\: one of the below types:
                                            
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            	**type**\:  str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            
                                            ----
                                            .. attribute:: network_prefix  <key>
                                            
                                            	Network in prefix/length format (prefix part)
                                            	**type**\:  int
                                            
                                            	**range:** 0..128
                                            
                                            .. attribute:: backdoor
                                            
                                            	Specify a BGP backdoor route, default is FALSE
                                            	**type**\:  bool
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork, self).__init__()

                                                self.yang_name = "sourced-network"
                                                self.yang_parent_name = "sourced-networks"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.network_addr = YLeaf(YType.str, "network-addr")

                                                self.network_prefix = YLeaf(YType.uint16, "network-prefix")

                                                self.backdoor = YLeaf(YType.boolean, "backdoor")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "sourced-network" + "[network-addr='" + self.network_addr.get() + "']" + "[network-prefix='" + self.network_prefix.get() + "']"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SourcedNetworks.SourcedNetwork, ['network_addr', 'network_prefix', 'backdoor', 'route_policy_name'], name, value)


                                    class StaticRoutes(Entity):
                                        """
                                        Redistribute static routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes, self).__init__()

                                            self.yang_name = "static-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "static-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.StaticRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                                    class SubscriberRoutes(Entity):
                                        """
                                        Redistribute subscriber routes
                                        
                                        .. attribute:: default_metric
                                        
                                        	Default metric
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: not_used
                                        
                                        	Not used
                                        	**type**\:  int
                                        
                                        	**range:** 0..127
                                        
                                        .. attribute:: route_policy_name
                                        
                                        	Route policy name
                                        	**type**\:  str
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes, self).__init__()

                                            self.yang_name = "subscriber-routes"
                                            self.yang_parent_name = "vrf-global-af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.default_metric = YLeaf(YType.uint32, "default-metric")

                                            self.not_used = YLeaf(YType.uint32, "not-used")

                                            self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                            self._segment_path = lambda: "subscriber-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfGlobal.VrfGlobalAfs.VrfGlobalAf.SubscriberRoutes, ['default_metric', 'not_used', 'route_policy_name'], name, value)


                        class VrfNeighbors(Entity):
                            """
                            BGP VRF peer
                            
                            .. attribute:: vrf_neighbor
                            
                            	A particular VRF peer
                            	**type**\: list of    :py:class:`VrfNeighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor>`
                            
                            .. attribute:: vrf_neighbor_prefix_length
                            
                            	A particular VRF peer
                            	**type**\: list of    :py:class:`VrfNeighborPrefixLength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength>`
                            
                            

                            """

                            _prefix = 'ipv4-bgp-cfg'
                            _revision = '2017-06-26'

                            def __init__(self):
                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors, self).__init__()

                                self.yang_name = "vrf-neighbors"
                                self.yang_parent_name = "vrf"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"vrf-neighbor" : ("vrf_neighbor", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor), "vrf-neighbor-prefix-length" : ("vrf_neighbor_prefix_length", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength)}

                                self.vrf_neighbor = YList(self)
                                self.vrf_neighbor_prefix_length = YList(self)
                                self._segment_path = lambda: "vrf-neighbors"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors, [], name, value)


                            class VrfNeighbor(Entity):
                                """
                                A particular VRF peer
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgp_ce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: vrf_neighbor_afs
                                
                                	Address family type of a VRF neighbor
                                	**type**\:   :py:class:`VrfNeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor, self).__init__()

                                    self.yang_name = "vrf-neighbor"
                                    self.yang_parent_name = "vrf-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertisement-interval" : ("advertisement_interval", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval), "bmp-activates" : ("bmp_activates", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates), "ebgp-multihop" : ("ebgp_multihop", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance), "keychain" : ("keychain", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain), "local-address" : ("local_address", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress), "local-as" : ("local_as", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs), "msg-log-in" : ("msg_log_in", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn), "msg-log-out" : ("msg_log_out", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut), "neighbor-cluster-id" : ("neighbor_cluster_id", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId), "password" : ("password", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password), "receive-buffer-size" : ("receive_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize), "remote-as" : ("remote_as", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs), "send-buffer-size" : ("send_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize), "tcpmss" : ("tcpmss", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss), "timers" : ("timers", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers), "tos" : ("tos", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos), "update-in-filtering" : ("update_in_filtering", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering), "vrf-neighbor-afs" : ("vrf_neighbor_afs", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs)}
                                    self._child_list_classes = {}

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgp_ce = YLeaf(YType.boolean, "internal-vpn-client-ibgp-ce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                    self.vrf_neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs()
                                    self.vrf_neighbor_afs.parent = self
                                    self._children_name_map["vrf_neighbor_afs"] = "vrf-neighbor-afs"
                                    self._children_yang_names.add("vrf-neighbor-afs")
                                    self._segment_path = lambda: "vrf-neighbor" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor, ['neighbor_address', 'additional_paths_receive_capability', 'additional_paths_send_capability', 'bfd_enable_modes', 'bfd_minimum_interval', 'bfd_multiplier', 'description', 'ebgp_recv_dmz', 'ebgp_send_dmz_enable_modes', 'egress_peer_engineering', 'enforce_first_as', 'idle_watch_time', 'ignore_connected_check_ebgp', 'internal_vpn_client_ibgp_ce', 'max_peers', 'neighbor_graceful_restart', 'neighbor_graceful_restart_stalepath_time', 'neighbor_graceful_restart_time', 'neighbor_group_add_member', 'propagate_dmz_link_bandwidth', 'remote_as_list', 'session_group_add_member', 'session_open_mode', 'shutdown', 'suppress_all_capabilities', 'suppress_four_byte_as_capability', 'ttl_security', 'update_source_interface'], name, value)


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")
                                        self._segment_path = lambda: "advertisement-interval"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.AdvertisementInterval, ['minimum_interval', 'minimum_interval_msecs'], name, value)


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-activate" : ("bmp_activate", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate)}

                                        self.bmp_activate = YList(self)
                                        self._segment_path = lambda: "bmp-activates"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates, [], name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.server_id = YLeaf(YType.uint32, "server-id")
                                            self._segment_path = lambda: "bmp-activate" + "[server-id='" + self.server_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.BmpActivates.BmpActivate, ['server_id'], name, value)


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")
                                        self._segment_path = lambda: "ebgp-multihop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.EbgpMultihop, ['max_hop_count', 'mpls_deactivation'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"graceful-maintenance-as-prepends" : ("graceful_maintenance_as_prepends", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends), "graceful-maintenance-local-preference" : ("graceful_maintenance_local_preference", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance, ['enable', 'graceful_maintenance_activate'], name, value)


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")
                                            self._segment_path = lambda: "graceful-maintenance-as-prepends"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceAsPrepends, ['as_prepends', 'gshut_prepends_disable'], name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")
                                            self._segment_path = lambda: "graceful-maintenance-local-preference"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.GracefulMaintenance.GracefulMaintenanceLocalPreference, ['gshut_loc_pref_disable', 'local_preference'], name, value)


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "keychain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Keychain, ['keychain_disable', 'keychain_name'], name, value)


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")
                                        self._segment_path = lambda: "local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAddress, ['local_address_disable', 'local_ip_address'], name, value)


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")
                                        self._segment_path = lambda: "local-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.LocalAs, ['as_xx', 'as_yy', 'disable', 'dual_as', 'no_prepend', 'replace_as'], name, value)


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-in"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogIn, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-out"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.MsgLogOut, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                        self._segment_path = lambda: "neighbor-cluster-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.NeighborClusterId, ['cluster_id_address', 'cluster_id_number'], name, value)


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")
                                        self._segment_path = lambda: "password"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Password, ['password', 'password_disable'], name, value)


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                        self._segment_path = lambda: "receive-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.ReceiveBufferSize, ['bgp_receive_size', 'socket_receive_size'], name, value)


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")
                                        self._segment_path = lambda: "remote-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.RemoteAs, ['as_xx', 'as_yy'], name, value)


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                        self._segment_path = lambda: "send-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.SendBufferSize, ['bgp_send_size', 'socket_send_size'], name, value)


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")
                                        self._segment_path = lambda: "tcpmss"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tcpmss, ['mss', 'tcpmss_disable'], name, value)


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                        self._segment_path = lambda: "timers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Timers, ['hold_time', 'keepalive_interval', 'min_accept_hold_time'], name, value)


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")
                                        self._segment_path = lambda: "tos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.Tos, ['type', 'value'], name, value)


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-in-filtering-message-buffers" : ("update_in_filtering_message_buffers", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")
                                        self._segment_path = lambda: "update-in-filtering"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering, ['enable', 'update_in_filtering_attribute_filter_group', 'update_in_filtering_syslog_disable'], name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")
                                            self._segment_path = lambda: "update-in-filtering-message-buffers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.UpdateInFiltering.UpdateInFilteringMessageBuffers, ['non_circular_buffer', 'number_of_buffers'], name, value)


                                class VrfNeighborAfs(Entity):
                                    """
                                    Address family type of a VRF neighbor
                                    
                                    .. attribute:: vrf_neighbor_af
                                    
                                    	Address family type of a VRF neighbor
                                    	**type**\: list of    :py:class:`VrfNeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs, self).__init__()

                                        self.yang_name = "vrf-neighbor-afs"
                                        self.yang_parent_name = "vrf-neighbor"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-neighbor-af" : ("vrf_neighbor_af", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf)}

                                        self.vrf_neighbor_af = YList(self)
                                        self._segment_path = lambda: "vrf-neighbor-afs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs, [], name, value)


                                    class VrfNeighborAf(Entity):
                                        """
                                        Address family type of a VRF neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpn_evpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_l2vpn_evpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: enforce_multiple_labels
                                        
                                        	TRUE to enforce multiple labels support
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf, self).__init__()

                                            self.yang_name = "vrf-neighbor-af"
                                            self.yang_parent_name = "vrf-neighbor-afs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"advertise-def-imp-disable-v4" : ("advertise_def_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4), "advertise-def-imp-disable-v6" : ("advertise_def_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6), "advertise-disable" : ("advertise_disable", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable), "advertise-l2vpn-evpn" : ("advertise_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn), "advertise-local-l2vpn-evpn" : ("advertise_local_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn), "advertise-local-v4" : ("advertise_local_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4), "advertise-local-v6" : ("advertise_local_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6), "advertise-v4" : ("advertise_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4), "advertise-v6" : ("advertise_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6), "advertise-vrf-imp-disable-v4" : ("advertise_vrf_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4), "advertise-vrf-imp-disable-v6" : ("advertise_vrf_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6), "aigp-cost-community" : ("aigp_cost_community", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity), "default-originate" : ("default_originate", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate), "import" : ("import_", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_), "maximum-prefixes" : ("maximum_prefixes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes), "neighbor-af-long-lived-graceful-restart-stale-time" : ("neighbor_af_long_lived_graceful_restart_stale_time", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime), "remove-private-as-entire-as-path" : ("remove_private_as_entire_as_path", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath), "remove-private-as-entire-as-path-inbound" : ("remove_private_as_entire_as_path_inbound", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound), "site-of-origin" : ("site_of_origin", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin), "soft-reconfiguration" : ("soft_reconfiguration", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.enforce_multiple_labels = YLeaf(YType.boolean, "enforce-multiple-labels")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn()
                                            self.advertise_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_l2vpn_evpn"] = "advertise-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-l2vpn-evpn")

                                            self.advertise_local_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn()
                                            self.advertise_local_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_local_l2vpn_evpn"] = "advertise-local-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-local-l2vpn-evpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")
                                            self._segment_path = lambda: "vrf-neighbor-af" + "[af-name='" + self.af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf, ['af_name', 'accept_own', 'accept_route_legacy_rt', 'activate', 'advertise_local_labeled_route', 'advertise_orf', 'advertise_permanent_network', 'af_group', 'aigp', 'aigp_send_med', 'allow_as_in', 'as_override', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'flowspec_validation', 'multipath', 'neighbor_af_long_lived_graceful_restart_capable', 'next_hop_self', 'next_hop_unchanged', 'next_hop_unchanged_multipath', 'prefix_orf_policy', 'route_policy_in', 'route_policy_out', 'route_reflector_client', 'send_community_ebgp', 'send_community_ebgp_graceful_shutdown', 'send_ext_community_ebgp'], name, value)


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-disable"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseL2VpnEvpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-l2vpn-evpn"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalL2VpnEvpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpn-evpn"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")
                                                self._segment_path = lambda: "aigp-cost-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, ['cost_community_id', 'cost_community_poi_type', 'enable', 'transitive'], name, value)


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "default-originate"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, ['enable', 'route_policy_name'], name, value)


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")
                                                self._segment_path = lambda: "import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.Import_, ['import_reoriginate', 'import_reoriginate_stitching', 'import_stitching'], name, value)


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")
                                                self._segment_path = lambda: "maximum-prefixes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, ['discard_extra_paths', 'prefix_limit', 'restart_time', 'warning_only', 'warning_percentage'], name, value)


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")
                                                self._segment_path = lambda: "neighbor-af-long-lived-graceful-restart-stale-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, ['stale_time_accept', 'stale_time_send'], name, value)


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, ['enable', 'entire'], name, value)


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path-inbound"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, ['enable', 'entire'], name, value)


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "site-of-origin"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, ['address', 'address_index', 'as_', 'as_index', 'as_xx', 'type'], name, value)


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")
                                                self._segment_path = lambda: "soft-reconfiguration"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighbor.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, ['inbound_soft', 'soft_always'], name, value)


                            class VrfNeighborPrefixLength(Entity):
                                """
                                A particular VRF peer
                                
                                .. attribute:: prefix_length  <key>
                                
                                	Prefix length
                                	**type**\:  int
                                
                                	**range:** 0..127
                                
                                .. attribute:: neighbor_address  <key>
                                
                                	Neighbor address
                                	**type**\: one of the below types:
                                
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                
                                ----
                                .. attribute:: additional_paths_receive_capability
                                
                                	Advertise additional paths Receive capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: additional_paths_send_capability
                                
                                	Advertise additional paths Send capability
                                	**type**\:   :py:class:`BgpNbrCapAdditionalPathsCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpNbrCapAdditionalPathsCfg>`
                                
                                .. attribute:: advertisement_interval
                                
                                	Minimum interval between sending BGP routing updates
                                	**type**\:   :py:class:`AdvertisementInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval>`
                                
                                	**presence node**\: True
                                
                                .. attribute:: bfd_enable_modes
                                
                                	Strict mode, Default mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpBfdEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpBfdEnableMode>`
                                
                                .. attribute:: bfd_minimum_interval
                                
                                	Hello interval for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 3..30000
                                
                                	**units**\: millisecond
                                
                                .. attribute:: bfd_multiplier
                                
                                	Detection multiplier for BFD sessions created by BGP
                                	**type**\:  int
                                
                                	**range:** 2..16
                                
                                .. attribute:: bmp_activates
                                
                                	Enable BMP logging for this neighbor
                                	**type**\:   :py:class:`BmpActivates <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates>`
                                
                                .. attribute:: description
                                
                                	Up to 80 characters describing this neighbor
                                	**type**\:  str
                                
                                .. attribute:: ebgp_multihop
                                
                                	Allow EBGP neighbors not on directly connected networks
                                	**type**\:   :py:class:`EbgpMultihop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop>`
                                
                                .. attribute:: ebgp_recv_dmz
                                
                                	TRUE to receive DMZ link bandwidth from ebgp peer. FALSE to not receive from ebgp peer and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: ebgp_send_dmz_enable_modes
                                
                                	Default mode, Cumulative mode or Disable to prevent inheritance from a parent
                                	**type**\:   :py:class:`BgpEbgpSendDmzEnableMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpEbgpSendDmzEnableMode>`
                                
                                .. attribute:: egress_peer_engineering
                                
                                	TRUE to enable egress peer engineering FALSE to disable egress peer engineering and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: enforce_first_as
                                
                                	TRUE to enforce first AS; FALSE to not enforce first AS
                                	**type**\:  bool
                                
                                .. attribute:: graceful_maintenance
                                
                                	Graceful Maintenance mode
                                	**type**\:   :py:class:`GracefulMaintenance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance>`
                                
                                .. attribute:: idle_watch_time
                                
                                	Time to wait for deleteing IDLE state Dynamic peer
                                	**type**\:  int
                                
                                	**range:** 30..1800
                                
                                	**units**\: second
                                
                                .. attribute:: ignore_connected_check_ebgp
                                
                                	TRUE to disable the connected nexthop check for this peer.FALSE to enable the connected nexthop check for this peer
                                	**type**\:  bool
                                
                                .. attribute:: internal_vpn_client_ibgp_ce
                                
                                	TRUE to preserve the CE path attributes.FALSE to override CE path attributes
                                	**type**\:  bool
                                
                                .. attribute:: keychain
                                
                                	Set or disable keychain based authentication
                                	**type**\:   :py:class:`Keychain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain>`
                                
                                .. attribute:: local_address
                                
                                	Local ip address
                                	**type**\:   :py:class:`LocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress>`
                                
                                .. attribute:: local_as
                                
                                	Specify a local\-as number
                                	**type**\:   :py:class:`LocalAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs>`
                                
                                .. attribute:: max_peers
                                
                                	Set Maximum Peers in Dynamic Range
                                	**type**\:  int
                                
                                	**range:** 1..4096
                                
                                .. attribute:: msg_log_in
                                
                                	Message log inbound
                                	**type**\:   :py:class:`MsgLogIn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn>`
                                
                                .. attribute:: msg_log_out
                                
                                	Message log outbound
                                	**type**\:   :py:class:`MsgLogOut <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut>`
                                
                                .. attribute:: neighbor_cluster_id
                                
                                	Neighbor Cluster\-id
                                	**type**\:   :py:class:`NeighborClusterId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId>`
                                
                                .. attribute:: neighbor_graceful_restart
                                
                                	TRUE to Enable graceful restart support for neighbor.  FALSE to disable graceful restart support for neighbor
                                	**type**\:  bool
                                
                                .. attribute:: neighbor_graceful_restart_stalepath_time
                                
                                	Maximum time to wait for restart of GR capable peer
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 360
                                
                                .. attribute:: neighbor_graceful_restart_time
                                
                                	Restart time advertised to neighbor
                                	**type**\:  int
                                
                                	**range:** 1..4095
                                
                                	**units**\: second
                                
                                	**default value**\: 120
                                
                                .. attribute:: neighbor_group_add_member
                                
                                	Inherit configuration from a neighbor\-group
                                	**type**\:  str
                                
                                .. attribute:: password
                                
                                	Set or disable a password
                                	**type**\:   :py:class:`Password <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password>`
                                
                                .. attribute:: propagate_dmz_link_bandwidth
                                
                                	TRUE to propagate DMZ link bandwidth.  FALSE to not propagate and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: receive_buffer_size
                                
                                	Set socket receive buffer size and BGP read buffer size
                                	**type**\:   :py:class:`ReceiveBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize>`
                                
                                .. attribute:: remote_as
                                
                                	Set remote AS
                                	**type**\:   :py:class:`RemoteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs>`
                                
                                .. attribute:: remote_as_list
                                
                                	Remote\-as\-list group name
                                	**type**\:  str
                                
                                .. attribute:: send_buffer_size
                                
                                	Set socket send buffer size and BGP write buffer size
                                	**type**\:   :py:class:`SendBufferSize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize>`
                                
                                .. attribute:: session_group_add_member
                                
                                	Inherit address\-family independent config from a session\-group
                                	**type**\:  str
                                
                                .. attribute:: session_open_mode
                                
                                	TCP mode to be used to establish BGP session
                                	**type**\:   :py:class:`BgpTcpMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpTcpMode>`
                                
                                	**default value**\: either
                                
                                .. attribute:: shutdown
                                
                                	TRUE to shutdown this entity, FALSE to prevent this entity from being shutdown even if the parent is
                                	**type**\:  bool
                                
                                .. attribute:: suppress_all_capabilities
                                
                                	TRUE to suppress all capabilities. FALSE to not suppress and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: suppress_four_byte_as_capability
                                
                                	TRUE to suppress BGP 4\-byte\-as capability.  FALSE to not suppress it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: tcpmss
                                
                                	TCP Maximum segment size
                                	**type**\:   :py:class:`Tcpmss <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss>`
                                
                                .. attribute:: timers
                                
                                	BGP per neighbor timers
                                	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers>`
                                
                                .. attribute:: tos
                                
                                	TOS (Type Of Service)
                                	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos>`
                                
                                .. attribute:: ttl_security
                                
                                	TRUE to enable BGP TTL Security.  FALSE to not enable it and to prevent inheritance from a parent
                                	**type**\:  bool
                                
                                .. attribute:: update_in_filtering
                                
                                	Inbound update filtering
                                	**type**\:   :py:class:`UpdateInFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering>`
                                
                                .. attribute:: update_source_interface
                                
                                	Select an interface to configure
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: vrf_neighbor_afs
                                
                                	Address family type of a VRF neighbor
                                	**type**\:   :py:class:`VrfNeighborAfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs>`
                                
                                

                                """

                                _prefix = 'ipv4-bgp-cfg'
                                _revision = '2017-06-26'

                                def __init__(self):
                                    super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength, self).__init__()

                                    self.yang_name = "vrf-neighbor-prefix-length"
                                    self.yang_parent_name = "vrf-neighbors"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {"advertisement-interval" : ("advertisement_interval", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval), "bmp-activates" : ("bmp_activates", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates), "ebgp-multihop" : ("ebgp_multihop", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop), "graceful-maintenance" : ("graceful_maintenance", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance), "keychain" : ("keychain", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain), "local-address" : ("local_address", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress), "local-as" : ("local_as", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs), "msg-log-in" : ("msg_log_in", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn), "msg-log-out" : ("msg_log_out", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut), "neighbor-cluster-id" : ("neighbor_cluster_id", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId), "password" : ("password", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password), "receive-buffer-size" : ("receive_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize), "remote-as" : ("remote_as", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs), "send-buffer-size" : ("send_buffer_size", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize), "tcpmss" : ("tcpmss", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss), "timers" : ("timers", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers), "tos" : ("tos", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos), "update-in-filtering" : ("update_in_filtering", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering), "vrf-neighbor-afs" : ("vrf_neighbor_afs", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs)}
                                    self._child_list_classes = {}

                                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                    self.neighbor_address = YLeaf(YType.str, "neighbor-address")

                                    self.additional_paths_receive_capability = YLeaf(YType.enumeration, "additional-paths-receive-capability")

                                    self.additional_paths_send_capability = YLeaf(YType.enumeration, "additional-paths-send-capability")

                                    self.bfd_enable_modes = YLeaf(YType.enumeration, "bfd-enable-modes")

                                    self.bfd_minimum_interval = YLeaf(YType.uint32, "bfd-minimum-interval")

                                    self.bfd_multiplier = YLeaf(YType.uint32, "bfd-multiplier")

                                    self.description = YLeaf(YType.str, "description")

                                    self.ebgp_recv_dmz = YLeaf(YType.boolean, "ebgp-recv-dmz")

                                    self.ebgp_send_dmz_enable_modes = YLeaf(YType.enumeration, "ebgp-send-dmz-enable-modes")

                                    self.egress_peer_engineering = YLeaf(YType.boolean, "egress-peer-engineering")

                                    self.enforce_first_as = YLeaf(YType.boolean, "enforce-first-as")

                                    self.idle_watch_time = YLeaf(YType.uint32, "idle-watch-time")

                                    self.ignore_connected_check_ebgp = YLeaf(YType.boolean, "ignore-connected-check-ebgp")

                                    self.internal_vpn_client_ibgp_ce = YLeaf(YType.boolean, "internal-vpn-client-ibgp-ce")

                                    self.max_peers = YLeaf(YType.uint32, "max-peers")

                                    self.neighbor_graceful_restart = YLeaf(YType.boolean, "neighbor-graceful-restart")

                                    self.neighbor_graceful_restart_stalepath_time = YLeaf(YType.uint32, "neighbor-graceful-restart-stalepath-time")

                                    self.neighbor_graceful_restart_time = YLeaf(YType.uint32, "neighbor-graceful-restart-time")

                                    self.neighbor_group_add_member = YLeaf(YType.str, "neighbor-group-add-member")

                                    self.propagate_dmz_link_bandwidth = YLeaf(YType.boolean, "propagate-dmz-link-bandwidth")

                                    self.remote_as_list = YLeaf(YType.str, "remote-as-list")

                                    self.session_group_add_member = YLeaf(YType.str, "session-group-add-member")

                                    self.session_open_mode = YLeaf(YType.enumeration, "session-open-mode")

                                    self.shutdown = YLeaf(YType.boolean, "shutdown")

                                    self.suppress_all_capabilities = YLeaf(YType.boolean, "suppress-all-capabilities")

                                    self.suppress_four_byte_as_capability = YLeaf(YType.boolean, "suppress-four-byte-as-capability")

                                    self.ttl_security = YLeaf(YType.boolean, "ttl-security")

                                    self.update_source_interface = YLeaf(YType.str, "update-source-interface")

                                    self.advertisement_interval = None
                                    self._children_name_map["advertisement_interval"] = "advertisement-interval"
                                    self._children_yang_names.add("advertisement-interval")

                                    self.bmp_activates = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates()
                                    self.bmp_activates.parent = self
                                    self._children_name_map["bmp_activates"] = "bmp-activates"
                                    self._children_yang_names.add("bmp-activates")

                                    self.ebgp_multihop = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop()
                                    self.ebgp_multihop.parent = self
                                    self._children_name_map["ebgp_multihop"] = "ebgp-multihop"
                                    self._children_yang_names.add("ebgp-multihop")

                                    self.graceful_maintenance = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance()
                                    self.graceful_maintenance.parent = self
                                    self._children_name_map["graceful_maintenance"] = "graceful-maintenance"
                                    self._children_yang_names.add("graceful-maintenance")

                                    self.keychain = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._children_yang_names.add("keychain")

                                    self.local_address = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress()
                                    self.local_address.parent = self
                                    self._children_name_map["local_address"] = "local-address"
                                    self._children_yang_names.add("local-address")

                                    self.local_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs()
                                    self.local_as.parent = self
                                    self._children_name_map["local_as"] = "local-as"
                                    self._children_yang_names.add("local-as")

                                    self.msg_log_in = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn()
                                    self.msg_log_in.parent = self
                                    self._children_name_map["msg_log_in"] = "msg-log-in"
                                    self._children_yang_names.add("msg-log-in")

                                    self.msg_log_out = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut()
                                    self.msg_log_out.parent = self
                                    self._children_name_map["msg_log_out"] = "msg-log-out"
                                    self._children_yang_names.add("msg-log-out")

                                    self.neighbor_cluster_id = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId()
                                    self.neighbor_cluster_id.parent = self
                                    self._children_name_map["neighbor_cluster_id"] = "neighbor-cluster-id"
                                    self._children_yang_names.add("neighbor-cluster-id")

                                    self.password = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password()
                                    self.password.parent = self
                                    self._children_name_map["password"] = "password"
                                    self._children_yang_names.add("password")

                                    self.receive_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize()
                                    self.receive_buffer_size.parent = self
                                    self._children_name_map["receive_buffer_size"] = "receive-buffer-size"
                                    self._children_yang_names.add("receive-buffer-size")

                                    self.remote_as = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs()
                                    self.remote_as.parent = self
                                    self._children_name_map["remote_as"] = "remote-as"
                                    self._children_yang_names.add("remote-as")

                                    self.send_buffer_size = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize()
                                    self.send_buffer_size.parent = self
                                    self._children_name_map["send_buffer_size"] = "send-buffer-size"
                                    self._children_yang_names.add("send-buffer-size")

                                    self.tcpmss = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss()
                                    self.tcpmss.parent = self
                                    self._children_name_map["tcpmss"] = "tcpmss"
                                    self._children_yang_names.add("tcpmss")

                                    self.timers = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers()
                                    self.timers.parent = self
                                    self._children_name_map["timers"] = "timers"
                                    self._children_yang_names.add("timers")

                                    self.tos = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos()
                                    self.tos.parent = self
                                    self._children_name_map["tos"] = "tos"
                                    self._children_yang_names.add("tos")

                                    self.update_in_filtering = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering()
                                    self.update_in_filtering.parent = self
                                    self._children_name_map["update_in_filtering"] = "update-in-filtering"
                                    self._children_yang_names.add("update-in-filtering")

                                    self.vrf_neighbor_afs = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs()
                                    self.vrf_neighbor_afs.parent = self
                                    self._children_name_map["vrf_neighbor_afs"] = "vrf-neighbor-afs"
                                    self._children_yang_names.add("vrf-neighbor-afs")
                                    self._segment_path = lambda: "vrf-neighbor-prefix-length" + "[prefix-length='" + self.prefix_length.get() + "']" + "[neighbor-address='" + self.neighbor_address.get() + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength, ['prefix_length', 'neighbor_address', 'additional_paths_receive_capability', 'additional_paths_send_capability', 'bfd_enable_modes', 'bfd_minimum_interval', 'bfd_multiplier', 'description', 'ebgp_recv_dmz', 'ebgp_send_dmz_enable_modes', 'egress_peer_engineering', 'enforce_first_as', 'idle_watch_time', 'ignore_connected_check_ebgp', 'internal_vpn_client_ibgp_ce', 'max_peers', 'neighbor_graceful_restart', 'neighbor_graceful_restart_stalepath_time', 'neighbor_graceful_restart_time', 'neighbor_group_add_member', 'propagate_dmz_link_bandwidth', 'remote_as_list', 'session_group_add_member', 'session_open_mode', 'shutdown', 'suppress_all_capabilities', 'suppress_four_byte_as_capability', 'ttl_security', 'update_source_interface'], name, value)


                                class AdvertisementInterval(Entity):
                                    """
                                    Minimum interval between sending BGP routing
                                    updates
                                    
                                    .. attribute:: minimum_interval
                                    
                                    	Minimum advertisement interval time, secs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..600
                                    
                                    	**mandatory**\: True
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: minimum_interval_msecs
                                    
                                    	Minimum advertisement interval time, msecs part
                                    	**type**\:  int
                                    
                                    	**range:** 0..999
                                    
                                    	**units**\: millisecond
                                    
                                    

                                    This class is a :ref:`presence class<presence-class>`

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval, self).__init__()

                                        self.yang_name = "advertisement-interval"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}
                                        self.is_presence_container = True

                                        self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                                        self.minimum_interval_msecs = YLeaf(YType.uint32, "minimum-interval-msecs")
                                        self._segment_path = lambda: "advertisement-interval"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.AdvertisementInterval, ['minimum_interval', 'minimum_interval_msecs'], name, value)


                                class BmpActivates(Entity):
                                    """
                                    Enable BMP logging for this neighbor
                                    
                                    .. attribute:: bmp_activate
                                    
                                    	Enable BMP logging for this particular server
                                    	**type**\: list of    :py:class:`BmpActivate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates, self).__init__()

                                        self.yang_name = "bmp-activates"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"bmp-activate" : ("bmp_activate", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate)}

                                        self.bmp_activate = YList(self)
                                        self._segment_path = lambda: "bmp-activates"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates, [], name, value)


                                    class BmpActivate(Entity):
                                        """
                                        Enable BMP logging for this particular server
                                        
                                        .. attribute:: server_id  <key>
                                        
                                        	BMP Server ID
                                        	**type**\:  int
                                        
                                        	**range:** 1..8
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate, self).__init__()

                                            self.yang_name = "bmp-activate"
                                            self.yang_parent_name = "bmp-activates"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.server_id = YLeaf(YType.uint32, "server-id")
                                            self._segment_path = lambda: "bmp-activate" + "[server-id='" + self.server_id.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.BmpActivates.BmpActivate, ['server_id'], name, value)


                                class EbgpMultihop(Entity):
                                    """
                                    Allow EBGP neighbors not on directly connected
                                    networks
                                    
                                    .. attribute:: max_hop_count
                                    
                                    	Maximum hop count
                                    	**type**\:  int
                                    
                                    	**range:** 1..255
                                    
                                    	**default value**\: 255
                                    
                                    .. attribute:: mpls_deactivation
                                    
                                    	TRUE to not enable MPLS and NULL rewrite
                                    	**type**\:  bool
                                    
                                    	**default value**\: false
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop, self).__init__()

                                        self.yang_name = "ebgp-multihop"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.max_hop_count = YLeaf(YType.uint32, "max-hop-count")

                                        self.mpls_deactivation = YLeaf(YType.boolean, "mpls-deactivation")
                                        self._segment_path = lambda: "ebgp-multihop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.EbgpMultihop, ['max_hop_count', 'mpls_deactivation'], name, value)


                                class GracefulMaintenance(Entity):
                                    """
                                    Graceful Maintenance mode
                                    
                                    .. attribute:: enable
                                    
                                    	Enter Graceful Maintenance mode to configure parametrs
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: graceful_maintenance_activate
                                    
                                    	Initiate the graceful shutdown procedure
                                    	**type**\:  bool
                                    
                                    .. attribute:: graceful_maintenance_as_prepends
                                    
                                    	Number of times to prepend local AS number to the AS path
                                    	**type**\:   :py:class:`GracefulMaintenanceAsPrepends <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends>`
                                    
                                    .. attribute:: graceful_maintenance_local_preference
                                    
                                    	Set Local Preference to advertise routes with
                                    	**type**\:   :py:class:`GracefulMaintenanceLocalPreference <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance, self).__init__()

                                        self.yang_name = "graceful-maintenance"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"graceful-maintenance-as-prepends" : ("graceful_maintenance_as_prepends", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends), "graceful-maintenance-local-preference" : ("graceful_maintenance_local_preference", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.graceful_maintenance_activate = YLeaf(YType.boolean, "graceful-maintenance-activate")

                                        self.graceful_maintenance_as_prepends = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends()
                                        self.graceful_maintenance_as_prepends.parent = self
                                        self._children_name_map["graceful_maintenance_as_prepends"] = "graceful-maintenance-as-prepends"
                                        self._children_yang_names.add("graceful-maintenance-as-prepends")

                                        self.graceful_maintenance_local_preference = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference()
                                        self.graceful_maintenance_local_preference.parent = self
                                        self._children_name_map["graceful_maintenance_local_preference"] = "graceful-maintenance-local-preference"
                                        self._children_yang_names.add("graceful-maintenance-local-preference")
                                        self._segment_path = lambda: "graceful-maintenance"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance, ['enable', 'graceful_maintenance_activate'], name, value)


                                    class GracefulMaintenanceAsPrepends(Entity):
                                        """
                                        Number of times to prepend local AS number to
                                        the AS path
                                        
                                        .. attribute:: as_prepends
                                        
                                        	number of times AS prepends
                                        	**type**\:  int
                                        
                                        	**range:** 0..6
                                        
                                        .. attribute:: gshut_prepends_disable
                                        
                                        	TRUE, to prevent inheritance of AS Prepends value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, self).__init__()

                                            self.yang_name = "graceful-maintenance-as-prepends"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.as_prepends = YLeaf(YType.uint32, "as-prepends")

                                            self.gshut_prepends_disable = YLeaf(YType.boolean, "gshut-prepends-disable")
                                            self._segment_path = lambda: "graceful-maintenance-as-prepends"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceAsPrepends, ['as_prepends', 'gshut_prepends_disable'], name, value)


                                    class GracefulMaintenanceLocalPreference(Entity):
                                        """
                                        Set Local Preference to advertise routes with
                                        
                                        .. attribute:: gshut_loc_pref_disable
                                        
                                        	TRUE, to prevent inheritance of Local Pref value from its parents.FALSE, otherwise
                                        	**type**\:  bool
                                        
                                        .. attribute:: local_preference
                                        
                                        	Local Preference Value
                                        	**type**\:  int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, self).__init__()

                                            self.yang_name = "graceful-maintenance-local-preference"
                                            self.yang_parent_name = "graceful-maintenance"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}

                                            self.gshut_loc_pref_disable = YLeaf(YType.boolean, "gshut-loc-pref-disable")

                                            self.local_preference = YLeaf(YType.uint32, "local-preference")
                                            self._segment_path = lambda: "graceful-maintenance-local-preference"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.GracefulMaintenance.GracefulMaintenanceLocalPreference, ['gshut_loc_pref_disable', 'local_preference'], name, value)


                                class Keychain(Entity):
                                    """
                                    Set or disable keychain based authentication
                                    
                                    .. attribute:: keychain_disable
                                    
                                    	TRUE to prevent this entity from having a keychain based authentication even if the parent has one.FALSE to specify a keychain name
                                    	**type**\:  bool
                                    
                                    .. attribute:: keychain_name
                                    
                                    	Name of the keychain associated with neighbor
                                    	**type**\:  str
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain, self).__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.keychain_disable = YLeaf(YType.boolean, "keychain-disable")

                                        self.keychain_name = YLeaf(YType.str, "keychain-name")
                                        self._segment_path = lambda: "keychain"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Keychain, ['keychain_disable', 'keychain_name'], name, value)


                                class LocalAddress(Entity):
                                    """
                                    Local ip address
                                    
                                    .. attribute:: local_address_disable
                                    
                                    	TRUE to prevent this entity from having a local address if the parent has one.FALSE to specify local ip address
                                    	**type**\:  bool
                                    
                                    .. attribute:: local_ip_address
                                    
                                    	Local ip address for neighbor
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    	**type**\:  str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress, self).__init__()

                                        self.yang_name = "local-address"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.local_address_disable = YLeaf(YType.boolean, "local-address-disable")

                                        self.local_ip_address = YLeaf(YType.str, "local-ip-address")
                                        self._segment_path = lambda: "local-address"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAddress, ['local_address_disable', 'local_ip_address'], name, value)


                                class LocalAs(Entity):
                                    """
                                    Specify a local\-as number
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: disable
                                    
                                    	Disable Local AS and prevent it from being inherited from a parent
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: dual_as
                                    
                                    	Dual\-AS mode
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: no_prepend
                                    
                                    	Do not prepend Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: replace_as
                                    
                                    	Prepend only Local AS to announcements from this neighbor
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs, self).__init__()

                                        self.yang_name = "local-as"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")

                                        self.disable = YLeaf(YType.empty, "disable")

                                        self.dual_as = YLeaf(YType.empty, "dual-as")

                                        self.no_prepend = YLeaf(YType.empty, "no-prepend")

                                        self.replace_as = YLeaf(YType.empty, "replace-as")
                                        self._segment_path = lambda: "local-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.LocalAs, ['as_xx', 'as_yy', 'disable', 'dual_as', 'no_prepend', 'replace_as'], name, value)


                                class MsgLogIn(Entity):
                                    """
                                    Message log inbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Inbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a inbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn, self).__init__()

                                        self.yang_name = "msg-log-in"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-in"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogIn, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class MsgLogOut(Entity):
                                    """
                                    Message log outbound
                                    
                                    .. attribute:: msg_buf_count
                                    
                                    	Outbound message log buffer size
                                    	**type**\:  int
                                    
                                    	**range:** 1..100
                                    
                                    .. attribute:: msg_log_disable
                                    
                                    	Disable inbound message logging
                                    	**type**\:  bool
                                    
                                    .. attribute:: msg_log_inherit_disable
                                    
                                    	TRUE, to prevent this entity from having a outbound message logging if parent has one
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut, self).__init__()

                                        self.yang_name = "msg-log-out"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.msg_buf_count = YLeaf(YType.uint32, "msg-buf-count")

                                        self.msg_log_disable = YLeaf(YType.boolean, "msg-log-disable")

                                        self.msg_log_inherit_disable = YLeaf(YType.boolean, "msg-log-inherit-disable")
                                        self._segment_path = lambda: "msg-log-out"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.MsgLogOut, ['msg_buf_count', 'msg_log_disable', 'msg_log_inherit_disable'], name, value)


                                class NeighborClusterId(Entity):
                                    """
                                    Neighbor Cluster\-id
                                    
                                    .. attribute:: cluster_id_address
                                    
                                    	Route\-Reflector Cluster ID in IPV4 address format
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: cluster_id_number
                                    
                                    	Route\-Reflector Cluster ID as 32 bit quantity
                                    	**type**\:  int
                                    
                                    	**range:** 1..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId, self).__init__()

                                        self.yang_name = "neighbor-cluster-id"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.cluster_id_address = YLeaf(YType.str, "cluster-id-address")

                                        self.cluster_id_number = YLeaf(YType.uint32, "cluster-id-number")
                                        self._segment_path = lambda: "neighbor-cluster-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.NeighborClusterId, ['cluster_id_address', 'cluster_id_number'], name, value)


                                class Password(Entity):
                                    """
                                    Set or disable a password
                                    
                                    .. attribute:: password
                                    
                                    	The neighbor password.  Leave unspecified when disabling the password
                                    	**type**\:  str
                                    
                                    	**pattern:** (!.+)\|([^!].+)
                                    
                                    .. attribute:: password_disable
                                    
                                    	TRUE to prevent this entity from having a password even if the parent has one.  FALSEto specify a password
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password, self).__init__()

                                        self.yang_name = "password"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.password = YLeaf(YType.str, "password")

                                        self.password_disable = YLeaf(YType.boolean, "password-disable")
                                        self._segment_path = lambda: "password"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Password, ['password', 'password_disable'], name, value)


                                class ReceiveBufferSize(Entity):
                                    """
                                    Set socket receive buffer size and BGP read
                                    buffer size
                                    
                                    .. attribute:: bgp_receive_size
                                    
                                    	BGP read buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_receive_size
                                    
                                    	Receive socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 512..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 32768
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize, self).__init__()

                                        self.yang_name = "receive-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_receive_size = YLeaf(YType.uint32, "bgp-receive-size")

                                        self.socket_receive_size = YLeaf(YType.uint32, "socket-receive-size")
                                        self._segment_path = lambda: "receive-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.ReceiveBufferSize, ['bgp_receive_size', 'socket_receive_size'], name, value)


                                class RemoteAs(Entity):
                                    """
                                    Set remote AS
                                    
                                    .. attribute:: as_xx
                                    
                                    	xx of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: as_yy
                                    
                                    	yy of AS number xx.yy
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs, self).__init__()

                                        self.yang_name = "remote-as"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.as_xx = YLeaf(YType.uint32, "as-xx")

                                        self.as_yy = YLeaf(YType.uint32, "as-yy")
                                        self._segment_path = lambda: "remote-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.RemoteAs, ['as_xx', 'as_yy'], name, value)


                                class SendBufferSize(Entity):
                                    """
                                    Set socket send buffer size and BGP write buffer
                                    size
                                    
                                    .. attribute:: bgp_send_size
                                    
                                    	BGP write buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 4096
                                    
                                    .. attribute:: socket_send_size
                                    
                                    	Send socket buffer size in bytes
                                    	**type**\:  int
                                    
                                    	**range:** 4096..131072
                                    
                                    	**units**\: byte
                                    
                                    	**default value**\: 24576
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize, self).__init__()

                                        self.yang_name = "send-buffer-size"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.bgp_send_size = YLeaf(YType.uint32, "bgp-send-size")

                                        self.socket_send_size = YLeaf(YType.uint32, "socket-send-size")
                                        self._segment_path = lambda: "send-buffer-size"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.SendBufferSize, ['bgp_send_size', 'socket_send_size'], name, value)


                                class Tcpmss(Entity):
                                    """
                                    TCP Maximum segment size
                                    
                                    .. attribute:: mss
                                    
                                    	Maximum Segment Size
                                    	**type**\:  int
                                    
                                    	**range:** 68..10000
                                    
                                    .. attribute:: tcpmss_disable
                                    
                                    	TRUE, to prevent inheritance ofTCP MSS valuefrom its parents.FALSE, otherwise
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss, self).__init__()

                                        self.yang_name = "tcpmss"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.mss = YLeaf(YType.uint32, "mss")

                                        self.tcpmss_disable = YLeaf(YType.boolean, "tcpmss-disable")
                                        self._segment_path = lambda: "tcpmss"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tcpmss, ['mss', 'tcpmss_disable'], name, value)


                                class Timers(Entity):
                                    """
                                    BGP per neighbor timers.
                                    
                                    .. attribute:: hold_time
                                    
                                    	Hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 180
                                    
                                    .. attribute:: keepalive_interval
                                    
                                    	Keepalive interval
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 60
                                    
                                    .. attribute:: min_accept_hold_time
                                    
                                    	Minimum acceptable hold time.  Specify 0 to disable keepalives/hold time
                                    	**type**\:  int
                                    
                                    	**range:** 0..65535
                                    
                                    	**default value**\: 3
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers, self).__init__()

                                        self.yang_name = "timers"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.hold_time = YLeaf(YType.uint32, "hold-time")

                                        self.keepalive_interval = YLeaf(YType.uint32, "keepalive-interval")

                                        self.min_accept_hold_time = YLeaf(YType.uint32, "min-accept-hold-time")
                                        self._segment_path = lambda: "timers"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Timers, ['hold_time', 'keepalive_interval', 'min_accept_hold_time'], name, value)


                                class Tos(Entity):
                                    """
                                    TOS (Type Of Service)
                                    
                                    .. attribute:: type
                                    
                                    	Set type of service
                                    	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
                                    
                                    .. attribute:: value
                                    
                                    	TOS value to set
                                    	**type**\: one of the below types:
                                    
                                    	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
                                    
                                    
                                    ----
                                    	**type**\:  int
                                    
                                    	**range:** 0..63
                                    
                                    
                                    ----
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos, self).__init__()

                                        self.yang_name = "tos"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.type = YLeaf(YType.enumeration, "type")

                                        self.value = YLeaf(YType.str, "value")
                                        self._segment_path = lambda: "tos"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.Tos, ['type', 'value'], name, value)


                                class UpdateInFiltering(Entity):
                                    """
                                    Inbound update filtering
                                    
                                    .. attribute:: enable
                                    
                                    	Configure inbound update filtering
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    .. attribute:: update_in_filtering_attribute_filter_group
                                    
                                    	Attribute\-filter group name for update filtering
                                    	**type**\:  str
                                    
                                    .. attribute:: update_in_filtering_message_buffers
                                    
                                    	Message buffers to store filtered updates
                                    	**type**\:   :py:class:`UpdateInFilteringMessageBuffers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers>`
                                    
                                    	**presence node**\: True
                                    
                                    .. attribute:: update_in_filtering_syslog_disable
                                    
                                    	Disable inbound update filtering syslog messages
                                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering, self).__init__()

                                        self.yang_name = "update-in-filtering"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"update-in-filtering-message-buffers" : ("update_in_filtering_message_buffers", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers)}
                                        self._child_list_classes = {}

                                        self.enable = YLeaf(YType.empty, "enable")

                                        self.update_in_filtering_attribute_filter_group = YLeaf(YType.str, "update-in-filtering-attribute-filter-group")

                                        self.update_in_filtering_syslog_disable = YLeaf(YType.empty, "update-in-filtering-syslog-disable")

                                        self.update_in_filtering_message_buffers = None
                                        self._children_name_map["update_in_filtering_message_buffers"] = "update-in-filtering-message-buffers"
                                        self._children_yang_names.add("update-in-filtering-message-buffers")
                                        self._segment_path = lambda: "update-in-filtering"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering, ['enable', 'update_in_filtering_attribute_filter_group', 'update_in_filtering_syslog_disable'], name, value)


                                    class UpdateInFilteringMessageBuffers(Entity):
                                        """
                                        Message buffers to store filtered updates
                                        
                                        .. attribute:: non_circular_buffer
                                        
                                        	TRUE to configure non\-circular buffer
                                        	**type**\:  bool
                                        
                                        	**mandatory**\: True
                                        
                                        .. attribute:: number_of_buffers
                                        
                                        	Number of message buffers
                                        	**type**\:  int
                                        
                                        	**range:** 0..25
                                        
                                        	**mandatory**\: True
                                        
                                        

                                        This class is a :ref:`presence class<presence-class>`

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, self).__init__()

                                            self.yang_name = "update-in-filtering-message-buffers"
                                            self.yang_parent_name = "update-in-filtering"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {}
                                            self.is_presence_container = True

                                            self.non_circular_buffer = YLeaf(YType.boolean, "non-circular-buffer")

                                            self.number_of_buffers = YLeaf(YType.uint32, "number-of-buffers")
                                            self._segment_path = lambda: "update-in-filtering-message-buffers"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.UpdateInFiltering.UpdateInFilteringMessageBuffers, ['non_circular_buffer', 'number_of_buffers'], name, value)


                                class VrfNeighborAfs(Entity):
                                    """
                                    Address family type of a VRF neighbor
                                    
                                    .. attribute:: vrf_neighbor_af
                                    
                                    	Address family type of a VRF neighbor
                                    	**type**\: list of    :py:class:`VrfNeighborAf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf>`
                                    
                                    

                                    """

                                    _prefix = 'ipv4-bgp-cfg'
                                    _revision = '2017-06-26'

                                    def __init__(self):
                                        super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs, self).__init__()

                                        self.yang_name = "vrf-neighbor-afs"
                                        self.yang_parent_name = "vrf-neighbor-prefix-length"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {"vrf-neighbor-af" : ("vrf_neighbor_af", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf)}

                                        self.vrf_neighbor_af = YList(self)
                                        self._segment_path = lambda: "vrf-neighbor-afs"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs, [], name, value)


                                    class VrfNeighborAf(Entity):
                                        """
                                        Address family type of a VRF neighbor
                                        
                                        .. attribute:: af_name  <key>
                                        
                                        	BGP neighbor address family
                                        	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                        
                                        .. attribute:: accept_own
                                        
                                        	Handle self\-originated routes with Accept\-Own community. Valid for following neighbor address\-families\: VPNv4Unicast, VPNv6Unicast
                                        	**type**\:  bool
                                        
                                        .. attribute:: accept_route_legacy_rt
                                        
                                        	TRUE to configure as a accept\-route\-legacy\-RT.  FALSE to prevent accept\-route\-legacy\-RT from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: activate
                                        
                                        	Activate an address family for this neighbor. Deletion of this object causes deletion of all the objects under NeighborAF/VRFNeighborAF/NeighborGroupAF associated with this object
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v4
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4>`
                                        
                                        .. attribute:: advertise_def_imp_disable_v6
                                        
                                        	Disable Advertise Of Default VRF Imported Routes
                                        	**type**\:   :py:class:`AdvertiseDefImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6>`
                                        
                                        .. attribute:: advertise_disable
                                        
                                        	Disable Advertise Of Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseDisable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable>`
                                        
                                        .. attribute:: advertise_l2vpn_evpn
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_l2vpn_evpn
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalL2VpnEvpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn>`
                                        
                                        .. attribute:: advertise_local_labeled_route
                                        
                                        	Enable/disable advertisement of routes with local\-label
                                        	**type**\:   :py:class:`BgpAdvertiseLocalLabeledRouteCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAdvertiseLocalLabeledRouteCfg>`
                                        
                                        .. attribute:: advertise_local_v4
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4>`
                                        
                                        .. attribute:: advertise_local_v6
                                        
                                        	Advertise Of Local Routes to the peer with different RT
                                        	**type**\:   :py:class:`AdvertiseLocalV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6>`
                                        
                                        .. attribute:: advertise_orf
                                        
                                        	Advertise ORF capability to the peer
                                        	**type**\:   :py:class:`BgpOrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpOrf>`
                                        
                                        	**default value**\: none
                                        
                                        .. attribute:: advertise_permanent_network
                                        
                                        	Advertise Permanent Networks to the peer
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: advertise_v4
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4>`
                                        
                                        .. attribute:: advertise_v6
                                        
                                        	Advertise Translated Routes to the peer
                                        	**type**\:   :py:class:`AdvertiseV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v4
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4>`
                                        
                                        .. attribute:: advertise_vrf_imp_disable_v6
                                        
                                        	Disable Advertise Of VRF ReImported Routes
                                        	**type**\:   :py:class:`AdvertiseVrfImpDisableV6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6>`
                                        
                                        .. attribute:: af_group
                                        
                                        	Inherit configuration for this address\-family from an AF\-group
                                        	**type**\:  str
                                        
                                        .. attribute:: aigp
                                        
                                        	Enable Accumulated IGP Metric for this neighbor
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: aigp_cost_community
                                        
                                        	Send AIGP value in Cost Community. 
                                        	**type**\:   :py:class:`AigpCostCommunity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: aigp_send_med
                                        
                                        	Enable/Disable sending AIGP in MED 
                                        	**type**\:   :py:class:`BgpAigpCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfg>`
                                        
                                        .. attribute:: allow_as_in
                                        
                                        	Allow as\-path with my AS present in it
                                        	**type**\:  int
                                        
                                        	**range:** 1..10
                                        
                                        	**default value**\: 3
                                        
                                        .. attribute:: as_override
                                        
                                        	TRUE to override matching AS\-number while sending update. FALSE to prevent as\-override from being inherited from the parent
                                        	**type**\:  bool
                                        
                                        	**default value**\: true
                                        
                                        .. attribute:: default_originate
                                        
                                        	Originate default route to this neighbor
                                        	**type**\:   :py:class:`DefaultOriginate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate>`
                                        
                                        .. attribute:: default_weight
                                        
                                        	Set default weight for routes from this neighbor/neighbor\-group/af\-group
                                        	**type**\:  int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation type for this neighbor
                                        	**type**\:   :py:class:`BgpAfEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAfEncapsulation>`
                                        
                                        .. attribute:: enforce_multiple_labels
                                        
                                        	TRUE to enforce multiple labels support
                                        	**type**\:  bool
                                        
                                        .. attribute:: flowspec_validation
                                        
                                        	Config Flowspec validation for this neighbor
                                        	**type**\:   :py:class:`BgpFlowspecValidationCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpFlowspecValidationCfg>`
                                        
                                        .. attribute:: import_
                                        
                                        	Import Reorigination options for Routes from the peer
                                        	**type**\:   :py:class:`Import_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_>`
                                        
                                        .. attribute:: maximum_prefixes
                                        
                                        	Maximum number of prefixes to accept from this peer
                                        	**type**\:   :py:class:`MaximumPrefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: multipath
                                        
                                        	Allow paths from this neighbor to be eligible for selective multipath
                                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_capable
                                        
                                        	TRUE to treat neighbor as Long\-lived Graceful\-restart capable. FALSE to rely on capability negotiation
                                        	**type**\:  bool
                                        
                                        	**default value**\: false
                                        
                                        .. attribute:: neighbor_af_long_lived_graceful_restart_stale_time
                                        
                                        	Maximum time to wait before purging long lived routes
                                        	**type**\:   :py:class:`NeighborAfLongLivedGracefulRestartStaleTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime>`
                                        
                                        .. attribute:: next_hop_self
                                        
                                        	Disable the next hop calculation and  insert your own address in the nexthop field of advertised routes you learned from the neighbor
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged
                                        
                                        	TRUE to disable overwriting of next hop before advertising to eBGP peers. FALSE to prevent next\-hop\-unchanged from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: next_hop_unchanged_multipath
                                        
                                        	TRUE to disable overwriting of next hop for multipaths. FALSE to prevent next\-hop\-unchanged for multipaths
                                        	**type**\:  bool
                                        
                                        .. attribute:: prefix_orf_policy
                                        
                                        	Prefix ORF policy name for incoming updates
                                        	**type**\:  str
                                        
                                        .. attribute:: remove_private_as_entire_as_path
                                        
                                        	Remove private AS number from outbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: remove_private_as_entire_as_path_inbound
                                        
                                        	Remove private AS number from inbound updates
                                        	**type**\:   :py:class:`RemovePrivateAsEntireAsPathInbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound>`
                                        
                                        	**presence node**\: True
                                        
                                        .. attribute:: route_policy_in
                                        
                                        	Route policy name to apply to inbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_policy_out
                                        
                                        	Route policy name to apply to outbound routes
                                        	**type**\:  str
                                        
                                        .. attribute:: route_reflector_client
                                        
                                        	TRUE to configure as a route\-reflector\-client.  FALSE to prevent route\-reflector\-client from being inherited
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_community_ebgp_graceful_shutdown
                                        
                                        	TRUE to send communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: send_ext_community_ebgp
                                        
                                        	TRUE to send extended communities to the external neighbor/neighbor\-group/af\-group.  FALSE not to send and to prevent inheritance from a parent
                                        	**type**\:  bool
                                        
                                        .. attribute:: site_of_origin
                                        
                                        	Site\-of\-Origin extended community associated with the neighbor
                                        	**type**\:   :py:class:`SiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin>`
                                        
                                        .. attribute:: soft_reconfiguration
                                        
                                        	Enable/disable inbound soft reconfiguration for this neighbor/neighbor\-group/af\-group
                                        	**type**\:   :py:class:`SoftReconfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration>`
                                        
                                        

                                        """

                                        _prefix = 'ipv4-bgp-cfg'
                                        _revision = '2017-06-26'

                                        def __init__(self):
                                            super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf, self).__init__()

                                            self.yang_name = "vrf-neighbor-af"
                                            self.yang_parent_name = "vrf-neighbor-afs"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"advertise-def-imp-disable-v4" : ("advertise_def_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4), "advertise-def-imp-disable-v6" : ("advertise_def_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6), "advertise-disable" : ("advertise_disable", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable), "advertise-l2vpn-evpn" : ("advertise_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn), "advertise-local-l2vpn-evpn" : ("advertise_local_l2vpn_evpn", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn), "advertise-local-v4" : ("advertise_local_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4), "advertise-local-v6" : ("advertise_local_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6), "advertise-v4" : ("advertise_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4), "advertise-v6" : ("advertise_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6), "advertise-vrf-imp-disable-v4" : ("advertise_vrf_imp_disable_v4", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4), "advertise-vrf-imp-disable-v6" : ("advertise_vrf_imp_disable_v6", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6), "aigp-cost-community" : ("aigp_cost_community", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity), "default-originate" : ("default_originate", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate), "import" : ("import_", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_), "maximum-prefixes" : ("maximum_prefixes", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes), "neighbor-af-long-lived-graceful-restart-stale-time" : ("neighbor_af_long_lived_graceful_restart_stale_time", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime), "remove-private-as-entire-as-path" : ("remove_private_as_entire_as_path", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath), "remove-private-as-entire-as-path-inbound" : ("remove_private_as_entire_as_path_inbound", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound), "site-of-origin" : ("site_of_origin", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin), "soft-reconfiguration" : ("soft_reconfiguration", Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration)}
                                            self._child_list_classes = {}

                                            self.af_name = YLeaf(YType.enumeration, "af-name")

                                            self.accept_own = YLeaf(YType.boolean, "accept-own")

                                            self.accept_route_legacy_rt = YLeaf(YType.boolean, "accept-route-legacy-rt")

                                            self.activate = YLeaf(YType.empty, "activate")

                                            self.advertise_local_labeled_route = YLeaf(YType.enumeration, "advertise-local-labeled-route")

                                            self.advertise_orf = YLeaf(YType.enumeration, "advertise-orf")

                                            self.advertise_permanent_network = YLeaf(YType.empty, "advertise-permanent-network")

                                            self.af_group = YLeaf(YType.str, "af-group")

                                            self.aigp = YLeaf(YType.enumeration, "aigp")

                                            self.aigp_send_med = YLeaf(YType.enumeration, "aigp-send-med")

                                            self.allow_as_in = YLeaf(YType.uint32, "allow-as-in")

                                            self.as_override = YLeaf(YType.boolean, "as-override")

                                            self.default_weight = YLeaf(YType.uint32, "default-weight")

                                            self.encapsulation_type = YLeaf(YType.enumeration, "encapsulation-type")

                                            self.enforce_multiple_labels = YLeaf(YType.boolean, "enforce-multiple-labels")

                                            self.flowspec_validation = YLeaf(YType.enumeration, "flowspec-validation")

                                            self.multipath = YLeaf(YType.empty, "multipath")

                                            self.neighbor_af_long_lived_graceful_restart_capable = YLeaf(YType.boolean, "neighbor-af-long-lived-graceful-restart-capable")

                                            self.next_hop_self = YLeaf(YType.boolean, "next-hop-self")

                                            self.next_hop_unchanged = YLeaf(YType.boolean, "next-hop-unchanged")

                                            self.next_hop_unchanged_multipath = YLeaf(YType.boolean, "next-hop-unchanged-multipath")

                                            self.prefix_orf_policy = YLeaf(YType.str, "prefix-orf-policy")

                                            self.route_policy_in = YLeaf(YType.str, "route-policy-in")

                                            self.route_policy_out = YLeaf(YType.str, "route-policy-out")

                                            self.route_reflector_client = YLeaf(YType.boolean, "route-reflector-client")

                                            self.send_community_ebgp = YLeaf(YType.boolean, "send-community-ebgp")

                                            self.send_community_ebgp_graceful_shutdown = YLeaf(YType.boolean, "send-community-ebgp-graceful-shutdown")

                                            self.send_ext_community_ebgp = YLeaf(YType.boolean, "send-ext-community-ebgp")

                                            self.advertise_def_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4()
                                            self.advertise_def_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v4"] = "advertise-def-imp-disable-v4"
                                            self._children_yang_names.add("advertise-def-imp-disable-v4")

                                            self.advertise_def_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6()
                                            self.advertise_def_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_def_imp_disable_v6"] = "advertise-def-imp-disable-v6"
                                            self._children_yang_names.add("advertise-def-imp-disable-v6")

                                            self.advertise_disable = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable()
                                            self.advertise_disable.parent = self
                                            self._children_name_map["advertise_disable"] = "advertise-disable"
                                            self._children_yang_names.add("advertise-disable")

                                            self.advertise_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn()
                                            self.advertise_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_l2vpn_evpn"] = "advertise-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-l2vpn-evpn")

                                            self.advertise_local_l2vpn_evpn = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn()
                                            self.advertise_local_l2vpn_evpn.parent = self
                                            self._children_name_map["advertise_local_l2vpn_evpn"] = "advertise-local-l2vpn-evpn"
                                            self._children_yang_names.add("advertise-local-l2vpn-evpn")

                                            self.advertise_local_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4()
                                            self.advertise_local_v4.parent = self
                                            self._children_name_map["advertise_local_v4"] = "advertise-local-v4"
                                            self._children_yang_names.add("advertise-local-v4")

                                            self.advertise_local_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6()
                                            self.advertise_local_v6.parent = self
                                            self._children_name_map["advertise_local_v6"] = "advertise-local-v6"
                                            self._children_yang_names.add("advertise-local-v6")

                                            self.advertise_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4()
                                            self.advertise_v4.parent = self
                                            self._children_name_map["advertise_v4"] = "advertise-v4"
                                            self._children_yang_names.add("advertise-v4")

                                            self.advertise_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6()
                                            self.advertise_v6.parent = self
                                            self._children_name_map["advertise_v6"] = "advertise-v6"
                                            self._children_yang_names.add("advertise-v6")

                                            self.advertise_vrf_imp_disable_v4 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4()
                                            self.advertise_vrf_imp_disable_v4.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v4"] = "advertise-vrf-imp-disable-v4"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v4")

                                            self.advertise_vrf_imp_disable_v6 = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6()
                                            self.advertise_vrf_imp_disable_v6.parent = self
                                            self._children_name_map["advertise_vrf_imp_disable_v6"] = "advertise-vrf-imp-disable-v6"
                                            self._children_yang_names.add("advertise-vrf-imp-disable-v6")

                                            self.aigp_cost_community = None
                                            self._children_name_map["aigp_cost_community"] = "aigp-cost-community"
                                            self._children_yang_names.add("aigp-cost-community")

                                            self.default_originate = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate()
                                            self.default_originate.parent = self
                                            self._children_name_map["default_originate"] = "default-originate"
                                            self._children_yang_names.add("default-originate")

                                            self.import_ = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_()
                                            self.import_.parent = self
                                            self._children_name_map["import_"] = "import"
                                            self._children_yang_names.add("import")

                                            self.maximum_prefixes = None
                                            self._children_name_map["maximum_prefixes"] = "maximum-prefixes"
                                            self._children_yang_names.add("maximum-prefixes")

                                            self.neighbor_af_long_lived_graceful_restart_stale_time = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime()
                                            self.neighbor_af_long_lived_graceful_restart_stale_time.parent = self
                                            self._children_name_map["neighbor_af_long_lived_graceful_restart_stale_time"] = "neighbor-af-long-lived-graceful-restart-stale-time"
                                            self._children_yang_names.add("neighbor-af-long-lived-graceful-restart-stale-time")

                                            self.remove_private_as_entire_as_path = None
                                            self._children_name_map["remove_private_as_entire_as_path"] = "remove-private-as-entire-as-path"
                                            self._children_yang_names.add("remove-private-as-entire-as-path")

                                            self.remove_private_as_entire_as_path_inbound = None
                                            self._children_name_map["remove_private_as_entire_as_path_inbound"] = "remove-private-as-entire-as-path-inbound"
                                            self._children_yang_names.add("remove-private-as-entire-as-path-inbound")

                                            self.site_of_origin = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin()
                                            self.site_of_origin.parent = self
                                            self._children_name_map["site_of_origin"] = "site-of-origin"
                                            self._children_yang_names.add("site-of-origin")

                                            self.soft_reconfiguration = Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration()
                                            self.soft_reconfiguration.parent = self
                                            self._children_name_map["soft_reconfiguration"] = "soft-reconfiguration"
                                            self._children_yang_names.add("soft-reconfiguration")
                                            self._segment_path = lambda: "vrf-neighbor-af" + "[af-name='" + self.af_name.get() + "']"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf, ['af_name', 'accept_own', 'accept_route_legacy_rt', 'activate', 'advertise_local_labeled_route', 'advertise_orf', 'advertise_permanent_network', 'af_group', 'aigp', 'aigp_send_med', 'allow_as_in', 'as_override', 'default_weight', 'encapsulation_type', 'enforce_multiple_labels', 'flowspec_validation', 'multipath', 'neighbor_af_long_lived_graceful_restart_capable', 'next_hop_self', 'next_hop_unchanged', 'next_hop_unchanged_multipath', 'prefix_orf_policy', 'route_policy_in', 'route_policy_out', 'route_reflector_client', 'send_community_ebgp', 'send_community_ebgp_graceful_shutdown', 'send_ext_community_ebgp'], name, value)


                                        class AdvertiseDefImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDefImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of Default VRF Imported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-def-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-def-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDefImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseDisable(Entity):
                                            """
                                            Disable Advertise Of Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, self).__init__()

                                                self.yang_name = "advertise-disable"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-disable"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseDisable, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseL2VpnEvpn(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-l2vpn-evpn"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalL2VpnEvpn(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn, self).__init__()

                                                self.yang_name = "advertise-local-l2vpn-evpn"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-l2vpn-evpn"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalL2VpnEvpn, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV4(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, self).__init__()

                                                self.yang_name = "advertise-local-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseLocalV6(Entity):
                                            """
                                            Advertise Of Local Routes to the peer with
                                            different RT
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, self).__init__()

                                                self.yang_name = "advertise-local-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-local-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseLocalV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV4(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, self).__init__()

                                                self.yang_name = "advertise-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV4, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseV6(Entity):
                                            """
                                            Advertise Translated Routes to the peer
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: reorg_option
                                            
                                            	Reorigination option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, self).__init__()

                                                self.yang_name = "advertise-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.reorg_option = YLeaf(YType.enumeration, "reorg-option")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseV6, ['af_name', 'reorg_option', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV4(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v4"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v4"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV4, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AdvertiseVrfImpDisableV6(Entity):
                                            """
                                            Disable Advertise Of VRF ReImported Routes
                                            
                                            .. attribute:: adv_option
                                            
                                            	Advertise option
                                            	**type**\:   :py:class:`BgpReorgOpt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpReorgOpt>`
                                            
                                            .. attribute:: af_name
                                            
                                            	Address family
                                            	**type**\:   :py:class:`BgpAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpAddressFamily>`
                                            
                                            .. attribute:: rt_type
                                            
                                            	RT type
                                            	**type**\:   :py:class:`BgpAdvRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAdvRt>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, self).__init__()

                                                self.yang_name = "advertise-vrf-imp-disable-v6"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.adv_option = YLeaf(YType.enumeration, "adv-option")

                                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                                self.rt_type = YLeaf(YType.enumeration, "rt-type")
                                                self._segment_path = lambda: "advertise-vrf-imp-disable-v6"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AdvertiseVrfImpDisableV6, ['adv_option', 'af_name', 'rt_type'], name, value)


                                        class AigpCostCommunity(Entity):
                                            """
                                            Send AIGP value in Cost Community. 
                                            
                                            .. attribute:: cost_community_id
                                            
                                            	Cost Community ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: cost_community_poi_type
                                            
                                            	Cost Community POI
                                            	**type**\:   :py:class:`BgpAigpCfgPoi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpAigpCfgPoi>`
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to enable sending cost community, FALSE otherwise 
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: transitive
                                            
                                            	True to send transitive cost community FALSE otherwise
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, self).__init__()

                                                self.yang_name = "aigp-cost-community"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.cost_community_id = YLeaf(YType.uint32, "cost-community-id")

                                                self.cost_community_poi_type = YLeaf(YType.enumeration, "cost-community-poi-type")

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.transitive = YLeaf(YType.boolean, "transitive")
                                                self._segment_path = lambda: "aigp-cost-community"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.AigpCostCommunity, ['cost_community_id', 'cost_community_poi_type', 'enable', 'transitive'], name, value)


                                        class DefaultOriginate(Entity):
                                            """
                                            Originate default route to this neighbor
                                            
                                            .. attribute:: enable
                                            
                                            	FALSE to prevent default\-originate from, being inherited from a parent. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: route_policy_name
                                            
                                            	Route policy name to specify criteria to originate default
                                            	**type**\:  str
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, self).__init__()

                                                self.yang_name = "default-originate"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.route_policy_name = YLeaf(YType.str, "route-policy-name")
                                                self._segment_path = lambda: "default-originate"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.DefaultOriginate, ['enable', 'route_policy_name'], name, value)


                                        class Import_(Entity):
                                            """
                                            Import Reorigination options for Routes from the
                                            peer
                                            
                                            .. attribute:: import_reoriginate
                                            
                                            	TRUE to Reoriginate imported routes, FALSE to not Reoriginate imported routes \- not supported
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_reoriginate_stitching
                                            
                                            	TRUE to Reoriginate imported routes with Stitching RTs, FALSE to Reoriginate imported routes with normal RTs
                                            	**type**\:  bool
                                            
                                            .. attribute:: import_stitching
                                            
                                            	TRUE to Import with Stitching RTs, FALSE to Import with normal RTs
                                            	**type**\:  bool
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_, self).__init__()

                                                self.yang_name = "import"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.import_reoriginate = YLeaf(YType.boolean, "import-reoriginate")

                                                self.import_reoriginate_stitching = YLeaf(YType.boolean, "import-reoriginate-stitching")

                                                self.import_stitching = YLeaf(YType.boolean, "import-stitching")
                                                self._segment_path = lambda: "import"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.Import_, ['import_reoriginate', 'import_reoriginate_stitching', 'import_stitching'], name, value)


                                        class MaximumPrefixes(Entity):
                                            """
                                            Maximum number of prefixes to accept from this
                                            peer
                                            
                                            .. attribute:: discard_extra_paths
                                            
                                            	Discard extra paths when limit is exceeded
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: prefix_limit
                                            
                                            	Maximum prefixes limit
                                            	**type**\:  int
                                            
                                            	**range:** 1..4294967295
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: restart_time
                                            
                                            	Restart interval
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: warning_only
                                            
                                            	TRUE to only give a warning message when limit is exceeded.  FALSE to accept max prefix limit only
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: warning_percentage
                                            
                                            	Threshold value (%) at which to generate a warning message
                                            	**type**\:  int
                                            
                                            	**range:** 1..100
                                            
                                            	**default value**\: 75
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, self).__init__()

                                                self.yang_name = "maximum-prefixes"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.discard_extra_paths = YLeaf(YType.boolean, "discard-extra-paths")

                                                self.prefix_limit = YLeaf(YType.uint32, "prefix-limit")

                                                self.restart_time = YLeaf(YType.uint32, "restart-time")

                                                self.warning_only = YLeaf(YType.boolean, "warning-only")

                                                self.warning_percentage = YLeaf(YType.uint32, "warning-percentage")
                                                self._segment_path = lambda: "maximum-prefixes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.MaximumPrefixes, ['discard_extra_paths', 'prefix_limit', 'restart_time', 'warning_only', 'warning_percentage'], name, value)


                                        class NeighborAfLongLivedGracefulRestartStaleTime(Entity):
                                            """
                                            Maximum time to wait before purging long lived
                                            routes
                                            
                                            .. attribute:: stale_time_accept
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            .. attribute:: stale_time_send
                                            
                                            	Max time (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..16777215
                                            
                                            	**units**\: second
                                            
                                            	**default value**\: 0
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, self).__init__()

                                                self.yang_name = "neighbor-af-long-lived-graceful-restart-stale-time"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.stale_time_accept = YLeaf(YType.uint32, "stale-time-accept")

                                                self.stale_time_send = YLeaf(YType.uint32, "stale-time-send")
                                                self._segment_path = lambda: "neighbor-af-long-lived-graceful-restart-stale-time"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.NeighborAfLongLivedGracefulRestartStaleTime, ['stale_time_accept', 'stale_time_send'], name, value)


                                        class RemovePrivateAsEntireAsPath(Entity):
                                            """
                                            Remove private AS number from outbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from outbound updates .  FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from outbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPath, ['enable', 'entire'], name, value)


                                        class RemovePrivateAsEntireAsPathInbound(Entity):
                                            """
                                            Remove private AS number from inbound updates
                                            
                                            .. attribute:: enable
                                            
                                            	TRUE to remove private AS from inbound updates. FALSE to prevent remove\-private\-AS from being inherited
                                            	**type**\:  bool
                                            
                                            	**mandatory**\: True
                                            
                                            .. attribute:: entire
                                            
                                            	TRUE to remove private AS from inbound updates if all ASes in aspath areprivate. FALSE to prevent remove\-private\-ASfrom being inherited
                                            	**type**\:  bool
                                            
                                            

                                            This class is a :ref:`presence class<presence-class>`

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, self).__init__()

                                                self.yang_name = "remove-private-as-entire-as-path-inbound"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}
                                                self.is_presence_container = True

                                                self.enable = YLeaf(YType.boolean, "enable")

                                                self.entire = YLeaf(YType.boolean, "entire")
                                                self._segment_path = lambda: "remove-private-as-entire-as-path-inbound"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.RemovePrivateAsEntireAsPathInbound, ['enable', 'entire'], name, value)


                                        class SiteOfOrigin(Entity):
                                            """
                                            Site\-of\-Origin extended community associated
                                            with the neighbor
                                            
                                            .. attribute:: address
                                            
                                            	IP address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: address_index
                                            
                                            	IP address Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: as_
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_index
                                            
                                            	AS number Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: as_xx
                                            
                                            	AS number
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: type
                                            
                                            	Type of Extended community
                                            	**type**\:   :py:class:`BgpSiteOfOrigin <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BgpSiteOfOrigin>`
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, self).__init__()

                                                self.yang_name = "site-of-origin"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.address = YLeaf(YType.str, "address")

                                                self.address_index = YLeaf(YType.uint32, "address-index")

                                                self.as_ = YLeaf(YType.uint32, "as")

                                                self.as_index = YLeaf(YType.uint32, "as-index")

                                                self.as_xx = YLeaf(YType.uint32, "as-xx")

                                                self.type = YLeaf(YType.enumeration, "type")
                                                self._segment_path = lambda: "site-of-origin"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SiteOfOrigin, ['address', 'address_index', 'as_', 'as_index', 'as_xx', 'type'], name, value)


                                        class SoftReconfiguration(Entity):
                                            """
                                            Enable/disable inbound soft reconfiguration for
                                            this neighbor/neighbor\-group/af\-group
                                            
                                            .. attribute:: inbound_soft
                                            
                                            	FALSE to prohibit inbound soft reconfiguration. TRUE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            .. attribute:: soft_always
                                            
                                            	TRUE to always use soft reconfig, even if route refresh is supported.  FALSE otherwise
                                            	**type**\:  bool
                                            
                                            	**default value**\: false
                                            
                                            

                                            """

                                            _prefix = 'ipv4-bgp-cfg'
                                            _revision = '2017-06-26'

                                            def __init__(self):
                                                super(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, self).__init__()

                                                self.yang_name = "soft-reconfiguration"
                                                self.yang_parent_name = "vrf-neighbor-af"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.inbound_soft = YLeaf(YType.boolean, "inbound-soft")

                                                self.soft_always = YLeaf(YType.boolean, "soft-always")
                                                self._segment_path = lambda: "soft-reconfiguration"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Bgp.Instance.InstanceAs.FourByteAs.Vrfs.Vrf.VrfNeighbors.VrfNeighborPrefixLength.VrfNeighborAfs.VrfNeighborAf.SoftReconfiguration, ['inbound_soft', 'soft_always'], name, value)

    def clone_ptr(self):
        self._top_entity = Bgp()
        return self._top_entity

class BmpServerAll(Entity):
    """
    bmp server all
    
    .. attribute:: maximum_buffer_size
    
    	Range in MegaBytes for the maximum buffer size of BMP message queue. The maximum buf\-size is 20% and default buf\-size is 15% of the platform virtual memory max\-limit (aka rlimit). Please run show bgp process performance\-statistics to see the individual values. Unit is in Megabytes
    	**type**\:  int
    
    	**range:** 1..4294967295
    
    	**units**\: megabyte
    
    .. attribute:: route_monitoring
    
    	Enable Route Monitoring capability for the BMP servers. BGP update messages messages will be regenrated with a table walk 
    	**type**\:   :py:class:`RouteMonitoring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServerAll.RouteMonitoring>`
    
    

    """

    _prefix = 'ipv4-bgp-cfg'
    _revision = '2017-06-26'

    def __init__(self):
        super(BmpServerAll, self).__init__()
        self._top_entity = None

        self.yang_name = "bmp-server-all"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"route-monitoring" : ("route_monitoring", BmpServerAll.RouteMonitoring)}
        self._child_list_classes = {}

        self.maximum_buffer_size = YLeaf(YType.uint32, "maximum-buffer-size")

        self.route_monitoring = BmpServerAll.RouteMonitoring()
        self.route_monitoring.parent = self
        self._children_name_map["route_monitoring"] = "route-monitoring"
        self._children_yang_names.add("route-monitoring")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-server-all"

    def __setattr__(self, name, value):
        self._perform_setattr(BmpServerAll, ['maximum_buffer_size'], name, value)


    class RouteMonitoring(Entity):
        """
        Enable Route Monitoring capability for the BMP
        servers.
        BGP update messages messages will be
        regenrated with a table walk
        
        
        .. attribute:: direction
        
        	Specify if the routes should be picked up at inbound or outbound direction
        	**type**\:   :py:class:`BmpRouteDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpRouteDirection>`
        
        .. attribute:: policy
        
        	Specify if the routes packed in update messages should be before or after the application of route\-policy
        	**type**\:   :py:class:`BmpPolicySelect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpPolicySelect>`
        
        

        """

        _prefix = 'ipv4-bgp-cfg'
        _revision = '2017-06-26'

        def __init__(self):
            super(BmpServerAll.RouteMonitoring, self).__init__()

            self.yang_name = "route-monitoring"
            self.yang_parent_name = "bmp-server-all"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {}

            self.direction = YLeaf(YType.enumeration, "direction")

            self.policy = YLeaf(YType.enumeration, "policy")
            self._segment_path = lambda: "route-monitoring"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-server-all/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(BmpServerAll.RouteMonitoring, ['direction', 'policy'], name, value)

    def clone_ptr(self):
        self._top_entity = BmpServerAll()
        return self._top_entity

class BmpServers(Entity):
    """
    bmp servers
    
    .. attribute:: bmp_server
    
    	A particular BMP server
    	**type**\: list of    :py:class:`BmpServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer>`
    
    

    """

    _prefix = 'ipv4-bgp-cfg'
    _revision = '2017-06-26'

    def __init__(self):
        super(BmpServers, self).__init__()
        self._top_entity = None

        self.yang_name = "bmp-servers"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-bgp-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {}
        self._child_list_classes = {"bmp-server" : ("bmp_server", BmpServers.BmpServer)}

        self.bmp_server = YList(self)
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-servers"

    def __setattr__(self, name, value):
        self._perform_setattr(BmpServers, [], name, value)


    class BmpServer(Entity):
        """
        A particular BMP server
        
        .. attribute:: server_id  <key>
        
        	BMP Server ID
        	**type**\:  int
        
        	**range:** 1..8
        
        .. attribute:: bmptcp_keep_alive
        
        	configure TCP keep alives to be exchanged between client and server. Default=1000
        	**type**\:  int
        
        	**range:** 0..7200
        
        	**units**\: second
        
        .. attribute:: bmptcp_maximum_segment_size
        
        	configure TCP maximum segment size. Default=16384
        	**type**\:  int
        
        	**range:** 68..10000
        
        	**units**\: byte
        
        .. attribute:: create
        
        	BMP Server Creation
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: description
        
        	String to describe the BMP server
        	**type**\:  str
        
        .. attribute:: flapping_delay
        
        	Delay in connecting to BMP Server after a flap had been detected
        	**type**\:  int
        
        	**range:** 60..3600
        
        	**units**\: second
        
        .. attribute:: host_port
        
        	Configure Host Name/Address and Port for BMP Server
        	**type**\:   :py:class:`HostPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer.HostPort>`
        
        .. attribute:: initial_delay
        
        	Initial connect delay in seconds in sending updates
        	**type**\:  int
        
        	**range:** 1..3600
        
        	**units**\: second
        
        .. attribute:: initial_refresh_delay
        
        	Initial refresh to generate BGP updates
        	**type**\:   :py:class:`InitialRefreshDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer.InitialRefreshDelay>`
        
        .. attribute:: maximum_buffer_size
        
        	Range in MegaBytes for the maximum buffer size of BMP message queue. The maximum buf\-size is 20% and default buf\-size is 15% of the platform virtual memory max\-limit (aka rlimit) . Please run show bgp process performance\-statistics to see the individual values. Unit is in Megabytes
        	**type**\:  int
        
        	**range:** 1..4294967295
        
        	**units**\: megabyte
        
        .. attribute:: shutdown
        
        	Shutdown connection to BMP server
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: status_report_interval
        
        	Stats reporting period for BMP server
        	**type**\:  int
        
        	**range:** 1..3600
        
        	**units**\: second
        
        .. attribute:: tos
        
        	TOS (Type Of Service)
        	**type**\:   :py:class:`Tos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_cfg.BmpServers.BmpServer.Tos>`
        
        .. attribute:: update_source_interface
        
        	Select an interface to configure
        	**type**\:  str
        
        	**pattern:** [a\-zA\-Z0\-9./\-]+
        
        .. attribute:: vrf
        
        	VRF for BMP Server
        	**type**\:  str
        
        

        """

        _prefix = 'ipv4-bgp-cfg'
        _revision = '2017-06-26'

        def __init__(self):
            super(BmpServers.BmpServer, self).__init__()

            self.yang_name = "bmp-server"
            self.yang_parent_name = "bmp-servers"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"host-port" : ("host_port", BmpServers.BmpServer.HostPort), "initial-refresh-delay" : ("initial_refresh_delay", BmpServers.BmpServer.InitialRefreshDelay), "tos" : ("tos", BmpServers.BmpServer.Tos)}
            self._child_list_classes = {}

            self.server_id = YLeaf(YType.uint32, "server-id")

            self.bmptcp_keep_alive = YLeaf(YType.uint32, "bmptcp-keep-alive")

            self.bmptcp_maximum_segment_size = YLeaf(YType.uint32, "bmptcp-maximum-segment-size")

            self.create = YLeaf(YType.empty, "create")

            self.description = YLeaf(YType.str, "description")

            self.flapping_delay = YLeaf(YType.uint32, "flapping-delay")

            self.initial_delay = YLeaf(YType.uint32, "initial-delay")

            self.maximum_buffer_size = YLeaf(YType.uint32, "maximum-buffer-size")

            self.shutdown = YLeaf(YType.empty, "shutdown")

            self.status_report_interval = YLeaf(YType.uint32, "status-report-interval")

            self.update_source_interface = YLeaf(YType.str, "update-source-interface")

            self.vrf = YLeaf(YType.str, "vrf")

            self.host_port = BmpServers.BmpServer.HostPort()
            self.host_port.parent = self
            self._children_name_map["host_port"] = "host-port"
            self._children_yang_names.add("host-port")

            self.initial_refresh_delay = BmpServers.BmpServer.InitialRefreshDelay()
            self.initial_refresh_delay.parent = self
            self._children_name_map["initial_refresh_delay"] = "initial-refresh-delay"
            self._children_yang_names.add("initial-refresh-delay")

            self.tos = BmpServers.BmpServer.Tos()
            self.tos.parent = self
            self._children_name_map["tos"] = "tos"
            self._children_yang_names.add("tos")
            self._segment_path = lambda: "bmp-server" + "[server-id='" + self.server_id.get() + "']"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-bgp-cfg:bmp-servers/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(BmpServers.BmpServer, ['server_id', 'bmptcp_keep_alive', 'bmptcp_maximum_segment_size', 'create', 'description', 'flapping_delay', 'initial_delay', 'maximum_buffer_size', 'shutdown', 'status_report_interval', 'update_source_interface', 'vrf'], name, value)


        class HostPort(Entity):
            """
            Configure Host Name/Address and Port for BMP
            Server
            
            .. attribute:: host
            
            	Name of the BMP server(accepts IPv4/IPv6 Address format too)
            	**type**\:  str
            
            .. attribute:: port
            
            	Port Number of listening BMP server
            	**type**\:  int
            
            	**range:** 1..65535
            
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(BmpServers.BmpServer.HostPort, self).__init__()

                self.yang_name = "host-port"
                self.yang_parent_name = "bmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.host = YLeaf(YType.str, "host")

                self.port = YLeaf(YType.uint16, "port")
                self._segment_path = lambda: "host-port"

            def __setattr__(self, name, value):
                self._perform_setattr(BmpServers.BmpServer.HostPort, ['host', 'port'], name, value)


        class InitialRefreshDelay(Entity):
            """
            Initial refresh to generate BGP updates
            
            .. attribute:: delay
            
            	Delay in seconds before sending Refresh request to Peers
            	**type**\:  int
            
            	**range:** 1..3600
            
            	**units**\: second
            
            .. attribute:: skip
            
            	Skip Route Refresh request to Peers
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: spread
            
            	Spread over which to send initial Refresh request to Peers
            	**type**\:  int
            
            	**range:** 1..3600
            
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(BmpServers.BmpServer.InitialRefreshDelay, self).__init__()

                self.yang_name = "initial-refresh-delay"
                self.yang_parent_name = "bmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.delay = YLeaf(YType.uint32, "delay")

                self.skip = YLeaf(YType.empty, "skip")

                self.spread = YLeaf(YType.uint32, "spread")
                self._segment_path = lambda: "initial-refresh-delay"

            def __setattr__(self, name, value):
                self._perform_setattr(BmpServers.BmpServer.InitialRefreshDelay, ['delay', 'skip', 'spread'], name, value)


        class Tos(Entity):
            """
            TOS (Type Of Service)
            
            .. attribute:: type
            
            	Set type of service
            	**type**\:   :py:class:`BgpTos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpTos>`
            
            .. attribute:: value
            
            	TOS value to set
            	**type**\: one of the below types:
            
            	**type**\:   :py:class:`BgpPrecedenceDscp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_bgp_datatypes.BgpPrecedenceDscp>`
            
            
            ----
            	**type**\:  int
            
            	**range:** 0..63
            
            
            ----
            

            """

            _prefix = 'ipv4-bgp-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(BmpServers.BmpServer.Tos, self).__init__()

                self.yang_name = "tos"
                self.yang_parent_name = "bmp-server"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.type = YLeaf(YType.enumeration, "type")

                self.value = YLeaf(YType.str, "value")
                self._segment_path = lambda: "tos"

            def __setattr__(self, name, value):
                self._perform_setattr(BmpServers.BmpServer.Tos, ['type', 'value'], name, value)

    def clone_ptr(self):
        self._top_entity = BmpServers()
        return self._top_entity

