""" Cisco_IOS_XR_ipv4_igmp_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ipv4\-igmp package operational data.

This module contains definitions
for the following management objects\:
  mld\: MLD operational data
  igmp\: igmp

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class IgmpAfi(Enum):
    """
    IgmpAfi

    Address family

    .. data:: ipv4_unicast = 0

    	IP v4 unicast

    .. data:: ipv6_unicast = 1

    	IP v6 unicast

    """

    ipv4_unicast = Enum.YLeaf(0, "ipv4-unicast")

    ipv6_unicast = Enum.YLeaf(1, "ipv6-unicast")


class IgmpEdmProtocol(Enum):
    """
    IgmpEdmProtocol

    IGMP Protocol

    .. data:: no_route = 0

    	no route

    .. data:: sm = 1

    	sm

    .. data:: dm = 2

    	dm

    .. data:: bidir = 3

    	bidir

    .. data:: ssm = 4

    	ssm

    .. data:: any = 6

    	any

    """

    no_route = Enum.YLeaf(0, "no-route")

    sm = Enum.YLeaf(1, "sm")

    dm = Enum.YLeaf(2, "dm")

    bidir = Enum.YLeaf(3, "bidir")

    ssm = Enum.YLeaf(4, "ssm")

    any = Enum.YLeaf(6, "any")


class IgmpssmMap(Enum):
    """
    IgmpssmMap

    Igmpssm map

    .. data:: static = 0

    	Static

    .. data:: dns = 1

    	Dns

    .. data:: all = 2

    	All

    """

    static = Enum.YLeaf(0, "static")

    dns = Enum.YLeaf(1, "dns")

    all = Enum.YLeaf(2, "all")



class Igmp(Entity):
    """
    igmp
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby>`
    
    

    """

    _prefix = 'ipv4-igmp-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Igmp, self).__init__()
        self._top_entity = None

        self.yang_name = "igmp"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-igmp-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"active" : ("active", Igmp.Active), "standby" : ("standby", Igmp.Standby)}
        self._child_list_classes = {}

        self.active = Igmp.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Igmp.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp"


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Igmp.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "igmp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Igmp.Active.DefaultContext), "process" : ("process", Igmp.Active.Process), "vrfs" : ("vrfs", Igmp.Active.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Igmp.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Igmp.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Igmp.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"detail-groups" : ("detail_groups", Igmp.Active.DefaultContext.DetailGroups), "explicit-groups" : ("explicit_groups", Igmp.Active.DefaultContext.ExplicitGroups), "global-interface-table" : ("global_interface_table", Igmp.Active.DefaultContext.GlobalInterfaceTable), "group-summary" : ("group_summary", Igmp.Active.DefaultContext.GroupSummary), "groups" : ("groups", Igmp.Active.DefaultContext.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Igmp.Active.DefaultContext.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Igmp.Active.DefaultContext.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Igmp.Active.DefaultContext.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Igmp.Active.DefaultContext.InterfaceStateOns), "interface-table" : ("interface_table", Igmp.Active.DefaultContext.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Igmp.Active.DefaultContext.NonActiveGroups), "ranges" : ("ranges", Igmp.Active.DefaultContext.Ranges), "ssm-map-details" : ("ssm_map_details", Igmp.Active.DefaultContext.SsmMapDetails), "ssm-maps" : ("ssm_maps", Igmp.Active.DefaultContext.SsmMaps), "summary" : ("summary", Igmp.Active.DefaultContext.Summary), "traffic-counters" : ("traffic_counters", Igmp.Active.DefaultContext.TrafficCounters)}
                self._child_list_classes = {}

                self.detail_groups = Igmp.Active.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Igmp.Active.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Igmp.Active.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Igmp.Active.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Igmp.Active.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Igmp.Active.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Igmp.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Igmp.Active.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Igmp.Active.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Igmp.Active.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Igmp.Active.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Igmp.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Igmp.Active.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Igmp.Active.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Igmp.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Igmp.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/%s" % self._segment_path()


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"detail-group" : ("detail_group", Igmp.Active.DefaultContext.DetailGroups.DetailGroup)}

                    self.detail_group = YList(self)
                    self._segment_path = lambda: "detail-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups, [], name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo)}
                        self._child_list_classes = {"source" : ("source", Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source)}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)
                        self._segment_path = lambda: "detail-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"source-address" : ("source_address", Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/detail-groups/detail-group/source/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"explicit-group" : ("explicit_group", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup)}

                    self.explicit_group = YList(self)
                    self._segment_path = lambda: "explicit-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups, [], name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo)}
                        self._child_list_classes = {"host" : ("host", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host)}

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)
                        self._segment_path = lambda: "explicit-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"address" : ("address", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address)}
                            self._child_list_classes = {"source-address" : ("source_address", Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)
                            self._segment_path = lambda: "host"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "global-interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.GlobalInterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/global-interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                    self._segment_path = lambda: "group-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group" : ("group", Igmp.Active.DefaultContext.Groups.Group)}

                    self.group = YList(self)
                    self._segment_path = lambda: "groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.Groups, [], name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Active.DefaultContext.Groups.Group.LastReporter), "source-address" : ("source_address", Igmp.Active.DefaultContext.Groups.Group.SourceAddress)}
                        self._child_list_classes = {}

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Igmp.Active.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Igmp.Active.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "last-reporter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-interface-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "igmp-interface-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-off" : ("interface_state_off", Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff)}

                    self.interface_state_off = YList(self)
                    self._segment_path = lambda: "interface-state-offs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOffs, [], name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-state-offs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-on" : ("interface_state_on", Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn)}

                    self.interface_state_on = YList(self)
                    self._segment_path = lambda: "interface-state-ons"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOns, [], name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-state-ons/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Igmp.Active.DefaultContext.InterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.InterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Active.DefaultContext.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Active.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                    self.interface_unicast_qos_adjust = YList(self)
                    self._segment_path = lambda: "interface-unicast-qos-adjusts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts, [], name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"update" : ("update", Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/interface-unicast-qos-adjusts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                            self._child_list_classes = {}

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "update"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"non-active-groups" : ("non_active_groups", Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups)}

                    self.non_active_groups = YList(self)
                    self._segment_path = lambda: "non-active-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.NonActiveGroups, [], name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address" : ("group_address", Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "non-active-groups"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/non-active-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Igmp.Active.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail)}

                    self.ssm_map_detail = YList(self)
                    self._segment_path = lambda: "ssm-map-details"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.SsmMapDetails, [], name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"map-info" : ("map_info", Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo)}
                        self._child_list_classes = {"sources" : ("sources", Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources)}

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)
                        self._segment_path = lambda: "ssm-map-detail"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "map-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map" : ("ssm_map", Igmp.Active.DefaultContext.SsmMaps.SsmMap)}

                    self.ssm_map = YList(self)
                    self._segment_path = lambda: "ssm-maps"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.SsmMaps, [], name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "ssm-map"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-maps/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/ssm-maps/ssm-map/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Igmp.Active.DefaultContext.Summary.Interface)}

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                        self._segment_path = lambda: "interface"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.DefaultContext.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.DefaultContext.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"amt-gatewaies" : ("amt_gatewaies", Igmp.Active.Process.AmtGatewaies), "amt-summary" : ("amt_summary", Igmp.Active.Process.AmtSummary), "bvi-statistics" : ("bvi_statistics", Igmp.Active.Process.BviStatistics), "nsf" : ("nsf", Igmp.Active.Process.Nsf), "nsr" : ("nsr", Igmp.Active.Process.Nsr), "unicast-qos-adjust-stats" : ("unicast_qos_adjust_stats", Igmp.Active.Process.UnicastQosAdjustStats)}
                self._child_list_classes = {}

                self.amt_gatewaies = Igmp.Active.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Igmp.Active.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Igmp.Active.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Igmp.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Igmp.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Igmp.Active.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/%s" % self._segment_path()


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"amt-gateway" : ("amt_gateway", Igmp.Active.Process.AmtGatewaies.AmtGateway)}

                    self.amt_gateway = YList(self)
                    self._segment_path = lambda: "amt-gatewaies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.Process.AmtGatewaies, [], name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")
                        self._segment_path = lambda: "amt-gateway"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/amt-gatewaies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Process.AmtGatewaies.AmtGateway, ['amt_nonce', 'amt_port', 'amtgw', 'amtnh', 'gateway_address', 'idb', 'key_len', 'mem_upd_in', 'mem_upd_out', 'port'], name, value)


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")
                    self._segment_path = lambda: "amt-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.Process.AmtSummary, ['anycast_prefix', 'gateway_count', 'is_acl_configured', 'is_gateway_simulation', 'is_ou_of_resource', 'max_gateway', 'mtu', 'prefix_length', 'query_interval', 'relay_address', 'tos', 'ttl', 'tunnel_configured_maximum', 'tunnel_count'], name, value)


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")
                    self._segment_path = lambda: "bvi-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.Process.BviStatistics, ['null_buffer_handles', 'receive_buffers', 'release_buffers', 'release_fail_buffers', 'rx_add_mrouter_msg', 'rx_delete_mrouter_msg', 'rx_igmp_packet_success', 'rx_ipc_close_notif', 'rx_ipc_connect_notif', 'rx_ipc_error_notif', 'rx_ipc_input_wait_notif', 'rx_ipc_lwm_notif', 'rx_ipc_open_notif', 'rx_ipc_output_notif', 'rx_ipc_publish_notif', 'rx_ipc_q_full_notif', 'rx_ipc_send_status_notif', 'rx_sweep_mrouter_msg', 'rx_unknown_mrouter_msg', 'send_blocks', 'tx_add_mrouter_msg', 'tx_buffer_errors', 'tx_buffers', 'tx_delete_mrouter_msg', 'tx_mrouter_buffers', 'tx_protocol_buffers', 'tx_sweep_mrouter_msg', 'tx_unknown_buffers', 'tx_unknown_mrouter_msg', 'wtx_msg_drop_dc', 'wtx_msg_drop_nomem', 'wtx_msg_freed', 'wtx_msg_proto_sent', 'wtx_msg_recvd', 'wtx_msg_sent'], name, value)


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.Process.Nsf, ['is_multicast_nsf_active', 'last_icd_notif_recv', 'last_icd_notif_recv_min', 'last_nsf_off', 'last_nsf_off_min', 'last_nsf_on', 'last_nsf_on_min', 'multicast_nsf_time_left', 'multicast_nsf_timeout', 'respawn_count'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.Process.Nsr, ['collab_conv_done', 'count_proc_connection_dn', 'count_proc_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_proc', 'last_proc_connection_dn', 'last_proc_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_proc_connected', 'rmf_notification_done', 'state'], name, value)


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")
                    self._segment_path = lambda: "unicast-qos-adjust-stats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.Process.UnicastQosAdjustStats, ['add_to_batches', 'batches', 'delete_to_batches', 'is_qos_s_sweeped', 'is_resync_received', 'is_resync_required', 'is_resync_start_sent', 'last_download_time', 'last_sweep_time', 'queues', 'received_resync_requests', 'send_comm_errors', 'send_errors', 'send_partial_errors', 'send_success', 'sent_resync_bulks'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Igmp.Active.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Igmp.Active.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"detail-groups" : ("detail_groups", Igmp.Active.Vrfs.Vrf.DetailGroups), "explicit-groups" : ("explicit_groups", Igmp.Active.Vrfs.Vrf.ExplicitGroups), "global-interface-table" : ("global_interface_table", Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable), "group-summary" : ("group_summary", Igmp.Active.Vrfs.Vrf.GroupSummary), "groups" : ("groups", Igmp.Active.Vrfs.Vrf.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Igmp.Active.Vrfs.Vrf.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Igmp.Active.Vrfs.Vrf.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Igmp.Active.Vrfs.Vrf.InterfaceStateOns), "interface-table" : ("interface_table", Igmp.Active.Vrfs.Vrf.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Igmp.Active.Vrfs.Vrf.NonActiveGroups), "ranges" : ("ranges", Igmp.Active.Vrfs.Vrf.Ranges), "ssm-map-details" : ("ssm_map_details", Igmp.Active.Vrfs.Vrf.SsmMapDetails), "ssm-maps" : ("ssm_maps", Igmp.Active.Vrfs.Vrf.SsmMaps), "summary" : ("summary", Igmp.Active.Vrfs.Vrf.Summary), "traffic-counters" : ("traffic_counters", Igmp.Active.Vrfs.Vrf.TrafficCounters)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Igmp.Active.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Igmp.Active.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Igmp.Active.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Igmp.Active.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Igmp.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Igmp.Active.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Igmp.Active.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Igmp.Active.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Igmp.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Igmp.Active.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Igmp.Active.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Igmp.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Igmp.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/active/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"detail-group" : ("detail_group", Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup)}

                        self.detail_group = YList(self)
                        self._segment_path = lambda: "detail-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups, [], name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo)}
                            self._child_list_classes = {"source" : ("source", Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source)}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)
                            self._segment_path = lambda: "detail-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"source-address" : ("source_address", Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"explicit-group" : ("explicit_group", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup)}

                        self.explicit_group = YList(self)
                        self._segment_path = lambda: "explicit-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups, [], name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo)}
                            self._child_list_classes = {"host" : ("host", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host)}

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)
                            self._segment_path = lambda: "explicit-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address)}
                                self._child_list_classes = {"source-address" : ("source_address", Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)
                                self._segment_path = lambda: "host"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "global-interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                        self._segment_path = lambda: "group-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group" : ("group", Igmp.Active.Vrfs.Vrf.Groups.Group)}

                        self.group = YList(self)
                        self._segment_path = lambda: "groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.Groups, [], name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter), "source-address" : ("source_address", Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-interface-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                                self._child_list_classes = {}

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")
                                self._segment_path = lambda: "igmp-interface-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "querier-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "subscriber-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-off" : ("interface_state_off", Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff)}

                        self.interface_state_off = YList(self)
                        self._segment_path = lambda: "interface-state-offs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs, [], name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-on" : ("interface_state_on", Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn)}

                        self.interface_state_on = YList(self)
                        self._segment_path = lambda: "interface-state-ons"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOns, [], name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                        self.interface_unicast_qos_adjust = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjusts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, [], name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update" : ("update", Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)
                            self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address" : ("group_address", Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                                self._child_list_classes = {}

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "update"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"non-active-groups" : ("non_active_groups", Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups)}

                        self.non_active_groups = YList(self)
                        self._segment_path = lambda: "non-active-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.NonActiveGroups, [], name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress)}
                            self._child_list_classes = {}

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "non-active-groups"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Igmp.Active.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail)}

                        self.ssm_map_detail = YList(self)
                        self._segment_path = lambda: "ssm-map-details"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMapDetails, [], name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"map-info" : ("map_info", Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo)}
                            self._child_list_classes = {"sources" : ("sources", Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources)}

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)
                            self._segment_path = lambda: "ssm-map-detail"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                                self._child_list_classes = {}

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")
                                self._segment_path = lambda: "map-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map" : ("ssm_map", Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap)}

                        self.ssm_map = YList(self)
                        self._segment_path = lambda: "ssm-maps"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMaps, [], name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "ssm-map"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Active.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Igmp.Active.Vrfs.Vrf.Summary.Interface)}

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Active.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Active.Vrfs.Vrf.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Active.Vrfs.Vrf.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Igmp.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "igmp"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Igmp.Standby.DefaultContext), "process" : ("process", Igmp.Standby.Process), "vrfs" : ("vrfs", Igmp.Standby.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Igmp.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Igmp.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Igmp.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"detail-groups" : ("detail_groups", Igmp.Standby.DefaultContext.DetailGroups), "explicit-groups" : ("explicit_groups", Igmp.Standby.DefaultContext.ExplicitGroups), "global-interface-table" : ("global_interface_table", Igmp.Standby.DefaultContext.GlobalInterfaceTable), "group-summary" : ("group_summary", Igmp.Standby.DefaultContext.GroupSummary), "groups" : ("groups", Igmp.Standby.DefaultContext.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Igmp.Standby.DefaultContext.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Igmp.Standby.DefaultContext.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Igmp.Standby.DefaultContext.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Igmp.Standby.DefaultContext.InterfaceStateOns), "interface-table" : ("interface_table", Igmp.Standby.DefaultContext.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Igmp.Standby.DefaultContext.NonActiveGroups), "ranges" : ("ranges", Igmp.Standby.DefaultContext.Ranges), "ssm-map-details" : ("ssm_map_details", Igmp.Standby.DefaultContext.SsmMapDetails), "ssm-maps" : ("ssm_maps", Igmp.Standby.DefaultContext.SsmMaps), "summary" : ("summary", Igmp.Standby.DefaultContext.Summary), "traffic-counters" : ("traffic_counters", Igmp.Standby.DefaultContext.TrafficCounters)}
                self._child_list_classes = {}

                self.detail_groups = Igmp.Standby.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Igmp.Standby.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Igmp.Standby.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Igmp.Standby.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Igmp.Standby.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Igmp.Standby.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Igmp.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Igmp.Standby.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Igmp.Standby.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Igmp.Standby.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Igmp.Standby.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Igmp.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Igmp.Standby.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Igmp.Standby.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Igmp.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Igmp.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/%s" % self._segment_path()


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"detail-group" : ("detail_group", Igmp.Standby.DefaultContext.DetailGroups.DetailGroup)}

                    self.detail_group = YList(self)
                    self._segment_path = lambda: "detail-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups, [], name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo)}
                        self._child_list_classes = {"source" : ("source", Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source)}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)
                        self._segment_path = lambda: "detail-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"source-address" : ("source_address", Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/detail-groups/detail-group/source/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"explicit-group" : ("explicit_group", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup)}

                    self.explicit_group = YList(self)
                    self._segment_path = lambda: "explicit-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups, [], name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo)}
                        self._child_list_classes = {"host" : ("host", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host)}

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)
                        self._segment_path = lambda: "explicit-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"address" : ("address", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address)}
                            self._child_list_classes = {"source-address" : ("source_address", Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)
                            self._segment_path = lambda: "host"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "global-interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.GlobalInterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/global-interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                    self._segment_path = lambda: "group-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group" : ("group", Igmp.Standby.DefaultContext.Groups.Group)}

                    self.group = YList(self)
                    self._segment_path = lambda: "groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.Groups, [], name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Standby.DefaultContext.Groups.Group.LastReporter), "source-address" : ("source_address", Igmp.Standby.DefaultContext.Groups.Group.SourceAddress)}
                        self._child_list_classes = {}

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Igmp.Standby.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Igmp.Standby.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "last-reporter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-interface-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "igmp-interface-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-off" : ("interface_state_off", Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff)}

                    self.interface_state_off = YList(self)
                    self._segment_path = lambda: "interface-state-offs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOffs, [], name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-state-offs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-on" : ("interface_state_on", Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn)}

                    self.interface_state_on = YList(self)
                    self._segment_path = lambda: "interface-state-ons"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOns, [], name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-state-ons/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Igmp.Standby.DefaultContext.InterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                    self.interface_unicast_qos_adjust = YList(self)
                    self._segment_path = lambda: "interface-unicast-qos-adjusts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts, [], name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"update" : ("update", Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/interface-unicast-qos-adjusts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                            self._child_list_classes = {}

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "update"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"non-active-groups" : ("non_active_groups", Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups)}

                    self.non_active_groups = YList(self)
                    self._segment_path = lambda: "non-active-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.NonActiveGroups, [], name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address" : ("group_address", Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "non-active-groups"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/non-active-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Igmp.Standby.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail)}

                    self.ssm_map_detail = YList(self)
                    self._segment_path = lambda: "ssm-map-details"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.SsmMapDetails, [], name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"map-info" : ("map_info", Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo)}
                        self._child_list_classes = {"sources" : ("sources", Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources)}

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)
                        self._segment_path = lambda: "ssm-map-detail"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "map-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map" : ("ssm_map", Igmp.Standby.DefaultContext.SsmMaps.SsmMap)}

                    self.ssm_map = YList(self)
                    self._segment_path = lambda: "ssm-maps"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.SsmMaps, [], name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "ssm-map"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-maps/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/ssm-maps/ssm-map/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Igmp.Standby.DefaultContext.Summary.Interface)}

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                        self._segment_path = lambda: "interface"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.DefaultContext.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.DefaultContext.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"amt-gatewaies" : ("amt_gatewaies", Igmp.Standby.Process.AmtGatewaies), "amt-summary" : ("amt_summary", Igmp.Standby.Process.AmtSummary), "bvi-statistics" : ("bvi_statistics", Igmp.Standby.Process.BviStatistics), "nsf" : ("nsf", Igmp.Standby.Process.Nsf), "nsr" : ("nsr", Igmp.Standby.Process.Nsr), "unicast-qos-adjust-stats" : ("unicast_qos_adjust_stats", Igmp.Standby.Process.UnicastQosAdjustStats)}
                self._child_list_classes = {}

                self.amt_gatewaies = Igmp.Standby.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Igmp.Standby.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Igmp.Standby.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Igmp.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Igmp.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Igmp.Standby.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/%s" % self._segment_path()


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"amt-gateway" : ("amt_gateway", Igmp.Standby.Process.AmtGatewaies.AmtGateway)}

                    self.amt_gateway = YList(self)
                    self._segment_path = lambda: "amt-gatewaies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.Process.AmtGatewaies, [], name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")
                        self._segment_path = lambda: "amt-gateway"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/amt-gatewaies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Process.AmtGatewaies.AmtGateway, ['amt_nonce', 'amt_port', 'amtgw', 'amtnh', 'gateway_address', 'idb', 'key_len', 'mem_upd_in', 'mem_upd_out', 'port'], name, value)


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")
                    self._segment_path = lambda: "amt-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.Process.AmtSummary, ['anycast_prefix', 'gateway_count', 'is_acl_configured', 'is_gateway_simulation', 'is_ou_of_resource', 'max_gateway', 'mtu', 'prefix_length', 'query_interval', 'relay_address', 'tos', 'ttl', 'tunnel_configured_maximum', 'tunnel_count'], name, value)


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")
                    self._segment_path = lambda: "bvi-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.Process.BviStatistics, ['null_buffer_handles', 'receive_buffers', 'release_buffers', 'release_fail_buffers', 'rx_add_mrouter_msg', 'rx_delete_mrouter_msg', 'rx_igmp_packet_success', 'rx_ipc_close_notif', 'rx_ipc_connect_notif', 'rx_ipc_error_notif', 'rx_ipc_input_wait_notif', 'rx_ipc_lwm_notif', 'rx_ipc_open_notif', 'rx_ipc_output_notif', 'rx_ipc_publish_notif', 'rx_ipc_q_full_notif', 'rx_ipc_send_status_notif', 'rx_sweep_mrouter_msg', 'rx_unknown_mrouter_msg', 'send_blocks', 'tx_add_mrouter_msg', 'tx_buffer_errors', 'tx_buffers', 'tx_delete_mrouter_msg', 'tx_mrouter_buffers', 'tx_protocol_buffers', 'tx_sweep_mrouter_msg', 'tx_unknown_buffers', 'tx_unknown_mrouter_msg', 'wtx_msg_drop_dc', 'wtx_msg_drop_nomem', 'wtx_msg_freed', 'wtx_msg_proto_sent', 'wtx_msg_recvd', 'wtx_msg_sent'], name, value)


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.Process.Nsf, ['is_multicast_nsf_active', 'last_icd_notif_recv', 'last_icd_notif_recv_min', 'last_nsf_off', 'last_nsf_off_min', 'last_nsf_on', 'last_nsf_on_min', 'multicast_nsf_time_left', 'multicast_nsf_timeout', 'respawn_count'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.Process.Nsr, ['collab_conv_done', 'count_proc_connection_dn', 'count_proc_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_proc', 'last_proc_connection_dn', 'last_proc_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_proc_connected', 'rmf_notification_done', 'state'], name, value)


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")
                    self._segment_path = lambda: "unicast-qos-adjust-stats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.Process.UnicastQosAdjustStats, ['add_to_batches', 'batches', 'delete_to_batches', 'is_qos_s_sweeped', 'is_resync_received', 'is_resync_required', 'is_resync_start_sent', 'last_download_time', 'last_sweep_time', 'queues', 'received_resync_requests', 'send_comm_errors', 'send_errors', 'send_partial_errors', 'send_success', 'sent_resync_bulks'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Igmp.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Igmp.Standby.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Igmp.Standby.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Igmp.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"detail-groups" : ("detail_groups", Igmp.Standby.Vrfs.Vrf.DetailGroups), "explicit-groups" : ("explicit_groups", Igmp.Standby.Vrfs.Vrf.ExplicitGroups), "global-interface-table" : ("global_interface_table", Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable), "group-summary" : ("group_summary", Igmp.Standby.Vrfs.Vrf.GroupSummary), "groups" : ("groups", Igmp.Standby.Vrfs.Vrf.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Igmp.Standby.Vrfs.Vrf.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Igmp.Standby.Vrfs.Vrf.InterfaceStateOns), "interface-table" : ("interface_table", Igmp.Standby.Vrfs.Vrf.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Igmp.Standby.Vrfs.Vrf.NonActiveGroups), "ranges" : ("ranges", Igmp.Standby.Vrfs.Vrf.Ranges), "ssm-map-details" : ("ssm_map_details", Igmp.Standby.Vrfs.Vrf.SsmMapDetails), "ssm-maps" : ("ssm_maps", Igmp.Standby.Vrfs.Vrf.SsmMaps), "summary" : ("summary", Igmp.Standby.Vrfs.Vrf.Summary), "traffic-counters" : ("traffic_counters", Igmp.Standby.Vrfs.Vrf.TrafficCounters)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Igmp.Standby.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Igmp.Standby.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Igmp.Standby.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Igmp.Standby.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Igmp.Standby.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Igmp.Standby.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Igmp.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Igmp.Standby.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Igmp.Standby.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Igmp.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Igmp.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:igmp/standby/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"detail-group" : ("detail_group", Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup)}

                        self.detail_group = YList(self)
                        self._segment_path = lambda: "detail-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups, [], name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo)}
                            self._child_list_classes = {"source" : ("source", Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source)}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)
                            self._segment_path = lambda: "detail-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"source-address" : ("source_address", Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"explicit-group" : ("explicit_group", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup)}

                        self.explicit_group = YList(self)
                        self._segment_path = lambda: "explicit-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups, [], name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo)}
                            self._child_list_classes = {"host" : ("host", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host)}

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)
                            self._segment_path = lambda: "explicit-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address)}
                                self._child_list_classes = {"source-address" : ("source_address", Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)
                                self._segment_path = lambda: "host"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "global-interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                        self._segment_path = lambda: "group-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group" : ("group", Igmp.Standby.Vrfs.Vrf.Groups.Group)}

                        self.group = YList(self)
                        self._segment_path = lambda: "groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Groups, [], name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter), "source-address" : ("source_address", Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-interface-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                                self._child_list_classes = {}

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")
                                self._segment_path = lambda: "igmp-interface-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "querier-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "subscriber-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-off" : ("interface_state_off", Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff)}

                        self.interface_state_off = YList(self)
                        self._segment_path = lambda: "interface-state-offs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs, [], name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-on" : ("interface_state_on", Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn)}

                        self.interface_state_on = YList(self)
                        self._segment_path = lambda: "interface-state-ons"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns, [], name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                        self.interface_unicast_qos_adjust = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjusts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, [], name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update" : ("update", Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)
                            self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address" : ("group_address", Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                                self._child_list_classes = {}

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "update"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"non-active-groups" : ("non_active_groups", Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups)}

                        self.non_active_groups = YList(self)
                        self._segment_path = lambda: "non-active-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.NonActiveGroups, [], name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress)}
                            self._child_list_classes = {}

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "non-active-groups"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Igmp.Standby.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail)}

                        self.ssm_map_detail = YList(self)
                        self._segment_path = lambda: "ssm-map-details"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMapDetails, [], name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"map-info" : ("map_info", Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo)}
                            self._child_list_classes = {"sources" : ("sources", Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources)}

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)
                            self._segment_path = lambda: "ssm-map-detail"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                                self._child_list_classes = {}

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")
                                self._segment_path = lambda: "map-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map" : ("ssm_map", Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap)}

                        self.ssm_map = YList(self)
                        self._segment_path = lambda: "ssm-maps"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMaps, [], name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "ssm-map"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Igmp.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Igmp.Standby.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Igmp.Standby.Vrfs.Vrf.Summary.Interface)}

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Igmp.Standby.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Igmp.Standby.Vrfs.Vrf.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Igmp.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Igmp.Standby.Vrfs.Vrf.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)

    def clone_ptr(self):
        self._top_entity = Igmp()
        return self._top_entity

class Mld(Entity):
    """
    MLD operational data
    
    .. attribute:: active
    
    	Active Process
    	**type**\:   :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active>`
    
    .. attribute:: standby
    
    	Standby Process
    	**type**\:   :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby>`
    
    

    """

    _prefix = 'ipv4-igmp-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Mld, self).__init__()
        self._top_entity = None

        self.yang_name = "mld"
        self.yang_parent_name = "Cisco-IOS-XR-ipv4-igmp-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"active" : ("active", Mld.Active), "standby" : ("standby", Mld.Standby)}
        self._child_list_classes = {}

        self.active = Mld.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._children_yang_names.add("active")

        self.standby = Mld.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"
        self._children_yang_names.add("standby")
        self._segment_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld"


    class Active(Entity):
        """
        Active Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Mld.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "mld"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Mld.Active.DefaultContext), "process" : ("process", Mld.Active.Process), "vrfs" : ("vrfs", Mld.Active.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Mld.Active.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Mld.Active.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Mld.Active.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Active.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"detail-groups" : ("detail_groups", Mld.Active.DefaultContext.DetailGroups), "explicit-groups" : ("explicit_groups", Mld.Active.DefaultContext.ExplicitGroups), "global-interface-table" : ("global_interface_table", Mld.Active.DefaultContext.GlobalInterfaceTable), "group-summary" : ("group_summary", Mld.Active.DefaultContext.GroupSummary), "groups" : ("groups", Mld.Active.DefaultContext.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Mld.Active.DefaultContext.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Mld.Active.DefaultContext.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Mld.Active.DefaultContext.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Mld.Active.DefaultContext.InterfaceStateOns), "interface-table" : ("interface_table", Mld.Active.DefaultContext.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Mld.Active.DefaultContext.NonActiveGroups), "ranges" : ("ranges", Mld.Active.DefaultContext.Ranges), "ssm-map-details" : ("ssm_map_details", Mld.Active.DefaultContext.SsmMapDetails), "ssm-maps" : ("ssm_maps", Mld.Active.DefaultContext.SsmMaps), "summary" : ("summary", Mld.Active.DefaultContext.Summary), "traffic-counters" : ("traffic_counters", Mld.Active.DefaultContext.TrafficCounters)}
                self._child_list_classes = {}

                self.detail_groups = Mld.Active.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Mld.Active.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Mld.Active.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Mld.Active.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Mld.Active.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Mld.Active.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Mld.Active.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Mld.Active.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Mld.Active.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Mld.Active.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Mld.Active.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Mld.Active.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Mld.Active.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Mld.Active.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Mld.Active.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Mld.Active.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/%s" % self._segment_path()


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"detail-group" : ("detail_group", Mld.Active.DefaultContext.DetailGroups.DetailGroup)}

                    self.detail_group = YList(self)
                    self._segment_path = lambda: "detail-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.DetailGroups, [], name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo)}
                        self._child_list_classes = {"source" : ("source", Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source)}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)
                        self._segment_path = lambda: "detail-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"source-address" : ("source_address", Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/detail-groups/detail-group/source/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"explicit-group" : ("explicit_group", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup)}

                    self.explicit_group = YList(self)
                    self._segment_path = lambda: "explicit-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups, [], name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo)}
                        self._child_list_classes = {"host" : ("host", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host)}

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)
                        self._segment_path = lambda: "explicit-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"address" : ("address", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address)}
                            self._child_list_classes = {"source-address" : ("source_address", Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)
                            self._segment_path = lambda: "host"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Mld.Active.DefaultContext.GlobalInterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "global-interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.GlobalInterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/global-interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                    self._segment_path = lambda: "group-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group" : ("group", Mld.Active.DefaultContext.Groups.Group)}

                    self.group = YList(self)
                    self._segment_path = lambda: "groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.Groups, [], name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.DefaultContext.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Active.DefaultContext.Groups.Group.LastReporter), "source-address" : ("source_address", Mld.Active.DefaultContext.Groups.Group.SourceAddress)}
                        self._child_list_classes = {}

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Mld.Active.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Mld.Active.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Mld.Active.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "last-reporter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-interface-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "igmp-interface-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-off" : ("interface_state_off", Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff)}

                    self.interface_state_off = YList(self)
                    self._segment_path = lambda: "interface-state-offs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOffs, [], name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-state-offs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-on" : ("interface_state_on", Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn)}

                    self.interface_state_on = YList(self)
                    self._segment_path = lambda: "interface-state-ons"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOns, [], name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-state-ons/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Mld.Active.DefaultContext.InterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.InterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Active.DefaultContext.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Active.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                    self.interface_unicast_qos_adjust = YList(self)
                    self._segment_path = lambda: "interface-unicast-qos-adjusts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts, [], name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"update" : ("update", Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/interface-unicast-qos-adjusts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                            self._child_list_classes = {}

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "update"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"non-active-groups" : ("non_active_groups", Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups)}

                    self.non_active_groups = YList(self)
                    self._segment_path = lambda: "non-active-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.NonActiveGroups, [], name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address" : ("group_address", Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "non-active-groups"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/non-active-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Mld.Active.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail)}

                    self.ssm_map_detail = YList(self)
                    self._segment_path = lambda: "ssm-map-details"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.SsmMapDetails, [], name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"map-info" : ("map_info", Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo)}
                        self._child_list_classes = {"sources" : ("sources", Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources)}

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)
                        self._segment_path = lambda: "ssm-map-detail"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "map-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map" : ("ssm_map", Mld.Active.DefaultContext.SsmMaps.SsmMap)}

                    self.ssm_map = YList(self)
                    self._segment_path = lambda: "ssm-maps"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.SsmMaps, [], name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "ssm-map"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-maps/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/ssm-maps/ssm-map/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Mld.Active.DefaultContext.Summary.Interface)}

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                        self._segment_path = lambda: "interface"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.DefaultContext.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.DefaultContext.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Active.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"amt-gatewaies" : ("amt_gatewaies", Mld.Active.Process.AmtGatewaies), "amt-summary" : ("amt_summary", Mld.Active.Process.AmtSummary), "bvi-statistics" : ("bvi_statistics", Mld.Active.Process.BviStatistics), "nsf" : ("nsf", Mld.Active.Process.Nsf), "nsr" : ("nsr", Mld.Active.Process.Nsr), "unicast-qos-adjust-stats" : ("unicast_qos_adjust_stats", Mld.Active.Process.UnicastQosAdjustStats)}
                self._child_list_classes = {}

                self.amt_gatewaies = Mld.Active.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Mld.Active.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Mld.Active.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Mld.Active.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Mld.Active.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Mld.Active.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/%s" % self._segment_path()


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"amt-gateway" : ("amt_gateway", Mld.Active.Process.AmtGatewaies.AmtGateway)}

                    self.amt_gateway = YList(self)
                    self._segment_path = lambda: "amt-gatewaies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.Process.AmtGatewaies, [], name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")
                        self._segment_path = lambda: "amt-gateway"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/amt-gatewaies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Process.AmtGatewaies.AmtGateway, ['amt_nonce', 'amt_port', 'amtgw', 'amtnh', 'gateway_address', 'idb', 'key_len', 'mem_upd_in', 'mem_upd_out', 'port'], name, value)


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")
                    self._segment_path = lambda: "amt-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.Process.AmtSummary, ['anycast_prefix', 'gateway_count', 'is_acl_configured', 'is_gateway_simulation', 'is_ou_of_resource', 'max_gateway', 'mtu', 'prefix_length', 'query_interval', 'relay_address', 'tos', 'ttl', 'tunnel_configured_maximum', 'tunnel_count'], name, value)


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")
                    self._segment_path = lambda: "bvi-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.Process.BviStatistics, ['null_buffer_handles', 'receive_buffers', 'release_buffers', 'release_fail_buffers', 'rx_add_mrouter_msg', 'rx_delete_mrouter_msg', 'rx_igmp_packet_success', 'rx_ipc_close_notif', 'rx_ipc_connect_notif', 'rx_ipc_error_notif', 'rx_ipc_input_wait_notif', 'rx_ipc_lwm_notif', 'rx_ipc_open_notif', 'rx_ipc_output_notif', 'rx_ipc_publish_notif', 'rx_ipc_q_full_notif', 'rx_ipc_send_status_notif', 'rx_sweep_mrouter_msg', 'rx_unknown_mrouter_msg', 'send_blocks', 'tx_add_mrouter_msg', 'tx_buffer_errors', 'tx_buffers', 'tx_delete_mrouter_msg', 'tx_mrouter_buffers', 'tx_protocol_buffers', 'tx_sweep_mrouter_msg', 'tx_unknown_buffers', 'tx_unknown_mrouter_msg', 'wtx_msg_drop_dc', 'wtx_msg_drop_nomem', 'wtx_msg_freed', 'wtx_msg_proto_sent', 'wtx_msg_recvd', 'wtx_msg_sent'], name, value)


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.Process.Nsf, ['is_multicast_nsf_active', 'last_icd_notif_recv', 'last_icd_notif_recv_min', 'last_nsf_off', 'last_nsf_off_min', 'last_nsf_on', 'last_nsf_on_min', 'multicast_nsf_time_left', 'multicast_nsf_timeout', 'respawn_count'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.Process.Nsr, ['collab_conv_done', 'count_proc_connection_dn', 'count_proc_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_proc', 'last_proc_connection_dn', 'last_proc_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_proc_connected', 'rmf_notification_done', 'state'], name, value)


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")
                    self._segment_path = lambda: "unicast-qos-adjust-stats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.Process.UnicastQosAdjustStats, ['add_to_batches', 'batches', 'delete_to_batches', 'is_qos_s_sweeped', 'is_resync_received', 'is_resync_required', 'is_resync_start_sent', 'last_download_time', 'last_sweep_time', 'queues', 'received_resync_requests', 'send_comm_errors', 'send_errors', 'send_partial_errors', 'send_success', 'sent_resync_bulks'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Active.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Mld.Active.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Mld.Active.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Active.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"detail-groups" : ("detail_groups", Mld.Active.Vrfs.Vrf.DetailGroups), "explicit-groups" : ("explicit_groups", Mld.Active.Vrfs.Vrf.ExplicitGroups), "global-interface-table" : ("global_interface_table", Mld.Active.Vrfs.Vrf.GlobalInterfaceTable), "group-summary" : ("group_summary", Mld.Active.Vrfs.Vrf.GroupSummary), "groups" : ("groups", Mld.Active.Vrfs.Vrf.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Mld.Active.Vrfs.Vrf.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Mld.Active.Vrfs.Vrf.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Mld.Active.Vrfs.Vrf.InterfaceStateOns), "interface-table" : ("interface_table", Mld.Active.Vrfs.Vrf.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Mld.Active.Vrfs.Vrf.NonActiveGroups), "ranges" : ("ranges", Mld.Active.Vrfs.Vrf.Ranges), "ssm-map-details" : ("ssm_map_details", Mld.Active.Vrfs.Vrf.SsmMapDetails), "ssm-maps" : ("ssm_maps", Mld.Active.Vrfs.Vrf.SsmMaps), "summary" : ("summary", Mld.Active.Vrfs.Vrf.Summary), "traffic-counters" : ("traffic_counters", Mld.Active.Vrfs.Vrf.TrafficCounters)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Mld.Active.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Mld.Active.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Mld.Active.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Mld.Active.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Mld.Active.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Mld.Active.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Mld.Active.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Mld.Active.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Mld.Active.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Mld.Active.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Mld.Active.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Mld.Active.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Mld.Active.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Mld.Active.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/active/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Active.Vrfs.Vrf, ['vrf_name'], name, value)


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"detail-group" : ("detail_group", Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup)}

                        self.detail_group = YList(self)
                        self._segment_path = lambda: "detail-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups, [], name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo)}
                            self._child_list_classes = {"source" : ("source", Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source)}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)
                            self._segment_path = lambda: "detail-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"source-address" : ("source_address", Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"explicit-group" : ("explicit_group", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup)}

                        self.explicit_group = YList(self)
                        self._segment_path = lambda: "explicit-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups, [], name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo)}
                            self._child_list_classes = {"host" : ("host", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host)}

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)
                            self._segment_path = lambda: "explicit-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address)}
                                self._child_list_classes = {"source-address" : ("source_address", Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)
                                self._segment_path = lambda: "host"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "global-interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                        self._segment_path = lambda: "group-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group" : ("group", Mld.Active.Vrfs.Vrf.Groups.Group)}

                        self.group = YList(self)
                        self._segment_path = lambda: "groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.Groups, [], name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter), "source-address" : ("source_address", Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-interface-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                                self._child_list_classes = {}

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")
                                self._segment_path = lambda: "igmp-interface-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "querier-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "subscriber-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-off" : ("interface_state_off", Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff)}

                        self.interface_state_off = YList(self)
                        self._segment_path = lambda: "interface-state-offs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOffs, [], name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-on" : ("interface_state_on", Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn)}

                        self.interface_state_on = YList(self)
                        self._segment_path = lambda: "interface-state-ons"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOns, [], name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Mld.Active.Vrfs.Vrf.InterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                        self.interface_unicast_qos_adjust = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjusts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts, [], name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update" : ("update", Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)
                            self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address" : ("group_address", Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                                self._child_list_classes = {}

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "update"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"non-active-groups" : ("non_active_groups", Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups)}

                        self.non_active_groups = YList(self)
                        self._segment_path = lambda: "non-active-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.NonActiveGroups, [], name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress)}
                            self._child_list_classes = {}

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "non-active-groups"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Mld.Active.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail)}

                        self.ssm_map_detail = YList(self)
                        self._segment_path = lambda: "ssm-map-details"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMapDetails, [], name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"map-info" : ("map_info", Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo)}
                            self._child_list_classes = {"sources" : ("sources", Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources)}

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)
                            self._segment_path = lambda: "ssm-map-detail"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                                self._child_list_classes = {}

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")
                                self._segment_path = lambda: "map-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map" : ("ssm_map", Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap)}

                        self.ssm_map = YList(self)
                        self._segment_path = lambda: "ssm-maps"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMaps, [], name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "ssm-map"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Active.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Active.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Mld.Active.Vrfs.Vrf.Summary.Interface)}

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Active.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Active.Vrfs.Vrf.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Active.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Active.Vrfs.Vrf.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)


    class Standby(Entity):
        """
        Standby Process
        
        .. attribute:: default_context
        
        	Default Context
        	**type**\:   :py:class:`DefaultContext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext>`
        
        .. attribute:: process
        
        	Process
        	**type**\:   :py:class:`Process <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process>`
        
        .. attribute:: vrfs
        
        	VRF Table
        	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs>`
        
        

        """

        _prefix = 'ipv4-igmp-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Mld.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "mld"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"default-context" : ("default_context", Mld.Standby.DefaultContext), "process" : ("process", Mld.Standby.Process), "vrfs" : ("vrfs", Mld.Standby.Vrfs)}
            self._child_list_classes = {}

            self.default_context = Mld.Standby.DefaultContext()
            self.default_context.parent = self
            self._children_name_map["default_context"] = "default-context"
            self._children_yang_names.add("default-context")

            self.process = Mld.Standby.Process()
            self.process.parent = self
            self._children_name_map["process"] = "process"
            self._children_yang_names.add("process")

            self.vrfs = Mld.Standby.Vrfs()
            self.vrfs.parent = self
            self._children_name_map["vrfs"] = "vrfs"
            self._children_yang_names.add("vrfs")
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/%s" % self._segment_path()


        class DefaultContext(Entity):
            """
            Default Context
            
            .. attribute:: detail_groups
            
            	IGMP Detail Group Database
            	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups>`
            
            .. attribute:: explicit_groups
            
            	IGMP Explicit Group Database
            	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups>`
            
            .. attribute:: global_interface_table
            
            	IGMP Global Interface 
            	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable>`
            
            .. attribute:: group_summary
            
            	IGMP Groups Summary
            	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GroupSummary>`
            
            .. attribute:: groups
            
            	IGMP Group Database Table
            	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups>`
            
            .. attribute:: ifrs_interface_summary
            
            	IGMP IFRS Interface summary
            	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaceSummary>`
            
            .. attribute:: ifrs_interfaces
            
            	IGMP Interface specific
            	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces>`
            
            .. attribute:: interface_state_offs
            
            	IGMP Interface state off
            	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs>`
            
            .. attribute:: interface_state_ons
            
            	IGMP Interface state on
            	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns>`
            
            .. attribute:: interface_table
            
            	IGMP Interface specific Table
            	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable>`
            
            .. attribute:: interface_unicast_qos_adjusts
            
            	IGMP Interface Unicast\-Qos\-Adjust
            	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts>`
            
            .. attribute:: non_active_groups
            
            	IGMP Non\-Active Groups Information
            	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups>`
            
            .. attribute:: ranges
            
            	Range table
            	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Ranges>`
            
            .. attribute:: ssm_map_details
            
            	SSM Map Detail
            	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails>`
            
            .. attribute:: ssm_maps
            
            	SSM Map Table
            	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMaps>`
            
            .. attribute:: summary
            
            	IGMP Summary Information
            	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Summary>`
            
            .. attribute:: traffic_counters
            
            	IGMP Message Traffic Counters
            	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.TrafficCounters>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Standby.DefaultContext, self).__init__()

                self.yang_name = "default-context"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"detail-groups" : ("detail_groups", Mld.Standby.DefaultContext.DetailGroups), "explicit-groups" : ("explicit_groups", Mld.Standby.DefaultContext.ExplicitGroups), "global-interface-table" : ("global_interface_table", Mld.Standby.DefaultContext.GlobalInterfaceTable), "group-summary" : ("group_summary", Mld.Standby.DefaultContext.GroupSummary), "groups" : ("groups", Mld.Standby.DefaultContext.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Mld.Standby.DefaultContext.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Mld.Standby.DefaultContext.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Mld.Standby.DefaultContext.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Mld.Standby.DefaultContext.InterfaceStateOns), "interface-table" : ("interface_table", Mld.Standby.DefaultContext.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Mld.Standby.DefaultContext.NonActiveGroups), "ranges" : ("ranges", Mld.Standby.DefaultContext.Ranges), "ssm-map-details" : ("ssm_map_details", Mld.Standby.DefaultContext.SsmMapDetails), "ssm-maps" : ("ssm_maps", Mld.Standby.DefaultContext.SsmMaps), "summary" : ("summary", Mld.Standby.DefaultContext.Summary), "traffic-counters" : ("traffic_counters", Mld.Standby.DefaultContext.TrafficCounters)}
                self._child_list_classes = {}

                self.detail_groups = Mld.Standby.DefaultContext.DetailGroups()
                self.detail_groups.parent = self
                self._children_name_map["detail_groups"] = "detail-groups"
                self._children_yang_names.add("detail-groups")

                self.explicit_groups = Mld.Standby.DefaultContext.ExplicitGroups()
                self.explicit_groups.parent = self
                self._children_name_map["explicit_groups"] = "explicit-groups"
                self._children_yang_names.add("explicit-groups")

                self.global_interface_table = Mld.Standby.DefaultContext.GlobalInterfaceTable()
                self.global_interface_table.parent = self
                self._children_name_map["global_interface_table"] = "global-interface-table"
                self._children_yang_names.add("global-interface-table")

                self.group_summary = Mld.Standby.DefaultContext.GroupSummary()
                self.group_summary.parent = self
                self._children_name_map["group_summary"] = "group-summary"
                self._children_yang_names.add("group-summary")

                self.groups = Mld.Standby.DefaultContext.Groups()
                self.groups.parent = self
                self._children_name_map["groups"] = "groups"
                self._children_yang_names.add("groups")

                self.ifrs_interface_summary = Mld.Standby.DefaultContext.IfrsInterfaceSummary()
                self.ifrs_interface_summary.parent = self
                self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                self._children_yang_names.add("ifrs-interface-summary")

                self.ifrs_interfaces = Mld.Standby.DefaultContext.IfrsInterfaces()
                self.ifrs_interfaces.parent = self
                self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                self._children_yang_names.add("ifrs-interfaces")

                self.interface_state_offs = Mld.Standby.DefaultContext.InterfaceStateOffs()
                self.interface_state_offs.parent = self
                self._children_name_map["interface_state_offs"] = "interface-state-offs"
                self._children_yang_names.add("interface-state-offs")

                self.interface_state_ons = Mld.Standby.DefaultContext.InterfaceStateOns()
                self.interface_state_ons.parent = self
                self._children_name_map["interface_state_ons"] = "interface-state-ons"
                self._children_yang_names.add("interface-state-ons")

                self.interface_table = Mld.Standby.DefaultContext.InterfaceTable()
                self.interface_table.parent = self
                self._children_name_map["interface_table"] = "interface-table"
                self._children_yang_names.add("interface-table")

                self.interface_unicast_qos_adjusts = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts()
                self.interface_unicast_qos_adjusts.parent = self
                self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                self._children_yang_names.add("interface-unicast-qos-adjusts")

                self.non_active_groups = Mld.Standby.DefaultContext.NonActiveGroups()
                self.non_active_groups.parent = self
                self._children_name_map["non_active_groups"] = "non-active-groups"
                self._children_yang_names.add("non-active-groups")

                self.ranges = Mld.Standby.DefaultContext.Ranges()
                self.ranges.parent = self
                self._children_name_map["ranges"] = "ranges"
                self._children_yang_names.add("ranges")

                self.ssm_map_details = Mld.Standby.DefaultContext.SsmMapDetails()
                self.ssm_map_details.parent = self
                self._children_name_map["ssm_map_details"] = "ssm-map-details"
                self._children_yang_names.add("ssm-map-details")

                self.ssm_maps = Mld.Standby.DefaultContext.SsmMaps()
                self.ssm_maps.parent = self
                self._children_name_map["ssm_maps"] = "ssm-maps"
                self._children_yang_names.add("ssm-maps")

                self.summary = Mld.Standby.DefaultContext.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._children_yang_names.add("summary")

                self.traffic_counters = Mld.Standby.DefaultContext.TrafficCounters()
                self.traffic_counters.parent = self
                self._children_name_map["traffic_counters"] = "traffic-counters"
                self._children_yang_names.add("traffic-counters")
                self._segment_path = lambda: "default-context"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/%s" % self._segment_path()


            class DetailGroups(Entity):
                """
                IGMP Detail Group Database
                
                .. attribute:: detail_group
                
                	IGMP Detail Group Entry Information
                	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.DetailGroups, self).__init__()

                    self.yang_name = "detail-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"detail-group" : ("detail_group", Mld.Standby.DefaultContext.DetailGroups.DetailGroup)}

                    self.detail_group = YList(self)
                    self._segment_path = lambda: "detail-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups, [], name, value)


                class DetailGroup(Entity):
                    """
                    IGMP Detail Group Entry Information
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_host_exclude_mode
                    
                    	Group host filter mode
                    	**type**\:  bool
                    
                    .. attribute:: is_router_exclude_mode
                    
                    	Group router filter mode
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source>`
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup, self).__init__()

                        self.yang_name = "detail-group"
                        self.yang_parent_name = "detail-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo)}
                        self._child_list_classes = {"source" : ("source", Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source)}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                        self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.source = YList(self)
                        self._segment_path = lambda: "detail-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Source(Entity):
                        """
                        List of sources
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: flags
                        
                        	Source flags
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_forward
                        
                        	Should we forward on this entry
                        	**type**\:  bool
                        
                        .. attribute:: is_local
                        
                        	Is this a local source
                        	**type**\:  bool
                        
                        .. attribute:: is_remote
                        
                        	Is this a remote source
                        	**type**\:  bool
                        
                        .. attribute:: is_we_report
                        
                        	Should we report the source
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source, self).__init__()

                            self.yang_name = "source"
                            self.yang_parent_name = "detail-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"source-address" : ("source_address", Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.flags = YLeaf(YType.int32, "flags")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_forward = YLeaf(YType.boolean, "is-forward")

                            self.is_local = YLeaf(YType.boolean, "is-local")

                            self.is_remote = YLeaf(YType.boolean, "is-remote")

                            self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.source_address = Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "source"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "source"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/detail-groups/detail-group/source/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class ExplicitGroups(Entity):
                """
                IGMP Explicit Group Database
                
                .. attribute:: explicit_group
                
                	IGMP Explicit Group Entry Information
                	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.ExplicitGroups, self).__init__()

                    self.yang_name = "explicit-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"explicit-group" : ("explicit_group", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup)}

                    self.explicit_group = YList(self)
                    self._segment_path = lambda: "explicit-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups, [], name, value)


                class ExplicitGroup(Entity):
                    """
                    IGMP Explicit Group Entry Information
                    
                    .. attribute:: exclude_hosts
                    
                    	No. of hosts who are excluded
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_info
                    
                    	Basic Group information
                    	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo>`
                    
                    .. attribute:: host
                    
                    	List of hosts
                    	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host>`
                    
                    .. attribute:: include_hosts
                    
                    	No. of hosts who are included
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: source_address
                    
                    	Source/Host Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, self).__init__()

                        self.yang_name = "explicit-group"
                        self.yang_parent_name = "explicit-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-info" : ("group_info", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo)}
                        self._child_list_classes = {"host" : ("host", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host)}

                        self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.source_address = YLeaf(YType.str, "source-address")

                        self.group_info = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo()
                        self.group_info.parent = self
                        self._children_name_map["group_info"] = "group-info"
                        self._children_yang_names.add("group-info")

                        self.host = YList(self)
                        self._segment_path = lambda: "explicit-group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                    class GroupInfo(Entity):
                        """
                        Basic Group information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                            self.yang_name = "group-info"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/group-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Host(Entity):
                        """
                        List of hosts
                        
                        .. attribute:: address
                        
                        	Host Address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address>`
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: is_exclude
                        
                        	Exclude flag set
                        	**type**\:  bool
                        
                        .. attribute:: source_address
                        
                        	First 3 source addresses
                        	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                        
                        .. attribute:: source_count
                        
                        	No. of sources in entry
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                            self.yang_name = "host"
                            self.yang_parent_name = "explicit-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"address" : ("address", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address)}
                            self._child_list_classes = {"source-address" : ("source_address", Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                            self.source_count = YLeaf(YType.uint32, "source-count")

                            self.uptime = YLeaf(YType.uint32, "uptime")

                            self.address = Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.source_address = YList(self)
                            self._segment_path = lambda: "host"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                        class Address(Entity):
                            """
                            Host Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            First 3 source addresses
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "host"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/explicit-groups/explicit-group/host/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GlobalInterfaceTable(Entity):
                """
                IGMP Global Interface 
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.GlobalInterfaceTable, self).__init__()

                    self.yang_name = "global-interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "global-interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.GlobalInterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "global-interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/global-interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class GroupSummary(Entity):
                """
                IGMP Groups Summary
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: groutes
                
                	No. of (\*,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_low_memory
                
                	Node is running low on memory
                	**type**\:  bool
                
                .. attribute:: sg_routes
                
                	No. of (S,G) routes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.GroupSummary, self).__init__()

                    self.yang_name = "group-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.groutes = YLeaf(YType.uint32, "groutes")

                    self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                    self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                    self._segment_path = lambda: "group-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


            class Groups(Entity):
                """
                IGMP Group Database Table
                
                .. attribute:: group
                
                	IGMP Group Entry Information
                	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.Groups, self).__init__()

                    self.yang_name = "groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"group" : ("group", Mld.Standby.DefaultContext.Groups.Group)}

                    self.group = YList(self)
                    self._segment_path = lambda: "groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.Groups, [], name, value)


                class Group(Entity):
                    """
                    IGMP Group Entry Information
                    
                    .. attribute:: expiration_time
                    
                    	Expiration time in seconds
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    	**units**\: second
                    
                    .. attribute:: explicit_tracking_enabled
                    
                    	Is explicit tracking enabled
                    	**type**\:  bool
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr>`
                    
                    .. attribute:: interface_name
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_added
                    
                    	Joined
                    	**type**\:  bool
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: is_self_join
                    
                    	If local system is member of this group on this interface
                    	**type**\:  bool
                    
                    .. attribute:: is_suppressed
                    
                    	Suppressed
                    	**type**\:  bool
                    
                    .. attribute:: last_reporter
                    
                    	Last reporter address
                    	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group.LastReporter>`
                    
                    .. attribute:: older_host_version1_timer
                    
                    	IGMP Hostversion1timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: older_host_version2_timer
                    
                    	IGMP Hostversion2timer
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_filter_mode
                    
                    	Filter mode
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: row_status
                    
                    	interface on or off for the group
                    	**type**\:  str
                    
                    	**length:** 0..16
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Groups.Group.SourceAddress>`
                    
                    .. attribute:: uptime
                    
                    	Uptime in seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.Groups.Group, self).__init__()

                        self.yang_name = "group"
                        self.yang_parent_name = "groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Standby.DefaultContext.Groups.Group.LastReporter), "source-address" : ("source_address", Mld.Standby.DefaultContext.Groups.Group.SourceAddress)}
                        self._child_list_classes = {}

                        self.expiration_time = YLeaf(YType.int32, "expiration-time")

                        self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_added = YLeaf(YType.boolean, "is-added")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                        self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                        self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                        self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                        self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                        self.row_status = YLeaf(YType.str, "row-status")

                        self.uptime = YLeaf(YType.uint64, "uptime")

                        self.group_address_xr = Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")

                        self.last_reporter = Mld.Standby.DefaultContext.Groups.Group.LastReporter()
                        self.last_reporter.parent = self
                        self._children_name_map["last_reporter"] = "last-reporter"
                        self._children_yang_names.add("last-reporter")

                        self.source_address = Mld.Standby.DefaultContext.Groups.Group.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "group"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class LastReporter(Entity):
                        """
                        Last reporter address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Groups.Group.LastReporter, self).__init__()

                            self.yang_name = "last-reporter"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "last-reporter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Groups.Group.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/groups/group/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class IfrsInterfaceSummary(Entity):
                """
                IGMP IFRS Interface summary
                
                .. attribute:: configuration_count
                
                	Configuration count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_count
                
                	Interface Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.IfrsInterfaceSummary, self).__init__()

                    self.yang_name = "ifrs-interface-summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                    self.interface_count = YLeaf(YType.uint32, "interface-count")
                    self._segment_path = lambda: "ifrs-interface-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


            class IfrsInterfaces(Entity):
                """
                IGMP Interface specific
                
                .. attribute:: ifrs_interface
                
                	IGMP IFRS Interface
                	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.IfrsInterfaces, self).__init__()

                    self.yang_name = "ifrs-interfaces"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface)}

                    self.ifrs_interface = YList(self)
                    self._segment_path = lambda: "ifrs-interfaces"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.IfrsInterfaces, [], name, value)


                class IfrsInterface(Entity):
                    """
                    IGMP IFRS Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	IFRS Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: igmp_interface_entry
                    
                    	IGMP interface entry
                    	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                    
                    .. attribute:: join_group_count
                    
                    	Join group count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, self).__init__()

                        self.yang_name = "ifrs-interface"
                        self.yang_parent_name = "ifrs-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                        self.igmp_interface_entry = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                        self.igmp_interface_entry.parent = self
                        self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                        self._children_yang_names.add("igmp-interface-entry")
                        self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ifrs-interfaces/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                    class IgmpInterfaceEntry(Entity):
                        """
                        IGMP interface entry
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                            self.yang_name = "igmp-interface-entry"
                            self.yang_parent_name = "ifrs-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "igmp-interface-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "igmp-interface-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOffs(Entity):
                """
                IGMP Interface state off
                
                .. attribute:: interface_state_off
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceStateOffs, self).__init__()

                    self.yang_name = "interface-state-offs"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-off" : ("interface_state_off", Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff)}

                    self.interface_state_off = YList(self)
                    self._segment_path = lambda: "interface-state-offs"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOffs, [], name, value)


                class InterfaceStateOff(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                        self.yang_name = "interface-state-off"
                        self.yang_parent_name = "interface-state-offs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-state-offs/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-off"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceStateOns(Entity):
                """
                IGMP Interface state on
                
                .. attribute:: interface_state_on
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceStateOns, self).__init__()

                    self.yang_name = "interface-state-ons"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-state-on" : ("interface_state_on", Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn)}

                    self.interface_state_on = YList(self)
                    self._segment_path = lambda: "interface-state-ons"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOns, [], name, value)


                class InterfaceStateOn(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, self).__init__()

                        self.yang_name = "interface-state-on"
                        self.yang_parent_name = "interface-state-ons"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-state-ons/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface-state-on"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceTable(Entity):
                """
                IGMP Interface specific Table
                
                .. attribute:: interface
                
                	IGMP Interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceTable, self).__init__()

                    self.yang_name = "interface-table"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Mld.Standby.DefaultContext.InterfaceTable.Interface)}

                    self.interface = YList(self)
                    self._segment_path = lambda: "interface-table"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.InterfaceTable, [], name, value)


                class Interface(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface.Address>`
                    
                    .. attribute:: configuration_mcast_vrf_error
                    
                    	Is mcast error
                    	**type**\:  bool
                    
                    .. attribute:: configuration_mcast_vrf_set
                    
                    	Is mcast set
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_error
                    
                    	CFG vrf error
                    	**type**\:  bool
                    
                    .. attribute:: configurationvrf_set
                    
                    	CFG vrf set
                    	**type**\:  bool
                    
                    .. attribute:: group_joins
                    
                    	No. of group joins
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_leaves
                    
                    	No. of group leaves
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: host_version
                    
                    	IGMP Host version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: igmp_version
                    
                    	IGMP Router version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_configurationverify
                    
                    	CFG verify
                    	**type**\:  bool
                    
                    .. attribute:: is_identity_present
                    
                    	Subscriber ID or Address available from AAA
                    	**type**\:  bool
                    
                    .. attribute:: is_im_state_registered
                    
                    	Im state registered
                    	**type**\:  bool
                    
                    .. attribute:: is_interface_up
                    
                    	Is interface up
                    	**type**\:  bool
                    
                    .. attribute:: is_ip_enabled
                    
                    	Is IP enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_las_registered
                    
                    	LAS registered
                    	**type**\:  bool
                    
                    .. attribute:: is_las_request
                    
                    	LAS req
                    	**type**\:  bool
                    
                    .. attribute:: is_querier
                    
                    	Are we querier
                    	**type**\:  bool
                    
                    .. attribute:: is_router_enabled
                    
                    	Is Router functionality enabled
                    	**type**\:  bool
                    
                    .. attribute:: is_subscriber
                    
                    	Subscriber interface
                    	**type**\:  bool
                    
                    .. attribute:: las_get_address_count
                    
                    	LAS get addr count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_add_update_count
                    
                    	LAS LL add update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_registration_count
                    
                    	LAS reg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_ll_remove_update_count
                    
                    	LAS LL remove update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_null_update_count
                    
                    	LAS Null update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_unregistration_count
                    
                    	LAS unreg count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: las_update_count
                    
                    	LAS Update count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: last_member_query_interval
                    
                    	Last Member Query Interval
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: location
                    
                    	Location
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_tuple_count
                    
                    	MTE Tuple count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mte_vrf_id
                    
                    	MTE VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent If Handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: proxy_interface
                    
                    	Proxy interface index
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: querier_address
                    
                    	Address of the Querier
                    	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress>`
                    
                    .. attribute:: querier_uptime
                    
                    	Time since the last querier took over
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_interval
                    
                    	Query Interval value in seconds
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**units**\: second
                    
                    .. attribute:: query_maximum_response_time
                    
                    	Max Response Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: query_timeout
                    
                    	Query Timeout value
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: robustness
                    
                    	Robustness Variable value
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Uptime since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	Interface state
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: subscriber_address
                    
                    	Address of subscriber
                    	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress>`
                    
                    .. attribute:: subscriber_id
                    
                    	ID string of subscriber
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: subscriber_mode
                    
                    	Subscriber mode
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: total_active_groups
                    
                    	Actual number of groups on interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_id
                    
                    	VRF id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vrf_state
                    
                    	Vrf State
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceTable.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "interface-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"address" : ("address", Mld.Standby.DefaultContext.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress)}
                        self._child_list_classes = {}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                        self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                        self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                        self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                        self.group_joins = YLeaf(YType.uint32, "group-joins")

                        self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                        self.host_version = YLeaf(YType.uint8, "host-version")

                        self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                        self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                        self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                        self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                        self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                        self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                        self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                        self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                        self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                        self.is_querier = YLeaf(YType.boolean, "is-querier")

                        self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                        self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                        self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                        self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                        self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                        self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                        self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                        self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                        self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                        self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                        self.location = YLeaf(YType.uint32, "location")

                        self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                        self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                        self.mtu = YLeaf(YType.uint32, "mtu")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                        self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                        self.query_interval = YLeaf(YType.uint16, "query-interval")

                        self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                        self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.state = YLeaf(YType.uint32, "state")

                        self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                        self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                        self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                        self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                        self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                        self.address = Mld.Standby.DefaultContext.InterfaceTable.Interface.Address()
                        self.address.parent = self
                        self._children_name_map["address"] = "address"
                        self._children_yang_names.add("address")

                        self.querier_address = Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress()
                        self.querier_address.parent = self
                        self._children_name_map["querier_address"] = "querier-address"
                        self._children_yang_names.add("querier-address")

                        self.subscriber_address = Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress()
                        self.subscriber_address.parent = self
                        self._children_name_map["subscriber_address"] = "subscriber-address"
                        self._children_yang_names.add("subscriber-address")
                        self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-table/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                    class Address(Entity):
                        """
                        IP address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceTable.Interface.Address, self).__init__()

                            self.yang_name = "address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class QuerierAddress(Entity):
                        """
                        Address of the Querier
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, self).__init__()

                            self.yang_name = "querier-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "querier-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SubscriberAddress(Entity):
                        """
                        Address of subscriber
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                            self.yang_name = "subscriber-address"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "subscriber-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class InterfaceUnicastQosAdjusts(Entity):
                """
                IGMP Interface Unicast\-Qos\-Adjust
                
                .. attribute:: interface_unicast_qos_adjust
                
                	IGMP Interface
                	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts, self).__init__()

                    self.yang_name = "interface-unicast-qos-adjusts"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                    self.interface_unicast_qos_adjust = YList(self)
                    self._segment_path = lambda: "interface-unicast-qos-adjusts"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts, [], name, value)


                class InterfaceUnicastQosAdjust(Entity):
                    """
                    IGMP Interface
                    
                    .. attribute:: interface_name  <key>
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: is_virtual_access
                    
                    	Is VirtualAccess Interface
                    	**type**\:  bool
                    
                    .. attribute:: rate
                    
                    	Overall rate in Kbps
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: kbit/s
                    
                    .. attribute:: rate_decrements
                    
                    	Count of rate decrements
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rate_increments
                    
                    	Count of rate increments
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update
                    
                    	List of updates
                    	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjust"
                        self.yang_parent_name = "interface-unicast-qos-adjusts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {"update" : ("update", Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                        self.rate = YLeaf(YType.uint32, "rate")

                        self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                        self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                        self.update = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/interface-unicast-qos-adjusts/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                    class Update(Entity):
                        """
                        List of updates
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                        
                        .. attribute:: is_add
                        
                        	Is this a rate increment
                        	**type**\:  bool
                        
                        .. attribute:: received_time
                        
                        	Time this update is received
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: source_address
                        
                        	Source address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                        
                        .. attribute:: weight
                        
                        	Weight from policy
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                            self.yang_name = "update"
                            self.yang_parent_name = "interface-unicast-qos-adjust"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                            self._child_list_classes = {}

                            self.is_add = YLeaf(YType.boolean, "is-add")

                            self.received_time = YLeaf(YType.uint64, "received-time")

                            self.weight = YLeaf(YType.uint32, "weight")

                            self.group_address = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "update"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "update"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class NonActiveGroups(Entity):
                """
                IGMP Non\-Active Groups Information
                
                .. attribute:: non_active_groups
                
                	List of non\-active groups
                	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.NonActiveGroups, self).__init__()

                    self.yang_name = "non-active-groups"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"non-active-groups" : ("non_active_groups", Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups)}

                    self.non_active_groups = YList(self)
                    self._segment_path = lambda: "non-active-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.NonActiveGroups, [], name, value)


                class NonActiveGroups(Entity):
                    """
                    List of non\-active groups
                    
                    .. attribute:: group_address
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress>`
                    
                    .. attribute:: interface
                    
                    	Interface Name
                    	**type**\:  str
                    
                    	**length:** 0..65
                    
                    .. attribute:: reason_for_non_activity
                    
                    	Reason for group join not being processed
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    .. attribute:: source_address
                    
                    	Source Address
                    	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "non-active-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address" : ("group_address", Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress)}
                        self._child_list_classes = {}

                        self.interface = YLeaf(YType.str, "interface")

                        self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                        self.group_address = Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress()
                        self.group_address.parent = self
                        self._children_name_map["group_address"] = "group-address"
                        self._children_yang_names.add("group-address")

                        self.source_address = Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress()
                        self.source_address.parent = self
                        self._children_name_map["source_address"] = "source-address"
                        self._children_yang_names.add("source-address")
                        self._segment_path = lambda: "non-active-groups"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/non-active-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                    class GroupAddress(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                            self.yang_name = "group-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class SourceAddress(Entity):
                        """
                        Source Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                            self.yang_name = "source-address"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "source-address"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/non-active-groups/non-active-groups/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Ranges(Entity):
                """
                Range table
                
                .. attribute:: range
                
                	Range information
                	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Ranges.Range>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.Ranges, self).__init__()

                    self.yang_name = "ranges"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"range" : ("range", Mld.Standby.DefaultContext.Ranges.Range)}

                    self.range = YList(self)
                    self._segment_path = lambda: "ranges"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.Ranges, [], name, value)


                class Range(Entity):
                    """
                    Range information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr>`
                    
                    .. attribute:: group_mask
                    
                    	Group Mask
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: is_stale
                    
                    	Is the entry stale
                    	**type**\:  bool
                    
                    .. attribute:: prefix_length
                    
                    	Prefix length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.Ranges.Range, self).__init__()

                        self.yang_name = "range"
                        self.yang_parent_name = "ranges"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.group_mask = YLeaf(YType.int32, "group-mask")

                        self.is_stale = YLeaf(YType.boolean, "is-stale")

                        self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                        self.protocol = YLeaf(YType.enumeration, "protocol")

                        self.group_address_xr = Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "range"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ranges/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "range"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ranges/range/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMapDetails(Entity):
                """
                SSM Map Detail
                
                .. attribute:: ssm_map_detail
                
                	SSM Map Detail Table information
                	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.SsmMapDetails, self).__init__()

                    self.yang_name = "ssm-map-details"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail)}

                    self.ssm_map_detail = YList(self)
                    self._segment_path = lambda: "ssm-map-details"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.SsmMapDetails, [], name, value)


                class SsmMapDetail(Entity):
                    """
                    SSM Map Detail Table information
                    
                    .. attribute:: elapsed_time
                    
                    	Elapsed time
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: expiration_time
                    
                    	Expiration Time in Seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: map_info
                    
                    	Basic Map Info
                    	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo>`
                    
                    .. attribute:: query_interval
                    
                    	Query interval
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: response_pending
                    
                    	Response Pending
                    	**type**\:  bool
                    
                    .. attribute:: sources
                    
                    	List of sources
                    	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources>`
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, self).__init__()

                        self.yang_name = "ssm-map-detail"
                        self.yang_parent_name = "ssm-map-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"map-info" : ("map_info", Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo)}
                        self._child_list_classes = {"sources" : ("sources", Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources)}

                        self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                        self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.query_interval = YLeaf(YType.uint32, "query-interval")

                        self.response_pending = YLeaf(YType.boolean, "response-pending")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.map_info = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo()
                        self.map_info.parent = self
                        self._children_name_map["map_info"] = "map-info"
                        self._children_yang_names.add("map-info")

                        self.sources = YList(self)
                        self._segment_path = lambda: "ssm-map-detail"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                    class MapInfo(Entity):
                        """
                        Basic Map Info
                        
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                            self.yang_name = "map-info"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.group_address_xr = Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "map-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "map-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/ssm-map-detail/map-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                    class Sources(Entity):
                        """
                        List of sources
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                            self.yang_name = "sources"
                            self.yang_parent_name = "ssm-map-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "sources"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-map-details/ssm-map-detail/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class SsmMaps(Entity):
                """
                SSM Map Table
                
                .. attribute:: ssm_map
                
                	SSM Map information
                	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMaps.SsmMap>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.SsmMaps, self).__init__()

                    self.yang_name = "ssm-maps"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"ssm-map" : ("ssm_map", Mld.Standby.DefaultContext.SsmMaps.SsmMap)}

                    self.ssm_map = YList(self)
                    self._segment_path = lambda: "ssm-maps"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.SsmMaps, [], name, value)


                class SsmMap(Entity):
                    """
                    SSM Map information
                    
                    .. attribute:: group_address
                    
                    	Group address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: group_address_xr
                    
                    	Group Address
                    	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr>`
                    
                    .. attribute:: map_type
                    
                    	Map Type of group
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: source_counts
                    
                    	Count of Sources
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ssm_map_type
                    
                    	SSM Map Type
                    	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.SsmMaps.SsmMap, self).__init__()

                        self.yang_name = "ssm-map"
                        self.yang_parent_name = "ssm-maps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr)}
                        self._child_list_classes = {}

                        self.group_address = YLeaf(YType.str, "group-address")

                        self.map_type = YLeaf(YType.uint32, "map-type")

                        self.source_counts = YLeaf(YType.uint32, "source-counts")

                        self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                        self.group_address_xr = Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr()
                        self.group_address_xr.parent = self
                        self._children_name_map["group_address_xr"] = "group-address-xr"
                        self._children_yang_names.add("group-address-xr")
                        self._segment_path = lambda: "ssm-map"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-maps/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                    class GroupAddressXr(Entity):
                        """
                        Group Address
                        
                        .. attribute:: af_name
                        
                        	AFName
                        	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Addr
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_address
                        
                        	IPV6 Addr
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                            self.yang_name = "group-address-xr"
                            self.yang_parent_name = "ssm-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.af_name = YLeaf(YType.enumeration, "af-name")

                            self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                            self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                            self._segment_path = lambda: "group-address-xr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/ssm-maps/ssm-map/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.DefaultContext.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


            class Summary(Entity):
                """
                IGMP Summary Information
                
                .. attribute:: disabled_interface_count
                
                	No. of disabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: enabled_interface_count
                
                	No. of enabled interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_count
                
                	Current groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: group_limit
                
                	Maximum groups accepted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Maximum and current groups accepted for each interface
                	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.DefaultContext.Summary.Interface>`
                
                .. attribute:: is_disabled
                
                	Is maximum enforcement disabled
                	**type**\:  bool
                
                .. attribute:: node_low_memory
                
                	Is node in low memory condition
                	**type**\:  bool
                
                .. attribute:: robustness
                
                	Robustness variable
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: supported_interfaces
                
                	No. of supported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_mte_config_count
                
                	No. of static group commands
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsupported_interfaces
                
                	No. of unsupported interfaces
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"interface" : ("interface", Mld.Standby.DefaultContext.Summary.Interface)}

                    self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                    self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                    self.group_count = YLeaf(YType.uint32, "group-count")

                    self.group_limit = YLeaf(YType.uint32, "group-limit")

                    self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                    self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                    self.robustness = YLeaf(YType.uint32, "robustness")

                    self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                    self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                    self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                    self.interface = YList(self)
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                class Interface(Entity):
                    """
                    Maximum and current groups accepted for each
                    interface
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted per interface
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_name
                    
                    	Interface
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: on_off
                    
                    	Enabled/Disabled
                    	**type**\:  bool
                    
                    .. attribute:: parent_ifhandle
                    
                    	Parent if handle
                    	**type**\:  str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: router_uptime_in_seconds
                    
                    	Time elapsed since router enabled event
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_query_in_seconds
                    
                    	Time elapsed since last query
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time_since_last_report_in_seconds
                    
                    	Time elapsed since last report
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.DefaultContext.Summary.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.interface_name = YLeaf(YType.str, "interface-name")

                        self.on_off = YLeaf(YType.boolean, "on-off")

                        self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                        self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                        self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                        self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                        self._segment_path = lambda: "interface"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.DefaultContext.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


            class TrafficCounters(Entity):
                """
                IGMP Message Traffic Counters
                
                .. attribute:: auxillary_data_length_errors
                
                	AuxDataLen errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: bad_scope_errors
                
                	BadScope errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: checksum_errors
                
                	Checksum errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: elapsed_time
                
                	Running time for counters
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: format_errors
                
                	Malformed packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: get_packet_failure
                
                	Packet get failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_disabled_idb
                
                	Packet received on disabled idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_dvmrp
                
                	DVMRP packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_leaves
                
                	Leaves in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_martian_address
                
                	Packets received with Martian Address
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_mtrace
                
                	Mtrace packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_assigned_vrf_id
                
                	Packets received with no assigned vrf id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_idb
                
                	Packets received without idb
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_platform_support_mtrace
                
                	mtrace packets without platform support
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_in_idb
                
                	Packets received on idb without VRF
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_no_vrf_mtrace
                
                	mtrace packets with no vrf associated
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_pim
                
                	PIM packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_queries
                
                	Query packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: input_reports
                
                	Reports in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: invalid_source_address_errors
                
                	Invalid Source Address errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: miscellaneous_errors
                
                	Packets dropped for other reasons
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: no_socket_connection
                
                	Packets dropped since no socket connection
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_dvmrp
                
                	DVMRP packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_leaves
                
                	Leaves out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_mtrace
                
                	Mtrace packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_no_parent_interface_handle
                
                	Failures setting 2nd ifhandle
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_pim
                
                	PIM packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_queries
                
                	Query packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: output_reports
                
                	Reports out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_input_errors
                
                	Incoming Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packet_manager_output_errors
                
                	Outgoing Packet Manager packets dropped
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_in
                
                	Packets in
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: packets_out
                
                	Packets out
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_socket_errors
                
                	Socket errors on reception
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: socket_errors
                
                	Socket errors on send
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.DefaultContext.TrafficCounters, self).__init__()

                    self.yang_name = "traffic-counters"
                    self.yang_parent_name = "default-context"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                    self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                    self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                    self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                    self.format_errors = YLeaf(YType.uint32, "format-errors")

                    self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                    self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                    self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                    self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                    self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                    self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                    self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                    self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                    self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                    self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                    self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                    self.input_pim = YLeaf(YType.uint32, "input-pim")

                    self.input_queries = YLeaf(YType.uint32, "input-queries")

                    self.input_reports = YLeaf(YType.uint32, "input-reports")

                    self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                    self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                    self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                    self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                    self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                    self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                    self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                    self.output_pim = YLeaf(YType.uint32, "output-pim")

                    self.output_queries = YLeaf(YType.uint32, "output-queries")

                    self.output_reports = YLeaf(YType.uint32, "output-reports")

                    self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                    self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                    self.packets_in = YLeaf(YType.uint32, "packets-in")

                    self.packets_out = YLeaf(YType.uint32, "packets-out")

                    self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                    self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                    self._segment_path = lambda: "traffic-counters"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/default-context/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.DefaultContext.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)


        class Process(Entity):
            """
            Process
            
            .. attribute:: amt_gatewaies
            
            	Table containing AMT Gateway DataBase information
            	**type**\:   :py:class:`AmtGatewaies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.AmtGatewaies>`
            
            .. attribute:: amt_summary
            
            	MRIB RouteDB Expiry Information
            	**type**\:   :py:class:`AmtSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.AmtSummary>`
            
            .. attribute:: bvi_statistics
            
            	IGMP BVI Stats
            	**type**\:   :py:class:`BviStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.BviStatistics>`
            
            .. attribute:: nsf
            
            	NSF Information
            	**type**\:   :py:class:`Nsf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.Nsf>`
            
            .. attribute:: nsr
            
            	NSR Information
            	**type**\:   :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.Nsr>`
            
            .. attribute:: unicast_qos_adjust_stats
            
            	IGMP Unicast\-Qos\-Adjust Statistics
            	**type**\:   :py:class:`UnicastQosAdjustStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.UnicastQosAdjustStats>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Standby.Process, self).__init__()

                self.yang_name = "process"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"amt-gatewaies" : ("amt_gatewaies", Mld.Standby.Process.AmtGatewaies), "amt-summary" : ("amt_summary", Mld.Standby.Process.AmtSummary), "bvi-statistics" : ("bvi_statistics", Mld.Standby.Process.BviStatistics), "nsf" : ("nsf", Mld.Standby.Process.Nsf), "nsr" : ("nsr", Mld.Standby.Process.Nsr), "unicast-qos-adjust-stats" : ("unicast_qos_adjust_stats", Mld.Standby.Process.UnicastQosAdjustStats)}
                self._child_list_classes = {}

                self.amt_gatewaies = Mld.Standby.Process.AmtGatewaies()
                self.amt_gatewaies.parent = self
                self._children_name_map["amt_gatewaies"] = "amt-gatewaies"
                self._children_yang_names.add("amt-gatewaies")

                self.amt_summary = Mld.Standby.Process.AmtSummary()
                self.amt_summary.parent = self
                self._children_name_map["amt_summary"] = "amt-summary"
                self._children_yang_names.add("amt-summary")

                self.bvi_statistics = Mld.Standby.Process.BviStatistics()
                self.bvi_statistics.parent = self
                self._children_name_map["bvi_statistics"] = "bvi-statistics"
                self._children_yang_names.add("bvi-statistics")

                self.nsf = Mld.Standby.Process.Nsf()
                self.nsf.parent = self
                self._children_name_map["nsf"] = "nsf"
                self._children_yang_names.add("nsf")

                self.nsr = Mld.Standby.Process.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"
                self._children_yang_names.add("nsr")

                self.unicast_qos_adjust_stats = Mld.Standby.Process.UnicastQosAdjustStats()
                self.unicast_qos_adjust_stats.parent = self
                self._children_name_map["unicast_qos_adjust_stats"] = "unicast-qos-adjust-stats"
                self._children_yang_names.add("unicast-qos-adjust-stats")
                self._segment_path = lambda: "process"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/%s" % self._segment_path()


            class AmtGatewaies(Entity):
                """
                Table containing AMT Gateway DataBase
                information
                
                .. attribute:: amt_gateway
                
                	AMT Gateway DataBase information
                	**type**\: list of    :py:class:`AmtGateway <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Process.AmtGatewaies.AmtGateway>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.AmtGatewaies, self).__init__()

                    self.yang_name = "amt-gatewaies"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {"amt-gateway" : ("amt_gateway", Mld.Standby.Process.AmtGatewaies.AmtGateway)}

                    self.amt_gateway = YList(self)
                    self._segment_path = lambda: "amt-gatewaies"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.Process.AmtGatewaies, [], name, value)


                class AmtGateway(Entity):
                    """
                    AMT Gateway DataBase information
                    
                    .. attribute:: amt_nonce
                    
                    	Nonce
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amt_port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: amtgw
                    
                    	GW
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: amtnh
                    
                    	AMT NH
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: gateway_address
                    
                    	Gateway Address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    
                    ----
                    .. attribute:: idb
                    
                    	IDB
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: key_len
                    
                    	Len
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_in
                    
                    	UpdIn
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mem_upd_out
                    
                    	UpdOut
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port
                    
                    	Port
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Process.AmtGatewaies.AmtGateway, self).__init__()

                        self.yang_name = "amt-gateway"
                        self.yang_parent_name = "amt-gatewaies"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.amt_nonce = YLeaf(YType.uint32, "amt-nonce")

                        self.amt_port = YLeaf(YType.uint32, "amt-port")

                        self.amtgw = YLeaf(YType.str, "amtgw")

                        self.amtnh = YLeaf(YType.uint32, "amtnh")

                        self.gateway_address = YLeaf(YType.str, "gateway-address")

                        self.idb = YLeaf(YType.uint64, "idb")

                        self.key_len = YLeaf(YType.uint32, "key-len")

                        self.mem_upd_in = YLeaf(YType.uint32, "mem-upd-in")

                        self.mem_upd_out = YLeaf(YType.uint32, "mem-upd-out")

                        self.port = YLeaf(YType.int32, "port")
                        self._segment_path = lambda: "amt-gateway"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/amt-gatewaies/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Process.AmtGatewaies.AmtGateway, ['amt_nonce', 'amt_port', 'amtgw', 'amtnh', 'gateway_address', 'idb', 'key_len', 'mem_upd_in', 'mem_upd_out', 'port'], name, value)


            class AmtSummary(Entity):
                """
                MRIB RouteDB Expiry Information
                
                .. attribute:: anycast_prefix
                
                	Robustness variable
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: gateway_count
                
                	Number of AMT Gateway
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_acl_configured
                
                	ACL configured under AMT
                	**type**\:  bool
                
                .. attribute:: is_gateway_simulation
                
                	AMT Gateway Simulation
                	**type**\:  bool
                
                .. attribute:: is_ou_of_resource
                
                	AMT Out Of Resource
                	**type**\:  bool
                
                .. attribute:: max_gateway
                
                	Maximum Gateway allowed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: mtu
                
                	AMT Tunnel MTU
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_length
                
                	Advertize AMT prefix length
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: query_interval
                
                	AMT Query interval
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: relay_address
                
                	Advertaisment for AMT Relay address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tos
                
                	Type Of Service value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: ttl
                
                	Time To Live value in AMT header
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_configured_maximum
                
                	AMT Tunnel configured Maximum
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tunnel_count
                
                	AMT Tunnel Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.AmtSummary, self).__init__()

                    self.yang_name = "amt-summary"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.anycast_prefix = YLeaf(YType.str, "anycast-prefix")

                    self.gateway_count = YLeaf(YType.uint32, "gateway-count")

                    self.is_acl_configured = YLeaf(YType.boolean, "is-acl-configured")

                    self.is_gateway_simulation = YLeaf(YType.boolean, "is-gateway-simulation")

                    self.is_ou_of_resource = YLeaf(YType.boolean, "is-ou-of-resource")

                    self.max_gateway = YLeaf(YType.uint32, "max-gateway")

                    self.mtu = YLeaf(YType.uint32, "mtu")

                    self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                    self.query_interval = YLeaf(YType.uint32, "query-interval")

                    self.relay_address = YLeaf(YType.str, "relay-address")

                    self.tos = YLeaf(YType.uint32, "tos")

                    self.ttl = YLeaf(YType.uint32, "ttl")

                    self.tunnel_configured_maximum = YLeaf(YType.uint32, "tunnel-configured-maximum")

                    self.tunnel_count = YLeaf(YType.uint32, "tunnel-count")
                    self._segment_path = lambda: "amt-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.Process.AmtSummary, ['anycast_prefix', 'gateway_count', 'is_acl_configured', 'is_gateway_simulation', 'is_ou_of_resource', 'max_gateway', 'mtu', 'prefix_length', 'query_interval', 'relay_address', 'tos', 'ttl', 'tunnel_configured_maximum', 'tunnel_count'], name, value)


            class BviStatistics(Entity):
                """
                IGMP BVI Stats
                
                .. attribute:: null_buffer_handles
                
                	Number of AIPC NULL buffer handles
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: receive_buffers
                
                	Number of AIPC buffers received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_buffers
                
                	Number of AIPC buffers released
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: release_fail_buffers
                
                	Number of AIPC buffers release failed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_igmp_packet_success
                
                	Number of IGMP protocol messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_close_notif
                
                	Number of AIPC close notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_connect_notif
                
                	Number of AIPC connect notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_error_notif
                
                	Number of AIPC error notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_input_wait_notif
                
                	Number of AIPC input waiting notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_lwm_notif
                
                	Number of AIPC LWM notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_open_notif
                
                	Number of AIPC open notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_output_notif
                
                	Number of AIPC output notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_publish_notif
                
                	Number of AIPC publish notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_q_full_notif
                
                	Number of AIPC queue full notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_ipc_send_status_notif
                
                	Number of AIPC send status notifications received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: rx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_blocks
                
                	Number of AIPC buffers send blocked
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_add_mrouter_msg
                
                	Number of IGMP Mrouter Add messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffer_errors
                
                	Number of AIPC transmission errors
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_buffers
                
                	Number of AIPC buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_delete_mrouter_msg
                
                	Number of IGMP Mrouter Delete messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_mrouter_buffers
                
                	Number of IGMP Mrouter buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_protocol_buffers
                
                	Number of IGMP protocol buffers transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_sweep_mrouter_msg
                
                	Number of IGMP Mrouter Sweep messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_buffers
                
                	Number of IGMP Unknown buffers transmited
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: tx_unknown_mrouter_msg
                
                	Number of IGMP Mrouter Unknown messages transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_dc
                
                	Number of WTX messages dropped due to disconnect
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_drop_nomem
                
                	Number of WTX messages dropped to memory
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_freed
                
                	Number of WTX messages freed
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_proto_sent
                
                	Number of WTX messages sent to Protocol
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_recvd
                
                	Number of WTX messages received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: wtx_msg_sent
                
                	Number of WTX messages sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.BviStatistics, self).__init__()

                    self.yang_name = "bvi-statistics"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.null_buffer_handles = YLeaf(YType.uint32, "null-buffer-handles")

                    self.receive_buffers = YLeaf(YType.uint32, "receive-buffers")

                    self.release_buffers = YLeaf(YType.uint32, "release-buffers")

                    self.release_fail_buffers = YLeaf(YType.uint32, "release-fail-buffers")

                    self.rx_add_mrouter_msg = YLeaf(YType.uint32, "rx-add-mrouter-msg")

                    self.rx_delete_mrouter_msg = YLeaf(YType.uint32, "rx-delete-mrouter-msg")

                    self.rx_igmp_packet_success = YLeaf(YType.uint32, "rx-igmp-packet-success")

                    self.rx_ipc_close_notif = YLeaf(YType.uint32, "rx-ipc-close-notif")

                    self.rx_ipc_connect_notif = YLeaf(YType.uint32, "rx-ipc-connect-notif")

                    self.rx_ipc_error_notif = YLeaf(YType.uint32, "rx-ipc-error-notif")

                    self.rx_ipc_input_wait_notif = YLeaf(YType.uint32, "rx-ipc-input-wait-notif")

                    self.rx_ipc_lwm_notif = YLeaf(YType.uint32, "rx-ipc-lwm-notif")

                    self.rx_ipc_open_notif = YLeaf(YType.uint32, "rx-ipc-open-notif")

                    self.rx_ipc_output_notif = YLeaf(YType.uint32, "rx-ipc-output-notif")

                    self.rx_ipc_publish_notif = YLeaf(YType.uint32, "rx-ipc-publish-notif")

                    self.rx_ipc_q_full_notif = YLeaf(YType.uint32, "rx-ipc-q-full-notif")

                    self.rx_ipc_send_status_notif = YLeaf(YType.uint32, "rx-ipc-send-status-notif")

                    self.rx_sweep_mrouter_msg = YLeaf(YType.uint32, "rx-sweep-mrouter-msg")

                    self.rx_unknown_mrouter_msg = YLeaf(YType.uint32, "rx-unknown-mrouter-msg")

                    self.send_blocks = YLeaf(YType.uint32, "send-blocks")

                    self.tx_add_mrouter_msg = YLeaf(YType.uint32, "tx-add-mrouter-msg")

                    self.tx_buffer_errors = YLeaf(YType.uint32, "tx-buffer-errors")

                    self.tx_buffers = YLeaf(YType.uint32, "tx-buffers")

                    self.tx_delete_mrouter_msg = YLeaf(YType.uint32, "tx-delete-mrouter-msg")

                    self.tx_mrouter_buffers = YLeaf(YType.uint32, "tx-mrouter-buffers")

                    self.tx_protocol_buffers = YLeaf(YType.uint32, "tx-protocol-buffers")

                    self.tx_sweep_mrouter_msg = YLeaf(YType.uint32, "tx-sweep-mrouter-msg")

                    self.tx_unknown_buffers = YLeaf(YType.uint32, "tx-unknown-buffers")

                    self.tx_unknown_mrouter_msg = YLeaf(YType.uint32, "tx-unknown-mrouter-msg")

                    self.wtx_msg_drop_dc = YLeaf(YType.uint32, "wtx-msg-drop-dc")

                    self.wtx_msg_drop_nomem = YLeaf(YType.uint32, "wtx-msg-drop-nomem")

                    self.wtx_msg_freed = YLeaf(YType.uint32, "wtx-msg-freed")

                    self.wtx_msg_proto_sent = YLeaf(YType.uint32, "wtx-msg-proto-sent")

                    self.wtx_msg_recvd = YLeaf(YType.uint32, "wtx-msg-recvd")

                    self.wtx_msg_sent = YLeaf(YType.uint32, "wtx-msg-sent")
                    self._segment_path = lambda: "bvi-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.Process.BviStatistics, ['null_buffer_handles', 'receive_buffers', 'release_buffers', 'release_fail_buffers', 'rx_add_mrouter_msg', 'rx_delete_mrouter_msg', 'rx_igmp_packet_success', 'rx_ipc_close_notif', 'rx_ipc_connect_notif', 'rx_ipc_error_notif', 'rx_ipc_input_wait_notif', 'rx_ipc_lwm_notif', 'rx_ipc_open_notif', 'rx_ipc_output_notif', 'rx_ipc_publish_notif', 'rx_ipc_q_full_notif', 'rx_ipc_send_status_notif', 'rx_sweep_mrouter_msg', 'rx_unknown_mrouter_msg', 'send_blocks', 'tx_add_mrouter_msg', 'tx_buffer_errors', 'tx_buffers', 'tx_delete_mrouter_msg', 'tx_mrouter_buffers', 'tx_protocol_buffers', 'tx_sweep_mrouter_msg', 'tx_unknown_buffers', 'tx_unknown_mrouter_msg', 'wtx_msg_drop_dc', 'wtx_msg_drop_nomem', 'wtx_msg_freed', 'wtx_msg_proto_sent', 'wtx_msg_recvd', 'wtx_msg_sent'], name, value)


            class Nsf(Entity):
                """
                NSF Information
                
                .. attribute:: is_multicast_nsf_active
                
                	Is Multicast NSF active
                	**type**\:  bool
                
                .. attribute:: last_icd_notif_recv
                
                	Last ICD Notif Recv
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_icd_notif_recv_min
                
                	Last ICD Notif Recv in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_off
                
                	Last NSF time off
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_off_min
                
                	Last NSF time OFF in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: last_nsf_on
                
                	Last NSF time ON
                	**type**\:  int
                
                	**range:** \-9223372036854775808..9223372036854775807
                
                .. attribute:: last_nsf_on_min
                
                	Last NSF time ON in Seconds
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_time_left
                
                	Multicast NSF time remaining in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: multicast_nsf_timeout
                
                	Multicast NSF timeout in secs
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: respawn_count
                
                	Respawn Count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.Nsf, self).__init__()

                    self.yang_name = "nsf"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.is_multicast_nsf_active = YLeaf(YType.boolean, "is-multicast-nsf-active")

                    self.last_icd_notif_recv = YLeaf(YType.int64, "last-icd-notif-recv")

                    self.last_icd_notif_recv_min = YLeaf(YType.int32, "last-icd-notif-recv-min")

                    self.last_nsf_off = YLeaf(YType.int64, "last-nsf-off")

                    self.last_nsf_off_min = YLeaf(YType.int32, "last-nsf-off-min")

                    self.last_nsf_on = YLeaf(YType.int64, "last-nsf-on")

                    self.last_nsf_on_min = YLeaf(YType.int32, "last-nsf-on-min")

                    self.multicast_nsf_time_left = YLeaf(YType.uint32, "multicast-nsf-time-left")

                    self.multicast_nsf_timeout = YLeaf(YType.uint32, "multicast-nsf-timeout")

                    self.respawn_count = YLeaf(YType.uint32, "respawn-count")
                    self._segment_path = lambda: "nsf"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.Process.Nsf, ['is_multicast_nsf_active', 'last_icd_notif_recv', 'last_icd_notif_recv_min', 'last_nsf_off', 'last_nsf_off_min', 'last_nsf_on', 'last_nsf_on_min', 'multicast_nsf_time_left', 'multicast_nsf_timeout', 'respawn_count'], name, value)


            class Nsr(Entity):
                """
                NSR Information
                
                .. attribute:: collab_conv_done
                
                	Collaborators convergence done
                	**type**\:  bool
                
                .. attribute:: count_proc_connection_dn
                
                	No. of times process connection went down
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_proc_connection_up
                
                	No. of times process connection went up
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_not_ready
                
                	No. of times RMF Not Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: count_rmf_ready
                
                	No. of times RMF Ready notif was sent
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_proc
                
                	Time when process came up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_dn
                
                	Time when process connection went down
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_proc_connection_up
                
                	Time when process connection went up
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_not_ready
                
                	Time when RMF Not\-Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: last_rmf_ready
                
                	Time when RMF Rdy notif was sent
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: partner_proc_connected
                
                	Partner process connected
                	**type**\:  bool
                
                .. attribute:: rmf_notification_done
                
                	RMF Notification done
                	**type**\:  bool
                
                .. attribute:: state
                
                	NSR state
                	**type**\:  int
                
                	**range:** 0..255
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.collab_conv_done = YLeaf(YType.boolean, "collab-conv-done")

                    self.count_proc_connection_dn = YLeaf(YType.uint32, "count-proc-connection-dn")

                    self.count_proc_connection_up = YLeaf(YType.uint32, "count-proc-connection-up")

                    self.count_rmf_not_ready = YLeaf(YType.uint32, "count-rmf-not-ready")

                    self.count_rmf_ready = YLeaf(YType.uint32, "count-rmf-ready")

                    self.last_proc = YLeaf(YType.uint64, "last-proc")

                    self.last_proc_connection_dn = YLeaf(YType.uint64, "last-proc-connection-dn")

                    self.last_proc_connection_up = YLeaf(YType.uint64, "last-proc-connection-up")

                    self.last_rmf_not_ready = YLeaf(YType.uint64, "last-rmf-not-ready")

                    self.last_rmf_ready = YLeaf(YType.uint64, "last-rmf-ready")

                    self.partner_proc_connected = YLeaf(YType.boolean, "partner-proc-connected")

                    self.rmf_notification_done = YLeaf(YType.boolean, "rmf-notification-done")

                    self.state = YLeaf(YType.uint8, "state")
                    self._segment_path = lambda: "nsr"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.Process.Nsr, ['collab_conv_done', 'count_proc_connection_dn', 'count_proc_connection_up', 'count_rmf_not_ready', 'count_rmf_ready', 'last_proc', 'last_proc_connection_dn', 'last_proc_connection_up', 'last_rmf_not_ready', 'last_rmf_ready', 'partner_proc_connected', 'rmf_notification_done', 'state'], name, value)


            class UnicastQosAdjustStats(Entity):
                """
                IGMP Unicast\-Qos\-Adjust Statistics
                
                .. attribute:: add_to_batches
                
                	Add to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: batches
                
                	I2Q Rate Batch count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: delete_to_batches
                
                	Delete to batch count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_qos_s_sweeped
                
                	Is QOS Sweeped once 
                	**type**\:  bool
                
                .. attribute:: is_resync_received
                
                	Is Resync request received
                	**type**\:  bool
                
                .. attribute:: is_resync_required
                
                	Is Resync required
                	**type**\:  bool
                
                .. attribute:: is_resync_start_sent
                
                	Is Resync Start message sent
                	**type**\:  bool
                
                .. attribute:: last_download_time
                
                	Time elapsed since Last download to QOS in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: last_sweep_time
                
                	Time elapsed since Last mark and sweep in seconds
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                	**units**\: second
                
                .. attribute:: queues
                
                	I2Q Queue count
                	**type**\:  int
                
                	**range:** 0..65535
                
                .. attribute:: received_resync_requests
                
                	Number of Resync request received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_comm_errors
                
                	Send Error due to comms count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_errors
                
                	Number of Send errors in batch
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_partial_errors
                
                	Send Error due to partial issue count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: send_success
                
                	Send Success count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: sent_resync_bulks
                
                	Number of bulks sent for last resync received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Process.UnicastQosAdjustStats, self).__init__()

                    self.yang_name = "unicast-qos-adjust-stats"
                    self.yang_parent_name = "process"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.add_to_batches = YLeaf(YType.uint32, "add-to-batches")

                    self.batches = YLeaf(YType.uint16, "batches")

                    self.delete_to_batches = YLeaf(YType.uint32, "delete-to-batches")

                    self.is_qos_s_sweeped = YLeaf(YType.boolean, "is-qos-s-sweeped")

                    self.is_resync_received = YLeaf(YType.boolean, "is-resync-received")

                    self.is_resync_required = YLeaf(YType.boolean, "is-resync-required")

                    self.is_resync_start_sent = YLeaf(YType.boolean, "is-resync-start-sent")

                    self.last_download_time = YLeaf(YType.uint64, "last-download-time")

                    self.last_sweep_time = YLeaf(YType.uint64, "last-sweep-time")

                    self.queues = YLeaf(YType.uint16, "queues")

                    self.received_resync_requests = YLeaf(YType.uint32, "received-resync-requests")

                    self.send_comm_errors = YLeaf(YType.uint32, "send-comm-errors")

                    self.send_errors = YLeaf(YType.uint32, "send-errors")

                    self.send_partial_errors = YLeaf(YType.uint32, "send-partial-errors")

                    self.send_success = YLeaf(YType.uint32, "send-success")

                    self.sent_resync_bulks = YLeaf(YType.uint32, "sent-resync-bulks")
                    self._segment_path = lambda: "unicast-qos-adjust-stats"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/process/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.Process.UnicastQosAdjustStats, ['add_to_batches', 'batches', 'delete_to_batches', 'is_qos_s_sweeped', 'is_resync_received', 'is_resync_required', 'is_resync_start_sent', 'last_download_time', 'last_sweep_time', 'queues', 'received_resync_requests', 'send_comm_errors', 'send_errors', 'send_partial_errors', 'send_success', 'sent_resync_bulks'], name, value)


        class Vrfs(Entity):
            """
            VRF Table
            
            .. attribute:: vrf
            
            	VRF table Names
            	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf>`
            
            

            """

            _prefix = 'ipv4-igmp-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Mld.Standby.Vrfs, self).__init__()

                self.yang_name = "vrfs"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"vrf" : ("vrf", Mld.Standby.Vrfs.Vrf)}

                self.vrf = YList(self)
                self._segment_path = lambda: "vrfs"
                self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Mld.Standby.Vrfs, [], name, value)


            class Vrf(Entity):
                """
                VRF table Names
                
                .. attribute:: vrf_name  <key>
                
                	VRF name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: detail_groups
                
                	IGMP Detail Group Database
                	**type**\:   :py:class:`DetailGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups>`
                
                .. attribute:: explicit_groups
                
                	IGMP Explicit Group Database
                	**type**\:   :py:class:`ExplicitGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups>`
                
                .. attribute:: global_interface_table
                
                	IGMP Global Interface 
                	**type**\:   :py:class:`GlobalInterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable>`
                
                .. attribute:: group_summary
                
                	IGMP Groups Summary
                	**type**\:   :py:class:`GroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GroupSummary>`
                
                .. attribute:: groups
                
                	IGMP Group Database Table
                	**type**\:   :py:class:`Groups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups>`
                
                .. attribute:: ifrs_interface_summary
                
                	IGMP IFRS Interface summary
                	**type**\:   :py:class:`IfrsInterfaceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary>`
                
                .. attribute:: ifrs_interfaces
                
                	IGMP Interface specific
                	**type**\:   :py:class:`IfrsInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces>`
                
                .. attribute:: interface_state_offs
                
                	IGMP Interface state off
                	**type**\:   :py:class:`InterfaceStateOffs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs>`
                
                .. attribute:: interface_state_ons
                
                	IGMP Interface state on
                	**type**\:   :py:class:`InterfaceStateOns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns>`
                
                .. attribute:: interface_table
                
                	IGMP Interface specific Table
                	**type**\:   :py:class:`InterfaceTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable>`
                
                .. attribute:: interface_unicast_qos_adjusts
                
                	IGMP Interface Unicast\-Qos\-Adjust
                	**type**\:   :py:class:`InterfaceUnicastQosAdjusts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts>`
                
                .. attribute:: non_active_groups
                
                	IGMP Non\-Active Groups Information
                	**type**\:   :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups>`
                
                .. attribute:: ranges
                
                	Range table
                	**type**\:   :py:class:`Ranges <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Ranges>`
                
                .. attribute:: ssm_map_details
                
                	SSM Map Detail
                	**type**\:   :py:class:`SsmMapDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails>`
                
                .. attribute:: ssm_maps
                
                	SSM Map Table
                	**type**\:   :py:class:`SsmMaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMaps>`
                
                .. attribute:: summary
                
                	IGMP Summary Information
                	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Summary>`
                
                .. attribute:: traffic_counters
                
                	IGMP Message Traffic Counters
                	**type**\:   :py:class:`TrafficCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.TrafficCounters>`
                
                

                """

                _prefix = 'ipv4-igmp-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Mld.Standby.Vrfs.Vrf, self).__init__()

                    self.yang_name = "vrf"
                    self.yang_parent_name = "vrfs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"detail-groups" : ("detail_groups", Mld.Standby.Vrfs.Vrf.DetailGroups), "explicit-groups" : ("explicit_groups", Mld.Standby.Vrfs.Vrf.ExplicitGroups), "global-interface-table" : ("global_interface_table", Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable), "group-summary" : ("group_summary", Mld.Standby.Vrfs.Vrf.GroupSummary), "groups" : ("groups", Mld.Standby.Vrfs.Vrf.Groups), "ifrs-interface-summary" : ("ifrs_interface_summary", Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary), "ifrs-interfaces" : ("ifrs_interfaces", Mld.Standby.Vrfs.Vrf.IfrsInterfaces), "interface-state-offs" : ("interface_state_offs", Mld.Standby.Vrfs.Vrf.InterfaceStateOffs), "interface-state-ons" : ("interface_state_ons", Mld.Standby.Vrfs.Vrf.InterfaceStateOns), "interface-table" : ("interface_table", Mld.Standby.Vrfs.Vrf.InterfaceTable), "interface-unicast-qos-adjusts" : ("interface_unicast_qos_adjusts", Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts), "non-active-groups" : ("non_active_groups", Mld.Standby.Vrfs.Vrf.NonActiveGroups), "ranges" : ("ranges", Mld.Standby.Vrfs.Vrf.Ranges), "ssm-map-details" : ("ssm_map_details", Mld.Standby.Vrfs.Vrf.SsmMapDetails), "ssm-maps" : ("ssm_maps", Mld.Standby.Vrfs.Vrf.SsmMaps), "summary" : ("summary", Mld.Standby.Vrfs.Vrf.Summary), "traffic-counters" : ("traffic_counters", Mld.Standby.Vrfs.Vrf.TrafficCounters)}
                    self._child_list_classes = {}

                    self.vrf_name = YLeaf(YType.str, "vrf-name")

                    self.detail_groups = Mld.Standby.Vrfs.Vrf.DetailGroups()
                    self.detail_groups.parent = self
                    self._children_name_map["detail_groups"] = "detail-groups"
                    self._children_yang_names.add("detail-groups")

                    self.explicit_groups = Mld.Standby.Vrfs.Vrf.ExplicitGroups()
                    self.explicit_groups.parent = self
                    self._children_name_map["explicit_groups"] = "explicit-groups"
                    self._children_yang_names.add("explicit-groups")

                    self.global_interface_table = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable()
                    self.global_interface_table.parent = self
                    self._children_name_map["global_interface_table"] = "global-interface-table"
                    self._children_yang_names.add("global-interface-table")

                    self.group_summary = Mld.Standby.Vrfs.Vrf.GroupSummary()
                    self.group_summary.parent = self
                    self._children_name_map["group_summary"] = "group-summary"
                    self._children_yang_names.add("group-summary")

                    self.groups = Mld.Standby.Vrfs.Vrf.Groups()
                    self.groups.parent = self
                    self._children_name_map["groups"] = "groups"
                    self._children_yang_names.add("groups")

                    self.ifrs_interface_summary = Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary()
                    self.ifrs_interface_summary.parent = self
                    self._children_name_map["ifrs_interface_summary"] = "ifrs-interface-summary"
                    self._children_yang_names.add("ifrs-interface-summary")

                    self.ifrs_interfaces = Mld.Standby.Vrfs.Vrf.IfrsInterfaces()
                    self.ifrs_interfaces.parent = self
                    self._children_name_map["ifrs_interfaces"] = "ifrs-interfaces"
                    self._children_yang_names.add("ifrs-interfaces")

                    self.interface_state_offs = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs()
                    self.interface_state_offs.parent = self
                    self._children_name_map["interface_state_offs"] = "interface-state-offs"
                    self._children_yang_names.add("interface-state-offs")

                    self.interface_state_ons = Mld.Standby.Vrfs.Vrf.InterfaceStateOns()
                    self.interface_state_ons.parent = self
                    self._children_name_map["interface_state_ons"] = "interface-state-ons"
                    self._children_yang_names.add("interface-state-ons")

                    self.interface_table = Mld.Standby.Vrfs.Vrf.InterfaceTable()
                    self.interface_table.parent = self
                    self._children_name_map["interface_table"] = "interface-table"
                    self._children_yang_names.add("interface-table")

                    self.interface_unicast_qos_adjusts = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts()
                    self.interface_unicast_qos_adjusts.parent = self
                    self._children_name_map["interface_unicast_qos_adjusts"] = "interface-unicast-qos-adjusts"
                    self._children_yang_names.add("interface-unicast-qos-adjusts")

                    self.non_active_groups = Mld.Standby.Vrfs.Vrf.NonActiveGroups()
                    self.non_active_groups.parent = self
                    self._children_name_map["non_active_groups"] = "non-active-groups"
                    self._children_yang_names.add("non-active-groups")

                    self.ranges = Mld.Standby.Vrfs.Vrf.Ranges()
                    self.ranges.parent = self
                    self._children_name_map["ranges"] = "ranges"
                    self._children_yang_names.add("ranges")

                    self.ssm_map_details = Mld.Standby.Vrfs.Vrf.SsmMapDetails()
                    self.ssm_map_details.parent = self
                    self._children_name_map["ssm_map_details"] = "ssm-map-details"
                    self._children_yang_names.add("ssm-map-details")

                    self.ssm_maps = Mld.Standby.Vrfs.Vrf.SsmMaps()
                    self.ssm_maps.parent = self
                    self._children_name_map["ssm_maps"] = "ssm-maps"
                    self._children_yang_names.add("ssm-maps")

                    self.summary = Mld.Standby.Vrfs.Vrf.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._children_yang_names.add("summary")

                    self.traffic_counters = Mld.Standby.Vrfs.Vrf.TrafficCounters()
                    self.traffic_counters.parent = self
                    self._children_name_map["traffic_counters"] = "traffic-counters"
                    self._children_yang_names.add("traffic-counters")
                    self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ipv4-igmp-oper:mld/standby/vrfs/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Mld.Standby.Vrfs.Vrf, ['vrf_name'], name, value)


                class DetailGroups(Entity):
                    """
                    IGMP Detail Group Database
                    
                    .. attribute:: detail_group
                    
                    	IGMP Detail Group Entry Information
                    	**type**\: list of    :py:class:`DetailGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.DetailGroups, self).__init__()

                        self.yang_name = "detail-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"detail-group" : ("detail_group", Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup)}

                        self.detail_group = YList(self)
                        self._segment_path = lambda: "detail-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups, [], name, value)


                    class DetailGroup(Entity):
                        """
                        IGMP Detail Group Entry Information
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_host_exclude_mode
                        
                        	Group host filter mode
                        	**type**\:  bool
                        
                        .. attribute:: is_router_exclude_mode
                        
                        	Group router filter mode
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source>`
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, self).__init__()

                            self.yang_name = "detail-group"
                            self.yang_parent_name = "detail-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo)}
                            self._child_list_classes = {"source" : ("source", Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source)}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_host_exclude_mode = YLeaf(YType.boolean, "is-host-exclude-mode")

                            self.is_router_exclude_mode = YLeaf(YType.boolean, "is-router-exclude-mode")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.source = YList(self)
                            self._segment_path = lambda: "detail-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup, ['group_address', 'interface_name', 'is_host_exclude_mode', 'is_router_exclude_mode', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Source(Entity):
                            """
                            List of sources
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: flags
                            
                            	Source flags
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_forward
                            
                            	Should we forward on this entry
                            	**type**\:  bool
                            
                            .. attribute:: is_local
                            
                            	Is this a local source
                            	**type**\:  bool
                            
                            .. attribute:: is_remote
                            
                            	Is this a remote source
                            	**type**\:  bool
                            
                            .. attribute:: is_we_report
                            
                            	Should we report the source
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, self).__init__()

                                self.yang_name = "source"
                                self.yang_parent_name = "detail-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"source-address" : ("source_address", Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.flags = YLeaf(YType.int32, "flags")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_forward = YLeaf(YType.boolean, "is-forward")

                                self.is_local = YLeaf(YType.boolean, "is-local")

                                self.is_remote = YLeaf(YType.boolean, "is-remote")

                                self.is_we_report = YLeaf(YType.boolean, "is-we-report")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.source_address = Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "source"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source, ['expiration_time', 'flags', 'is_added', 'is_forward', 'is_local', 'is_remote', 'is_we_report', 'uptime'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "source"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.DetailGroups.DetailGroup.Source.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class ExplicitGroups(Entity):
                    """
                    IGMP Explicit Group Database
                    
                    .. attribute:: explicit_group
                    
                    	IGMP Explicit Group Entry Information
                    	**type**\: list of    :py:class:`ExplicitGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.ExplicitGroups, self).__init__()

                        self.yang_name = "explicit-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"explicit-group" : ("explicit_group", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup)}

                        self.explicit_group = YList(self)
                        self._segment_path = lambda: "explicit-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups, [], name, value)


                    class ExplicitGroup(Entity):
                        """
                        IGMP Explicit Group Entry Information
                        
                        .. attribute:: exclude_hosts
                        
                        	No. of hosts who are excluded
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_info
                        
                        	Basic Group information
                        	**type**\:   :py:class:`GroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo>`
                        
                        .. attribute:: host
                        
                        	List of hosts
                        	**type**\: list of    :py:class:`Host <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host>`
                        
                        .. attribute:: include_hosts
                        
                        	No. of hosts who are included
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: source_address
                        
                        	Source/Host Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, self).__init__()

                            self.yang_name = "explicit-group"
                            self.yang_parent_name = "explicit-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-info" : ("group_info", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo)}
                            self._child_list_classes = {"host" : ("host", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host)}

                            self.exclude_hosts = YLeaf(YType.uint32, "exclude-hosts")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.include_hosts = YLeaf(YType.uint32, "include-hosts")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.source_address = YLeaf(YType.str, "source-address")

                            self.group_info = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo()
                            self.group_info.parent = self
                            self._children_name_map["group_info"] = "group-info"
                            self._children_yang_names.add("group-info")

                            self.host = YList(self)
                            self._segment_path = lambda: "explicit-group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup, ['exclude_hosts', 'group_address', 'include_hosts', 'interface_name', 'source_address'], name, value)


                        class GroupInfo(Entity):
                            """
                            Basic Group information
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**units**\: second
                            
                            .. attribute:: explicit_tracking_enabled
                            
                            	Is explicit tracking enabled
                            	**type**\:  bool
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr>`
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_added
                            
                            	Joined
                            	**type**\:  bool
                            
                            .. attribute:: is_low_memory
                            
                            	Node is running low on memory
                            	**type**\:  bool
                            
                            .. attribute:: is_self_join
                            
                            	If local system is member of this group on this interface
                            	**type**\:  bool
                            
                            .. attribute:: is_suppressed
                            
                            	Suppressed
                            	**type**\:  bool
                            
                            .. attribute:: last_reporter
                            
                            	Last reporter address
                            	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter>`
                            
                            .. attribute:: older_host_version1_timer
                            
                            	IGMP Hostversion1timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: older_host_version2_timer
                            
                            	IGMP Hostversion2timer
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_filter_mode
                            
                            	Filter mode
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: row_status
                            
                            	interface on or off for the group
                            	**type**\:  str
                            
                            	**length:** 0..16
                            
                            .. attribute:: source_address
                            
                            	Source Address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress>`
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, self).__init__()

                                self.yang_name = "group-info"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter), "source-address" : ("source_address", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress)}
                                self._child_list_classes = {}

                                self.expiration_time = YLeaf(YType.int32, "expiration-time")

                                self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_added = YLeaf(YType.boolean, "is-added")

                                self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                                self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                                self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                                self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                                self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                                self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                                self.row_status = YLeaf(YType.str, "row-status")

                                self.uptime = YLeaf(YType.uint64, "uptime")

                                self.group_address_xr = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")

                                self.last_reporter = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter()
                                self.last_reporter.parent = self
                                self._children_name_map["last_reporter"] = "last-reporter"
                                self._children_yang_names.add("last-reporter")

                                self.source_address = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo, ['expiration_time', 'explicit_tracking_enabled', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class LastReporter(Entity):
                                """
                                Last reporter address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, self).__init__()

                                    self.yang_name = "last-reporter"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "last-reporter"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.GroupInfo.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Host(Entity):
                            """
                            List of hosts
                            
                            .. attribute:: address
                            
                            	Host Address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address>`
                            
                            .. attribute:: expiration_time
                            
                            	Expiration time in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: is_exclude
                            
                            	Exclude flag set
                            	**type**\:  bool
                            
                            .. attribute:: source_address
                            
                            	First 3 source addresses
                            	**type**\: list of    :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress>`
                            
                            .. attribute:: source_count
                            
                            	No. of sources in entry
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: uptime
                            
                            	Uptime in seconds
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, self).__init__()

                                self.yang_name = "host"
                                self.yang_parent_name = "explicit-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address)}
                                self._child_list_classes = {"source-address" : ("source_address", Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress)}

                                self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                                self.is_exclude = YLeaf(YType.boolean, "is-exclude")

                                self.source_count = YLeaf(YType.uint32, "source-count")

                                self.uptime = YLeaf(YType.uint32, "uptime")

                                self.address = Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.source_address = YList(self)
                                self._segment_path = lambda: "host"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host, ['expiration_time', 'is_exclude', 'source_count', 'uptime'], name, value)


                            class Address(Entity):
                                """
                                Host Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                First 3 source addresses
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "host"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.ExplicitGroups.ExplicitGroup.Host.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GlobalInterfaceTable(Entity):
                    """
                    IGMP Global Interface 
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable, self).__init__()

                        self.yang_name = "global-interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "global-interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "global-interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.GlobalInterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class GroupSummary(Entity):
                    """
                    IGMP Groups Summary
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: groutes
                    
                    	No. of (\*,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_low_memory
                    
                    	Node is running low on memory
                    	**type**\:  bool
                    
                    .. attribute:: sg_routes
                    
                    	No. of (S,G) routes
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.GroupSummary, self).__init__()

                        self.yang_name = "group-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.groutes = YLeaf(YType.uint32, "groutes")

                        self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                        self.sg_routes = YLeaf(YType.uint32, "sg-routes")
                        self._segment_path = lambda: "group-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.GroupSummary, ['group_count', 'groutes', 'is_low_memory', 'sg_routes'], name, value)


                class Groups(Entity):
                    """
                    IGMP Group Database Table
                    
                    .. attribute:: group
                    
                    	IGMP Group Entry Information
                    	**type**\: list of    :py:class:`Group <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.Groups, self).__init__()

                        self.yang_name = "groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"group" : ("group", Mld.Standby.Vrfs.Vrf.Groups.Group)}

                        self.group = YList(self)
                        self._segment_path = lambda: "groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.Groups, [], name, value)


                    class Group(Entity):
                        """
                        IGMP Group Entry Information
                        
                        .. attribute:: expiration_time
                        
                        	Expiration time in seconds
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**units**\: second
                        
                        .. attribute:: explicit_tracking_enabled
                        
                        	Is explicit tracking enabled
                        	**type**\:  bool
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr>`
                        
                        .. attribute:: interface_name
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_added
                        
                        	Joined
                        	**type**\:  bool
                        
                        .. attribute:: is_low_memory
                        
                        	Node is running low on memory
                        	**type**\:  bool
                        
                        .. attribute:: is_self_join
                        
                        	If local system is member of this group on this interface
                        	**type**\:  bool
                        
                        .. attribute:: is_suppressed
                        
                        	Suppressed
                        	**type**\:  bool
                        
                        .. attribute:: last_reporter
                        
                        	Last reporter address
                        	**type**\:   :py:class:`LastReporter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter>`
                        
                        .. attribute:: older_host_version1_timer
                        
                        	IGMP Hostversion1timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: older_host_version2_timer
                        
                        	IGMP Hostversion2timer
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_filter_mode
                        
                        	Filter mode
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: row_status
                        
                        	interface on or off for the group
                        	**type**\:  str
                        
                        	**length:** 0..16
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress>`
                        
                        .. attribute:: uptime
                        
                        	Uptime in seconds
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.Groups.Group, self).__init__()

                            self.yang_name = "group"
                            self.yang_parent_name = "groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr), "last-reporter" : ("last_reporter", Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter), "source-address" : ("source_address", Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress)}
                            self._child_list_classes = {}

                            self.expiration_time = YLeaf(YType.int32, "expiration-time")

                            self.explicit_tracking_enabled = YLeaf(YType.boolean, "explicit-tracking-enabled")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_added = YLeaf(YType.boolean, "is-added")

                            self.is_low_memory = YLeaf(YType.boolean, "is-low-memory")

                            self.is_self_join = YLeaf(YType.boolean, "is-self-join")

                            self.is_suppressed = YLeaf(YType.boolean, "is-suppressed")

                            self.older_host_version1_timer = YLeaf(YType.uint32, "older-host-version1-timer")

                            self.older_host_version2_timer = YLeaf(YType.uint32, "older-host-version2-timer")

                            self.router_filter_mode = YLeaf(YType.uint8, "router-filter-mode")

                            self.row_status = YLeaf(YType.str, "row-status")

                            self.uptime = YLeaf(YType.uint64, "uptime")

                            self.group_address_xr = Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")

                            self.last_reporter = Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter()
                            self.last_reporter.parent = self
                            self._children_name_map["last_reporter"] = "last-reporter"
                            self._children_yang_names.add("last-reporter")

                            self.source_address = Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "group"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.Groups.Group, ['expiration_time', 'explicit_tracking_enabled', 'group_address', 'interface_name', 'interface_name_xr', 'is_added', 'is_low_memory', 'is_self_join', 'is_suppressed', 'older_host_version1_timer', 'older_host_version2_timer', 'router_filter_mode', 'row_status', 'uptime'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.Groups.Group.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class LastReporter(Entity):
                            """
                            Last reporter address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter, self).__init__()

                                self.yang_name = "last-reporter"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "last-reporter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.Groups.Group.LastReporter, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.Groups.Group.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class IfrsInterfaceSummary(Entity):
                    """
                    IGMP IFRS Interface summary
                    
                    .. attribute:: configuration_count
                    
                    	Configuration count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface Count
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary, self).__init__()

                        self.yang_name = "ifrs-interface-summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.configuration_count = YLeaf(YType.uint32, "configuration-count")

                        self.interface_count = YLeaf(YType.uint32, "interface-count")
                        self._segment_path = lambda: "ifrs-interface-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.IfrsInterfaceSummary, ['configuration_count', 'interface_count'], name, value)


                class IfrsInterfaces(Entity):
                    """
                    IGMP Interface specific
                    
                    .. attribute:: ifrs_interface
                    
                    	IGMP IFRS Interface
                    	**type**\: list of    :py:class:`IfrsInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces, self).__init__()

                        self.yang_name = "ifrs-interfaces"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ifrs-interface" : ("ifrs_interface", Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface)}

                        self.ifrs_interface = YList(self)
                        self._segment_path = lambda: "ifrs-interfaces"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.IfrsInterfaces, [], name, value)


                    class IfrsInterface(Entity):
                        """
                        IGMP IFRS Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	IFRS Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: igmp_interface_entry
                        
                        	IGMP interface entry
                        	**type**\:   :py:class:`IgmpInterfaceEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry>`
                        
                        .. attribute:: join_group_count
                        
                        	Join group count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, self).__init__()

                            self.yang_name = "ifrs-interface"
                            self.yang_parent_name = "ifrs-interfaces"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"igmp-interface-entry" : ("igmp_interface_entry", Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.join_group_count = YLeaf(YType.uint32, "join-group-count")

                            self.igmp_interface_entry = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry()
                            self.igmp_interface_entry.parent = self
                            self._children_name_map["igmp_interface_entry"] = "igmp-interface-entry"
                            self._children_yang_names.add("igmp-interface-entry")
                            self._segment_path = lambda: "ifrs-interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface, ['interface_name', 'join_group_count'], name, value)


                        class IgmpInterfaceEntry(Entity):
                            """
                            IGMP interface entry
                            
                            .. attribute:: address
                            
                            	IP address
                            	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address>`
                            
                            .. attribute:: configuration_mcast_vrf_error
                            
                            	Is mcast error
                            	**type**\:  bool
                            
                            .. attribute:: configuration_mcast_vrf_set
                            
                            	Is mcast set
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_error
                            
                            	CFG vrf error
                            	**type**\:  bool
                            
                            .. attribute:: configurationvrf_set
                            
                            	CFG vrf set
                            	**type**\:  bool
                            
                            .. attribute:: group_joins
                            
                            	No. of group joins
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_leaves
                            
                            	No. of group leaves
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: host_version
                            
                            	IGMP Host version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: igmp_version
                            
                            	IGMP Router version
                            	**type**\:  int
                            
                            	**range:** 0..255
                            
                            .. attribute:: interface_name_xr
                            
                            	Interface
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: is_configurationverify
                            
                            	CFG verify
                            	**type**\:  bool
                            
                            .. attribute:: is_identity_present
                            
                            	Subscriber ID or Address available from AAA
                            	**type**\:  bool
                            
                            .. attribute:: is_im_state_registered
                            
                            	Im state registered
                            	**type**\:  bool
                            
                            .. attribute:: is_interface_up
                            
                            	Is interface up
                            	**type**\:  bool
                            
                            .. attribute:: is_ip_enabled
                            
                            	Is IP enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_las_registered
                            
                            	LAS registered
                            	**type**\:  bool
                            
                            .. attribute:: is_las_request
                            
                            	LAS req
                            	**type**\:  bool
                            
                            .. attribute:: is_querier
                            
                            	Are we querier
                            	**type**\:  bool
                            
                            .. attribute:: is_router_enabled
                            
                            	Is Router functionality enabled
                            	**type**\:  bool
                            
                            .. attribute:: is_subscriber
                            
                            	Subscriber interface
                            	**type**\:  bool
                            
                            .. attribute:: las_get_address_count
                            
                            	LAS get addr count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_add_update_count
                            
                            	LAS LL add update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_registration_count
                            
                            	LAS reg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_ll_remove_update_count
                            
                            	LAS LL remove update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_null_update_count
                            
                            	LAS Null update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_unregistration_count
                            
                            	LAS unreg count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: las_update_count
                            
                            	LAS Update count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: last_member_query_interval
                            
                            	Last Member Query Interval
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: location
                            
                            	Location
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_tuple_count
                            
                            	MTE Tuple count
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mte_vrf_id
                            
                            	MTE VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_ifhandle
                            
                            	Parent If Handle
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: prefix_length
                            
                            	Prefix length
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: proxy_interface
                            
                            	Proxy interface index
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: querier_address
                            
                            	Address of the Querier
                            	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress>`
                            
                            .. attribute:: querier_uptime
                            
                            	Time since the last querier took over
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_interval
                            
                            	Query Interval value in seconds
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            	**units**\: second
                            
                            .. attribute:: query_maximum_response_time
                            
                            	Max Response Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: query_timeout
                            
                            	Query Timeout value
                            	**type**\:  int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: robustness
                            
                            	Robustness Variable value
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: router_uptime_in_seconds
                            
                            	Uptime since router enabled event
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	Interface state
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: subscriber_address
                            
                            	Address of subscriber
                            	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress>`
                            
                            .. attribute:: subscriber_id
                            
                            	ID string of subscriber
                            	**type**\:  str
                            
                            	**length:** 0..257
                            
                            .. attribute:: subscriber_mode
                            
                            	Subscriber mode
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_query_in_seconds
                            
                            	Time elapsed since last query
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_since_last_report_in_seconds
                            
                            	Time elapsed since last report
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: total_active_groups
                            
                            	Actual number of groups on interface
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_id
                            
                            	VRF id
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vrf_state
                            
                            	Vrf State
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, self).__init__()

                                self.yang_name = "igmp-interface-entry"
                                self.yang_parent_name = "ifrs-interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"address" : ("address", Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address), "querier-address" : ("querier_address", Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress)}
                                self._child_list_classes = {}

                                self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                                self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                                self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                                self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                                self.group_joins = YLeaf(YType.uint32, "group-joins")

                                self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                                self.host_version = YLeaf(YType.uint8, "host-version")

                                self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                                self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                                self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                                self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                                self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                                self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                                self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                                self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                                self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                                self.is_querier = YLeaf(YType.boolean, "is-querier")

                                self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                                self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                                self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                                self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                                self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                                self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                                self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                                self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                                self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                                self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                                self.location = YLeaf(YType.uint32, "location")

                                self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                                self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                                self.mtu = YLeaf(YType.uint32, "mtu")

                                self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                                self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                                self.query_interval = YLeaf(YType.uint16, "query-interval")

                                self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                                self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                                self.robustness = YLeaf(YType.uint32, "robustness")

                                self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                                self.state = YLeaf(YType.uint32, "state")

                                self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                                self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                                self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                                self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                                self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                                self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                                self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                                self.address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address()
                                self.address.parent = self
                                self._children_name_map["address"] = "address"
                                self._children_yang_names.add("address")

                                self.querier_address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress()
                                self.querier_address.parent = self
                                self._children_name_map["querier_address"] = "querier-address"
                                self._children_yang_names.add("querier-address")

                                self.subscriber_address = Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress()
                                self.subscriber_address.parent = self
                                self._children_name_map["subscriber_address"] = "subscriber-address"
                                self._children_yang_names.add("subscriber-address")
                                self._segment_path = lambda: "igmp-interface-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry, ['configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                            class Address(Entity):
                                """
                                IP address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, self).__init__()

                                    self.yang_name = "address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class QuerierAddress(Entity):
                                """
                                Address of the Querier
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, self).__init__()

                                    self.yang_name = "querier-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "querier-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SubscriberAddress(Entity):
                                """
                                Address of subscriber
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, self).__init__()

                                    self.yang_name = "subscriber-address"
                                    self.yang_parent_name = "igmp-interface-entry"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "subscriber-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.IfrsInterfaces.IfrsInterface.IgmpInterfaceEntry.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOffs(Entity):
                    """
                    IGMP Interface state off
                    
                    .. attribute:: interface_state_off
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOff <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs, self).__init__()

                        self.yang_name = "interface-state-offs"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-off" : ("interface_state_off", Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff)}

                        self.interface_state_off = YList(self)
                        self._segment_path = lambda: "interface-state-offs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs, [], name, value)


                    class InterfaceStateOff(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, self).__init__()

                            self.yang_name = "interface-state-off"
                            self.yang_parent_name = "interface-state-offs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address), "querier-address" : ("querier_address", Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-off" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-off"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOffs.InterfaceStateOff.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceStateOns(Entity):
                    """
                    IGMP Interface state on
                    
                    .. attribute:: interface_state_on
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceStateOn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns, self).__init__()

                        self.yang_name = "interface-state-ons"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-state-on" : ("interface_state_on", Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn)}

                        self.interface_state_on = YList(self)
                        self._segment_path = lambda: "interface-state-ons"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOns, [], name, value)


                    class InterfaceStateOn(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, self).__init__()

                            self.yang_name = "interface-state-on"
                            self.yang_parent_name = "interface-state-ons"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address), "querier-address" : ("querier_address", Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface-state-on" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface-state-on"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceStateOns.InterfaceStateOn.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceTable(Entity):
                    """
                    IGMP Interface specific Table
                    
                    .. attribute:: interface
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceTable, self).__init__()

                        self.yang_name = "interface-table"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface)}

                        self.interface = YList(self)
                        self._segment_path = lambda: "interface-table"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceTable, [], name, value)


                    class Interface(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP address
                        	**type**\:   :py:class:`Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address>`
                        
                        .. attribute:: configuration_mcast_vrf_error
                        
                        	Is mcast error
                        	**type**\:  bool
                        
                        .. attribute:: configuration_mcast_vrf_set
                        
                        	Is mcast set
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_error
                        
                        	CFG vrf error
                        	**type**\:  bool
                        
                        .. attribute:: configurationvrf_set
                        
                        	CFG vrf set
                        	**type**\:  bool
                        
                        .. attribute:: group_joins
                        
                        	No. of group joins
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_leaves
                        
                        	No. of group leaves
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: host_version
                        
                        	IGMP Host version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: igmp_version
                        
                        	IGMP Router version
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: interface_name_xr
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_configurationverify
                        
                        	CFG verify
                        	**type**\:  bool
                        
                        .. attribute:: is_identity_present
                        
                        	Subscriber ID or Address available from AAA
                        	**type**\:  bool
                        
                        .. attribute:: is_im_state_registered
                        
                        	Im state registered
                        	**type**\:  bool
                        
                        .. attribute:: is_interface_up
                        
                        	Is interface up
                        	**type**\:  bool
                        
                        .. attribute:: is_ip_enabled
                        
                        	Is IP enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_las_registered
                        
                        	LAS registered
                        	**type**\:  bool
                        
                        .. attribute:: is_las_request
                        
                        	LAS req
                        	**type**\:  bool
                        
                        .. attribute:: is_querier
                        
                        	Are we querier
                        	**type**\:  bool
                        
                        .. attribute:: is_router_enabled
                        
                        	Is Router functionality enabled
                        	**type**\:  bool
                        
                        .. attribute:: is_subscriber
                        
                        	Subscriber interface
                        	**type**\:  bool
                        
                        .. attribute:: las_get_address_count
                        
                        	LAS get addr count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_add_update_count
                        
                        	LAS LL add update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_registration_count
                        
                        	LAS reg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_ll_remove_update_count
                        
                        	LAS LL remove update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_null_update_count
                        
                        	LAS Null update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_unregistration_count
                        
                        	LAS unreg count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: las_update_count
                        
                        	LAS Update count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: last_member_query_interval
                        
                        	Last Member Query Interval
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: location
                        
                        	Location
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_tuple_count
                        
                        	MTE Tuple count
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mte_vrf_id
                        
                        	MTE VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mtu
                        
                        	MTU
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent If Handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: proxy_interface
                        
                        	Proxy interface index
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: querier_address
                        
                        	Address of the Querier
                        	**type**\:   :py:class:`QuerierAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress>`
                        
                        .. attribute:: querier_uptime
                        
                        	Time since the last querier took over
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_interval
                        
                        	Query Interval value in seconds
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        	**units**\: second
                        
                        .. attribute:: query_maximum_response_time
                        
                        	Max Response Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: query_timeout
                        
                        	Query Timeout value
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: robustness
                        
                        	Robustness Variable value
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Uptime since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	Interface state
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: subscriber_address
                        
                        	Address of subscriber
                        	**type**\:   :py:class:`SubscriberAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress>`
                        
                        .. attribute:: subscriber_id
                        
                        	ID string of subscriber
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: subscriber_mode
                        
                        	Subscriber mode
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: total_active_groups
                        
                        	Actual number of groups on interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_id
                        
                        	VRF id
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vrf_state
                        
                        	Vrf State
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"address" : ("address", Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address), "querier-address" : ("querier_address", Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress), "subscriber-address" : ("subscriber_address", Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress)}
                            self._child_list_classes = {}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.configuration_mcast_vrf_error = YLeaf(YType.boolean, "configuration-mcast-vrf-error")

                            self.configuration_mcast_vrf_set = YLeaf(YType.boolean, "configuration-mcast-vrf-set")

                            self.configurationvrf_error = YLeaf(YType.boolean, "configurationvrf-error")

                            self.configurationvrf_set = YLeaf(YType.boolean, "configurationvrf-set")

                            self.group_joins = YLeaf(YType.uint32, "group-joins")

                            self.group_leaves = YLeaf(YType.uint32, "group-leaves")

                            self.host_version = YLeaf(YType.uint8, "host-version")

                            self.igmp_version = YLeaf(YType.uint8, "igmp-version")

                            self.interface_name_xr = YLeaf(YType.str, "interface-name-xr")

                            self.is_configurationverify = YLeaf(YType.boolean, "is-configurationverify")

                            self.is_identity_present = YLeaf(YType.boolean, "is-identity-present")

                            self.is_im_state_registered = YLeaf(YType.boolean, "is-im-state-registered")

                            self.is_interface_up = YLeaf(YType.boolean, "is-interface-up")

                            self.is_ip_enabled = YLeaf(YType.boolean, "is-ip-enabled")

                            self.is_las_registered = YLeaf(YType.boolean, "is-las-registered")

                            self.is_las_request = YLeaf(YType.boolean, "is-las-request")

                            self.is_querier = YLeaf(YType.boolean, "is-querier")

                            self.is_router_enabled = YLeaf(YType.boolean, "is-router-enabled")

                            self.is_subscriber = YLeaf(YType.boolean, "is-subscriber")

                            self.las_get_address_count = YLeaf(YType.uint32, "las-get-address-count")

                            self.las_ll_add_update_count = YLeaf(YType.uint32, "las-ll-add-update-count")

                            self.las_ll_registration_count = YLeaf(YType.uint32, "las-ll-registration-count")

                            self.las_ll_remove_update_count = YLeaf(YType.uint32, "las-ll-remove-update-count")

                            self.las_null_update_count = YLeaf(YType.uint32, "las-null-update-count")

                            self.las_unregistration_count = YLeaf(YType.uint32, "las-unregistration-count")

                            self.las_update_count = YLeaf(YType.uint32, "las-update-count")

                            self.last_member_query_interval = YLeaf(YType.uint16, "last-member-query-interval")

                            self.location = YLeaf(YType.uint32, "location")

                            self.mte_tuple_count = YLeaf(YType.uint32, "mte-tuple-count")

                            self.mte_vrf_id = YLeaf(YType.uint32, "mte-vrf-id")

                            self.mtu = YLeaf(YType.uint32, "mtu")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.proxy_interface = YLeaf(YType.str, "proxy-interface")

                            self.querier_uptime = YLeaf(YType.uint16, "querier-uptime")

                            self.query_interval = YLeaf(YType.uint16, "query-interval")

                            self.query_maximum_response_time = YLeaf(YType.uint16, "query-maximum-response-time")

                            self.query_timeout = YLeaf(YType.uint16, "query-timeout")

                            self.robustness = YLeaf(YType.uint32, "robustness")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.state = YLeaf(YType.uint32, "state")

                            self.subscriber_id = YLeaf(YType.str, "subscriber-id")

                            self.subscriber_mode = YLeaf(YType.uint32, "subscriber-mode")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")

                            self.total_active_groups = YLeaf(YType.uint32, "total-active-groups")

                            self.vrf_id = YLeaf(YType.uint32, "vrf-id")

                            self.vrf_state = YLeaf(YType.uint32, "vrf-state")

                            self.address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address()
                            self.address.parent = self
                            self._children_name_map["address"] = "address"
                            self._children_yang_names.add("address")

                            self.querier_address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress()
                            self.querier_address.parent = self
                            self._children_name_map["querier_address"] = "querier-address"
                            self._children_yang_names.add("querier-address")

                            self.subscriber_address = Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress()
                            self.subscriber_address.parent = self
                            self._children_name_map["subscriber_address"] = "subscriber-address"
                            self._children_yang_names.add("subscriber-address")
                            self._segment_path = lambda: "interface" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface, ['interface_name', 'configuration_mcast_vrf_error', 'configuration_mcast_vrf_set', 'configurationvrf_error', 'configurationvrf_set', 'group_joins', 'group_leaves', 'host_version', 'igmp_version', 'interface_name_xr', 'is_configurationverify', 'is_identity_present', 'is_im_state_registered', 'is_interface_up', 'is_ip_enabled', 'is_las_registered', 'is_las_request', 'is_querier', 'is_router_enabled', 'is_subscriber', 'las_get_address_count', 'las_ll_add_update_count', 'las_ll_registration_count', 'las_ll_remove_update_count', 'las_null_update_count', 'las_unregistration_count', 'las_update_count', 'last_member_query_interval', 'location', 'mte_tuple_count', 'mte_vrf_id', 'mtu', 'parent_ifhandle', 'prefix_length', 'proxy_interface', 'querier_uptime', 'query_interval', 'query_maximum_response_time', 'query_timeout', 'robustness', 'router_uptime_in_seconds', 'state', 'subscriber_id', 'subscriber_mode', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds', 'total_active_groups', 'vrf_id', 'vrf_state'], name, value)


                        class Address(Entity):
                            """
                            IP address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, self).__init__()

                                self.yang_name = "address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.Address, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class QuerierAddress(Entity):
                            """
                            Address of the Querier
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, self).__init__()

                                self.yang_name = "querier-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "querier-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.QuerierAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SubscriberAddress(Entity):
                            """
                            Address of subscriber
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, self).__init__()

                                self.yang_name = "subscriber-address"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "subscriber-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceTable.Interface.SubscriberAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class InterfaceUnicastQosAdjusts(Entity):
                    """
                    IGMP Interface Unicast\-Qos\-Adjust
                    
                    .. attribute:: interface_unicast_qos_adjust
                    
                    	IGMP Interface
                    	**type**\: list of    :py:class:`InterfaceUnicastQosAdjust <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, self).__init__()

                        self.yang_name = "interface-unicast-qos-adjusts"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface-unicast-qos-adjust" : ("interface_unicast_qos_adjust", Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust)}

                        self.interface_unicast_qos_adjust = YList(self)
                        self._segment_path = lambda: "interface-unicast-qos-adjusts"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts, [], name, value)


                    class InterfaceUnicastQosAdjust(Entity):
                        """
                        IGMP Interface
                        
                        .. attribute:: interface_name  <key>
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: is_virtual_access
                        
                        	Is VirtualAccess Interface
                        	**type**\:  bool
                        
                        .. attribute:: rate
                        
                        	Overall rate in Kbps
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: rate_decrements
                        
                        	Count of rate decrements
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rate_increments
                        
                        	Count of rate increments
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: update
                        
                        	List of updates
                        	**type**\: list of    :py:class:`Update <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, self).__init__()

                            self.yang_name = "interface-unicast-qos-adjust"
                            self.yang_parent_name = "interface-unicast-qos-adjusts"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"update" : ("update", Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update)}

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.is_virtual_access = YLeaf(YType.boolean, "is-virtual-access")

                            self.rate = YLeaf(YType.uint32, "rate")

                            self.rate_decrements = YLeaf(YType.uint32, "rate-decrements")

                            self.rate_increments = YLeaf(YType.uint32, "rate-increments")

                            self.update = YList(self)
                            self._segment_path = lambda: "interface-unicast-qos-adjust" + "[interface-name='" + self.interface_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust, ['interface_name', 'is_virtual_access', 'rate', 'rate_decrements', 'rate_increments'], name, value)


                        class Update(Entity):
                            """
                            List of updates
                            
                            .. attribute:: group_address
                            
                            	Group address
                            	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress>`
                            
                            .. attribute:: is_add
                            
                            	Is this a rate increment
                            	**type**\:  bool
                            
                            .. attribute:: received_time
                            
                            	Time this update is received
                            	**type**\:  int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: source_address
                            
                            	Source address
                            	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress>`
                            
                            .. attribute:: weight
                            
                            	Weight from policy
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, self).__init__()

                                self.yang_name = "update"
                                self.yang_parent_name = "interface-unicast-qos-adjust"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address" : ("group_address", Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress), "source-address" : ("source_address", Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress)}
                                self._child_list_classes = {}

                                self.is_add = YLeaf(YType.boolean, "is-add")

                                self.received_time = YLeaf(YType.uint64, "received-time")

                                self.weight = YLeaf(YType.uint32, "weight")

                                self.group_address = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress()
                                self.group_address.parent = self
                                self._children_name_map["group_address"] = "group-address"
                                self._children_yang_names.add("group-address")

                                self.source_address = Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress()
                                self.source_address.parent = self
                                self._children_name_map["source_address"] = "source-address"
                                self._children_yang_names.add("source-address")
                                self._segment_path = lambda: "update"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update, ['is_add', 'received_time', 'weight'], name, value)


                            class GroupAddress(Entity):
                                """
                                Group address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, self).__init__()

                                    self.yang_name = "group-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                            class SourceAddress(Entity):
                                """
                                Source address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, self).__init__()

                                    self.yang_name = "source-address"
                                    self.yang_parent_name = "update"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "source-address"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.InterfaceUnicastQosAdjusts.InterfaceUnicastQosAdjust.Update.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class NonActiveGroups(Entity):
                    """
                    IGMP Non\-Active Groups Information
                    
                    .. attribute:: non_active_groups
                    
                    	List of non\-active groups
                    	**type**\: list of    :py:class:`NonActiveGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.NonActiveGroups, self).__init__()

                        self.yang_name = "non-active-groups"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"non-active-groups" : ("non_active_groups", Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups)}

                        self.non_active_groups = YList(self)
                        self._segment_path = lambda: "non-active-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.NonActiveGroups, [], name, value)


                    class NonActiveGroups(Entity):
                        """
                        List of non\-active groups
                        
                        .. attribute:: group_address
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress>`
                        
                        .. attribute:: interface
                        
                        	Interface Name
                        	**type**\:  str
                        
                        	**length:** 0..65
                        
                        .. attribute:: reason_for_non_activity
                        
                        	Reason for group join not being processed
                        	**type**\:  str
                        
                        	**length:** 0..257
                        
                        .. attribute:: source_address
                        
                        	Source Address
                        	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, self).__init__()

                            self.yang_name = "non-active-groups"
                            self.yang_parent_name = "non-active-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address" : ("group_address", Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress), "source-address" : ("source_address", Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress)}
                            self._child_list_classes = {}

                            self.interface = YLeaf(YType.str, "interface")

                            self.reason_for_non_activity = YLeaf(YType.str, "reason-for-non-activity")

                            self.group_address = Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress()
                            self.group_address.parent = self
                            self._children_name_map["group_address"] = "group-address"
                            self._children_yang_names.add("group-address")

                            self.source_address = Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress()
                            self.source_address.parent = self
                            self._children_name_map["source_address"] = "source-address"
                            self._children_yang_names.add("source-address")
                            self._segment_path = lambda: "non-active-groups"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups, ['interface', 'reason_for_non_activity'], name, value)


                        class GroupAddress(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, self).__init__()

                                self.yang_name = "group-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.GroupAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class SourceAddress(Entity):
                            """
                            Source Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, self).__init__()

                                self.yang_name = "source-address"
                                self.yang_parent_name = "non-active-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "source-address"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.NonActiveGroups.NonActiveGroups.SourceAddress, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Ranges(Entity):
                    """
                    Range table
                    
                    .. attribute:: range
                    
                    	Range information
                    	**type**\: list of    :py:class:`Range <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Ranges.Range>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.Ranges, self).__init__()

                        self.yang_name = "ranges"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"range" : ("range", Mld.Standby.Vrfs.Vrf.Ranges.Range)}

                        self.range = YList(self)
                        self._segment_path = lambda: "ranges"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.Ranges, [], name, value)


                    class Range(Entity):
                        """
                        Range information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr>`
                        
                        .. attribute:: group_mask
                        
                        	Group Mask
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        .. attribute:: is_stale
                        
                        	Is the entry stale
                        	**type**\:  bool
                        
                        .. attribute:: prefix_length
                        
                        	Prefix length
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:   :py:class:`IgmpEdmProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpEdmProtocol>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.Ranges.Range, self).__init__()

                            self.yang_name = "range"
                            self.yang_parent_name = "ranges"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.group_mask = YLeaf(YType.int32, "group-mask")

                            self.is_stale = YLeaf(YType.boolean, "is-stale")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.protocol = YLeaf(YType.enumeration, "protocol")

                            self.group_address_xr = Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.Ranges.Range, ['group_address', 'group_mask', 'is_stale', 'prefix_length', 'protocol'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "range"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.Ranges.Range.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMapDetails(Entity):
                    """
                    SSM Map Detail
                    
                    .. attribute:: ssm_map_detail
                    
                    	SSM Map Detail Table information
                    	**type**\: list of    :py:class:`SsmMapDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.SsmMapDetails, self).__init__()

                        self.yang_name = "ssm-map-details"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map-detail" : ("ssm_map_detail", Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail)}

                        self.ssm_map_detail = YList(self)
                        self._segment_path = lambda: "ssm-map-details"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMapDetails, [], name, value)


                    class SsmMapDetail(Entity):
                        """
                        SSM Map Detail Table information
                        
                        .. attribute:: elapsed_time
                        
                        	Elapsed time
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: expiration_time
                        
                        	Expiration Time in Seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: map_info
                        
                        	Basic Map Info
                        	**type**\:   :py:class:`MapInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo>`
                        
                        .. attribute:: query_interval
                        
                        	Query interval
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: response_pending
                        
                        	Response Pending
                        	**type**\:  bool
                        
                        .. attribute:: sources
                        
                        	List of sources
                        	**type**\: list of    :py:class:`Sources <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources>`
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, self).__init__()

                            self.yang_name = "ssm-map-detail"
                            self.yang_parent_name = "ssm-map-details"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"map-info" : ("map_info", Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo)}
                            self._child_list_classes = {"sources" : ("sources", Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources)}

                            self.elapsed_time = YLeaf(YType.uint64, "elapsed-time")

                            self.expiration_time = YLeaf(YType.uint32, "expiration-time")

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.query_interval = YLeaf(YType.uint32, "query-interval")

                            self.response_pending = YLeaf(YType.boolean, "response-pending")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.map_info = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo()
                            self.map_info.parent = self
                            self._children_name_map["map_info"] = "map-info"
                            self._children_yang_names.add("map-info")

                            self.sources = YList(self)
                            self._segment_path = lambda: "ssm-map-detail"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail, ['elapsed_time', 'expiration_time', 'group_address', 'query_interval', 'response_pending', 'ssm_map_type'], name, value)


                        class MapInfo(Entity):
                            """
                            Basic Map Info
                            
                            .. attribute:: group_address_xr
                            
                            	Group Address
                            	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr>`
                            
                            .. attribute:: map_type
                            
                            	Map Type of group
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_counts
                            
                            	Count of Sources
                            	**type**\:  int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, self).__init__()

                                self.yang_name = "map-info"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr)}
                                self._child_list_classes = {}

                                self.map_type = YLeaf(YType.uint32, "map-type")

                                self.source_counts = YLeaf(YType.uint32, "source-counts")

                                self.group_address_xr = Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr()
                                self.group_address_xr.parent = self
                                self._children_name_map["group_address_xr"] = "group-address-xr"
                                self._children_yang_names.add("group-address-xr")
                                self._segment_path = lambda: "map-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo, ['map_type', 'source_counts'], name, value)


                            class GroupAddressXr(Entity):
                                """
                                Group Address
                                
                                .. attribute:: af_name
                                
                                	AFName
                                	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Addr
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_address
                                
                                	IPV6 Addr
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'ipv4-igmp-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, self).__init__()

                                    self.yang_name = "group-address-xr"
                                    self.yang_parent_name = "map-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.af_name = YLeaf(YType.enumeration, "af-name")

                                    self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                    self._segment_path = lambda: "group-address-xr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.MapInfo.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                        class Sources(Entity):
                            """
                            List of sources
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, self).__init__()

                                self.yang_name = "sources"
                                self.yang_parent_name = "ssm-map-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "sources"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMapDetails.SsmMapDetail.Sources, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class SsmMaps(Entity):
                    """
                    SSM Map Table
                    
                    .. attribute:: ssm_map
                    
                    	SSM Map information
                    	**type**\: list of    :py:class:`SsmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap>`
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.SsmMaps, self).__init__()

                        self.yang_name = "ssm-maps"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ssm-map" : ("ssm_map", Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap)}

                        self.ssm_map = YList(self)
                        self._segment_path = lambda: "ssm-maps"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMaps, [], name, value)


                    class SsmMap(Entity):
                        """
                        SSM Map information
                        
                        .. attribute:: group_address
                        
                        	Group address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: group_address_xr
                        
                        	Group Address
                        	**type**\:   :py:class:`GroupAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr>`
                        
                        .. attribute:: map_type
                        
                        	Map Type of group
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: source_counts
                        
                        	Count of Sources
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ssm_map_type
                        
                        	SSM Map Type
                        	**type**\:   :py:class:`IgmpssmMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpssmMap>`
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap, self).__init__()

                            self.yang_name = "ssm-map"
                            self.yang_parent_name = "ssm-maps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"group-address-xr" : ("group_address_xr", Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr)}
                            self._child_list_classes = {}

                            self.group_address = YLeaf(YType.str, "group-address")

                            self.map_type = YLeaf(YType.uint32, "map-type")

                            self.source_counts = YLeaf(YType.uint32, "source-counts")

                            self.ssm_map_type = YLeaf(YType.enumeration, "ssm-map-type")

                            self.group_address_xr = Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr()
                            self.group_address_xr.parent = self
                            self._children_name_map["group_address_xr"] = "group-address-xr"
                            self._children_yang_names.add("group-address-xr")
                            self._segment_path = lambda: "ssm-map"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap, ['group_address', 'map_type', 'source_counts', 'ssm_map_type'], name, value)


                        class GroupAddressXr(Entity):
                            """
                            Group Address
                            
                            .. attribute:: af_name
                            
                            	AFName
                            	**type**\:   :py:class:`IgmpAfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.IgmpAfi>`
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Addr
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_address
                            
                            	IPV6 Addr
                            	**type**\:  str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'ipv4-igmp-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, self).__init__()

                                self.yang_name = "group-address-xr"
                                self.yang_parent_name = "ssm-map"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.af_name = YLeaf(YType.enumeration, "af-name")

                                self.ipv4_address = YLeaf(YType.str, "ipv4-address")

                                self.ipv6_address = YLeaf(YType.str, "ipv6-address")
                                self._segment_path = lambda: "group-address-xr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Mld.Standby.Vrfs.Vrf.SsmMaps.SsmMap.GroupAddressXr, ['af_name', 'ipv4_address', 'ipv6_address'], name, value)


                class Summary(Entity):
                    """
                    IGMP Summary Information
                    
                    .. attribute:: disabled_interface_count
                    
                    	No. of disabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: enabled_interface_count
                    
                    	No. of enabled interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_count
                    
                    	Current groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_limit
                    
                    	Maximum groups accepted
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Maximum and current groups accepted for each interface
                    	**type**\: list of    :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_igmp_oper.Mld.Standby.Vrfs.Vrf.Summary.Interface>`
                    
                    .. attribute:: is_disabled
                    
                    	Is maximum enforcement disabled
                    	**type**\:  bool
                    
                    .. attribute:: node_low_memory
                    
                    	Is node in low memory condition
                    	**type**\:  bool
                    
                    .. attribute:: robustness
                    
                    	Robustness variable
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: supported_interfaces
                    
                    	No. of supported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_mte_config_count
                    
                    	No. of static group commands
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsupported_interfaces
                    
                    	No. of unsupported interfaces
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"interface" : ("interface", Mld.Standby.Vrfs.Vrf.Summary.Interface)}

                        self.disabled_interface_count = YLeaf(YType.uint32, "disabled-interface-count")

                        self.enabled_interface_count = YLeaf(YType.uint32, "enabled-interface-count")

                        self.group_count = YLeaf(YType.uint32, "group-count")

                        self.group_limit = YLeaf(YType.uint32, "group-limit")

                        self.is_disabled = YLeaf(YType.boolean, "is-disabled")

                        self.node_low_memory = YLeaf(YType.boolean, "node-low-memory")

                        self.robustness = YLeaf(YType.uint32, "robustness")

                        self.supported_interfaces = YLeaf(YType.uint32, "supported-interfaces")

                        self.tunnel_mte_config_count = YLeaf(YType.uint32, "tunnel-mte-config-count")

                        self.unsupported_interfaces = YLeaf(YType.uint32, "unsupported-interfaces")

                        self.interface = YList(self)
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.Summary, ['disabled_interface_count', 'enabled_interface_count', 'group_count', 'group_limit', 'is_disabled', 'node_low_memory', 'robustness', 'supported_interfaces', 'tunnel_mte_config_count', 'unsupported_interfaces'], name, value)


                    class Interface(Entity):
                        """
                        Maximum and current groups accepted for each
                        interface
                        
                        .. attribute:: group_count
                        
                        	Current groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: group_limit
                        
                        	Maximum groups accepted per interface
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_name
                        
                        	Interface
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: on_off
                        
                        	Enabled/Disabled
                        	**type**\:  bool
                        
                        .. attribute:: parent_ifhandle
                        
                        	Parent if handle
                        	**type**\:  str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: router_uptime_in_seconds
                        
                        	Time elapsed since router enabled event
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_query_in_seconds
                        
                        	Time elapsed since last query
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_since_last_report_in_seconds
                        
                        	Time elapsed since last report
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-igmp-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Mld.Standby.Vrfs.Vrf.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.group_count = YLeaf(YType.uint32, "group-count")

                            self.group_limit = YLeaf(YType.uint32, "group-limit")

                            self.interface_name = YLeaf(YType.str, "interface-name")

                            self.on_off = YLeaf(YType.boolean, "on-off")

                            self.parent_ifhandle = YLeaf(YType.str, "parent-ifhandle")

                            self.router_uptime_in_seconds = YLeaf(YType.uint32, "router-uptime-in-seconds")

                            self.time_since_last_query_in_seconds = YLeaf(YType.uint32, "time-since-last-query-in-seconds")

                            self.time_since_last_report_in_seconds = YLeaf(YType.uint32, "time-since-last-report-in-seconds")
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Mld.Standby.Vrfs.Vrf.Summary.Interface, ['group_count', 'group_limit', 'interface_name', 'on_off', 'parent_ifhandle', 'router_uptime_in_seconds', 'time_since_last_query_in_seconds', 'time_since_last_report_in_seconds'], name, value)


                class TrafficCounters(Entity):
                    """
                    IGMP Message Traffic Counters
                    
                    .. attribute:: auxillary_data_length_errors
                    
                    	AuxDataLen errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bad_scope_errors
                    
                    	BadScope errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: checksum_errors
                    
                    	Checksum errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: elapsed_time
                    
                    	Running time for counters
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: format_errors
                    
                    	Malformed packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: get_packet_failure
                    
                    	Packet get failed
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_disabled_idb
                    
                    	Packet received on disabled idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_dvmrp
                    
                    	DVMRP packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_leaves
                    
                    	Leaves in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_martian_address
                    
                    	Packets received with Martian Address
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_mtrace
                    
                    	Mtrace packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_assigned_vrf_id
                    
                    	Packets received with no assigned vrf id
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_idb
                    
                    	Packets received without idb
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_platform_support_mtrace
                    
                    	mtrace packets without platform support
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_in_idb
                    
                    	Packets received on idb without VRF
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_no_vrf_mtrace
                    
                    	mtrace packets with no vrf associated
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_pim
                    
                    	PIM packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_queries
                    
                    	Query packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: input_reports
                    
                    	Reports in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: invalid_source_address_errors
                    
                    	Invalid Source Address errors
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: miscellaneous_errors
                    
                    	Packets dropped for other reasons
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: no_socket_connection
                    
                    	Packets dropped since no socket connection
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_dvmrp
                    
                    	DVMRP packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_leaves
                    
                    	Leaves out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_mtrace
                    
                    	Mtrace packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_no_parent_interface_handle
                    
                    	Failures setting 2nd ifhandle
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_pim
                    
                    	PIM packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_queries
                    
                    	Query packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: output_reports
                    
                    	Reports out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_input_errors
                    
                    	Incoming Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packet_manager_output_errors
                    
                    	Outgoing Packet Manager packets dropped
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_in
                    
                    	Packets in
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: packets_out
                    
                    	Packets out
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: receive_socket_errors
                    
                    	Socket errors on reception
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: socket_errors
                    
                    	Socket errors on send
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv4-igmp-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Mld.Standby.Vrfs.Vrf.TrafficCounters, self).__init__()

                        self.yang_name = "traffic-counters"
                        self.yang_parent_name = "vrf"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.auxillary_data_length_errors = YLeaf(YType.uint32, "auxillary-data-length-errors")

                        self.bad_scope_errors = YLeaf(YType.uint32, "bad-scope-errors")

                        self.checksum_errors = YLeaf(YType.uint32, "checksum-errors")

                        self.elapsed_time = YLeaf(YType.uint32, "elapsed-time")

                        self.format_errors = YLeaf(YType.uint32, "format-errors")

                        self.get_packet_failure = YLeaf(YType.uint32, "get-packet-failure")

                        self.input_disabled_idb = YLeaf(YType.uint32, "input-disabled-idb")

                        self.input_dvmrp = YLeaf(YType.uint32, "input-dvmrp")

                        self.input_leaves = YLeaf(YType.uint32, "input-leaves")

                        self.input_martian_address = YLeaf(YType.uint32, "input-martian-address")

                        self.input_mtrace = YLeaf(YType.uint32, "input-mtrace")

                        self.input_no_assigned_vrf_id = YLeaf(YType.uint32, "input-no-assigned-vrf-id")

                        self.input_no_idb = YLeaf(YType.uint32, "input-no-idb")

                        self.input_no_platform_support_mtrace = YLeaf(YType.uint32, "input-no-platform-support-mtrace")

                        self.input_no_vrf_in_idb = YLeaf(YType.uint32, "input-no-vrf-in-idb")

                        self.input_no_vrf_mtrace = YLeaf(YType.uint32, "input-no-vrf-mtrace")

                        self.input_pim = YLeaf(YType.uint32, "input-pim")

                        self.input_queries = YLeaf(YType.uint32, "input-queries")

                        self.input_reports = YLeaf(YType.uint32, "input-reports")

                        self.invalid_source_address_errors = YLeaf(YType.uint32, "invalid-source-address-errors")

                        self.miscellaneous_errors = YLeaf(YType.uint32, "miscellaneous-errors")

                        self.no_socket_connection = YLeaf(YType.uint32, "no-socket-connection")

                        self.output_dvmrp = YLeaf(YType.uint32, "output-dvmrp")

                        self.output_leaves = YLeaf(YType.uint32, "output-leaves")

                        self.output_mtrace = YLeaf(YType.uint32, "output-mtrace")

                        self.output_no_parent_interface_handle = YLeaf(YType.uint32, "output-no-parent-interface-handle")

                        self.output_pim = YLeaf(YType.uint32, "output-pim")

                        self.output_queries = YLeaf(YType.uint32, "output-queries")

                        self.output_reports = YLeaf(YType.uint32, "output-reports")

                        self.packet_manager_input_errors = YLeaf(YType.uint32, "packet-manager-input-errors")

                        self.packet_manager_output_errors = YLeaf(YType.uint32, "packet-manager-output-errors")

                        self.packets_in = YLeaf(YType.uint32, "packets-in")

                        self.packets_out = YLeaf(YType.uint32, "packets-out")

                        self.receive_socket_errors = YLeaf(YType.uint32, "receive-socket-errors")

                        self.socket_errors = YLeaf(YType.uint32, "socket-errors")
                        self._segment_path = lambda: "traffic-counters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Mld.Standby.Vrfs.Vrf.TrafficCounters, ['auxillary_data_length_errors', 'bad_scope_errors', 'checksum_errors', 'elapsed_time', 'format_errors', 'get_packet_failure', 'input_disabled_idb', 'input_dvmrp', 'input_leaves', 'input_martian_address', 'input_mtrace', 'input_no_assigned_vrf_id', 'input_no_idb', 'input_no_platform_support_mtrace', 'input_no_vrf_in_idb', 'input_no_vrf_mtrace', 'input_pim', 'input_queries', 'input_reports', 'invalid_source_address_errors', 'miscellaneous_errors', 'no_socket_connection', 'output_dvmrp', 'output_leaves', 'output_mtrace', 'output_no_parent_interface_handle', 'output_pim', 'output_queries', 'output_reports', 'packet_manager_input_errors', 'packet_manager_output_errors', 'packets_in', 'packets_out', 'receive_socket_errors', 'socket_errors'], name, value)

    def clone_ptr(self):
        self._top_entity = Mld()
        return self._top_entity

